@@ -33,6 +33,7 @@ package intel.management.wsman;
 
 
 import org.w3c.dom.*;
+
 import java.util.ArrayList;
 import java.util.List;
 
@@ -147,6 +148,19 @@ public class ManagedReference {
         clearSelectors();
     }
 
+    public void setResourceURIForCreate(String resourceURI) {
+    	resourceURI = WsmanUtils.getFullResourceURI(resourceURI);
+    	
+        Element headerElt=WsmanUtils.findChild(document.getDocumentElement(),
+                WsmanUtils.SOAP_NAMESPACE,
+                "Header");
+
+        Element resElt=WsmanUtils.findChild(headerElt,
+                WsmanUtils.WSMAN_NAMESPACE,
+                "ResourceURI");
+
+        resElt.setTextContent(resourceURI);
+    }
 
      /**
      * Get the name of the resource or instance to access. The ResourceURI
@@ -645,7 +659,15 @@ public class ManagedReference {
         return new ManagedInstance(connection,input);
     }
 
+    public ManagedInstance createMethod(String namespace, String methodName ) {
+        Document node = document.getImplementation().createDocument(
+                namespace,
+                methodName, null);
 
+        node.getDocumentElement().setPrefix("p");
+
+        return new ManagedInstance(connection, node);
+    }
 
      /**
      * Allows an application to express interest in receiving events from a resource.
@@ -781,6 +803,30 @@ public class ManagedReference {
     }
 
     
+    public ManagedInstance create(ManagedInstance input) throws WsmanException {
+
+        WsmanUtils util = new WsmanUtils();
+        Document reqDoc = util.loadDocument("CreateXMLDoc.xml");
+
+        WsmanUtils.setEpr(document, reqDoc);
+
+        Element bodyElt=WsmanUtils.findChild(reqDoc.getDocumentElement(),
+                WsmanUtils.SOAP_NAMESPACE,
+                "Body");
+
+        Node node = reqDoc.importNode(input.document.getDocumentElement(), true);
+        bodyElt.appendChild(node);
+
+        Document resDoc = connection.SendRequest(reqDoc);
+
+        bodyElt=WsmanUtils.findChild(resDoc.getDocumentElement(),
+                WsmanUtils.SOAP_NAMESPACE,
+                "Body");
+
+        Document itemDoc = WsmanUtils.loadDocument(bodyElt);
+
+        return new ManagedInstance(connection,itemDoc);
+    }
 
 
 
@@ -843,6 +889,43 @@ public class ManagedReference {
         return new ManagedInstance(connection,itemDoc);
     }
 
+    public ManagedInstance invoke(ManagedInstance input, String actionName) throws WsmanException {
+
+        WsmanUtils util = new WsmanUtils();
+        Document reqDoc = util.loadDocument("PutXMLDoc.xml");
+
+        WsmanUtils.setEpr(document, reqDoc);
+
+        Element headerElt=WsmanUtils.findChild(reqDoc.getDocumentElement(),
+                WsmanUtils.SOAP_NAMESPACE,
+                "Header");
+
+        Element actionElt=WsmanUtils.findChild(headerElt,
+                WsmanUtils.ADDRESSING_NAMESPACE,
+                "Action");
+
+        actionElt.setTextContent(actionName);
+
+        Element bodyElt=WsmanUtils.findChild(reqDoc.getDocumentElement(),
+                WsmanUtils.SOAP_NAMESPACE,
+                "Body");
+
+        Node node = reqDoc.importNode(input.document.getDocumentElement(), true);
+        bodyElt.appendChild(node);
+
+        Document resDoc = connection.SendRequest(reqDoc);
+
+        bodyElt=WsmanUtils.findChild(resDoc.getDocumentElement(),
+                WsmanUtils.SOAP_NAMESPACE,
+                "Body");
+
+        Element itemElt = WsmanUtils.findChild(bodyElt);
+
+        Document itemDoc = WsmanUtils.loadDocument(itemElt);
+
+        return new ManagedInstance(connection,itemDoc);
+    }
+
 
     /**
      * Invokes a method on a resource.
