@@ -22,17 +22,19 @@ import java.util.ResourceBundle;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.eclipse.core.runtime.ILogListener; 
-import org.eclipse.core.runtime.IStatus; 
-import org.eclipse.core.runtime.Platform; 
+import org.eclipse.core.runtime.ILogListener;
+import org.eclipse.core.runtime.IStatus;
+import org.eclipse.core.runtime.Platform;
 import org.eclipse.jface.resource.ImageDescriptor;
 import org.eclipse.jface.resource.ImageRegistry;
+import org.eclipse.swt.graphics.Rectangle;
+import org.eclipse.swt.widgets.Display;
 import org.eclipse.ui.plugin.AbstractUIPlugin;
+import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleContext;
 
-import com.clustercontrol.action.FacilityTree;
-import com.clustercontrol.plugin.monitor.IMonitorPlugin;
-import com.clustercontrol.plugin.monitor.LoadMonitorPlugin;
+import com.clustercontrol.monitor.plugin.IMonitorPlugin;
+import com.clustercontrol.monitor.plugin.LoadMonitorPlugin;
 
 /**
  * 
@@ -121,28 +123,6 @@ public class ClusterControlPlugin extends AbstractUIPlugin {
 	/** 編集モードアイコンの取得キー */
 	public static final String IMG_JOB_EDIT_MODE = "job_edit_mode";
 
-
-	/** コンポジットアイコンの取得キー */
-	public static final String IMG_COMPOSITE = "composite";
-
-	/** コマンドツリーコンポジットアイコンの取得キー */
-	public static final String IMG_COMMAND_COMPOSITE = "commandComposite";
-
-	/** パラメータツリーコンポジットアイコンの取得キー */
-	public static final String IMG_PARAMETER_COMPOSITE = "parameterComposite";
-
-	/** 種別アイコンの取得キー */
-	public static final String IMG_TYPE = "type";
-
-	/** コマンドアイコンの取得キー */
-	public static final String IMG_COMMAND = "command";
-
-	/** パラメータアイコンの取得キー */
-	public static final String IMG_PARAMETER = "parameter";
-
-	/** 選択肢アイコンの取得キー */
-	public static final String IMG_SELECT_ITEM = "selectItem";
-
 	/** ロール設定のルートアイコンの取得キー */
 	public static final String IMG_ROLESETTING_ROOT = "rootSettingsRoot";
 
@@ -152,9 +132,19 @@ public class ClusterControlPlugin extends AbstractUIPlugin {
 	/** ロール設定のユーザアイコンの取得キー */
 	public static final String IMG_ROLESETTING_USER = "rootSettingsUser";
 
-	//The shared instance.
+	/** Initial window size and position */
+	public static final Rectangle WINDOW_INIT_SIZE = new Rectangle( -1, -1, 1024, 768 );
+
+	/** スコープの区切り文字（セパレータ） */
+	private final static String DEFAULT_SEPARATOR = ">";
+
+
+	/** The shared instance */
 	private static ClusterControlPlugin plugin;
 
+	/** RAPかどうかを判別する */
+	private static Boolean is_rap = null;
+
 	// ----- instance メソッド ----- //
 
 	//Resource bundle.
@@ -202,8 +192,8 @@ public class ClusterControlPlugin extends AbstractUIPlugin {
 		// 起動時刻
 		long startDate = System.currentTimeMillis();
 		m_log.info("start date = " + new Date(startDate) + "(" + startDate + ")");
-		
-		
+
+
 		// 追加監視の情報をログへ出力　*ここでクラスを初期化しています。
 		for(IMonitorPlugin pluginMonitor: LoadMonitorPlugin.getExtensionMonitorList()){
 			m_log.info("Extended monitor " + pluginMonitor.getMonitorPluginId() + " pluged in.");
@@ -315,24 +305,12 @@ public class ClusterControlPlugin extends AbstractUIPlugin {
 		this.registerImage(registry, IMG_SCHEDULE_FUTURE, "schedule_w.gif");
 		this.registerImage(registry, IMG_JOB_EDIT_MODE, "job_edit_mode.gif");
 
-		/*
-		 * CollectiveRunPlugin
-		 */
-		this.registerImage(registry, IMG_COMPOSITE, "composite.gif");
-		this.registerImage(registry, IMG_COMMAND_COMPOSITE, "composite.gif");
-		this.registerImage(registry, IMG_PARAMETER_COMPOSITE, "composite.gif");
-		this.registerImage(registry, IMG_TYPE, "type.gif");
-		this.registerImage(registry, IMG_COMMAND, "command.gif");
-		this.registerImage(registry, IMG_PARAMETER, "parameter.gif");
-		this.registerImage(registry, IMG_SELECT_ITEM, "select_item.gif");
-
 		/*
 		 * RoleSettingTree
 		 */
 		this.registerImage(registry, IMG_ROLESETTING_ROOT, "node.gif");
 		this.registerImage(registry, IMG_ROLESETTING_ROLE, "role.gif");
 		this.registerImage(registry, IMG_ROLESETTING_USER, "user.gif");
-
 	}
 
 	/**
@@ -361,10 +339,8 @@ public class ClusterControlPlugin extends AbstractUIPlugin {
 	 */
 	public String getSeparator() {
 		if (separator == null || separator.compareTo("") == 0) {
-			FacilityTree facilityTree = new FacilityTree();
-			separator = facilityTree.getSeparator();
+			separator = DEFAULT_SEPARATOR;
 		}
-
 		return separator;
 	}
 
@@ -385,4 +361,17 @@ public class ClusterControlPlugin extends AbstractUIPlugin {
 	public static String getPluginId() {
 		return getDefault().getBundle().getSymbolicName();
 	}
-}
\ No newline at end of file
+
+	/**
+	 * Check if this application is run in RAP
+	 * @return Is RAP or not
+	 */
+	public static Boolean isRAP() {
+		if( null == is_rap ){
+			// getAppName() will return null in RAP
+			is_rap = (null == Display.getAppName());
+		}
+		return is_rap;
+	}
+
+}
