@@ -22,18 +22,19 @@ import com.clustercontrol.ClusterControlPlugin;
 
 /**
  * チェックボックスイメージ定数クラス<BR>
- * 
+ *
  * @version 2.0.0
  * @since 2.0.0
  */
 public class CheckBoxImageConstant {
+	/** Checked image */
 	private static Image checked = null;
-
-	private static Image unChecked = null;
+	/** Unchecked image */
+	private static Image unchecked = null;
 
 	/**
 	 * 種別からImageに変換します。<BR>
-	 * 
+	 *
 	 * @param type
 	 * @return image
 	 */
@@ -42,17 +43,19 @@ public class CheckBoxImageConstant {
 				.getImageRegistry();
 
 		if (type) {
-			if (checked == null)
+			if (checked == null){
 				checked = registry.getDescriptor(
 						ClusterControlPlugin.IMG_CHECKED)
 						.createImage();
+			}
 			return checked;
 		} else {
-			if (unChecked == null)
-				unChecked = registry.getDescriptor(
+			if (unchecked == null){
+				unchecked = registry.getDescriptor(
 						ClusterControlPlugin.IMG_UNCHECKED)
 						.createImage();
-			return unChecked;
+			}
+			return unchecked;
 		}
 	}
-}
\ No newline at end of file
+}
