@@ -19,11 +19,13 @@ import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.widgets.Combo;
 
+import com.clustercontrol.util.WidgetTestUtil;
+
 /**
  * コンボボックス用ModifyListenerクラス<BR>
- * 
+ *
  * 入力された文字列がコンボボックスに用意されていない場合、クリアする
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
@@ -31,12 +33,13 @@ public class ComboModifyListener implements ModifyListener {
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see org.eclipse.swt.events.ModifyListener#modifyText(org.eclipse.swt.events.ModifyEvent)
 	 */
 	@Override
 	public void modifyText(ModifyEvent e) {
 		Combo combo = (Combo) e.getSource();
+		WidgetTestUtil.setTestId(this, null, combo);
 		String modify = combo.getText();
 		if (modify.length() == combo.getTextLimit()) {
 			int index = 0;
@@ -50,4 +53,4 @@ public class ComboModifyListener implements ModifyListener {
 			}
 		}
 	}
-}
\ No newline at end of file
+}
