@@ -16,9 +16,8 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.editor;
 
 import org.eclipse.jface.viewers.DialogCellEditor;
-import org.eclipse.swt.SWT;
 import org.eclipse.swt.widgets.Control;
-import org.eclipse.swt.widgets.FileDialog;
+//import org.eclipse.swt.widgets.FileDialog;
 
 /**
  * ファイルダイアログセルエディタークラス<BR>
@@ -36,10 +35,10 @@ public class FileDialogCellEditor extends DialogCellEditor {
 	@Override
 	protected Object openDialogBox(Control cellEditorWindow) {
 		//ファイルダイアログを表示
-		FileDialog dialog = new FileDialog(cellEditorWindow.getShell(),
-				SWT.OPEN);
+		//FileDialog dialog = new FileDialog(cellEditorWindow.getShell(),
+		//		SWT.OPEN);
 		//選択したファイルパスを取得する
-		String file = dialog.open();
-		return file;
+		//String file = dialog.open();
+		return "";
 	}
-}
\ No newline at end of file
+}
