@@ -15,18 +15,23 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.view;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.eclipse.jface.action.ActionContributionItem;
 import org.eclipse.jface.action.IAction;
 import org.eclipse.jface.action.IContributionItem;
 import org.eclipse.jface.action.IToolBarManager;
+import org.eclipse.jface.action.MenuManager;
+import org.eclipse.jface.action.ToolBarManager;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.swt.widgets.Composite;
+import org.eclipse.swt.widgets.Widget;
+import org.eclipse.ui.IViewSite;
+import org.eclipse.ui.PartInitException;
 import org.eclipse.ui.internal.ViewPluginAction;
 import org.eclipse.ui.part.ViewPart;
 
+import com.clustercontrol.startup.view.StartUpView;
 import com.clustercontrol.util.LoginManager;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * 共通ViewPartクラス<BR>
@@ -38,17 +43,38 @@ import com.clustercontrol.util.LoginManager;
  */
 public class CommonViewPart extends ViewPart {
 
-	// ログ
-	private static Log m_log = LogFactory.getLog( CommonViewPart.class );
+	@Override
+	public void init( IViewSite site ) throws PartInitException{
+		super.init( site );
+
+		// Set testid for test
+		Widget widget;
+		widget = ((ToolBarManager)getViewSite().getActionBars().getToolBarManager()).getControl();
+		if( null != widget ){
+			WidgetTestUtil.setTestId( this, null, widget );
+		}
+		widget = ((MenuManager)getViewSite().getActionBars().getMenuManager()).getMenu();
+		if( null != widget ){
+			WidgetTestUtil.setTestId( this, null, widget );
+		}
+	}
 
 	/**
 	 * コンストラクタ
 	 */
 	public CommonViewPart(){
-		super();
-		LoginManager.login();  // ログインしていない場合は、ビュー表示前に必ずログインダイアログを出すようにする
+		super(); 
+
+		// Condition-1 Skip login if it is StartUpView
+		// Condition-2 Skip and redirect to the login in postWindowCreate() at startup ( 0 == loginAttempts)
+		if( !(this instanceof StartUpView) && 0 < LoginManager.getLoginAttempts() ){
+			// ログインしていない場合は、ビュー表示前に必ずログインダイアログを出すようにする
+			if (! LoginManager.isLogin() ) {
+				LoginManager.login();
+			}
+		}
 	}
-	
+
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -56,7 +82,6 @@ public class CommonViewPart extends ViewPart {
 	 */
 	@Override
 	public void createPartControl(Composite parent) {
-
 	}
 
 	/*
@@ -66,7 +91,6 @@ public class CommonViewPart extends ViewPart {
 	 */
 	@Override
 	public void setFocus() {
-
 	}
 
 	/**
@@ -118,4 +142,4 @@ public class CommonViewPart extends ViewPart {
 		ViewPluginAction action =  (ViewPluginAction)ci.getAction();
 		action.selectionChanged(selection);
 	}
-}
\ No newline at end of file
+}
