@@ -21,16 +21,17 @@ package org.vafada.swtcalendar;
 
 import java.util.ArrayList;
 
-import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.MouseAdapter;
 import org.eclipse.swt.events.MouseEvent;
 import org.eclipse.swt.events.MouseTrackAdapter;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.events.SelectionListener;
-import org.eclipse.swt.widgets.Button;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Event;
 
+import com.clustercontrol.client.swt.SWT;
+import com.clustercontrol.client.swt.widgets.Button;
+
 /**
  * Push button that repeats selection event based on timer.
  */
@@ -43,7 +44,7 @@ public class RepeatingButton extends Button {
 
 	private int repeatDelay = DEFAULT_REPEAT_DELAY;
 
-	private ArrayList selectionListeners = new ArrayList(3);
+	private ArrayList<SelectionListener> selectionListeners = new ArrayList<SelectionListener>(3);
 
 	private Repeater repeater;
 
@@ -184,4 +185,4 @@ public class RepeatingButton extends Button {
 			canceled = true;
 		}
 	}
-}
\ No newline at end of file
+}
