@@ -1,17 +1,17 @@
 /*
  * SWTMonthChooser.java - A month chooser component for SWT Author: Mark Bryan
  * Yu Modified by: Sergey Prigogin swtcalendar.sourceforge.net
- * 
+ *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
  * Software Foundation; either version 2 of the License, or (at your option) any
  * later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
  * details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software Foundation, Inc.,
  * 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -21,6 +21,7 @@ package org.vafada.swtcalendar;
 import java.text.DateFormatSymbols;
 import java.util.Calendar;
 import java.util.Locale;
+import java.util.regex.Pattern;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.SelectionListener;
@@ -29,9 +30,10 @@ import org.eclipse.swt.layout.FillLayout;
 import org.eclipse.swt.widgets.Combo;
 import org.eclipse.swt.widgets.Composite;
 
-public class SWTMonthChooser extends Composite {
-	private SWTDayChooser dayChooser;
+import com.clustercontrol.util.WidgetTestUtil;
 
+
+public class SWTMonthChooser extends Composite {
 	private Combo comboBox;
 
 	private Locale locale;
@@ -39,9 +41,12 @@ public class SWTMonthChooser extends Composite {
 	public SWTMonthChooser(Composite parent) {
 		super(parent, SWT.NONE);
 
+		Pattern.compile("[^\\w\\.]").matcher(this.getClass().getName()).replaceAll("-");
+
 		locale = Locale.getDefault();
 		setLayout(new FillLayout());
 		comboBox = new Combo(this, SWT.DROP_DOWN | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, null, comboBox);
 
 		initNames();
 
@@ -97,7 +102,7 @@ public class SWTMonthChooser extends Composite {
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see org.eclipse.swt.widgets.Control#setFont(org.eclipse.swt.graphics.Font)
 	 */
 	@Override
@@ -105,4 +110,4 @@ public class SWTMonthChooser extends Composite {
 		super.setFont(font);
 		comboBox.setFont(getFont());
 	}
-}
\ No newline at end of file
+}
