@@ -15,6 +15,7 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.accesscontrol.util;
 
+import com.clustercontrol.commons.bean.SettingUpdateInfo;
 import com.clustercontrol.commons.util.JpaTransactionCallback;
 
 public class UserRoleCacheRefreshCallback implements JpaTransactionCallback {
@@ -38,6 +39,9 @@ public class UserRoleCacheRefreshCallback implements JpaTransactionCallback {
 	public void postCommit() {
 		// ユーザ管理系のキャッシュ情報を更新する
 		UserRoleCache.refresh();
+		
+		// ユーザ情報の更新ででリポジトリ参照情報も変わるため、更新時刻をリフレッシュ
+		SettingUpdateInfo.getInstance().setRepositoryUpdateTime(System.currentTimeMillis());
 	}
 
 	@Override
