@@ -584,7 +584,12 @@ public class Agent {
 		RunHistoryUtil.logHistory();
 
 		try {
-			AgentEndPointWrapper.deleteAgent();
+			// deleteAgentを行った直後に別スレッドのgetTopicと競合するとエージェントが重複されたと認識されるため、
+			// deleteAgentとgetTopicを排他する
+			synchronized(ReceiveTopic.lockTopicReceiveTiming) {
+				AgentEndPointWrapper.deleteAgent();
+				ReceiveTopic.terminate();
+			}
 		} catch (InvalidRole_Exception e) {
 			m_log.info("InvalidRoleException " + e.getMessage());
 		} catch (InvalidUserPass_Exception e) {
