@@ -16,13 +16,11 @@ package com.clustercontrol.agent.winevent;
 
 import java.io.BufferedReader;
 import java.io.ByteArrayInputStream;
-import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.PrintWriter;
-import java.io.UnsupportedEncodingException;
 import java.nio.charset.Charset;
 import java.text.DateFormat;
 import java.text.ParseException;
@@ -30,19 +28,13 @@ import java.text.SimpleDateFormat;
 import java.util.ArrayList;
 import java.util.Calendar;
 import java.util.Collections;
-import java.util.Comparator;
 import java.util.Date;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
 import java.util.TimeZone;
-import java.util.Map.Entry;
 import java.util.concurrent.Executors;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.ScheduledFuture;
 import java.util.concurrent.ThreadFactory;
 import java.util.concurrent.TimeUnit;
-import java.util.regex.Pattern;
 
 import javax.xml.stream.XMLInputFactory;
 import javax.xml.stream.XMLStreamConstants;
@@ -101,24 +93,24 @@ public class WinEventCollector implements CollectorTask, Runnable {
 	private ScheduledFuture<?> future;
 	
 	// イベントログ監視間隔
-	private static final String RUN_INTERVAL_KEY = "collector.winevent.interval";
+	private static final String RUN_INTERVAL_KEY = "monitor.winevent.filter.interval";
 	private static long runInterval = 10000;
 	
 	// イベント取得タイムアウト
-	private static final String TIMEOUT_KEY = "collector.winevent.timeout";
+	private static final String TIMEOUT_KEY = "monitor.winevent.filter.timeout";
 	private static long timeout = 30000;
 	
 	// イベント実行結果バッファ
-	private static final String BUFFER_LENGTH_KEY = "collector.winevent.buffer";
+	private static final String BUFFER_LENGTH_KEY = "monitor.winevent.buffer";
 	private static int bufferLength = 100000;
 	
 	// ポーリング1回あたりのイベントログの最大取得件数
-	private static final String MAX_EVENTS_KEY = "collector.winevent.maxevents";
+	private static final String MAX_EVENTS_KEY = "monitor.winevent.maxevents";
 	private static final int UNLIMITED_EVENTS = -1;
 	private static int maxEvents = 1000;
 
 	// イベント収集モード
-	private static final String COLLECT_MODE_KEY = "collector.winevent.mode";
+	private static final String COLLECT_MODE_KEY = "monitor.winevent.mode";
 	private static final String MODE_AUTO = "auto";
 	private static final String MODE_GET_WIN_EVENT = "get-winevent";
 	private static final String MODE_GET_EVENT_LOG = "get-eventlog";
@@ -126,9 +118,9 @@ public class WinEventCollector implements CollectorTask, Runnable {
 	private static String collectMode = MODE_AUTO;
 
 	// イベントメッセージの文字の一時置換用文字
-	private static String RETURN_CHAR_REPLACE_KEY = "collector.winevent.return.char.replace";
-	private static String GT_CHAR_REPLACE_KEY = "collector.winevent.gt.char.replace";
-	private static String LT_CHAR_REPLACE_KEY = "collector.winevent.lt.char.replace";
+	private static String RETURN_CHAR_REPLACE_KEY = "monitor.winevent.return.char.replace";
+	private static String GT_CHAR_REPLACE_KEY = "monitor.winevent.gt.char.replace";
+	private static String LT_CHAR_REPLACE_KEY = "monitor.winevent.lt.char.replace";
 	private static final String TMP_RETURN_CODE = "#n;";
 	private static final String TMP_GT_CODE = "#gt;";
 	private static final String TMP_LT_CODE = "#lt;";
@@ -146,18 +138,6 @@ public class WinEventCollector implements CollectorTask, Runnable {
 	private Calendar lastrun = null;
 	private static String targetProperty;
 	
-	// Windowsイベントのローテーション対応(wevtutilのみ)
-	private static final String BASE_EVTX_DIR_KEY = "collector.winevent.base.evtx.dir";
-	private static final String ARCHIVE_ROTATE = "collector.winevent.archive.rotate";
-	private String baseEvtxDir;
-	private boolean rotation = false;
-	
-	// Windowsイベントのチェック対象の数
-	private int targetFileCount;
-	
-	// PowerShellの文字コード
-	private static final String POWERSHELL_CHARSET_KEY = "collector.winevent.charset";
-	private final String charset;
 	
 	public WinEventCollector(final MonitorInfo monitorInfo, SendQueue sendQueue) {
 		this.monitorInfo = monitorInfo;
@@ -240,34 +220,13 @@ public class WinEventCollector implements CollectorTask, Runnable {
 			tmpLtCode = TMP_GT_CODE;
 			m_log.info("collector.winevent.lt.char.replace uses " + tmpLtCode + ". ");
 		}
-		
-		// イベントの出力先ディレクトリのベース
-		baseEvtxDir = AgentProperties.getProperty(BASE_EVTX_DIR_KEY);
-		if(baseEvtxDir == null){
-			baseEvtxDir = "C:\\Windows\\System32\\winevt\\Logs";
-		}
-		// 
-		String tmpRotation = AgentProperties.getProperty(ARCHIVE_ROTATE);
-		m_log.info(ARCHIVE_ROTATE + " " + tmpRotation + ".");
-		if(tmpRotation != null && "true".equals(tmpRotation)){
-			rotation = true;
-		}
-		
-		// PowerShellの書き出し・実行文字コードを決定する
-		String tmpCharset = AgentProperties.getProperty(POWERSHELL_CHARSET_KEY);
-		if (tmpCharset == null || tmpCharset.length() == 0) {
-			tmpCharset = "MS932";
-			m_log.info(POWERSHELL_CHARSET_KEY + " uses " + tmpCharset);
-		}
-		charset = tmpCharset;
-
 	}
 	
 	@Override
 	public void run() {
 		m_log.debug("run WinEventMonitorThread");
 		
-		try {
+		try{
 			long start = System.currentTimeMillis(); // 計測開始
 			
 			// 監視設定をもとにPowerShellスクリプトを生成する
@@ -276,14 +235,14 @@ public class WinEventCollector implements CollectorTask, Runnable {
 			
 			// 収集モードごとに合わせた形式で現在時刻を取得する
 			Calendar currentCal = null;
-			if(MODE_AUTO.equals(collectMode)){
-				// Windows Server 2003(5.2)の場合
+			if(MODE_AUTO.equals(collectMode)){			
+			// Windows Server 2003(5.2)の場合
 				if(WIN2003_VERSION_NUM.equals(osVersion)){
 					currentCal = Calendar.getInstance();	// 現在時刻をlocal timeで取得
 				}
 				// Windows Server 2008(6.0), Windows Server 2008 R2(6.1), Windows Server 2012(6.2)の場合、
 				else{
-					currentCal = Calendar.getInstance(TimeZone.getTimeZone("UTC"));	// 現在時刻をUTCで取得
+					currentCal = Calendar.getInstance(TimeZone.getTimeZone("UTC"));	// 現在時刻をUTCで取得	
 				}
 			}
 			else if(MODE_WEVTUTIL.equals(collectMode)){
@@ -324,7 +283,7 @@ public class WinEventCollector implements CollectorTask, Runnable {
 					}
 					// Windows Server 2008(6.0), Windows Server 2008 R2(6.1), Windows Server 2012(6.2)の場合、
 					else{
-						createWevtutilPs(currentCal, lastrun, monitorInfo.getWinEventCheckInfo());
+					createWevtutilPs(currentCal, lastrun, monitorInfo.getWinEventCheckInfo());
 					}
 				}
 				else if(MODE_WEVTUTIL.equals(collectMode)){
@@ -342,31 +301,31 @@ public class WinEventCollector implements CollectorTask, Runnable {
 					return;
 				}
 			} catch (Exception e){
-				m_log.error("unknown error occurred. ", e);
+				m_log.error("unknown error occurred. ", e); 
 				updateLastRun(currentCal);
-				return;
+				return;	
 			}
-	
+				
 			// コマンドを生成する
 			String[] command = null;
 			String commandGetEvent = "powershell -inputformat none -File \"" + psFileName + "\"";
 			try {
 				CommandCreator.PlatformType platform = CommandCreator.convertPlatform("windows");
 				command = CommandCreator.createCommand(System.getProperty("user.name"), commandGetEvent, platform);
-	
+
 			} catch (HinemosException e) {
 				m_log.warn("command creation failure. ", e);
 			}
 			long commandCreated = System.currentTimeMillis();
 			m_log.trace("command creating time : " + (commandCreated - start));
-	
+
 			// コマンドを実行する
 			CommandResult ret = null;
 			synchronized(WinEventCollector.class){
 				try {
 					CommandExecutor cmdExecutor = new CommandExecutor(command,
-							Charset.forName(charset), timeout, bufferLength);
-		
+							Charset.forName("MS932"), timeout, bufferLength);
+	
 					// 実行結果を取得する
 					cmdExecutor.execute();
 					ret = cmdExecutor.getResult();
@@ -374,15 +333,10 @@ public class WinEventCollector implements CollectorTask, Runnable {
 					m_log.warn("failed executing command for " + monitorInfo.getMonitorId(), e);
 				}
 			}
-	
+
 			long commandExecuted = System.currentTimeMillis();
 			m_log.trace("command running time : " + (commandExecuted - commandCreated));
 			
-			m_log.debug(String.format("successful executing command for %s : %s", monitorInfo.getMonitorId(),  ret));
-			if (ret != null && ret.exitCode != 0) {
-				m_log.warn(String.format("failed executing command for %s : %s", monitorInfo.getMonitorId(),  ret));
-			}
-			
 			// バッファのあふれをチェック
 			if(ret.bufferDiscarded){
 				// マネージャにエラー内容を通知する
@@ -392,41 +346,21 @@ public class WinEventCollector implements CollectorTask, Runnable {
 				return;
 			}
 			
-			// powershellスクリプト実行後に、今回の探索範囲のevtxファイルが増加していた場合をチェック
-			if (rotation) {
-				int count = 0;
-				for (String logName : monitorInfo.getWinEventCheckInfo().getLogName()) {
-					// アーカイブファイルと現行のログファイル分をカウント
-					count =  count + getFileList(logName, currentCal, lastrun).size() + 1;
-				}
-				
-				m_log.debug("run() : count:"+count +", targetFileCount" + targetFileCount);
-				
-				if (count > targetFileCount) {
-					m_log.warn("The number of target files is changed, " + targetFileCount + " -> " + count);
-					// 次のpowershell実行タイミングで、今回分を再度検索するので、lastrunは更新しない（イベントの取得漏れを防ぐため）
-					return;
-				}
-			}
-			
-			
 			// 実行結果をStAXでパースできるようにフォーマット
 			String formattedStdout = "<Events>" + ret.stdout + "</Events>";
 			formattedStdout = formattedStdout.replaceAll("\n", "");
 			formattedStdout = formattedStdout.replaceAll("\r", "");
 			formattedStdout = formattedStdout.replaceAll(tmpReturnCode + "<", "<");	// wevtutilでタグ間に不要な改行文字が入るのを除去
 			
-			if(m_log.isTraceEnabled()){
-				m_log.trace("stdout(formatted) : " + (ret != null ? formattedStdout : null));
-			}
-			
+			m_log.debug("stdout(formatted) : " + (ret != null ? formattedStdout : null));
+
 			// 実行結果をパースしてEventLogRecordクラスに格納
 			ArrayList<EventLogRecord> eventlogs = parseEventXML(new ByteArrayInputStream(formattedStdout.getBytes()));
 			Collections.reverse(eventlogs);
-			
+		
 			long resultParsed = System.currentTimeMillis();
 			m_log.trace("xml parsing time : " + (resultParsed - commandExecuted));
-	
+
 			// 監視設定をもとにパターンマッチし、通知情報をマネージャに送信する
 			for(EventLogRecord eventlog : eventlogs){
 				m_log.debug("Event : " + eventlog);
@@ -436,23 +370,24 @@ public class WinEventCollector implements CollectorTask, Runnable {
 			
 			long end = System.currentTimeMillis();
 			m_log.trace("pattern matching time : " + (end - resultParsed));
-	
+
+			m_log.trace("total running time : " + (end - start));
+			
 			updateLastRun(currentCal);
 			
-			m_log.trace("total running time : " + (end - start));
-		} catch (Exception e) {
+		} catch (Exception e){
 			// ScheduledExecutorServiceはrunにて例外がthrowされると次回以降の定期実行を行わなくなるため、catchする。
 			m_log.warn("failed executing monitor for " + monitorInfo.getMonitorId(), e);
 			
-			// lastrunは更新しない。
-			// 何度もExceptionが生じた場合は無限ループとなるが、環境障害 or 不具合の可能性が高いため、勝手にスキップするのはそもそもナンセンス。
+			//lasetrunは更新しない。
+			//何度もExceptionが生じた場合は無限ループとなるが、環境障害 or 不具合の可能性が高いため、勝手にスキップするのはそもそもナンセンス。
 		}
 	}
 
-	/**
-	 * 現在時刻を採集実行日時（lastrun）としてファイルに出力する
-	 * @param currentCal 最後の採集実行日時
-	 */
+	/** 
+	* 現在時刻を最終実行日時（lastrun）としてファイルに出力する
+	* powershellの実行に失敗した場合はここに到達せず、lastrunを更新しない
+	*/
 	private void updateLastRun(Calendar currentCal) {
 		PrintWriter pw = null;
 		try {
@@ -460,7 +395,7 @@ public class WinEventCollector implements CollectorTask, Runnable {
 			pw.println(currentCal.getTimeInMillis());
 		} catch (FileNotFoundException e) {
 			m_log.debug("parseEvent() create new lastrun file(" + lastrunFileName + ")");
-		} finally {
+		} finally {			
 			// 現在時刻を前回時刻として格納する
 			lastrun = currentCal;
 			pw.close();
@@ -490,7 +425,7 @@ public class WinEventCollector implements CollectorTask, Runnable {
 			command = CommandCreator.createCommand(System.getProperty("user.name"), commandCheckEnabled, platform);
 
 			CommandExecutor cmdExecutor = new CommandExecutor(command,
-					Charset.forName(charset), timeout, bufferLength);
+					Charset.forName("MS932"), timeout, bufferLength);
 			cmdExecutor.execute();
 			CommandResult ret = cmdExecutor.getResult();
 			
@@ -530,7 +465,7 @@ public class WinEventCollector implements CollectorTask, Runnable {
 			command = CommandCreator.createCommand(System.getProperty("user.name"), commandCheckPolicy, platform);
 
 			CommandExecutor cmdExecutor = new CommandExecutor(command,
-					Charset.forName(charset), timeout, bufferLength);
+					Charset.forName("MS932"), timeout, bufferLength);
 			cmdExecutor.execute();
 			CommandResult ret = cmdExecutor.getResult();
 			
@@ -589,7 +524,7 @@ public class WinEventCollector implements CollectorTask, Runnable {
 		// PowerShellスクリプトを生成する
 		PrintWriter pw = null;
 		try {
-			pw = new PrintWriter(psFileName, charset);
+			pw = new PrintWriter(psFileName);
 			pw.println("$Error.Clear()");
 
 			for(String logName : checkInfo.getLogName()){
@@ -705,8 +640,6 @@ public class WinEventCollector implements CollectorTask, Runnable {
 
 		} catch (FileNotFoundException e) {
 			m_log.debug("createGetEventLogPs() cannot create powershell script", e);
-		} catch (UnsupportedEncodingException e) {
-			m_log.warn("createGetEventLogPs() : can't create powershell script. invalid charset. charset = " + charset, e);
 		} finally {
 			pw.close();
 		}
@@ -732,7 +665,7 @@ public class WinEventCollector implements CollectorTask, Runnable {
 		// PowerShellスクリプトを生成する
 		PrintWriter pw = null;
 		try {
-			pw = new PrintWriter(psFileName, charset);
+			pw = new PrintWriter(psFileName);
 			pw.println("$eventlogs = @()");
 			pw.println("$Error.Clear()");
 
@@ -860,8 +793,6 @@ public class WinEventCollector implements CollectorTask, Runnable {
 
 		} catch (FileNotFoundException e) {
 			m_log.debug("createGetWinEventPs() cannot create powershell script", e);
-		} catch (UnsupportedEncodingException e) {
-			m_log.warn("createGetWinEventPs() : can't create powershell script. invalid charset. charset = " + charset, e);
 		} finally {
 			pw.close();
 		}
@@ -884,153 +815,110 @@ public class WinEventCollector implements CollectorTask, Runnable {
 		df.setTimeZone(currentCal.getTimeZone());
 		String currentTimestamp = df.format(currentCal.getTime());
 		String previousTimestamp = df.format(previousCal.getTime());
-
-		if(m_log.isDebugEnabled()){
-			m_log.debug("createWevtutilPs() wevtutil.exe generate timestamp currentTimestamp : " + currentTimestamp);
-			m_log.debug("createWevtutilPs() wevtutil.exe generate timestamp previousTimestamp : " + previousTimestamp);
-		}
-		m_log.debug("createWevtutilPs() from " + previousTimestamp + " to " + currentTimestamp);
-
+		
 		// PowerShellスクリプトを生成する
 		PrintWriter pw = null;
 		try {
-			pw = new PrintWriter(psFileName, charset);
+			pw = new PrintWriter(psFileName);
 			pw.println("$Error.Clear()");
-			
-			targetFileCount = 0;
 
 			for(String logName : checkInfo.getLogName()){
-				m_log.debug("createWevtutilPs() wevtutil.exe target logName : " + logName);
 
-				// ソート用に時刻をキーに対象ログ（ファイルパス）をvalueにマップにセットする
-				Map<Long, String> targetLogMap = new HashMap<Long, String>();
-				targetLogMap.put(currentCal.getTimeInMillis(), logName);
+				// クエリの生成
+				String condition = "";
 				
-				// rotate対応の場合、過去参照すべきアーカイブログを検索し、クエリに渡す文字列をListに追加する
-				if(rotation){
-					targetLogMap.putAll(getFileList(logName, currentCal, previousCal));
-					targetFileCount += targetLogMap.size();
+				// ログ名
+				condition += " qe " + logName;
+	
+
+				// 最大取得件数の指定（任意）
+				if(maxEvents != UNLIMITED_EVENTS){
+					condition += " /c:" + maxEvents;
+				}
+	
+				// /q: System ここから
+				condition += "  /q:\"*[System[";
+				
+				// ソース
+				if(checkInfo.getSource() != null && checkInfo.getSource().size() != 0){
+					condition += "Provider[";
+					for(String sourceName : checkInfo.getSource()){
+						condition += "@Name='";
+						condition += sourceName;
+						condition += "' or ";
+					}
+					condition = condition.replaceFirst(" or \\z", "");	// 末尾の"or"を削除
+					condition += "] and ";
 				}
 				
-				//////////////////////////////////////////////
-				// イベントソースの検索処理を追加
-				// rotate=trueかつ、過去参照すべきアーカイブログがなければこれまで同様イベントソースのみ検索する
-				// もしあれば、過去参照すべきアーカイブログを直接検索する
-				//////////////////////////////////////////////
-				// Logを日付で降順でソート（wevtutilにて/rdオプションで降順(最新から順に表示)のため）
-				List<Map.Entry<Long, String>> entries = new ArrayList<Map.Entry<Long, String>>(
-						targetLogMap.entrySet());
-				Collections.sort(entries, new Comparator<Map.Entry<Long, String>>() {
-					@Override
-					public int compare(Entry<Long, String> entry1,
-							Entry<Long, String> entry2) {
-						return ((Long) entry2.getKey()).compareTo((Long) entry1
-								.getKey());
-					}
-				});
-
-				// 順に処理
-				for (Entry<Long, String> s : entries) {
-					String targetLog = s.getValue();
-					m_log.debug("createWevtutilPs() start creating powershell script string for " + targetLog);
-					
-					// クエリの生成
-					String condition = "";
-					
-					// ログ名
-					condition += " qe " + targetLog;
-					
-					
-					// 最大取得件数の指定（任意）
-					if(maxEvents != UNLIMITED_EVENTS){
-						condition += " /c:" + maxEvents;
-					}
-		
-					// /q: System ここから
-					condition += "  /q:\"*[System[";
-					
-					// ソース
-					if(checkInfo.getSource() != null && checkInfo.getSource().size() != 0){
-						condition += "Provider[";
-						for(String sourceName : checkInfo.getSource()){
-							condition += "@Name='";
-							condition += sourceName;
-							condition += "' or ";
-						}
-						condition = condition.replaceFirst(" or \\z", "");	// 末尾の"or"を削除
-						condition += "] and ";
-					}
-					
-					// レベル
+				// レベル
+				condition += "(";
+				condition += checkInfo.isLevelCritical() ? "Level=" + WinEventConstant.CRITICAL_LEVEL + " or " : "" ;
+				condition += checkInfo.isLevelWarning() ? "Level=" + WinEventConstant.WARNING_LEVEL + " or " : "" ;
+				condition += checkInfo.isLevelVerbose() ? "Level=" + WinEventConstant.VERBOSE_LEVEL + " or " : "" ;
+				condition += checkInfo.isLevelError() ? "Level=" + WinEventConstant.ERROR_LEVEL + " or " : "" ;
+				condition += checkInfo.isLevelInformational() ? "Level=" + WinEventConstant.INFORMATION_LEVEL0 
+						+ " or Level=" + WinEventConstant.INFORMATION_LEVEL4 + " or " : "" ;
+				
+				condition = condition.replaceFirst(" or \\z", "");	// 末尾の"or"を削除
+				condition += ") and ";
+				
+				// イベントID
+				if(checkInfo.getEventId() != null && checkInfo.getEventId().size() != 0){
 					condition += "(";
-					condition += checkInfo.isLevelCritical() ? "Level=" + WinEventConstant.CRITICAL_LEVEL + " or " : "" ;
-					condition += checkInfo.isLevelWarning() ? "Level=" + WinEventConstant.WARNING_LEVEL + " or " : "" ;
-					condition += checkInfo.isLevelVerbose() ? "Level=" + WinEventConstant.VERBOSE_LEVEL + " or " : "" ;
-					condition += checkInfo.isLevelError() ? "Level=" + WinEventConstant.ERROR_LEVEL + " or " : "" ;
-					condition += checkInfo.isLevelInformational() ? "Level=" + WinEventConstant.INFORMATION_LEVEL0 
-							+ " or Level=" + WinEventConstant.INFORMATION_LEVEL4 + " or " : "" ;
+					for(Integer id : checkInfo.getEventId()){
+						condition += "EventID=" + id + " or ";
+					}
 					
 					condition = condition.replaceFirst(" or \\z", "");	// 末尾の"or"を削除
 					condition += ") and ";
-					
-					// イベントID
-					if(checkInfo.getEventId() != null && checkInfo.getEventId().size() != 0){
-						condition += "(";
-						for(Integer id : checkInfo.getEventId()){
-							condition += "EventID=" + id + " or ";
-						}
-						
-						condition = condition.replaceFirst(" or \\z", "");	// 末尾の"or"を削除
-						condition += ") and ";
-					}
-		
-					// タスクの分類
-					if(checkInfo.getCategory() != null && checkInfo.getCategory().size() != 0){
-						condition += "(";
-						for(Integer category : checkInfo.getCategory()){
-							condition += "Task=" + category + " or ";
-						}
-						
-						condition = condition.replaceFirst(" or \\z", "");	// 末尾の"or"を削除
-						condition += ") and ";
+				}
+	
+				// タスクの分類
+				if(checkInfo.getCategory() != null && checkInfo.getCategory().size() != 0){
+					condition += "(";
+					for(Integer category : checkInfo.getCategory()){
+						condition += "Task=" + category + " or ";
 					}
 					
-					// キーワード
-					if(checkInfo.getKeywords() != null && checkInfo.getKeywords().size() != 0){
-						long targetKeyword = 0l;
-						for(Long keyword : checkInfo.getKeywords()){
-							targetKeyword += keyword.longValue();
-						}
-						condition += "(band(Keywords," + targetKeyword + ")) and ";
-					}
-					
-					// 出力時刻
-					condition += "TimeCreated[@SystemTime>='"
-							+ previousTimestamp
-							+ "' and @SystemTime<'"
-							+ currentTimestamp + "']";
-					
-					// /q: System ここまで
-					condition += "]]\"";
-
-					pw.println("$result = wevtutil.exe /rd /f:RenderedXml /e:root" + condition + " | out-string");
-					pw.println("$result=$result -replace \"`n\",\"" + tmpReturnCode + "\"; ");	// 改行のエスケープ
-					pw.println("$result=$result -replace \"&lt;\",\"" + tmpLtCode + "\"; ");		// "<"のエスケープ
-					pw.println("$result=$result -replace \"&gt;\",\"" + tmpGtCode + "\"; ");		// ">"のエスケープ
-					
-					// 出力結果がbufferLengthを超えた場合は処理しない
-					pw.println("if($result.Length -gt " + bufferLength + "){");
-					pw.println("    $len = $result.Length;");
-					pw.println("    $message = \"outputLength=$len, bufferLength=" + bufferLength + "\";");
-					pw.println("    Write-Output \"<BufferOverRunWarn>$message</BufferOverRunWarn>\"");
-					pw.println("}");
-					pw.println("else{");
-					pw.println("    Write-Output $result");
-					pw.println("}");
-					
-					m_log.debug("createWevtutilPs() wevtutil.exe condition : " + condition);
+					condition = condition.replaceFirst(" or \\z", "");	// 末尾の"or"を削除
+					condition += ") and ";
 				}
 				
+				// キーワード
+				if(checkInfo.getKeywords() != null && checkInfo.getKeywords().size() != 0){
+					long targetKeyword = 0l;
+					for(Long keyword : checkInfo.getKeywords()){
+						targetKeyword += keyword.longValue();
+					}
+					condition += "(band(Keywords," + targetKeyword + ")) and ";
+				}
+				
+				// 出力時刻
+				condition += "TimeCreated[@SystemTime>='"
+						+ previousTimestamp
+						+ "' and @SystemTime<'"
+						+ currentTimestamp + "']";
+				
+				// /q: System ここまで
+				condition += "]]\"";
+				
+				pw.println("$result = wevtutil.exe /rd /f:RenderedXml /e:root" + condition + " | out-string");
+				pw.println("$result=$result -replace \"`n\",\"" + tmpReturnCode + "\"; ");	// 改行のエスケープ
+				pw.println("$result=$result -replace \"&lt;\",\"" + tmpLtCode + "\"; ");		// "<"のエスケープ
+				pw.println("$result=$result -replace \"&gt;\",\"" + tmpGtCode + "\"; ");		// ">"のエスケープ
+				
+				// 出力結果がbufferLengthを超えた場合は処理しない
+				pw.println("if($result.Length -gt " + bufferLength + "){");
+				pw.println("    $len = $result.Length;");
+				pw.println("    $message = \"outputLength=$len, bufferLength=" + bufferLength + "\";");
+				pw.println("    Write-Output \"<BufferOverRunWarn>$message</BufferOverRunWarn>\"");
+				pw.println("}");
+				pw.println("else{");
+				pw.println("    Write-Output $result");
+				pw.println("}");
+
+				m_log.debug("createWevtutilPs() wevtutil.exe condition : " + condition);
 			}
 			
 			// 汎用エラー処理
@@ -1052,8 +940,6 @@ public class WinEventCollector implements CollectorTask, Runnable {
 
 		} catch (FileNotFoundException e) {
 			m_log.debug("createWevtutilPs() cannot create powershell script", e);
-		} catch (UnsupportedEncodingException e) {
-			m_log.warn("createWevtutilPs() : can't create powershell script. invalid charset. charset = " + charset, e);
 		} finally {
 			pw.close();
 		}
@@ -1362,7 +1248,7 @@ public class WinEventCollector implements CollectorTask, Runnable {
 		try {
 			scheduler.awaitTermination(30000L, TimeUnit.MILLISECONDS);
 		} catch (InterruptedException e) {
-			 m_log.warn("shutdown interrupted.", e);
+			m_log.warn("shutdown interrupted.", e);
 		}
 	}
 
@@ -1373,66 +1259,6 @@ public class WinEventCollector implements CollectorTask, Runnable {
 		
 	}
 	
-	private Map<Long, String> getFileList(String logName, Calendar currentCal, Calendar previousCal) {
-		Map<Long, String> targetLogMap = new HashMap<Long, String>();
-		
-		// 取得対象時刻のUTC文字列を生成する
-		DateFormat df = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss'Z'");
-		df.setTimeZone(currentCal.getTimeZone());
-		String currentTimestamp = df.format(currentCal.getTime());
-		String previousTimestamp = df.format(previousCal.getTime());
-		
-		String archive_file_prefix = "Archive-";
-		
-		//ディレクトリからファイル一覧を取得
-		String path = baseEvtxDir + "\\" + logName; // アーカイブログのディレクトリ作成ルール(仕様)
-		m_log.debug("createWevtutilPs() wevtutil.exe archive log search path : " + path);
-		
-		File dir = new File(path);
-		
-		//ルールに従ったディレクトリが存在したら処理を進める
-		if(dir.exists()){
-			m_log.debug("createWevtutilPs() wevtutil.exe search path : " + path + " exist");
+	
 
-			//アーカイブファイルの正規表現
-			Pattern p = Pattern.compile(archive_file_prefix + logName + "-\\d{4}-\\d{2}-\\d{2}-\\d{2}-\\d{2}-\\d{2}-\\d{3}.evtx");
-
-			//ルールに従ったディレクトリ内のファイルチェック
-			File[] files = dir.listFiles();
-			for (int i = 0; i < files.length; i++) {
-				File file = files[i];
-				
-				//全ファイルをデバック出力
-				if(m_log.isDebugEnabled()){
-					m_log.debug("no : " + (i + 1));
-					m_log.debug("getName : " + file.getName());
-					m_log.debug("getPath : " + file.getPath());
-					m_log.debug("lastModified : " + file.lastModified());
-					m_log.debug("lastModifiedTimestamnp : " + df.format(file.lastModified()));
-				}
-				
-				//アーカイブログファイルの形式にマッチする
-				if(p.matcher(file.getName()).matches()){
-					m_log.debug("file pattern match getName : " + file.getName());
-					
-					//lastModified時刻がpreviousTimestampより新しいものがあればイベントログの捜査対象
-					if(file.lastModified() >= previousCal.getTimeInMillis()){
-						
-						m_log.info("search archive file getName : " + file.getName() + " from " + previousTimestamp + " to " + currentTimestamp);
-						targetLogMap.put(file.lastModified(), file.getPath() + " /lf:true");
-						
-						
-					}else{
-						m_log.debug("not search archive file getName : " + file.getName());
-					}
-				}else{
-					m_log.debug("file pattern not match getName : " + file.getName());
-				}
-			}
-		}else{
-			m_log.debug("createWevtutilPs() wevtutil.exe search path : " + path + " not exist");
-		}
-		
-		return targetLogMap;
-	}
 }
