@@ -15,8 +15,8 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.calendar.composite;
 
-import java.util.ArrayList;
 import java.util.List;
+import java.util.concurrent.ConcurrentHashMap;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -30,14 +30,16 @@ import org.eclipse.swt.widgets.Label;
 
 import com.clustercontrol.calendar.util.CalendarEndpointWrapper;
 import com.clustercontrol.monitor.run.dialog.CommonMonitorDialog;
+import com.clustercontrol.notify.composite.NotifyBasicComposite;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.ws.calendar.CalendarInfo;
 import com.clustercontrol.ws.calendar.InvalidRole_Exception;
 
 
 /**
  * カレンダIDコンポジットクラス<BR>
- * 
+ *
  * @version 2.1.0
  * @since 2.1.0
  */
@@ -46,19 +48,24 @@ public class CalendarIdListComposite extends Composite {
 	// ログ
 	private static Log m_log = LogFactory.getLog( CalendarIdListComposite.class );
 
+	// 表示とIDを紐付けるマップ
+	// key=CalendarId
+	// value=CalendarName(CalendarId)
+	private ConcurrentHashMap<String, String> dispMap = new ConcurrentHashMap<>(); 
+	
 	// ----- instance フィールド ----- //
 
 	/** カレンダIDラベル */
 	private Label labelCalendarId = null;
 
 	/** カレンダIDコンボボックス */
-	private Combo comboCalendarId = null;
+	private Combo calIdCombo = null;
 
 	// ----- コンストラクタ ----- //
 
 	/**
 	 * インスタンスを返します。<BR>
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param style スタイル
 	 * @param labelFlg カレンダIDラベル表示フラグ
@@ -66,7 +73,7 @@ public class CalendarIdListComposite extends Composite {
 	public CalendarIdListComposite(Composite parent, int style, boolean labelFlg) {
 		super(parent, style);
 
-		this.initialize(parent, labelFlg);
+		initialize(parent, labelFlg);
 	}
 
 
@@ -89,29 +96,44 @@ public class CalendarIdListComposite extends Composite {
 		else{
 			layout.numColumns = 10;
 		}
-		this.setLayout(layout);
+		setLayout(layout);
 
 		/*
 		 * カレンダID
 		 */
 		if(labelFlg){
 			// ラベル
-			this.labelCalendarId = new Label(this, SWT.NONE);
+			labelCalendarId = new Label(this, SWT.NONE);
+			WidgetTestUtil.setTestId(this, "calendarid", labelCalendarId);
 			gridData = new GridData();
-			gridData.horizontalSpan = CommonMonitorDialog.WIDTH_TITLE;
+			if (parent instanceof NotifyBasicComposite) {
+				gridData.horizontalSpan = NotifyBasicComposite.WIDTH_TITLE;
+			} else {
+				gridData.horizontalSpan = CommonMonitorDialog.WIDTH_TITLE;
+			}
 			gridData.horizontalAlignment = GridData.FILL;
 			gridData.grabExcessHorizontalSpace = true;
-			this.labelCalendarId.setLayoutData(gridData);
-			this.labelCalendarId.setText(Messages.getString("calendar.id") + " : ");
+			labelCalendarId.setLayoutData(gridData);
+			labelCalendarId.setText(Messages.getString("calendar.id") + " : ");
 		}
 
 		// コンボボックス
-		this.comboCalendarId = new Combo(this, SWT.DROP_DOWN | SWT.READ_ONLY);
+		calIdCombo = new Combo(this, SWT.DROP_DOWN | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, null, calIdCombo);
 		gridData = new GridData();
-		gridData.horizontalSpan = 5;
+		if(labelFlg){
+			if (parent instanceof NotifyBasicComposite) {
+				gridData.horizontalSpan = CommonMonitorDialog.SMALL_UNIT;
+			} else {
+				gridData.horizontalSpan = CommonMonitorDialog.SHORT_UNIT;
+			}
+		}
+		else{
+			gridData.horizontalSpan = 5;
+		}
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		this.comboCalendarId.setLayoutData(gridData);
+		calIdCombo.setLayoutData(gridData);
 
 		this.update();
 	}
@@ -119,35 +141,53 @@ public class CalendarIdListComposite extends Composite {
 	/**
 	 * コンポジットを更新します。<BR>
 	 * <p>
-	 * 
+	 *
 	 */
 	@Override
 	public void update() {
 	}
 
+	private void removeAllMap() {
+		dispMap.clear();
+		calIdCombo.removeAll();
+	}
+	
+	private String putMap(String calId, String calName) {
+		String disp = null;
+		if (calId.length() == 0) {
+			disp = "";
+		} else {
+			int maxLength = 32;
+			if (maxLength < calName.length()) {
+				calName = calName.substring(0, maxLength) + "...";
+			}
+			disp = calName + "(" + calId + ")";
+		}
+		dispMap.put(calId, disp);
+		calIdCombo.add(disp);
+		return disp;
+	}
+
 	/**
 	 * オーダーロールIDが参照権限があるカレンダを選択するコンボボックスを生成します。
-	 * 
+	 *
+	 * @param managerName マネージャ名
 	 * @param ownerRoleId オーダーロールID
 	 */
-	public void setOwnerRoleId(String ownerRoleId){
+	public void createCalIdCombo(String managerName, String ownerRoleId){
 
 		// 初期化
-		this.comboCalendarId.removeAll();
+		removeAllMap();
 
 		// 空欄
-		this.comboCalendarId.add("");
+		putMap("", "");
 
-		List<String> list = null;
+		List<CalendarInfo> calList = null;
 		// データ取得
 		try {
-			List<CalendarInfo> listTmp = null;
-			list = new ArrayList<String>();
 			if (ownerRoleId != null && !"".equals(ownerRoleId)) {
-				listTmp = CalendarEndpointWrapper.getCalendarList(ownerRoleId);
-				for (CalendarInfo info : listTmp) {
-					list.add(info.getId());
-				}
+				CalendarEndpointWrapper wrapper = CalendarEndpointWrapper.getWrapper(managerName);
+				calList = wrapper.getCalendarList(ownerRoleId);
 			}
 		} catch (InvalidRole_Exception e) {
 			// 権限なし
@@ -164,10 +204,10 @@ public class CalendarIdListComposite extends Composite {
 					Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
 		}
 
-		if(list != null){
+		if(calList != null){
 			// カレンダIDリスト
-			for(String calendarId : list){
-				this.comboCalendarId.add(calendarId);
+			for(CalendarInfo info : calList){
+				putMap(info.getId(), info.getName());
 			}
 		}
 	}
@@ -177,7 +217,7 @@ public class CalendarIdListComposite extends Composite {
 	 */
 	@Override
 	public void setEnabled(boolean enabled) {
-		this.comboCalendarId.setEnabled(enabled);
+		calIdCombo.setEnabled(enabled);
 	}
 
 	/* (非 Javadoc)
@@ -185,27 +225,44 @@ public class CalendarIdListComposite extends Composite {
 	 */
 	@Override
 	public boolean getEnabled() {
-		return this.comboCalendarId.getEnabled();
+		return calIdCombo.getEnabled();
 	}
 
-	/* (非 Javadoc)
-	 * @see org.eclipse.swt.widgets.Combo#getText()
+	/**
+	 * 表示しているCalendarIdを返す
+	 * 表示されているのは、「CalendarName(CalendarId)」
 	 */
 	public String getText() {
-		return this.comboCalendarId.getText();
+		String selectedText = calIdCombo.getText();
+		if (selectedText == null && "".equals(selectedText)) {
+			return "";
+		}
+		for (String tmpId : dispMap.keySet()) {
+			if (dispMap.get(tmpId).equals(selectedText)) {
+				return tmpId;
+			}
+		}
+		m_log.warn("getText() warning"); // ここには到達しないはず。
+		return null;
 	}
 
 	/* (非 Javadoc)
 	 * @see org.eclipse.swt.widgets.Combo#setText(java.lang.String)
 	 */
-	public void setText(String string) {
-		this.comboCalendarId.setText(string);
+	public void setText(String calId) {
+		if (calId == null) {
+			return;
+		}
+		// 権限によっては、存在しないカレンダを選択(setText)する場合があるので、
+		// ここで追加する。
+		if (!dispMap.keySet().contains(calId)) {
+			// カレンダの参照権限がない場合のみ、ここに到達する。
+			// 参照権限がないので、IDしかわからない。
+			putMap(calId, "");
+		}
+
+		// 選択する
+		calIdCombo.setText(dispMap.get(calId));
 	}
 
-	/* (非 Javadoc)
-	 * コンボボックスにカレンダIDを追加する
-	 */
-	public void addText(String string) {
-		this.comboCalendarId.add(string);
-	}
-}
\ No newline at end of file
+}
