@@ -16,27 +16,28 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.calendar.session;
 
 import java.util.ArrayList;
+import java.util.List;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.calendar.bean.CalendarDetailInfo;
+import com.clustercontrol.calendar.bean.CalendarInfo;
+import com.clustercontrol.calendar.bean.CalendarPatternInfo;
+import com.clustercontrol.calendar.factory.ModifyCalendar;
+import com.clustercontrol.calendar.factory.SelectCalendar;
+import com.clustercontrol.calendar.util.CalendarCacheManagementCallback;
+import com.clustercontrol.calendar.util.CalendarChangedNotificationCallback;
+import com.clustercontrol.calendar.util.CalendarPatternCacheManagementCallback;
+import com.clustercontrol.calendar.util.CalendarValidator;
+import com.clustercontrol.commons.util.HinemosSessionContext;
+import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.fault.CalendarDuplicate;
 import com.clustercontrol.fault.CalendarNotFound;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.InvalidSetting;
 import com.clustercontrol.fault.ObjectPrivilege_InvalidRole;
-import com.clustercontrol.calendar.bean.CalendarDetailInfo;
-import com.clustercontrol.calendar.bean.CalendarInfo;
-import com.clustercontrol.calendar.bean.CalendarPatternInfo;
-import com.clustercontrol.calendar.factory.ModifyCalendar;
-import com.clustercontrol.calendar.factory.SelectCalendar;
-import com.clustercontrol.calendar.util.CalendarCache;
-import com.clustercontrol.calendar.util.CalendarManagerUtil;
-import com.clustercontrol.calendar.util.CalendarPatternCache;
-import com.clustercontrol.calendar.util.CalendarValidator;
-import com.clustercontrol.commons.util.HinemosSessionContext;
-import com.clustercontrol.commons.util.JpaTransactionManager;
 
 /**
  *
@@ -49,7 +50,7 @@ public class CalendarControllerBean {
 
 	/**
 	 * カレンダ一覧を取得します。<BR>
-	 * 
+	 *
 	 * @return カレンダ情報のリスト
 	 * @throws HinemosUnknown
 	 */
@@ -78,7 +79,7 @@ public class CalendarControllerBean {
 
 	/**
 	 * オーナーロールIDを指定してカレンダ一覧を取得します。<BR>
-	 * 
+	 *
 	 * @param ownerRoleId オーナーロールID
 	 * @return カレンダ情報のリスト
 	 * @throws InvalidRole
@@ -109,12 +110,12 @@ public class CalendarControllerBean {
 
 	/**
 	 * カレンダIDのリストを取得します。<BR>
-	 * 
+	 *
 	 * 引数のArrayListにはカレンダーidが含まれています。
 	 * <p>
 	 *	list.add(cal.getCalendar_id());
 	 * </p>
-	 * 
+	 *
 	 * @return カレンダIDのリスト
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
@@ -144,7 +145,7 @@ public class CalendarControllerBean {
 
 	/**
 	 * 引数で指定したカレンダーIDに対応するカレンダ情報を取得します。<BR>
-	 * 
+	 *
 	 * @param id
 	 * @return カレンダ情報
 	 * @throws CalendarNotFound
@@ -184,7 +185,7 @@ public class CalendarControllerBean {
 	/**
 	 * 引数で指定したカレンダーIDに対応するカレンダ情報を取得します。<BR>
 	 * CalendarInfo.CalendarDetailInfo.etcInfoも取得します。
-	 * 
+	 *
 	 * @param id
 	 * @return カレンダ情報
 	 * @throws CalendarNotFound
@@ -222,7 +223,7 @@ public class CalendarControllerBean {
 
 	/**
 	 * カレンダ[カレンダパターン]情報一覧を取得します。<BR>
-	 * 
+	 *
 	 * @param ownerRoleId オーナーロールID
 	 * @return カレンダ[カレンダパターン]情報のリスト
 	 * @throws HinemosUnknown
@@ -260,7 +261,7 @@ public class CalendarControllerBean {
 
 	/**
 	 * 引数で指定したIDに対応するカレンダ[カレンダパターン]情報を取得します。<BR>
-	 * 
+	 *
 	 * @param id
 	 * @return カレンダ[カレンダパターン]情報
 	 * @throws CalendarNotFound
@@ -298,10 +299,9 @@ public class CalendarControllerBean {
 
 	/**
 	 * カレンダ（基本）情報を登録します。<BR>
-	 * 
+	 *
 	 * 引数のDTOの内容をマネージャに登録します。
-	 * Database commit後に実施すべきユーザ実装が存在するため、トランザクション開始はユーザが制御する。
-	 * 
+	 *
 	 * @param info　登録するカレンダー（基本）情報
 	 * @return
 	 * @throws CalendarDuplicate
@@ -312,12 +312,10 @@ public class CalendarControllerBean {
 	public void addCalendar(CalendarInfo info)
 			throws CalendarDuplicate, HinemosUnknown, InvalidSetting, InvalidRole {
 		JpaTransactionManager jtm = null;
-		boolean commit = false;
 		try{
 			jtm = new JpaTransactionManager();
 
-			// トランザクションがすでに開始されている場合は処理終了
-			jtm.begin(true);
+			jtm.begin();
 
 			//入力チェック
 			CalendarValidator.validateCalendarInfo(info);
@@ -327,8 +325,8 @@ public class CalendarControllerBean {
 			ModifyCalendar modify = new ModifyCalendar();
 			modify.addCalendar(info, loginUser);
 
+			jtm.addCallback(new CalendarChangedNotificationCallback());
 			jtm.commit();
-			commit = true;
 		} catch (CalendarDuplicate e) {
 			jtm.rollback();
 			throw e;
@@ -350,18 +348,6 @@ public class CalendarControllerBean {
 			jtm.rollback();
 			throw new HinemosUnknown(e.getMessage(), e);
 		} finally {
-			if (commit) {
-				try {
-					// read-committedのため、commit後に外部コンポーネントに通知する
-					CalendarManagerUtil.broadcastConfigured();
-				} catch (Exception e) {
-					m_log.warn("addCalendar() transaction failure. : "
-							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
-					throw new HinemosUnknown(e.getMessage(), e);
-				} finally {
-					jtm.close();
-				}
-			}
 			// EntityManagerクリア
 			jtm.close();
 		}
@@ -369,10 +355,9 @@ public class CalendarControllerBean {
 
 	/**
 	 * カレンダ（基本）情報を変更します。<BR>
-	 * 
+	 *
 	 * 引数のプロパティの内容で更新します。
-	 * Database commit後に実施すべきユーザ実装が存在するため、トランザクション開始はユーザが制御する。
-	 * 
+	 *
 	 * @param info
 	 * @return
 	 * @throws CalendarNotFound
@@ -382,13 +367,10 @@ public class CalendarControllerBean {
 	 */
 	public void modifyCalendar(CalendarInfo info) throws CalendarNotFound, HinemosUnknown, InvalidSetting, InvalidRole {
 		JpaTransactionManager jtm = null;
-		boolean commit = false;
 
 		try {
 			jtm = new JpaTransactionManager();
-
-			// トランザクションがすでに開始されている場合は処理終了
-			jtm.begin(true);
+			jtm.begin();
 
 			//入力チェック
 			CalendarValidator.validateCalendarInfo(info);
@@ -396,10 +378,11 @@ public class CalendarControllerBean {
 			String loginUser = (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID);
 			ModifyCalendar modify = new ModifyCalendar();
 			modify.modifyCalendar(info, loginUser);
+			
+			jtm.addCallback(new CalendarCacheManagementCallback(info.getId()));
+			jtm.addCallback(new CalendarChangedNotificationCallback());
+			
 			jtm.commit();
-			commit = true;
-			// コミット後にキャッシュクリア
-			CalendarCache.remove(info.getId());
 		} catch (InvalidSetting e) {
 			jtm.rollback();
 			throw e;
@@ -419,49 +402,39 @@ public class CalendarControllerBean {
 			throw new HinemosUnknown(e.getMessage(), e);
 		} finally {
 			jtm.close();
-			if (commit) {
-				try {
-					// read-committedのため、commit後に外部コンポーネントに通知する
-					CalendarManagerUtil.broadcastConfigured();
-				} catch (Exception e) {
-					m_log.warn("modifyCalendar() : transaction failure. "
-							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
-					throw new HinemosUnknown(e.getMessage(), e);
-				}
-			}
 		}
 	}
 
 	/**
 	 * カレンダ(基本）情報を 削除します。<BR>
-	 * 
+	 *
 	 * 引数のIDに対応するカレンダー（基本）情報を削除します。
-	 * Database commit後に実施すべきユーザ実装が存在するため、トランザクション開始はユーザが制御する。
-	 * 
-	 * @param id カレンダーID
+	 *
+	 * @param idList カレンダーID
 	 * @return
 	 * @throws CalendarNotFound
 	 * @throws HinemosUnknown
 	 * @throws InvalidRole
 	 */
-	public void deleteCalendar(String id) throws CalendarNotFound, HinemosUnknown, InvalidRole {
+	public void deleteCalendar(List<String> idList) throws CalendarNotFound, HinemosUnknown, InvalidRole {
 		JpaTransactionManager jtm = null;
-		boolean commit = false;
 		try {
 			jtm = new JpaTransactionManager();
+			jtm.begin();
 
-			// トランザクションがすでに開始されている場合は処理終了
-			jtm.begin(true);
-
-			CalendarValidator.valideDeleteCalendar(id);
-
-			ModifyCalendar modify = new ModifyCalendar();
-			modify.deleteCalendar(id);
+			for(String id : idList) {
+				CalendarValidator.valideDeleteCalendar(id);
 
+				ModifyCalendar modify = new ModifyCalendar();
+				modify.deleteCalendar(id);
+			}
+			
+			for (String id : idList) {
+				jtm.addCallback(new CalendarCacheManagementCallback(id));
+			}
+			jtm.addCallback(new CalendarChangedNotificationCallback());
+			
 			jtm.commit();
-			commit = true;
-			// コミット後にキャッシュクリア
-			CalendarCache.remove(id);
 
 		} catch (CalendarNotFound e) {
 			jtm.rollback();
@@ -482,27 +455,14 @@ public class CalendarControllerBean {
 			throw new HinemosUnknown(e.getMessage(), e);
 		} finally {
 			jtm.close();
-
-			if (commit) {
-				try {
-					// read-committedのため、commit後に外部コンポーネントに通知する
-					CalendarManagerUtil.broadcastConfigured();
-				} catch (Exception e) {
-					m_log.warn("deleteCalendar() : transaction failure. "
-							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
-					throw new HinemosUnknown(e.getMessage(), e);
-				}
-			}
 		}
 	}
 
 	/**
 	 * カレンダ[カレンダパターン]情報を登録します。<BR>
-	 * 
+	 *
 	 * 引数のDTOの内容をマネージャに登録します。
-	 * Database commit後に実施すべきユーザ実装が存在するため、
-	 * トランザクション開始はユーザが制御する。
-	 * 
+	 *
 	 * @param info カレンダ[カレンダパターン]情報
 	 * @return
 	 * @throws CalendarDuplicate
@@ -513,12 +473,10 @@ public class CalendarControllerBean {
 	public void addCalendarPattern(CalendarPatternInfo info)
 			throws CalendarDuplicate, HinemosUnknown, InvalidSetting, InvalidRole {
 		JpaTransactionManager jtm = null;
-		boolean commit = false;
 		try{
 			jtm = new JpaTransactionManager();
 
-			// トランザクションがすでに開始されている場合は処理終了
-			jtm.begin(true);
+			jtm.begin();
 
 			//入力チェック
 			CalendarValidator.validateCalendarPatternInfo(info);
@@ -528,8 +486,8 @@ public class CalendarControllerBean {
 			ModifyCalendar modify = new ModifyCalendar();
 			modify.addCalendarPattern(info, loginUser);
 
+			jtm.addCallback(new CalendarChangedNotificationCallback());
 			jtm.commit();
-			commit = true;
 		} catch (CalendarDuplicate e) {
 			jtm.rollback();
 			throw e;
@@ -551,18 +509,6 @@ public class CalendarControllerBean {
 			jtm.rollback();
 			throw new HinemosUnknown(e.getMessage(), e);
 		} finally {
-			if (commit) {
-				try {
-					// read-committedのため、commit後に外部コンポーネントに通知する
-					CalendarManagerUtil.broadcastConfigured();
-				} catch (Exception e) {
-					m_log.warn("addCalendarPattern() transaction failure. : "
-							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
-					throw new HinemosUnknown(e.getMessage(), e);
-				} finally {
-					jtm.close();
-				}
-			}
 			// EntityManagerクリア
 			jtm.close();
 		}
@@ -570,11 +516,9 @@ public class CalendarControllerBean {
 
 	/**
 	 * カレンダ[カレンダパターン]情報を変更します。<BR>
-	 * 
+	 *
 	 * 引数のプロパティの内容で更新します。
-	 * Database commit後に実施すべきユーザ実装が存在するため、
-	 * トランザクション開始はユーザが制御する。
-	 * 
+	 *
 	 * @param info
 	 * @return
 	 * @throws CalendarNotFound
@@ -585,13 +529,10 @@ public class CalendarControllerBean {
 	public void modifyCalendarPattern(CalendarPatternInfo info)
 			throws CalendarNotFound, HinemosUnknown, InvalidSetting, InvalidRole {
 		JpaTransactionManager jtm = null;
-		boolean commit = false;
 
 		try {
 			jtm = new JpaTransactionManager();
-
-			// トランザクションがすでに開始されている場合は処理終了
-			jtm.begin(true);
+			jtm.begin();
 
 			//入力チェック
 			CalendarValidator.validateCalendarPatternInfo(info);
@@ -599,12 +540,11 @@ public class CalendarControllerBean {
 			String loginUser = (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID);
 			ModifyCalendar modify = new ModifyCalendar();
 			modify.modifyCalendarPattern(info, loginUser);
+			
+			jtm.addCallback(new CalendarPatternCacheManagementCallback(info.getId()));
+			jtm.addCallback(new CalendarChangedNotificationCallback());
+			
 			jtm.commit();
-			commit = true;
-
-			// コミット後にキャッシュクリア
-			CalendarPatternCache.remove(info.getId());
-
 		} catch (InvalidSetting e) {
 			jtm.rollback();
 			throw e;
@@ -624,52 +564,40 @@ public class CalendarControllerBean {
 			throw new HinemosUnknown(e.getMessage(), e);
 		} finally {
 			jtm.close();
-			if (commit) {
-				try {
-					// read-committedのため、commit後に外部コンポーネントに通知する
-					CalendarManagerUtil.broadcastConfigured();
-				} catch (Exception e) {
-					m_log.warn("modifyCalendarPattern() : transaction failure. "
-							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
-					throw new HinemosUnknown(e.getMessage(), e);
-				}
-			}
 		}
 	}
 
 	/**
 	 * カレンダ[カレンダパターン]情報を 削除します。<BR>
-	 * 
+	 *
 	 * 引数のIDに対応するカレンダ[カレンダパターン]情報を削除します。
-	 * Database commit後に実施すべきユーザ実装が存在するため、
-	 * トランザクション開始はユーザが制御する。
-	 * 
-	 * @param id ID
+	 *
+	 * @param idList IDリスト
 	 * @return
 	 * @throws CalendarNotFound
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
 	 */
-	public void deleteCalendarPattern(String id) throws CalendarNotFound, InvalidRole, HinemosUnknown  {
+	public void deleteCalendarPattern(List<String> idList) throws CalendarNotFound, InvalidRole, HinemosUnknown  {
 		JpaTransactionManager jtm = null;
-		boolean commit = false;
 
 		try {
 			jtm = new JpaTransactionManager();
+			jtm.begin();
 
-			// トランザクションがすでに開始されている場合は処理終了
-			jtm.begin(true);
+			for(String id : idList) {
+				CalendarValidator.valideDeleteCalendarPattern(id);
 
-			CalendarValidator.valideDeleteCalendarPattern(id);
-
-			ModifyCalendar modify = new ModifyCalendar();
-			modify.deleteCalendarPattern(id);
+				ModifyCalendar modify = new ModifyCalendar();
+				modify.deleteCalendarPattern(id);
+			}
+			
+			for (String id : idList) {
+				jtm.addCallback(new CalendarPatternCacheManagementCallback(id));
+			}
+			jtm.addCallback(new CalendarChangedNotificationCallback());
+			
 			jtm.commit();
-			commit = true;
-
-			// コミット後にキャッシュクリア
-			CalendarPatternCache.remove(id);
-
 		} catch (CalendarNotFound e) {
 			jtm.rollback();
 			throw e;
@@ -689,24 +617,13 @@ public class CalendarControllerBean {
 			throw new HinemosUnknown(e.getMessage(), e);
 		} finally {
 			jtm.close();
-
-			if (commit) {
-				try {
-					// read-committedのため、commit後に外部コンポーネントに通知する
-					CalendarManagerUtil.broadcastConfigured();
-				} catch (Exception e) {
-					m_log.warn("deleteCalendarPattern() : transaction failure. "
-							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
-					throw new HinemosUnknown(e.getMessage(), e);
-				}
-			}
 		}
 	}
 
 	/**
 	 * 月間カレンダビューに表示する情報
 	 * 引数で指定したカレンダーIDに対応するカレンダ詳細情報を取得します。<BR>
-	 * 
+	 *
 	 * @param id
 	 * @param orderNo
 	 * @return カレンダ詳細情報
@@ -791,9 +708,9 @@ public class CalendarControllerBean {
 
 	/**
 	 * カレンダが実行可能かチェックします。<BR>
-	 * 
+	 *
 	 * 引数のカレンダーidが引数のタイムスタンプにおいて実行可能であるかチェックします。
-	 * 
+	 *
 	 * @param id
 	 * @param checkTimestamp
 	 * @return カレンダが実行可能か
