@@ -38,6 +38,7 @@ import org.eclipse.swt.widgets.Text;
 import org.eclipse.ui.PlatformUI;
 
 import com.clustercontrol.ClusterControlPlugin;
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.YesNoConstant;
@@ -45,13 +46,12 @@ import com.clustercontrol.composite.TextWithParameterComposite;
 import com.clustercontrol.dialog.ScopeTreeDialog;
 import com.clustercontrol.monitor.run.dialog.CommonMonitorNumericDialog;
 import com.clustercontrol.monitor.util.MonitorSettingEndpointWrapper;
-import com.clustercontrol.notify.util.NotifyGroupIdGenerator;
 import com.clustercontrol.repository.FacilityPath;
 import com.clustercontrol.repository.bean.FacilityConstant;
 import com.clustercontrol.repository.util.RepositoryEndpointWrapper;
 import com.clustercontrol.util.Messages;
-import com.clustercontrol.ws.monitor.CustomCheckInfo;
 import com.clustercontrol.ws.monitor.CommandExecType;
+import com.clustercontrol.ws.monitor.CustomCheckInfo;
 import com.clustercontrol.ws.monitor.InvalidRole_Exception;
 import com.clustercontrol.ws.monitor.MonitorDuplicate_Exception;
 import com.clustercontrol.ws.monitor.MonitorInfo;
@@ -60,7 +60,7 @@ import com.clustercontrol.ws.repository.FacilityTreeItem;
 
 /**
  * コマンド監視の設定ダイアログクラス<br/>
- * 
+ *
  * @version 4.0.0
  * @since 2.4.0
  */
@@ -86,29 +86,31 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 	public static final int TIMEOUT_SEC_COMMAND = 15000;
 	/**
 	 * コンストラクタ(作成時)<br/>
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
 	 */
 	public MonitorCustomDialog(Shell parent) {
-		super(parent);
+		super(parent, null);
 	}
 
 	/**
 	 * コンストラクタ(変更時)<br/>
-	 * 
+	 *
 	 * @param parent 親となるシェルオブジェクト
+	 * @param managerName マネージャ名
 	 * @param monitorId 変更対象となるコマンド監視の監視項目ID
 	 * @param updateFlg 更新するか否か（true:変更、false:新規登録）
 	 */
-	public MonitorCustomDialog(Shell parent, String monitorId, boolean updateFlg) {
-		super(parent);
+	public MonitorCustomDialog(Shell parent, String managerName, String monitorId, boolean updateFlg) {
+		super(parent, managerName);
+		this.managerName = managerName;
 		this.monitorId = monitorId;
 		this.updateFlg = updateFlg;
 	}
 
 	/**
 	 * コマンド監視の入力項目を構成する。<br/>
-	 * 
+	 *
 	 * @param parent 親となるコンポジット
 	 */
 	@Override
@@ -130,18 +132,20 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 
 		// チェック設定のグループを設定
 		Group groupCheckRule = new Group(groupRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "checkrule", groupCheckRule);
 		groupCheckRule.setText(Messages.getString("check.rule"));
 		GridLayout layout = new GridLayout(15, true);
-		layout.marginWidth = 5;
-		layout.marginHeight = 5;
+		layout.marginWidth = HALF_MARGIN;
+		layout.marginHeight = HALF_MARGIN;
 		groupCheckRule.setLayout(layout);
 
 		gridData = new GridData(GridData.FILL_HORIZONTAL | GridData.GRAB_HORIZONTAL);
-		gridData.horizontalSpan = 15;
+		gridData.horizontalSpan = BASIC_UNIT;
 		groupCheckRule.setLayoutData(gridData);
 
 		// checkboxの設定(指定したノード上でコマンド実行)
 		this.checkSelected = new Button(groupCheckRule, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "selectedCheck", checkSelected);
 		this.checkSelected.setText(Messages.getString("monitor.custom.type.selected"));
 		this.checkSelected.setToolTipText(Messages.getString("monitor.custom.type.selected.tips"));
 		gridData = new GridData(GridData.FILL_HORIZONTAL | GridData.GRAB_HORIZONTAL);
@@ -164,6 +168,7 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 
 		// ノードを指定するテキストボックスとボタンの設定
 		this.textNode = new Text(groupCheckRule, SWT.BORDER | SWT.CENTER | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "nodetext", textNode);
 		this.textNode.setText("");
 		this.textNode.setMessage(Messages.getString("monitor.custom.node.selected"));
 		gridData = new GridData(GridData.FILL_HORIZONTAL | GridData.GRAB_HORIZONTAL);
@@ -177,6 +182,7 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 		});;
 
 		this.buttonNode = new Button(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "node", buttonNode);
 		this.buttonNode.setText(Messages.getString("refer"));
 		gridData = new GridData(GridData.FILL_HORIZONTAL | GridData.GRAB_HORIZONTAL);
 		gridData.horizontalSpan = 2;
@@ -187,7 +193,8 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 				// シェルを取得
 				Shell shell = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell();
 
-				ScopeTreeDialog dialog = new ScopeTreeDialog(shell, getMonitorBasicScope().getOwnerRoleId(), false, false);
+				String managerName = getMonitorBasicScope().getManagerListComposite().getText();
+				ScopeTreeDialog dialog = new ScopeTreeDialog(shell, managerName, getMonitorBasicScope().getOwnerRoleId(), false, false);
 				dialog.setSelectNodeOnly(true);
 				if (dialog.open() == IDialogConstants.OK_ID) {
 					FacilityTreeItem item = dialog.getSelectItem();
@@ -205,10 +212,11 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 
 		// チェック設定のグループを設定
 		Group groupEffectiveUser = new Group(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "effectiveuser", groupEffectiveUser);
 		groupEffectiveUser.setText(Messages.getString("effective.user"));
 		layout = new GridLayout(15, true);
-		layout.marginWidth = 5;
-		layout.marginHeight = 5;
+		layout.marginWidth = HALF_MARGIN;
+		layout.marginHeight = HALF_MARGIN;
 		groupEffectiveUser.setLayout(layout);
 
 		gridData = new GridData(GridData.FILL_HORIZONTAL | GridData.GRAB_HORIZONTAL);
@@ -216,9 +224,10 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 		groupEffectiveUser.setLayoutData(gridData);
 
 		this.buttonAgentUser = new Button(groupEffectiveUser, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "agentuser", buttonAgentUser);
 		this.buttonAgentUser.setText(Messages.getString("agent.user"));
 		gridData = new GridData(GridData.FILL_HORIZONTAL | GridData.GRAB_HORIZONTAL);
-		gridData.horizontalSpan = 15;
+		gridData.horizontalSpan = SMALL_UNIT;
 		this.buttonAgentUser.setLayoutData(gridData);
 		this.buttonAgentUser.addSelectionListener(new SelectionListener() {
 			@Override
@@ -238,9 +247,10 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 		});
 
 		this.buttonSpecifyUser = new Button(groupEffectiveUser, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "specifyuser", buttonSpecifyUser);
 		this.buttonSpecifyUser.setText(Messages.getString("specified.user"));
 		gridData = new GridData(GridData.FILL_HORIZONTAL | GridData.GRAB_HORIZONTAL);
-		gridData.horizontalSpan = 4;
+		gridData.horizontalSpan = WIDTH_TEXT_SHORT;
 		this.buttonSpecifyUser.setLayoutData(gridData);
 		this.buttonSpecifyUser.addSelectionListener(new SelectionListener() {
 			@Override
@@ -260,9 +270,10 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 		});
 
 		this.textEffectiveUser = new Text(groupEffectiveUser, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "effectiveuser", textEffectiveUser);
 		this.textEffectiveUser.setText("");
 		gridData = new GridData(GridData.FILL_HORIZONTAL | GridData.GRAB_HORIZONTAL);
-		gridData.horizontalSpan = 11;
+		gridData.horizontalSpan = HALF_UNIT - (SMALL_UNIT + WIDTH_TEXT_SHORT);
 		this.textEffectiveUser.setLayoutData(gridData);
 		this.textEffectiveUser.addModifyListener(new ModifyListener(){
 			@Override
@@ -272,12 +283,14 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 		});
 
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "customcommand", label);
 		gridData = new GridData(GridData.FILL_HORIZONTAL | GridData.GRAB_HORIZONTAL);
 		label.setText(Messages.getString("monitor.custom.command") + " : ");
 		gridData.horizontalSpan = WIDTH_TITLE;
 		label.setLayoutData(gridData);
 
 		this.textCommand = new TextWithParameterComposite(groupCheckRule, SWT.BORDER | SWT.LEFT | SWT.SINGLE);
+		WidgetTestUtil.setTestId(this, "commnad", textCommand);
 		this.textCommand.setText("");
 		this.textCommand.setToolTipText(Messages.getString("monitor.custom.commandline.tips"));
 		this.textCommand.setColor(new Color(parent.getDisplay(), new RGB(0, 0, 255)));
@@ -296,6 +309,7 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 		 */
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "timeout", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TITLE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -305,6 +319,7 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 
 		// テキスト
 		this.m_textTimeout = new Text(groupCheckRule, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "timeout", m_textTimeout);
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -319,6 +334,7 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 
 		// ラベル（単位）
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "millisec", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_VALUE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -328,6 +344,7 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 
 		// 空白
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "blank", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 5;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -347,7 +364,8 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 		} else {
 			// 変更の場合
 			try {
-				info = MonitorSettingEndpointWrapper.getMonitor(this.monitorId, HinemosModuleConstant.MONITOR_CUSTOM);
+				MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(managerName);
+				info = wrapper.getMonitor(this.monitorId, HinemosModuleConstant.MONITOR_CUSTOM);
 			} catch (InvalidRole_Exception e) {
 				// アクセス権なしの場合、エラーダイアログを表示する
 				MessageDialog.openInformation(
@@ -406,7 +424,7 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 各項目に入力値を設定します。
-	 * 
+	 *
 	 * @param monitor
 	 *			設定値として用いる通知情報
 	 */
@@ -435,8 +453,10 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 				this.nodeFacilityId = customInfo.getSelectedFacilityId();
 
 				String facilityPath = null;
+				String managerName = this.getManagerName();
 				try {
-					facilityPath = RepositoryEndpointWrapper.getFacilityPath(this.nodeFacilityId, null);
+					RepositoryEndpointWrapper wrapper = RepositoryEndpointWrapper.getWrapper(managerName);
+					facilityPath = wrapper.getFacilityPath(this.nodeFacilityId, null);
 				} catch (com.clustercontrol.ws.repository.InvalidRole_Exception e) {
 					// アクセス権が付与されていないことを通知する
 					MessageDialog.openInformation(
@@ -472,7 +492,7 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 入力値を用いて通知情報を生成します。
-	 * 
+	 *
 	 * @return 入力値を保持した通知情報
 	 */
 	@Override
@@ -530,7 +550,6 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 		}
 
 		// 通知設定の格納
-		monitorInfo.setNotifyGroupId(NotifyGroupIdGenerator.createNotifyGroupId(HinemosModuleConstant.MONITOR_CUSTOM, monitorInfo.getMonitorId()));
 		validateResult = m_notifyInfo.createInputData(monitorInfo);
 		if (validateResult != null) {
 			if (validateResult.getID() == null) {
@@ -548,7 +567,7 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 入力値をマネージャに反映する。<br/>
-	 * 
+	 *
 	 * @return 反映できた場合はtrue, その他はfalse
 	 */
 	@Override
@@ -556,12 +575,14 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 		boolean result = false;
 
 		MonitorInfo info = this.inputData;
+		String managerName = this.getManagerName();
 		if (info != null) {
-			String[] args = { info.getMonitorId() };
+			String[] args = { info.getMonitorId(), managerName };
+			MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(managerName);
 			if (!this.updateFlg) {
 				// 新規作成の場合
 				try {
-					result = MonitorSettingEndpointWrapper.addMonitor(info);
+					result = wrapper.addMonitor(info);
 
 					if (result) {
 						// 登録が成功したことを通知する
@@ -604,7 +625,7 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 				// 変更の場合
 				String errMessage = "";
 				try {
-					result = MonitorSettingEndpointWrapper.modifyMonitor(info);
+					result = wrapper.modifyMonitor(info);
 				} catch (InvalidRole_Exception e) {
 					// アクセス権が付与されていないことを通知する
 					MessageDialog.openInformation(
@@ -634,4 +655,4 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 
 		return result;
 	}
-}
\ No newline at end of file
+}
