@@ -15,10 +15,6 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.hinemosagent.factory;
 
-import javax.ejb.FinderException;
-import javax.ejb.RemoveException;
-import javax.naming.NamingException;
-
 import com.clustercontrol.monitor.run.factory.DeleteMonitor;
 
 /**
@@ -33,7 +29,7 @@ public class DeleteMonitorAgent extends DeleteMonitor{
 	 * @see com.clustercontrol.monitor.run.factory.DeleteMonitor#deleteCheckInfo()
 	 */
 	@Override
-	protected boolean deleteCheckInfo() throws FinderException, RemoveException, NamingException {
+	protected boolean deleteCheckInfo() {
 
 		// Agent監視情報を取得
 		// Agent監視は監視の有無を設定するのみ。CheckInfoは存在しない。
