@@ -28,6 +28,7 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.YesNoConstant;
@@ -35,15 +36,15 @@ import com.clustercontrol.composite.TextWithParameterComposite;
 import com.clustercontrol.http.action.AddHttp;
 import com.clustercontrol.http.action.GetHttp;
 import com.clustercontrol.http.action.ModifyHttp;
+import com.clustercontrol.monitor.bean.MonitorTypeMstConstant;
 import com.clustercontrol.monitor.run.dialog.CommonMonitorNumericDialog;
-import com.clustercontrol.notify.util.NotifyGroupIdGenerator;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.monitor.HttpCheckInfo;
 import com.clustercontrol.ws.monitor.MonitorInfo;
 
 /**
  * HTTP監視（数値）作成・変更ダイアログクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 4.0.0
  */
@@ -62,36 +63,40 @@ public class HttpNumericCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のシェルオブジェクト
 	 */
 	public HttpNumericCreateDialog(Shell parent) {
-		super(parent);
+		super(parent, null);
 	}
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
+	 * @param managerName マネージャ名
 	 * @param monitorType 監視判定タイプ
 	 */
-	public HttpNumericCreateDialog(Shell parent, int monitorType) {
-		super(parent);
+	public HttpNumericCreateDialog(Shell parent, String managerName, int monitorType) {
+		super(parent, managerName);
 
+		this.managerName = managerName;
 		this.m_monitorType = monitorType;
 	}
 
 	/**
 	 * 変更用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
+	 * @param managerName マネージャ名
 	 * @param monitorId 変更する監視項目ID
 	 * @param updateFlg 更新するか否か（true:変更、false:新規登録）
 	 */
-	public HttpNumericCreateDialog(Shell parent, String monitorId, boolean updateFlg) {
-		super(parent);
+	public HttpNumericCreateDialog(Shell parent, String managerName, String monitorId, boolean updateFlg) {
+		super(parent, managerName);
 
+		this.managerName = managerName;
 		this.monitorId = monitorId;
 		this.updateFlg = updateFlg;
 	}
@@ -100,7 +105,7 @@ public class HttpNumericCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親のインスタンス
 	 */
 	@Override
@@ -125,13 +130,14 @@ public class HttpNumericCreateDialog extends CommonMonitorNumericDialog {
 		 * チェック設定グループ（条件グループの子グループ）
 		 */
 		Group groupCheckRule = new Group(groupRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "checkrule", groupCheckRule);
 		GridLayout layout = new GridLayout(1, true);
-		layout.marginWidth = 5;
-		layout.marginHeight = 5;
-		layout.numColumns = 15;
+		layout.marginWidth = HALF_MARGIN;
+		layout.marginHeight = HALF_MARGIN;
+		layout.numColumns = BASIC_UNIT;
 		groupCheckRule.setLayout(layout);
 		gridData = new GridData();
-		gridData.horizontalSpan = 15;
+		gridData.horizontalSpan = BASIC_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		groupCheckRule.setLayoutData(gridData);
@@ -142,8 +148,9 @@ public class HttpNumericCreateDialog extends CommonMonitorNumericDialog {
 		 */
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "url", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -151,8 +158,9 @@ public class HttpNumericCreateDialog extends CommonMonitorNumericDialog {
 
 		// テキスト
 		this.m_textRequestUrl = new TextWithParameterComposite(groupCheckRule, SWT.BORDER | SWT.LEFT | SWT.SINGLE);
+		WidgetTestUtil.setTestId(this, "requesturl", m_textRequestUrl);
 		gridData = new GridData();
-		gridData.horizontalSpan = 10;
+		gridData.horizontalSpan = BASIC_UNIT - WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_textRequestUrl.setLayoutData(gridData);
@@ -171,8 +179,9 @@ public class HttpNumericCreateDialog extends CommonMonitorNumericDialog {
 		 */
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "timeout", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -180,8 +189,9 @@ public class HttpNumericCreateDialog extends CommonMonitorNumericDialog {
 
 		// テキスト
 		this.m_textTimeout = new Text(groupCheckRule, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "texttimeout", m_textTimeout);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_VALUE;
+		gridData.horizontalSpan = WIDTH_TEXT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_textTimeout.setLayoutData(gridData);
@@ -194,6 +204,7 @@ public class HttpNumericCreateDialog extends CommonMonitorNumericDialog {
 
 		// ラベル（単位）
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "millisec", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_VALUE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -203,8 +214,9 @@ public class HttpNumericCreateDialog extends CommonMonitorNumericDialog {
 
 		// 空白
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "blank", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = 7;
+		gridData.horizontalSpan = BASIC_UNIT - WIDTH_TEXT_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -213,7 +225,7 @@ public class HttpNumericCreateDialog extends CommonMonitorNumericDialog {
 		this.itemName.setText(Messages.getString("response.time"));
 
 		// 収集値単位のデフォルト値を設定
-		this.measure.setText(Messages.getString("time.msec"));
+		this.measure.setText("msec");
 
 		// ダイアログを調整
 		this.adjustDialog();
@@ -227,7 +239,7 @@ public class HttpNumericCreateDialog extends CommonMonitorNumericDialog {
 		}
 		else{
 			// 変更の場合、情報取得
-			info = new GetHttp().getHttp(this.monitorId);
+			info = new GetHttp().getHttp(this.getManagerName(), this.monitorId, MonitorTypeMstConstant.MONITOR_TYPE_NUMERIC);
 		}
 		this.setInputData(info);
 
@@ -235,7 +247,7 @@ public class HttpNumericCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	@Override
 	public void update(){
@@ -256,7 +268,7 @@ public class HttpNumericCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 各項目に入力値を設定します。
-	 * 
+	 *
 	 * @param monitor 設定値として用いる監視情報
 	 */
 	@Override
@@ -289,7 +301,7 @@ public class HttpNumericCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 入力値を用いて通知情報を生成します。
-	 * 
+	 *
 	 * @return 入力値を保持した通知情報
 	 */
 	@Override
@@ -300,7 +312,7 @@ public class HttpNumericCreateDialog extends CommonMonitorNumericDialog {
 		}
 
 		// HTTP監視固有情報を設定
-		monitorInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_HTTP);
+		monitorInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_HTTP_N);
 
 		// 監視条件 HTTP監視情報
 		HttpCheckInfo httpInfo = new HttpCheckInfo();
@@ -328,8 +340,6 @@ public class HttpNumericCreateDialog extends CommonMonitorNumericDialog {
 		monitorInfo.setHttpCheckInfo(httpInfo);
 
 		// 通知関連情報とアプリケーションの設定
-		// 通知グループIDの設定
-		monitorInfo.setNotifyGroupId(NotifyGroupIdGenerator.createNotifyGroupId(HinemosModuleConstant.MONITOR_HTTP, monitorInfo.getMonitorId()));
 		validateResult = m_notifyInfo.createInputData(monitorInfo);
 		if (validateResult != null) {
 			if(validateResult.getID() == null){	// 通知ID警告用出力
@@ -351,9 +361,9 @@ public class HttpNumericCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -361,14 +371,15 @@ public class HttpNumericCreateDialog extends CommonMonitorNumericDialog {
 		boolean result = false;
 
 		MonitorInfo info = this.inputData;
+		String managerName = this.getManagerName();
 		if(info != null){
 			if(!this.updateFlg){
 				// 作成の場合
-				result = new AddHttp().add(info);
+				result = new AddHttp().add(managerName, info);
 			}
 			else{
 				// 変更の場合
-				result = new ModifyHttp().modify(info);
+				result = new ModifyHttp().modify(managerName, info);
 			}
 		}
 
@@ -377,7 +388,7 @@ public class HttpNumericCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * MonitorInfoに初期値を設定します
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonMonitorDialog#setInfoInitialValue()
 	 */
 	@Override
@@ -396,4 +407,4 @@ public class HttpNumericCreateDialog extends CommonMonitorNumericDialog {
 		httpCheckInfo.setProxyPort(0);
 		monitor.setHttpCheckInfo(httpCheckInfo);
 	}
-}
\ No newline at end of file
+}
