@@ -15,20 +15,19 @@
 
 package com.clustercontrol.http.factory;
 
+import java.io.IOException;
 import java.text.NumberFormat;
 import java.util.Map;
 
-import javax.ejb.CreateException;
-import javax.ejb.FinderException;
-import javax.naming.NamingException;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.bean.PriorityConstant;
-import com.clustercontrol.http.ejb.entity.MonitorHttpInfoLocal;
-import com.clustercontrol.http.ejb.entity.MonitorHttpInfoUtil;
+import com.clustercontrol.fault.MonitorNotFound;
+import com.clustercontrol.http.model.MonitorHttpInfoEntity;
 import com.clustercontrol.http.util.GetHttpResponse;
+import com.clustercontrol.http.util.QueryUtil;
+import com.clustercontrol.maintenance.util.HinemosPropertyUtil;
 import com.clustercontrol.monitor.run.factory.RunMonitor;
 import com.clustercontrol.monitor.run.factory.RunMonitorNumericValueType;
 import com.clustercontrol.repository.util.RepositoryUtil;
@@ -51,14 +50,14 @@ public class RunMonitorHttp extends RunMonitorNumericValueType {
 	private static final String MESSAGE_ID_UNKNOWN = "004";
 
 	//	/** ノード ネットワーク情報 */
-	//	protected static final ArrayList<String> m_attributeList = new ArrayList<String>();
+	//	private static final ArrayList<String> m_attributeList = new ArrayList<String>();
 	//	static{
 	//		m_attributeList.add(FacilityAttributeConstant.IPNETWORKNUMBER);
 	//		m_attributeList.add(FacilityAttributeConstant.IPNETWORKNUMBERV6);
 	//	}
 
 	/** HTTP監視情報 */
-	private MonitorHttpInfoLocal m_http = null;
+	private MonitorHttpInfoEntity m_http = null;
 
 	/** URL */
 	private String m_requestUrl = null;
@@ -76,7 +75,7 @@ public class RunMonitorHttp extends RunMonitorNumericValueType {
 	 * コンストラクタ
 	 * 
 	 */
-	public RunMonitorHttp() throws NamingException, CreateException{
+	public RunMonitorHttp() {
 		super();
 	}
 
@@ -87,7 +86,7 @@ public class RunMonitorHttp extends RunMonitorNumericValueType {
 	 * @see com.clustercontrol.monitor.run.util.CallableTask
 	 */
 	@Override
-	protected RunMonitor createMonitorInstance() throws NamingException, CreateException{
+	protected RunMonitor createMonitorInstance() {
 		return new RunMonitorHttp();
 	}
 
@@ -108,7 +107,7 @@ public class RunMonitorHttp extends RunMonitorNumericValueType {
 		m_message = "";
 		m_messageOrg = "";
 
-		GetHttpResponse m_request = new GetHttpResponse();
+		;
 
 		String url = m_requestUrl;
 		// 変数を置換したURLの生成
@@ -119,36 +118,44 @@ public class RunMonitorHttp extends RunMonitorNumericValueType {
 			if (m_log.isTraceEnabled()) m_log.trace("http request. (nodeInfo = " + nodeInfo + ", facilityId = " + facilityId + ", url = " + url + ")");
 		}
 
-		boolean result = m_request.execute(url, m_httpTimeout);
+		boolean result = false;
+		try (GetHttpResponse m_request = GetHttpResponse.custom()
+				.setRequestTimeout(m_httpTimeout)
+				.setNeedAuthSSLCert(! HinemosPropertyUtil.getHinemosPropertyBool("monitor.http.ssl.trustall", true))
+				.build()) {
+			result = m_request.execute(url);
+			if(result){
+				m_value = m_request.getResponseTime();
 
-		if(result){
-			m_value = m_request.getResponseTime();
+				m_message = Messages.getString("response.time.milli.sec") + " : " + NumberFormat.getNumberInstance().format(m_value);
 
-			m_message = Messages.getString("response.time.milli.sec") + " : " + NumberFormat.getNumberInstance().format(m_value);
-
-			StringBuffer response = new StringBuffer();
-			response.append(Messages.getString("request.url") + " : " + url);
-			response.append("\n" + Messages.getString("status.code") + " : " + m_request.getStatusCode());
-			if(m_request.getHeader() != null && !"".equals(m_request.getHeader().trim())){
-				response.append("\n" + Messages.getString("header") + " :\n" + m_request.getHeader().trim());
+				StringBuffer response = new StringBuffer();
+				response.append(Messages.getString("request.url") + " : " + url);
+				response.append("\n" + Messages.getString("status.code") + " : " + m_request.getStatusCode());
+				if(m_request.getHeaderString() != null && !"".equals(m_request.getHeaderString().trim())){
+					response.append("\n" + Messages.getString("header") + " :\n" + m_request.getHeaderString().trim());
+				}
+				if(m_request.getResponseBody() != null && !"".equals(m_request.getResponseBody().trim())){
+					response.append("\n" + Messages.getString("response.body") + " :\n" + m_request.getResponseBody().trim());
+				}
+				m_messageOrg = response.toString();
 			}
-			if(m_request.getResponseBody() != null && !"".equals(m_request.getResponseBody().trim())){
-				response.append("\n" + Messages.getString("response.body") + " :\n" + m_request.getResponseBody().trim());
+			else{
+				m_message = Messages.getString("message.http.3");
+
+				StringBuffer response = new StringBuffer();
+				response.append(m_request.getErrorMessage());
+				response.append("\n");
+				response.append("\n" + Messages.getString("request.url") + " : " + url);
+				response.append("\n" + Messages.getString("status.code") + " : " + m_request.getStatusCode());
+				if(m_request.getHeaderString() != null && !"".equals(m_request.getHeaderString().trim())){
+					response.append("\n" + Messages.getString("header") + " :\n" + m_request.getHeaderString().trim());
+				}
+				m_messageOrg = response.toString();
 			}
-			m_messageOrg = response.toString();
 		}
-		else{
-			m_message = Messages.getString("message.http.3");
-
-			StringBuffer response = new StringBuffer();
-			response.append(m_request.getErrorMessage());
-			response.append("\n");
-			response.append("\n" + Messages.getString("request.url") + " : " + url);
-			response.append("\n" + Messages.getString("status.code") + " : " + m_request.getStatusCode());
-			if(m_request.getHeader() != null && !"".equals(m_request.getHeader().trim())){
-				response.append("\n" + Messages.getString("header") + " :\n" + m_request.getHeader().trim());
-			}
-			m_messageOrg = response.toString();
+		catch (IOException e) {
+			m_log.warn("fail to close HttpClient : " + e.getMessage(), e);
 		}
 		return result;
 	}
@@ -158,12 +165,10 @@ public class RunMonitorHttp extends RunMonitorNumericValueType {
 	 * @see com.clustercontrol.monitor.run.factory.OperationNumericValueInfo#setMonitorAdditionInfo()
 	 */
 	@Override
-	protected void setCheckInfo() throws FinderException, NamingException{
-
+	protected void setCheckInfo() throws MonitorNotFound {
 		if(m_http == null){
 			// HTTP監視情報を取得
-			m_http = MonitorHttpInfoUtil.getLocalHome().findByPrimaryKey(m_monitorId);
-
+			m_http = QueryUtil.getMonitorHttpInfoPK(m_monitorId);
 			// HTTP監視情報を設定
 			m_requestUrl = m_http.getRequestUrl().trim();
 			m_httpTimeout = m_http.getTimeout().intValue();
