@@ -23,6 +23,8 @@ import java.io.StringReader;
 import java.io.UnsupportedEncodingException;
 import java.net.URI;
 import java.net.URISyntaxException;
+import java.nio.charset.Charset;
+import java.nio.charset.UnsupportedCharsetException;
 import java.security.KeyManagementException;
 import java.security.KeyStoreException;
 import java.security.NoSuchAlgorithmException;
@@ -44,10 +46,12 @@ import javax.swing.text.html.parser.ParserDelegator;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.http.Consts;
 import org.apache.http.Header;
 import org.apache.http.HttpHost;
 import org.apache.http.HttpResponse;
 import org.apache.http.HttpStatus;
+import org.apache.http.NameValuePair;
 import org.apache.http.auth.AuthScope;
 import org.apache.http.auth.Credentials;
 import org.apache.http.auth.NTCredentials;
@@ -56,20 +60,22 @@ import org.apache.http.client.ClientProtocolException;
 import org.apache.http.client.CredentialsProvider;
 import org.apache.http.client.config.CookieSpecs;
 import org.apache.http.client.config.RequestConfig;
+import org.apache.http.client.entity.UrlEncodedFormEntity;
 import org.apache.http.client.methods.HttpGet;
 import org.apache.http.client.methods.HttpPost;
 import org.apache.http.client.methods.HttpRequestBase;
 import org.apache.http.conn.ssl.SSLConnectionSocketFactory;
 import org.apache.http.conn.ssl.SSLContextBuilder;
 import org.apache.http.conn.ssl.TrustStrategy;
-import org.apache.http.entity.StringEntity;
 import org.apache.http.impl.client.BasicCredentialsProvider;
 import org.apache.http.impl.client.CloseableHttpClient;
 import org.apache.http.impl.client.HttpClientBuilder;
 import org.apache.http.impl.client.HttpClients;
 import org.apache.http.message.BasicHeader;
+import org.apache.http.message.BasicNameValuePair;
 import org.apache.http.protocol.HTTP;
 
+import com.clustercontrol.maintenance.util.HinemosPropertyUtil;
 import com.clustercontrol.util.Messages;
 
 /**
@@ -294,8 +300,6 @@ public class GetHttpResponse implements Closeable {
 	/** ボディ取得対象のContent-Type */
 	private static final String TARGET_CONTENT_TYPE = "text";
 
-	private static final String DEFAULT_CHARSET = "utf-8";
-
 	private static final int BUFF_SIZE = 1024 * 1024;
 	private static final int BODY_MAX_SIZE = 5 * BUFF_SIZE;
 
@@ -443,9 +447,27 @@ public class GetHttpResponse implements Closeable {
 
 			HttpRequestBase request = null;
 			if (post != null && !post.isEmpty()) {
-				StringEntity entity = new StringEntity(post, DEFAULT_CHARSET);
+				List<NameValuePair> urlParameters = new ArrayList<NameValuePair>();
+				
+				for (String ss : post.split("&")) {
+					int index = ss.indexOf("=");
+					if (index <= 0) {
+						continue;
+					}
+					urlParameters.add(new BasicNameValuePair(ss.substring(0, index), ss.substring(index + 1)));
+				}
+				if (m_log.isTraceEnabled()) {
+					m_log.trace("post1=" + post + ", post2=" + urlParameters);
+				}
+				
 				HttpPost requestPost = new HttpPost(url);
-				requestPost.setEntity(entity);
+				Charset charset = Consts.UTF_8;
+				try {
+					charset = Charset.forName(HinemosPropertyUtil.getHinemosPropertyStr("monitor.http.post.charset", "UTF-8"));
+				} catch (UnsupportedCharsetException e){
+					m_log.warn("UnsupportedCharsetException " + e.getMessage());
+				}
+				requestPost.setEntity(new UrlEncodedFormEntity(urlParameters, charset));
 				requestPost.addHeader(HTTP.CONTENT_TYPE, "application/x-www-form-urlencoded");
 				request = requestPost;
 			}
