@@ -168,11 +168,6 @@ public class JschUtil {
 					throw new HinemosUnknown("Jsch command is spent too much time.");
 					
 				try { Thread.sleep(500); } catch (Exception ee) {}
-				
-				// sleep後もavailableが0以下なら、ストリームの終了と判定。scpコマンドがエラーを返す場合にはin.read()が-1を返さず、in.available()がずっと0になってしまう
-				if (in.available() <= 0) {
-					loop = false;
-				}
 			}
 		}
 		return pos >= maxSize ? buffer: Arrays.copyOfRange(buffer, 0, pos);
@@ -554,6 +549,8 @@ public class JschUtil {
 		} else if (ret != 1 && ret != 2) {
 			return new ModuleNodeResult(OkNgConstant.TYPE_OK, ret, "exitCode=" + ret);
 		} else {
+			// エラーの場合は切断する
+			channel.disconnect();
 			String message = String.format("exitCode=%d\nerr = %s", ret,
 					new String(JschUtil.getByteArray(channel, in, BUFF_SIZE, timeout)));
 			m_log.warn("checkAck : " + message);
