@@ -32,12 +32,11 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
 import com.clustercontrol.ClusterControlPlugin;
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.DataRangeConstant;
-import com.clustercontrol.bean.EndStatusConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.SizeConstant;
 import com.clustercontrol.bean.YesNoConstant;
-import com.clustercontrol.composite.action.NumberVerifyListener;
 import com.clustercontrol.composite.action.StringVerifyListener;
 import com.clustercontrol.dialog.ScopeTreeDialog;
 import com.clustercontrol.dialog.ValidateResult;
@@ -52,7 +51,7 @@ import com.clustercontrol.ws.repository.FacilityTreeItem;
 
 /**
  * コマンドタブ用のコンポジットクラスです。
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
@@ -83,14 +82,6 @@ public class CommandComposite extends Composite {
 	private Button m_allNode = null;
 	/** 正常終了するまでノードを順次リトライ用ラジオボタン */
 	private Button m_retry = null;
-	/** コマンド実行失敗時に終了する用チェックボタン */
-	private Button m_errorCondition = null;
-	/** 終了値用テキスト */
-	private Text m_errorEndValue = null;
-	/** コマンド実行失敗時に終了する用グループ */
-	private Group m_errorEndConditionGroup = null;
-	/** リトライ回数用テキスト */
-	private Text m_messageRetry;
 	/** ファシリティID */
 	private String m_facilityId = null;
 	/** スコープ */
@@ -101,13 +92,15 @@ public class CommandComposite extends Composite {
 	private Shell m_shell = null;
 	/** オーナーロールID */
 	private String m_ownerRoleId = null;
+	/** マネージャ名 */
+	private String m_managerName = null;
 
 	/**
 	 * コンストラクタ
-	 * 
+	 *
 	 * @param parent 親コンポジット
 	 * @param style スタイル
-	 * 
+	 *
 	 * @see org.eclipse.swt.SWT
 	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
 	 * @see #initialize()
@@ -130,25 +123,27 @@ public class CommandComposite extends Composite {
 		layout.fill = true;
 		this.setLayout(layout);
 
-		Composite composite = null;
 		RowLayout rowLayout = null;
 		Label label = null;
 
 		// スコープ
-		Group group = new Group(this, SWT.NONE);
-		group.setText(Messages.getString("scope"));
+		Group cmdScopeGroup = new Group(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "scope", cmdScopeGroup);
+		cmdScopeGroup.setText(Messages.getString("scope"));
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
 		rowLayout.marginWidth = 10;
 		rowLayout.marginHeight = 10;
-		group.setLayout(rowLayout);
+		cmdScopeGroup.setLayout(rowLayout);
 
-		composite = new Composite(group, SWT.NONE);
+		Composite commandComposite1 = new Composite(cmdScopeGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "command1", commandComposite1);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		m_scopeJobParam = new Button(composite, SWT.RADIO);
+		commandComposite1.setLayout(rowLayout);
+		m_scopeJobParam = new Button(commandComposite1, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "scopejob", m_scopeJobParam);
 		m_scopeJobParam.setText(Messages.getString("job.parameter") + " : ");
 		m_scopeJobParam.setLayoutData(
 				new RowData(120, SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -156,6 +151,7 @@ public class CommandComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_scopeFixedValue.setSelection(false);
 					m_scopeSelect.setEnabled(false);
@@ -168,19 +164,22 @@ public class CommandComposite extends Composite {
 
 			}
 		});
-		label = new Label(composite, SWT.LEFT);
+		label = new Label(commandComposite1, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "commandcomposite1", label);
 		label.setText(
 				SystemParameterConstant.getParamText(SystemParameterConstant.FACILITY_ID));
 		label.setLayoutData(
 				new RowData(100, SizeConstant.SIZE_LABEL_HEIGHT));
 
-		composite = new Composite(group, SWT.NONE);
+		Composite commandComposite2 = new Composite(cmdScopeGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "commandcomposite2", commandComposite2);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
+		commandComposite2.setLayout(rowLayout);
 
-		m_scopeFixedValue = new Button(composite, SWT.RADIO);
+		m_scopeFixedValue = new Button(commandComposite2, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "scopefieldvalue", m_scopeFixedValue);
 		m_scopeFixedValue.setText(Messages.getString("fixed.value") + " : ");
 		m_scopeFixedValue.setLayoutData(new RowData(120,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -188,6 +187,7 @@ public class CommandComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_scopeJobParam.setSelection(false);
 					m_scopeSelect.setEnabled(true);
@@ -200,7 +200,8 @@ public class CommandComposite extends Composite {
 
 			}
 		});
-		this.m_scope = new Text(composite, SWT.BORDER | SWT.READ_ONLY);
+		this.m_scope = new Text(commandComposite2, SWT.BORDER | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "scope", m_scope);
 		this.m_scope.setLayoutData(new RowData(200, SizeConstant.SIZE_TEXT_HEIGHT));
 		this.m_scope.setText("");
 		this.m_scope.addModifyListener(new ModifyListener(){
@@ -210,14 +211,15 @@ public class CommandComposite extends Composite {
 			}
 		});
 
-		m_scopeSelect = new Button(composite, SWT.NONE);
+		m_scopeSelect = new Button(commandComposite2, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "scopeselect", m_scopeSelect);
 		m_scopeSelect.setText(Messages.getString("refer"));
 		m_scopeSelect.setLayoutData(new RowData(80,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_scopeSelect.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
-				ScopeTreeDialog dialog = new ScopeTreeDialog(m_shell, m_ownerRoleId);
+				ScopeTreeDialog dialog = new ScopeTreeDialog(m_shell, m_managerName, m_ownerRoleId);
 				if (dialog.open() == IDialogConstants.OK_ID) {
 					FacilityTreeItem selectItem = dialog.getSelectItem();
 					FacilityInfo info = selectItem.getData();
@@ -233,36 +235,42 @@ public class CommandComposite extends Composite {
 		});
 
 		// スコープ処理
-		group = new Group(this, SWT.NONE);
-		group.setText(Messages.getString("scope.process"));
+		Group cmdScopeProcGroup = new Group(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "scopeproc", cmdScopeProcGroup);
+		cmdScopeProcGroup.setText(Messages.getString("scope.process"));
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.marginWidth = 10;
 		rowLayout.marginHeight = 10;
-		group.setLayout(rowLayout);
+		cmdScopeProcGroup.setLayout(rowLayout);
 
-		m_allNode = new Button(group, SWT.RADIO);
+		m_allNode = new Button(cmdScopeProcGroup, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "allnode", m_allNode);
 		m_allNode.setText(Messages.getString("scope.process.all.nodes"));
 		m_allNode.setLayoutData(
 				new RowData(200,SizeConstant.SIZE_BUTTON_HEIGHT));
-		m_retry = new Button(group, SWT.RADIO);
+		m_retry = new Button(cmdScopeProcGroup, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "retry", m_retry);
 		m_retry.setText(Messages.getString("scope.process.retry.nodes"));
 		m_retry.setLayoutData(
 				new RowData(300, SizeConstant.SIZE_BUTTON_HEIGHT));
 
-		composite = new Composite(this, SWT.NONE);
+		Composite commandComposite3 = new Composite(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "start", commandComposite3);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
+		commandComposite3.setLayout(rowLayout);
 
-		label = new Label(composite, SWT.NONE);
+		label = new Label(commandComposite3, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "startcommand", label);
 		label.setText(Messages.getString("start.command") + " : ");
 		label.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_LABEL_HEIGHT));
 
 		// 起動コマンド
-		this.m_startCommand = new Text(composite, SWT.BORDER);
+		this.m_startCommand = new Text(commandComposite3, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "start", m_startCommand);
 		this.m_startCommand.setLayoutData(new RowData(400,
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		this.m_startCommand.addVerifyListener(
@@ -275,21 +283,24 @@ public class CommandComposite extends Composite {
 		});
 
 		// 停止
-		group = new Group(this, SWT.NONE);
-		group.setText(Messages.getString("stop"));
+		Group cmdStopGroup = new Group(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "stop", cmdStopGroup);
+		cmdStopGroup.setText(Messages.getString("stop"));
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.marginWidth = 10;
 		rowLayout.marginHeight = 10;
-		group.setLayout(rowLayout);
+		cmdStopGroup.setLayout(rowLayout);
 
-		composite = new Composite(group, SWT.NONE);
+		Composite commandComposite4 = new Composite(cmdStopGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "destroyprocess", commandComposite4);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
+		commandComposite4.setLayout(rowLayout);
 
-		m_destroyProcess = new Button(composite, SWT.RADIO);
+		m_destroyProcess = new Button(commandComposite4, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "destroyprocess", m_destroyProcess);
 		m_destroyProcess.setText(Messages.getString("shutdown.process"));
 		m_destroyProcess.setLayoutData(
 				new RowData(190, SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -297,6 +308,7 @@ public class CommandComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_executeStopCommand.setSelection(false);
 					m_stopCommand.setEnabled(false);
@@ -310,13 +322,15 @@ public class CommandComposite extends Composite {
 			}
 		});
 
-		composite = new Composite(group, SWT.NONE);
+		Composite commandComposite5 = new Composite(cmdStopGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "stop", commandComposite5);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
+		commandComposite5.setLayout(rowLayout);
 
-		m_executeStopCommand = new Button(composite, SWT.RADIO);
+		m_executeStopCommand = new Button(commandComposite5, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "executestop", m_executeStopCommand);
 		m_executeStopCommand.setText(Messages.getString("stop.command"));
 		m_executeStopCommand.setLayoutData(
 				new RowData(120,SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -324,6 +338,7 @@ public class CommandComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_destroyProcess.setSelection(false);
 					m_stopCommand.setEnabled(true);
@@ -337,7 +352,8 @@ public class CommandComposite extends Composite {
 			}
 		});
 
-		this.m_stopCommand = new Text(composite, SWT.BORDER);
+		this.m_stopCommand = new Text(commandComposite5, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "stop", m_stopCommand);
 		this.m_stopCommand.setLayoutData(new RowData(160,
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		this.m_stopCommand.addVerifyListener(
@@ -350,21 +366,24 @@ public class CommandComposite extends Composite {
 		});
 
 		// 実効ユーザ
-		group = new Group(this, SWT.NONE);
-		group.setText(Messages.getString("effective.user"));
+		Group cmdExeUserGroup = new Group(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "cmdexeuser", cmdExeUserGroup);
+		cmdExeUserGroup.setText(Messages.getString("effective.user"));
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.marginWidth = 10;
 		rowLayout.marginHeight = 10;
-		group.setLayout(rowLayout);
+		cmdExeUserGroup.setLayout(rowLayout);
 
-		composite = new Composite(group, SWT.NONE);
+		Composite commandComposite6 = new Composite(cmdExeUserGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "agentuser", commandComposite6);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
+		commandComposite6.setLayout(rowLayout);
 
-		m_agentUser = new Button(composite, SWT.RADIO);
+		m_agentUser = new Button(commandComposite6, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "agentuser", m_agentUser);
 		m_agentUser.setText(Messages.getString("agent.user"));
 		m_agentUser.setLayoutData(
 				new RowData(190, SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -372,6 +391,7 @@ public class CommandComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_specifyUser.setSelection(false);
 					m_user.setEnabled(false);
@@ -385,13 +405,15 @@ public class CommandComposite extends Composite {
 			}
 		});
 
-		composite = new Composite(group, SWT.NONE);
+		Composite commandComposite7 = new Composite(cmdExeUserGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "specifyuser", commandComposite7);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
+		commandComposite7.setLayout(rowLayout);
 
-		m_specifyUser = new Button(composite, SWT.RADIO);
+		m_specifyUser = new Button(commandComposite7, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "specifyuser", m_specifyUser);
 		m_specifyUser.setText(Messages.getString("specified.user"));
 		m_specifyUser.setLayoutData(
 				new RowData(120, SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -399,6 +421,7 @@ public class CommandComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_agentUser.setSelection(false);
 					m_user.setEnabled(true);
@@ -412,7 +435,8 @@ public class CommandComposite extends Composite {
 			}
 		});
 
-		this.m_user = new Text(composite, SWT.BORDER);
+		this.m_user = new Text(commandComposite7, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "user", m_user);
 		this.m_user.setLayoutData(new RowData(160, SizeConstant.SIZE_TEXT_HEIGHT));
 		this.m_user.addVerifyListener(
 				new StringVerifyListener(DataRangeConstant.VARCHAR_64));
@@ -424,94 +448,17 @@ public class CommandComposite extends Composite {
 		});
 
 		//エラー時終了
-		composite = new Composite(this, SWT.NONE);
+		Composite commandComposite8 = new Composite(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "errorconfition", commandComposite8);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
-		composite.setLayout(rowLayout);
+		commandComposite8.setLayout(rowLayout);
 
-		m_errorCondition = new Button(composite, SWT.CHECK);
-		m_errorCondition.setText(Messages.getString("command.error.ended"));
-		m_errorCondition.setLayoutData(new RowData(300,
-				SizeConstant.SIZE_BUTTON_HEIGHT));
-		m_errorCondition.addSelectionListener(new SelectionListener() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				Button check = (Button) e.getSource();
-				if (check.getSelection()) {
-					m_errorEndConditionGroup.setEnabled(true);
-					m_errorEndValue.setEnabled(true);
-					m_messageRetry.setEnabled(true);
-				} else {
-					m_errorEndConditionGroup.setEnabled(false);
-					m_errorEndValue.setEnabled(false);
-					m_messageRetry.setEnabled(false);
-				}
-				update();
-			}
-
-			@Override
-			public void widgetDefaultSelected(SelectionEvent e) {
-
-			}
-		});
-
-		m_errorEndConditionGroup = new Group(this, SWT.NONE);
-		rowLayout = new RowLayout();
-		rowLayout.type = SWT.HORIZONTAL;
-		rowLayout.marginWidth = 10;
-		rowLayout.marginHeight = 10;
-		rowLayout.spacing = 10;
-		m_errorEndConditionGroup.setLayout(rowLayout);
-
-		composite = new Composite(m_errorEndConditionGroup, SWT.NONE);
-		rowLayout = new RowLayout();
-		rowLayout.type = SWT.HORIZONTAL;
-		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		Label messageRetryTitle = new Label(composite, SWT.LEFT);
-		messageRetryTitle.setText(Messages.getString("job.retries") + " : ");
-		messageRetryTitle.setLayoutData(new RowData(90,
-				SizeConstant.SIZE_LABEL_HEIGHT));
-		m_messageRetry= new Text(composite, SWT.BORDER);
-		m_messageRetry.setLayoutData(new RowData(100, SizeConstant.SIZE_TEXT_HEIGHT));
-		m_messageRetry.addVerifyListener(
-				new NumberVerifyListener(DataRangeConstant.SMALLINT_LOW, DataRangeConstant.SMALLINT_HIGH));
-		m_messageRetry.addModifyListener(
-				new ModifyListener(){
-					@Override
-					public void modifyText(ModifyEvent arg0) {
-						update();
-					}
-				}
-				);
-
-		composite = new Composite(m_errorEndConditionGroup, SWT.NONE);
-		rowLayout = new RowLayout();
-		rowLayout.type = SWT.HORIZONTAL;
-		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		Label skipEndValueTitle = new Label(composite, SWT.RIGHT);
-		skipEndValueTitle.setText(Messages.getString("end.value") + " : ");
-		skipEndValueTitle.setLayoutData(new RowData(70,
-				SizeConstant.SIZE_LABEL_HEIGHT));
-		m_errorEndValue = new Text(composite, SWT.BORDER);
-		m_errorEndValue.setLayoutData(new RowData(100,
-				SizeConstant.SIZE_TEXT_HEIGHT));
-		m_errorEndValue.addVerifyListener(
-				new NumberVerifyListener(DataRangeConstant.SMALLINT_LOW, DataRangeConstant.SMALLINT_HIGH));
-		m_errorEndValue.addModifyListener(
-				new ModifyListener(){
-					@Override
-					public void modifyText(ModifyEvent arg0) {
-						update();
-					}
-				}
-				);
 	}
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	@Override
 	public void update(){
@@ -536,21 +483,11 @@ public class CommandComposite extends Composite {
 		}else{
 			this.m_user.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
 		}
-		if(m_errorCondition.getSelection() && "".equals(m_errorEndValue.getText())) {
-			this.m_errorEndValue.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
-		}else{
-			this.m_errorEndValue.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-		}
-		if("".equals(this.m_messageRetry.getText())){
-			this.m_messageRetry.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
-		}else{
-			this.m_messageRetry.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-		}
 	}
 
 	/**
 	 * ジョブコマンド情報をコンポジットに反映する。
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.JobCommandInfo
 	 */
 	public void reflectCommandInfo() {
@@ -569,10 +506,6 @@ public class CommandComposite extends Composite {
 		m_specifyUser.setSelection(false);
 		m_user.setText("");
 		m_user.setEnabled(false);
-		m_messageRetry.setText("10");
-		m_errorCondition.setSelection(true);
-		m_errorEndValue.setText(String
-				.valueOf(EndStatusConstant.INITIAL_VALUE_ABNORMAL));
 
 		if (m_execute != null) {
 			//スコープ設定
@@ -635,16 +568,6 @@ public class CommandComposite extends Composite {
 				m_user.setText(m_execute.getUser());
 			}
 
-			//リトライ回数
-			m_messageRetry.setText(String.valueOf(m_execute.getMessageRetry()));
-
-			//エラー時終了
-			m_errorCondition.setSelection(YesNoConstant.typeToBoolean(m_execute
-					.getErrorEndFlg()));
-
-			//エラー時終了値
-			m_errorEndValue.setText(String
-					.valueOf(m_execute.getErrorEndValue()));
 		}
 
 		//スコープ
@@ -653,20 +576,11 @@ public class CommandComposite extends Composite {
 		} else {
 			m_scopeSelect.setEnabled(true);
 		}
-
-		//エラー時終了
-		if (m_errorCondition.getSelection()) {
-			m_errorEndValue.setEnabled(true);
-			m_messageRetry.setEnabled(true);
-		} else {
-			m_errorEndValue.setEnabled(false);
-			m_messageRetry.setEnabled(false);
-		}
 	}
 
 	/**
 	 * ジョブコマンド情報を設定する。
-	 * 
+	 *
 	 * @param execute ジョブコマンド情報
 	 */
 	public void setCommandInfo(JobCommandInfo execute) {
@@ -675,7 +589,7 @@ public class CommandComposite extends Composite {
 
 	/**
 	 * ジョブコマンド情報を返す。
-	 * 
+	 *
 	 * @return ジョブコマンド情報
 	 */
 	public JobCommandInfo getCommandInfo() {
@@ -684,9 +598,9 @@ public class CommandComposite extends Composite {
 
 	/**
 	 * コンポジットの情報から、ジョブコマンド情報を作成する。
-	 * 
+	 *
 	 * @return 入力値の検証結果
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.JobCommandInfo
 	 */
 	public ValidateResult createCommandInfo() {
@@ -767,52 +681,6 @@ public class CommandComposite extends Composite {
 			}
 		}
 
-		//リトライ回数
-		try {
-			if (m_messageRetry.getText().length() > 0) {
-				m_execute.setMessageRetry(Integer.parseInt(m_messageRetry.getText()));
-			} else {
-				result = new ValidateResult();
-				result.setValid(false);
-				result.setID(Messages.getString("message.hinemos.1"));
-				//FIXME
-				result.setMessage(Messages.getString("message.job.87"));
-				return result;
-			}
-		} catch(NumberFormatException e) {
-			result = new ValidateResult();
-			result.setValid(false);
-			result.setID(Messages.getString("message.hinemos.1"));
-			result.setMessage(Messages.getString("message.job.87"));
-			return result;
-		}
-
-		//エラー時終了
-		m_execute.setErrorEndFlg(YesNoConstant.booleanToType(m_errorCondition
-				.getSelection()));
-
-		//エラー時終了値取得
-		try {
-			if (m_errorEndValue.getText().length() > 0) {
-				m_execute.setErrorEndValue(Integer.parseInt(m_errorEndValue
-						.getText()));
-			} else {
-				result = new ValidateResult();
-				result.setValid(false);
-				result.setID(Messages.getString("message.hinemos.1"));
-				result.setMessage(Messages.getString("message.job.21"));
-				return result;
-			}
-		} catch (NumberFormatException e) {
-			if (m_execute.getErrorEndValue() == YesNoConstant.TYPE_YES) {
-				result = new ValidateResult();
-				result.setValid(false);
-				result.setID(Messages.getString("message.hinemos.1"));
-				result.setMessage(Messages.getString("message.job.21"));
-				return result;
-			}
-		}
-
 		return null;
 	}
 
@@ -821,7 +689,21 @@ public class CommandComposite extends Composite {
 		this.m_scope.setText("");
 		this.m_facilityId = null;
 	}
-	
+
+	/**
+	 * @return the m_managerName
+	 */
+	public String getManagerName() {
+		return m_managerName;
+	}
+
+	/**
+	 * @param m_managerName the m_managerName to set
+	 */
+	public void setManagerName(String m_managerName) {
+		this.m_managerName = m_managerName;
+	}
+
 	/**
 	 * 読み込み専用時にグレーアウトします。
 	 */
@@ -841,8 +723,5 @@ public class CommandComposite extends Composite {
 		m_scopeSelect.setEnabled(enabled);
 		m_allNode.setEnabled(enabled);
 		m_retry.setEnabled(enabled);
-		m_errorCondition.setEnabled(enabled);
-		m_errorEndValue.setEnabled(enabled);
-		m_messageRetry.setEnabled(enabled);
 	}
-}
\ No newline at end of file
+}
