@@ -47,11 +47,12 @@ import com.clustercontrol.jobmanagement.bean.ConditionTypeConstant;
 import com.clustercontrol.jobmanagement.bean.OperationConstant;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.TimeTo48hConverter;
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.ws.jobmanagement.JobWaitRuleInfo;
 
 /**
  * 終了遅延タブ用のコンポジットクラスです。
- * 
+ *
  * @version 2.1.0
  * @since 2.1.0
  */
@@ -95,10 +96,10 @@ public class EndDelayComposite extends Composite {
 
 	/**
 	 * コンストラクタ
-	 * 
+	 *
 	 * @param parent 親コンポジット
 	 * @param style スタイル
-	 * 
+	 *
 	 * @see org.eclipse.swt.SWT
 	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
 	 * @see #initialize()
@@ -120,17 +121,19 @@ public class EndDelayComposite extends Composite {
 		layout.fill = true;
 		this.setLayout(layout);
 
-		Composite composite = null;
 		RowLayout rowLayout = null;
 		Label label = null;
 
 		//終了遅延
-		composite = new Composite(this, SWT.NONE);
+		Composite endDelayComposite = new Composite(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "endDelay", endDelayComposite);
+		//endDelayComposite.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeConditionComposite");
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
-		composite.setLayout(rowLayout);
+		endDelayComposite.setLayout(rowLayout);
 
-		m_endDelayCondition = new Button(composite, SWT.CHECK);
+		m_endDelayCondition = new Button(endDelayComposite, SWT.CHECK);
+		//m_endDelayCondition.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeConditionCheck");
 		m_endDelayCondition.setText(Messages.getString("end.delay"));
 		m_endDelayCondition.setLayoutData(new RowData(200,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -138,7 +141,7 @@ public class EndDelayComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
-
+				WidgetTestUtil.setTestId(this, null, check);
 				//終了遅延コンポジットのオブジェクトの使用不可を設定
 				setEndDelayEnabled(check.getSelection());
 				update();
@@ -150,7 +153,9 @@ public class EndDelayComposite extends Composite {
 			}
 		});
 
-		m_endDelayConditionGroup = new Group(composite, SWT.NONE);
+		m_endDelayConditionGroup = new Group(endDelayComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "condition", m_endDelayConditionGroup);
+		//m_endDelayConditionGroup.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeConditionGroup");
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
 		rowLayout.marginWidth = 5;
@@ -159,22 +164,26 @@ public class EndDelayComposite extends Composite {
 		m_endDelayConditionGroup.setLayout(rowLayout);
 
 		//判定対象一覧
-		Group group = new Group(m_endDelayConditionGroup, SWT.NONE);
-		group.setText(Messages.getString("object.list"));
+		Group endDelayGroup = new Group(m_endDelayConditionGroup, SWT.NONE);
+		//endDelayGroup.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeObjectListGroup");
+		endDelayGroup.setText(Messages.getString("object.list"));
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
 		rowLayout.marginWidth = 5;
 		rowLayout.marginHeight = 5;
 		rowLayout.spacing = 1;
-		group.setLayout(rowLayout);
+		endDelayGroup.setLayout(rowLayout);
 
 		//セッション開始後の時間
-		composite = new Composite(group, SWT.NONE);
+		Composite endDelayAfterSessionComposite = new Composite(endDelayGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "aftersession", endDelayAfterSessionComposite);
+		////endDelayAfterSessionComposite.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeAfterSessionComposite");
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		m_sessionCondition = new Button(composite, SWT.CHECK);
+		endDelayAfterSessionComposite.setLayout(rowLayout);
+		m_sessionCondition = new Button(endDelayAfterSessionComposite, SWT.CHECK);
+		//m_sessionCondition.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeSessionConditionCheck");
 		m_sessionCondition.setText(Messages.getString("time.after.session.start") + " : ");
 		m_sessionCondition.setLayoutData(new RowData(220,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -182,6 +191,7 @@ public class EndDelayComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_sessionValue.setEnabled(true);
 				} else {
@@ -196,7 +206,8 @@ public class EndDelayComposite extends Composite {
 			}
 		});
 		//セッション開始後の時間の値
-		m_sessionValue = new Text(composite, SWT.BORDER);
+		m_sessionValue = new Text(endDelayAfterSessionComposite, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, null, m_sessionValue);
 		m_sessionValue.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		m_sessionValue.addVerifyListener(
@@ -211,12 +222,15 @@ public class EndDelayComposite extends Composite {
 				);
 
 		//ジョブ開始後の時間
-		composite = new Composite(group, SWT.NONE);
+		Composite endDelayAfterJobComposite = new Composite(endDelayGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "afterjob", endDelayAfterJobComposite);
+		//endDelayAfterJobComposite.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeAfterJobComposite");
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		m_jobCondition = new Button(composite, SWT.CHECK);
+		endDelayAfterJobComposite.setLayout(rowLayout);
+		m_jobCondition = new Button(endDelayAfterJobComposite, SWT.CHECK);
+		//m_jobCondition.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeJobConditionCheck");
 		m_jobCondition.setText(Messages.getString("time.after.job.start") + " : ");
 		m_jobCondition.setLayoutData(new RowData(220,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -224,6 +238,7 @@ public class EndDelayComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_jobValue.setEnabled(true);
 				} else {
@@ -238,7 +253,9 @@ public class EndDelayComposite extends Composite {
 			}
 		});
 		//ジョブ開始後の時間の値
-		m_jobValue = new Text(composite, SWT.BORDER);
+		m_jobValue = new Text(endDelayAfterJobComposite, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, null, m_jobValue);
+		//m_jobValue.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeJobValueText");
 		m_jobValue.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		m_jobValue.addVerifyListener(
@@ -253,12 +270,15 @@ public class EndDelayComposite extends Composite {
 				);
 
 		//時刻
-		composite = new Composite(group, SWT.NONE);
+		Composite endAfterJobComposite = new Composite(endDelayGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "endafterjob", endAfterJobComposite);
+		//endAfterJobComposite.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeTimeComposite");
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		m_timeCondition = new Button(composite, SWT.CHECK);
+		endAfterJobComposite.setLayout(rowLayout);
+		m_timeCondition = new Button(endAfterJobComposite, SWT.CHECK);
+		//m_timeCondition.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeTimeConditionCheck");
 		m_timeCondition.setText(Messages.getString("wait.rule.time.example") + " : ");
 		m_timeCondition.setLayoutData(new RowData(220,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -266,6 +286,7 @@ public class EndDelayComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_timeValue.setEnabled(true);
 				} else {
@@ -280,7 +301,8 @@ public class EndDelayComposite extends Composite {
 			}
 		});
 		//時刻の値
-		m_timeValue = new Text(composite, SWT.BORDER);
+		m_timeValue = new Text(endAfterJobComposite, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, null, m_timeValue);
 		m_timeValue.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		m_timeValue.addVerifyListener(new TimeVerifyListener());
@@ -294,46 +316,59 @@ public class EndDelayComposite extends Composite {
 				);
 
 		//判定対象の条件関係
-		group = new Group(m_endDelayConditionGroup, SWT.NONE);
-		group.setText(Messages.getString("condition.between.objects"));
+		Group endDelayBetweenGroup = new Group(m_endDelayConditionGroup, SWT.NONE);
+		//endDelayBetweenGroup.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeBetweenGroup");
+		endDelayBetweenGroup.setText(Messages.getString("condition.between.objects"));
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
 		rowLayout.marginWidth = 5;
 		rowLayout.marginHeight = 5;
 		rowLayout.spacing = 1;
-		group.setLayout(rowLayout);
+		endDelayBetweenGroup.setLayout(rowLayout);
 
-		composite = new Composite(group, SWT.NONE);
+		Composite endDelayConditionComposite= new Composite(endDelayBetweenGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "condition", endDelayConditionComposite);
+		//endDelayConditionComposite.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeConditionComposite");
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		m_andCondition = new Button(composite, SWT.RADIO);
+		endDelayConditionComposite.setLayout(rowLayout);
+		m_andCondition = new Button(endDelayConditionComposite, SWT.RADIO);
+		//m_andCondition.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeAndConditionRadio");
 		m_andCondition.setText(Messages.getString("and"));
 		m_andCondition.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
-		m_orCondition = new Button(composite, SWT.RADIO);
+		m_orCondition = new Button(endDelayConditionComposite, SWT.RADIO);
+		//m_orCondition.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeOrConditionRadio");
 		m_orCondition.setText(Messages.getString("or"));
 		m_orCondition.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
-		label = new Label(composite, SWT.NONE);
+		label = new Label(endDelayConditionComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "enddelaycondition", label);
 		label.setLayoutData(new RowData(77, SizeConstant.SIZE_LABEL_HEIGHT));
 
-		composite = new Composite(m_endDelayConditionGroup, SWT.NONE);
+		Composite endDelayComposite2 = new Composite(m_endDelayConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "2", endDelayComposite2);
+		//endDelayComposite2.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeDummyComposite");
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		label = new Label(composite, SWT.NONE);
+		endDelayComposite2.setLayout(rowLayout);
+		label = new Label(endDelayComposite2, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "enddelaycomposite", label);
 		label.setLayoutData(new RowData(5, SizeConstant.SIZE_LABEL_HEIGHT));
 
 		//通知
-		composite = new Composite(m_endDelayConditionGroup, SWT.NONE);
+		Composite endDelayNotificationComposite = new Composite(m_endDelayConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "notification", endDelayNotificationComposite);
+		//endDelayNotificationComposite.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeNotificationComposite");
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		m_notifyCondition = new Button(composite, SWT.CHECK);
+		endDelayNotificationComposite.setLayout(rowLayout);
+		m_notifyCondition = new Button(endDelayNotificationComposite, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "notification", m_notifyCondition);
+		//m_notifyCondition.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeNotifyConditionCheck");
 		m_notifyCondition.setText(Messages.getString("notify.attribute") + " : ");
 		m_notifyCondition.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -341,6 +376,7 @@ public class EndDelayComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_notifyPriority.setEnabled(true);
 				} else {
@@ -354,7 +390,9 @@ public class EndDelayComposite extends Composite {
 			}
 		});
 		//通知の重要度
-		m_notifyPriority = new Combo(composite, SWT.CENTER | SWT.READ_ONLY);
+		m_notifyPriority = new Combo(endDelayNotificationComposite, SWT.CENTER | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "notifyPriority", m_notifyPriority);
+		//m_notifyPriority.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeNotifyPriorityCombo");
 		m_notifyPriority.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_COMBO_HEIGHT));
 		m_notifyPriority.add(PriorityConstant.STRING_INFO);
@@ -363,12 +401,15 @@ public class EndDelayComposite extends Composite {
 		m_notifyPriority.add(PriorityConstant.STRING_UNKNOWN);
 
 		//操作
-		composite = new Composite(m_endDelayConditionGroup, SWT.NONE);
+		Composite endDelayOptComposite = new Composite(m_endDelayConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "opt", endDelayOptComposite);
+		//endDelayOptComposite.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeOptComposite");
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		m_operationCondition = new Button(composite, SWT.CHECK);
+		endDelayOptComposite.setLayout(rowLayout);
+		m_operationCondition = new Button(endDelayOptComposite, SWT.CHECK);
+		//m_operationCondition.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeOptConditionCheck");
 		m_operationCondition.setText(Messages.getString("operations"));
 		m_operationCondition.setLayoutData(new RowData(220,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -376,6 +417,7 @@ public class EndDelayComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_operationType.setEnabled(true);
 
@@ -407,6 +449,7 @@ public class EndDelayComposite extends Composite {
 		});
 
 		m_operationConditionGroup = new Group(m_endDelayConditionGroup, SWT.NONE);
+		//m_operationConditionGroup.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeOptConditionGroup");
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
 		rowLayout.marginWidth = 5;
@@ -415,16 +458,20 @@ public class EndDelayComposite extends Composite {
 		m_operationConditionGroup.setLayout(rowLayout);
 
 		//操作の名前
-		composite = new Composite(m_operationConditionGroup, SWT.NONE);
+		Composite endDelayOptNameComposite = new Composite(m_operationConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "optname", endDelayOptNameComposite);
+		//endDelayOptNameComposite.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeOptNameComposite");
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		label = new Label(composite, SWT.NONE);
+		endDelayOptNameComposite.setLayout(rowLayout);
+		label = new Label(endDelayOptNameComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "name", label);
 		label.setText(Messages.getString("name") + " : ");
 		label.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_LABEL_HEIGHT));
-		m_operationType = new Combo(composite, SWT.CENTER | SWT.READ_ONLY);
+		m_operationType = new Combo(endDelayOptNameComposite, SWT.CENTER | SWT.READ_ONLY);
+		//m_operationType.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeOptTypeCombo");
 		m_operationType.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_COMBO_HEIGHT));
 		if(!isFileJob){
@@ -436,7 +483,7 @@ public class EndDelayComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Combo check = (Combo) e.getSource();
-
+				WidgetTestUtil.setTestId(this, null, check);
 				int type = getSelectOperationName(check);
 				if (type == OperationConstant.TYPE_STOP_AT_ONCE) {
 					m_operationStatus.setEnabled(false);
@@ -457,18 +504,21 @@ public class EndDelayComposite extends Composite {
 			}
 		});
 
-
 		//操作の終了状態
-		composite = new Composite(m_operationConditionGroup, SWT.NONE);
+		Composite endDelayOptEndStatusComposite = new Composite(m_operationConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "optendstatus", endDelayOptEndStatusComposite);
+		//endDelayOptEndStatusComposite.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeOptEndStatusComposite");
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		label = new Label(composite, SWT.NONE);
+		endDelayOptEndStatusComposite.setLayout(rowLayout);
+		label = new Label(endDelayOptEndStatusComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "endstatus", label);
 		label.setText(Messages.getString("end.status") + " : ");
 		label.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_LABEL_HEIGHT));
-		m_operationStatus = new Combo(composite, SWT.CENTER | SWT.READ_ONLY);
+		m_operationStatus = new Combo(endDelayOptEndStatusComposite, SWT.CENTER | SWT.READ_ONLY);
+		//m_operationStatus.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeOptStatusCombo");
 		m_operationStatus.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_COMBO_HEIGHT));
 		m_operationStatus.add(EndStatusConstant.STRING_NORMAL);
@@ -476,16 +526,20 @@ public class EndDelayComposite extends Composite {
 		m_operationStatus.add(EndStatusConstant.STRING_ABNORMAL);
 
 		//操作の終了値
-		composite = new Composite(m_operationConditionGroup, SWT.NONE);
+		Composite endDelayOptEndValueComposite = new Composite(m_operationConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "optendvalue", endDelayOptEndValueComposite);
+		//endDelayOptEndValueComposite.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "endDelayCompositeOptEndValueComposite");
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		label = new Label(composite, SWT.NONE);
+		endDelayOptEndValueComposite.setLayout(rowLayout);
+		label = new Label(endDelayOptEndValueComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "endvalue", label);
 		label.setText(Messages.getString("end.value") + " : ");
 		label.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_LABEL_HEIGHT));
-		m_operationValue = new Text(composite, SWT.BORDER);
+		m_operationValue = new Text(endDelayOptEndValueComposite, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, null, m_operationValue);
 		m_operationValue.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		m_operationValue.addVerifyListener(
@@ -499,7 +553,8 @@ public class EndDelayComposite extends Composite {
 				}
 				);
 
-		label = new Label(composite, SWT.NONE);
+		label = new Label(endDelayOptEndValueComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "enddelayoptendvalue", label);
 		label.setLayoutData(new RowData(70, SizeConstant.SIZE_LABEL_HEIGHT));
 	}
 
@@ -535,7 +590,7 @@ public class EndDelayComposite extends Composite {
 
 	/**
 	 * ジョブ待ち条件情報をコンポジットに反映します。
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.JobWaitRuleInfo
 	 */
 	public void reflectWaitRuleInfo() {
@@ -603,7 +658,7 @@ public class EndDelayComposite extends Composite {
 
 	/**
 	 * ジョブ待ち条件情報を設定します。
-	 * 
+	 *
 	 * @param start ジョブ待ち条件情報
 	 */
 	public void setWaitRuleInfo(JobWaitRuleInfo start) {
@@ -612,7 +667,7 @@ public class EndDelayComposite extends Composite {
 
 	/**
 	 * ジョブ待ち条件情報を返します。
-	 * 
+	 *
 	 * @return ジョブ待ち条件情報
 	 */
 	public JobWaitRuleInfo getWaitRuleInfo() {
@@ -621,9 +676,9 @@ public class EndDelayComposite extends Composite {
 
 	/**
 	 * コンポジットの情報から、ジョブ待ち条件情報を作成する。
-	 * 
+	 *
 	 * @return 入力値の検証結果
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.JobWaitRuleInfo
 	 */
 	public ValidateResult createWaitRuleInfo() {
@@ -757,7 +812,7 @@ public class EndDelayComposite extends Composite {
 
 	/**
 	 * コンポジットに配置したオブジェクトの使用可・使用不可を設定します。
-	 * 
+	 *
 	 * @param enabled true：終了遅延を使用する、false：終了遅延を使用しない
 	 */
 	private void setEndDelayEnabled(boolean enabled) {
@@ -855,10 +910,10 @@ public class EndDelayComposite extends Composite {
 
 	/**
 	 * 指定した重要度に該当する終了遅延通知重要度用コンボボックスの項目を選択します。
-	 * 
+	 *
 	 * @param combo 終了遅延通知重要度用コンボボックスのインスタンス
 	 * @param priority 重要度
-	 * 
+	 *
 	 * @see com.clustercontrol.bean.PriorityConstant
 	 */
 	private void setSelectPriority(Combo combo, int priority) {
@@ -887,10 +942,10 @@ public class EndDelayComposite extends Composite {
 
 	/**
 	 * 終了遅延通知重要度用コンボボックスにて選択している重要度を取得します。
-	 * 
+	 *
 	 * @param combo 終了遅延通知重要度用コンボボックスのインスタンス
 	 * @return 重要度
-	 * 
+	 *
 	 * @see com.clustercontrol.bean.PriorityConstant
 	 */
 	private int getSelectPriority(Combo combo) {
@@ -913,10 +968,10 @@ public class EndDelayComposite extends Composite {
 
 	/**
 	 * 指定したジョブ操作種別に該当する終了遅延操作用コンボボックスの項目を選択しまう。
-	 * 
+	 *
 	 * @param combo コンボボックスのインスタンス
 	 * @param operation ジョブ操作種別
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.OperationConstant
 	 */
 	private void setSelectOperationName(Combo combo, int operation) {
@@ -941,10 +996,10 @@ public class EndDelayComposite extends Composite {
 
 	/**
 	 * 終了遅延操作用コンボボックスにて選択しているジョブ操作種別を取得します。
-	 * 
+	 *
 	 * @param combo コンボボックスのインスタンス
 	 * @return ジョブ操作種別
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.OperationConstant
 	 */
 	private int getSelectOperationName(Combo combo) {
@@ -963,7 +1018,7 @@ public class EndDelayComposite extends Composite {
 
 	/**
 	 * 指定した重要度に該当する終了遅延終了状態用コンボボックスの項目を選択します。
-	 * 
+	 *
 	 */
 	private void setSelectOperationEndStatus(Combo combo, int status) {
 		String select = "";
@@ -981,13 +1036,13 @@ public class EndDelayComposite extends Composite {
 
 	/**
 	 * 終了遅延通知終了状態用コンボボックスにて選択している項目を取得します。
-	 * 
+	 *
 	 */
 	private int getSelectOperationEndStatus(Combo combo) {
 		String select = combo.getText();
 		return EndStatusConstant.stringToType(select);
 	}
-	
+
 	/**
 	 * 読み込み専用時にグレーアウトします。
 	 */
@@ -1010,4 +1065,4 @@ public class EndDelayComposite extends Composite {
 		m_operationValue.setEnabled(enabled);
 		m_endDelayCondition.setEnabled(enabled);
 	}
-}
\ No newline at end of file
+}
