@@ -36,10 +36,11 @@ import com.clustercontrol.composite.action.NumberVerifyListener;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.jobmanagement.JobEndStatusInfo;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * 終了状態タブ用のコンポジットクラスです。
- * 
+ *
  * @version 4.0.0
  * @since 1.0.0
  */
@@ -63,10 +64,10 @@ public class EndStatusComposite extends Composite {
 
 	/**
 	 * コンストラクタ
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param style スタイル
-	 * 
+	 *
 	 * @see org.eclipse.swt.SWT
 	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
 	 * @see #initialize()
@@ -88,42 +89,48 @@ public class EndStatusComposite extends Composite {
 		layout.fill = true;
 		this.setLayout(layout);
 
-		Composite composite = null;
 		RowLayout rowLayout = null;
 
-		composite = new Composite(this, SWT.NONE);
+		Composite endStatusComposite = new Composite(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "dummy", endStatusComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
+		endStatusComposite.setLayout(rowLayout);
 
-		Label dummy1 = new Label(composite, SWT.NONE);
+		Label dummy1 = new Label(endStatusComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "dymmy1", dummy1);
 		dummy1.setLayoutData(new RowData(60, SizeConstant.SIZE_LABEL_HEIGHT));
 
-		Label endValueTitle = new Label(composite, SWT.CENTER);
+		Label endValueTitle = new Label(endStatusComposite, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "endvalue", endValueTitle);
 		endValueTitle.setText(Messages.getString("end.value"));
 		endValueTitle.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_LABEL_HEIGHT));
 
-		Label rangeTitle = new Label(composite, SWT.CENTER);
+		Label rangeTitle = new Label(endStatusComposite, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "rangeendvalue", rangeTitle);
 		rangeTitle.setText(Messages.getString("range.end.value"));
 		rangeTitle.setLayoutData(new RowData(240,
 				SizeConstant.SIZE_LABEL_HEIGHT));
 
 		//正常
-		composite = new Composite(this, SWT.NONE);
+		Composite endStatusNormComposite = new Composite(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "normal", endStatusNormComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
+		endStatusNormComposite.setLayout(rowLayout);
 
-		Label normalTitle = new Label(composite, SWT.CENTER);
+		Label normalTitle = new Label(endStatusNormComposite, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "normaltitle", normalTitle);
 		normalTitle.setText(EndStatusConstant.STRING_NORMAL + " : ");
 		normalTitle.setLayoutData(new RowData(60,
 				SizeConstant.SIZE_LABEL_HEIGHT));
 		normalTitle.setBackground(EndStatusColorConstant.COLOR_NORMAL);
 
-		this.m_normalValue = new Text(composite, SWT.BORDER);
+		this.m_normalValue = new Text(endStatusNormComposite, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "normalvalue", m_normalValue);
 		this.m_normalValue.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		this.m_normalValue.addVerifyListener(
@@ -135,7 +142,8 @@ public class EndStatusComposite extends Composite {
 			}
 		});
 
-		this.m_normalStartRange = new Text(composite, SWT.BORDER);
+		this.m_normalStartRange = new Text(endStatusNormComposite, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "startrange", m_normalStartRange);
 		this.m_normalStartRange.setText("");
 		this.m_normalStartRange.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_TEXT_HEIGHT));
@@ -148,11 +156,13 @@ public class EndStatusComposite extends Composite {
 			}
 		});
 
-		Label normalTo = new Label(composite, SWT.CENTER);
+		Label normalTo = new Label(endStatusNormComposite, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "normalto", normalTo);
 		normalTo.setText("-");
 		normalTo.setLayoutData(new RowData(20, SizeConstant.SIZE_LABEL_HEIGHT));
 
-		this.m_normalEndRange = new Text(composite, SWT.BORDER);
+		this.m_normalEndRange = new Text(endStatusNormComposite, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "endrange", m_normalEndRange);
 		this.m_normalEndRange.setText("");
 		this.m_normalEndRange.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_TEXT_HEIGHT));
@@ -166,19 +176,22 @@ public class EndStatusComposite extends Composite {
 		});
 
 		//警告
-		composite = new Composite(this, SWT.NONE);
+		Composite endStatusWarnComposite = new Composite(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "warn", endStatusWarnComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
+		endStatusWarnComposite.setLayout(rowLayout);
 
-		Label warningTitle = new Label(composite, SWT.CENTER);
+		Label warningTitle = new Label(endStatusWarnComposite, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "warningtitle", warningTitle);
 		warningTitle.setText(EndStatusConstant.STRING_WARNING + " : ");
 		warningTitle.setLayoutData(new RowData(60,
 				SizeConstant.SIZE_LABEL_HEIGHT));
 		warningTitle.setBackground(EndStatusColorConstant.COLOR_WARNING);
 
-		this.m_warningValue = new Text(composite, SWT.BORDER);
+		this.m_warningValue = new Text(endStatusWarnComposite, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "warningvalue", m_warningValue);
 		this.m_warningValue.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		this.m_warningValue.addVerifyListener(
@@ -190,7 +203,8 @@ public class EndStatusComposite extends Composite {
 			}
 		});
 
-		this.m_warningStartRange = new Text(composite, SWT.BORDER);
+		this.m_warningStartRange = new Text(endStatusWarnComposite, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "warningstartrange", m_warningStartRange);
 		this.m_warningStartRange.setText("");
 		this.m_warningStartRange.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_TEXT_HEIGHT));
@@ -203,12 +217,14 @@ public class EndStatusComposite extends Composite {
 			}
 		});
 
-		Label warningTo = new Label(composite, SWT.CENTER);
+		Label warningTo = new Label(endStatusWarnComposite, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "warningto", warningTo);
 		warningTo.setText("-");
 		warningTo
 		.setLayoutData(new RowData(20, SizeConstant.SIZE_LABEL_HEIGHT));
 
-		this.m_warningEndRange = new Text(composite, SWT.BORDER);
+		this.m_warningEndRange = new Text(endStatusWarnComposite, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "warningendrange", m_warningEndRange);
 		this.m_warningEndRange.setText("");
 		this.m_warningEndRange.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_TEXT_HEIGHT));
@@ -222,19 +238,22 @@ public class EndStatusComposite extends Composite {
 		});
 
 		//異常
-		composite = new Composite(this, SWT.NONE);
+		Composite endStatusAbnormalComposite = new Composite(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "abnormal", endStatusAbnormalComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
+		endStatusAbnormalComposite.setLayout(rowLayout);
 
-		Label abnormalTitle = new Label(composite, SWT.CENTER);
+		Label abnormalTitle = new Label(endStatusAbnormalComposite, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "abnormaltitle", abnormalTitle);
 		abnormalTitle.setText(EndStatusConstant.STRING_ABNORMAL + " : ");
 		abnormalTitle.setLayoutData(new RowData(60,
 				SizeConstant.SIZE_LABEL_HEIGHT));
 		abnormalTitle.setBackground(EndStatusColorConstant.COLOR_ABNORMAL);
 
-		this.m_abnormalValue = new Text(composite, SWT.BORDER);
+		this.m_abnormalValue = new Text(endStatusAbnormalComposite, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "abnormalvalue", m_abnormalValue);
 		this.m_abnormalValue.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		this.m_abnormalValue.addVerifyListener(
@@ -246,7 +265,8 @@ public class EndStatusComposite extends Composite {
 			}
 		});
 
-		Label abnormalMessage = new Label(composite, SWT.CENTER);
+		Label abnormalMessage = new Label(endStatusAbnormalComposite, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "abnormalmessage", abnormalMessage);
 		abnormalMessage.setText(Messages.getString("other"));
 		abnormalMessage.setLayoutData(new RowData(240,
 				SizeConstant.SIZE_LABEL_HEIGHT));
@@ -254,7 +274,7 @@ public class EndStatusComposite extends Composite {
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	@Override
 	public void update(){
@@ -298,7 +318,7 @@ public class EndStatusComposite extends Composite {
 
 	/**
 	 * ジョブ終了状態情報をコンポジットに反映します。
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.JobEndStatusInfo
 	 */
 	public void reflectEndInfo() {
@@ -365,7 +385,7 @@ public class EndStatusComposite extends Composite {
 
 	/**
 	 * ジョブ終了状態情報を設定します。
-	 * 
+	 *
 	 * @param end ジョブ終了状態情報のリスト
 	 */
 	public void setEndInfo(List<JobEndStatusInfo> end) {
@@ -374,7 +394,7 @@ public class EndStatusComposite extends Composite {
 
 	/**
 	 * ジョブ終了状態情報を返します。
-	 * 
+	 *
 	 * @return ジョブ終了状態情報のリスト
 	 */
 	public List<JobEndStatusInfo> getEndInfo() {
@@ -383,12 +403,11 @@ public class EndStatusComposite extends Composite {
 
 	/**
 	 * コンポジットの情報から、ジョブ終了状態情報を作成する。
-	 * 
+	 *
 	 * @return 入力値の検証結果
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.JobEndStatusInfo
 	 */
-	@SuppressWarnings("unchecked")
 	public ValidateResult createEndInfo() {
 		ValidateResult result = null;
 
@@ -505,7 +524,7 @@ public class EndStatusComposite extends Composite {
 
 		return null;
 	}
-	
+
 	/**
 	 * 読み込み専用時にグレーアウトします。
 	 */
@@ -520,4 +539,4 @@ public class EndStatusComposite extends Composite {
 		m_warningEndRange.setEnabled(enabled);
 		m_abnormalValue.setEnabled(enabled);
 	}
-}
\ No newline at end of file
+}
