@@ -27,20 +27,23 @@ import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Table;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.YesNoConstant;
 import com.clustercontrol.jobmanagement.action.GetJobTableDefine;
+import com.clustercontrol.jobmanagement.bean.JobConstant;
 import com.clustercontrol.jobmanagement.composite.action.JobDoubleClickListener;
 import com.clustercontrol.jobmanagement.util.JobPropertyUtil;
 import com.clustercontrol.jobmanagement.util.JobTreeItemUtil;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.viewer.CommonTableViewer;
 import com.clustercontrol.ws.jobmanagement.JobCommandInfo;
+import com.clustercontrol.ws.jobmanagement.JobInfo;
 import com.clustercontrol.ws.jobmanagement.JobTreeItem;
 import com.clustercontrol.ws.jobmanagement.JobWaitRuleInfo;
 
 /**
  * ジョブ[一覧]ビュー用のコンポジットクラスです。
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
@@ -51,15 +54,15 @@ public class JobListComposite extends Composite {
 	private Label m_path = null;
 	/** ジョブツリーアイテム */
 	private JobTreeItem m_jobTreeItem = null;
-	/** 選択ジョブツリーアイテム */
-	private JobTreeItem m_selectJobTreeItem = null;
+	/** 選択ジョブツリーアイテムリスト */
+	private List<JobTreeItem> m_selectJobTreeItemList = new ArrayList<JobTreeItem>();
 
 	/**
 	 * コンストラクタ
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param style スタイル
-	 * 
+	 *
 	 * @see org.eclipse.swt.SWT
 	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
 	 * @see #initialize()
@@ -79,13 +82,15 @@ public class JobListComposite extends Composite {
 		layout.marginWidth = 0;
 
 		m_path = new Label(this, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "path", m_path);
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
 		m_path.setLayoutData(gridData);
 
 		Table table = new Table(this, SWT.H_SCROLL | SWT.V_SCROLL
-				| SWT.FULL_SELECTION | SWT.SINGLE);
+				| SWT.FULL_SELECTION | SWT.MULTI);
+		WidgetTestUtil.setTestId(this, null, table);
 		table.setHeaderVisible(true);
 		table.setLinesVisible(true);
 
@@ -99,7 +104,9 @@ public class JobListComposite extends Composite {
 
 		m_viewer = new CommonTableViewer(table);
 		m_viewer.createTableColumn(GetJobTableDefine.get(),
-				GetJobTableDefine.SORT_COLUMN_INDEX, GetJobTableDefine.SORT_ORDER);
+				GetJobTableDefine.SORT_COLUMN_INDEX1,
+				GetJobTableDefine.SORT_COLUMN_INDEX2,
+				GetJobTableDefine.SORT_ORDER);
 
 		// ダブルクリックリスナの追加
 		m_viewer.addDoubleClickListener(new JobDoubleClickListener(this));
@@ -107,7 +114,7 @@ public class JobListComposite extends Composite {
 
 	/**
 	 * このコンポジットが利用するテーブルビューアを返します。
-	 * 
+	 *
 	 * @return テーブルビューア
 	 */
 	public TableViewer getTableViewer() {
@@ -116,7 +123,7 @@ public class JobListComposite extends Composite {
 
 	/**
 	 * このコンポジットが利用するテーブルを返します。
-	 * 
+	 *
 	 * @return テーブル
 	 */
 	public Table getTable() {
@@ -132,50 +139,44 @@ public class JobListComposite extends Composite {
 	 * <li>引数で指定されたジョブツリー情報からジョブ一覧情報を取得します。</li>
 	 * <li>共通テーブルビューアーにジョブ一覧情報をセットします。</li>
 	 * </ol>
-	 * 
+	 *
 	 * @param item ジョブツリー情報
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.action.GetJobList#getJobList(JobTreeItem)
 	 */
 	public void update(JobTreeItem item) {
-		if (item instanceof JobTreeItem) {
-			m_path.setText(Messages.getString("job") + " : " + JobTreeItemUtil.getPath(item));
-		} else {
-			m_path.setText(Messages.getString("job") + " : ");
-		}
+		m_selectJobTreeItemList.clear();
 
-		m_jobTreeItem = item;
-		m_selectJobTreeItem = null;
-
-		ArrayList jobInfo = null;
+		// Set path label
+		m_path.setText(Messages.getString("job") + " : " + (( null != item ) ? JobTreeItemUtil.getPath(item) : ""));
 
 		//ジョブ一覧情報取得
-		jobInfo = getJobList(item);
+		m_viewer.setInput(getJobList(item));
 
-		m_viewer.setInput(jobInfo);
+		m_jobTreeItem = item;
 	}
 
 	/**
-	 * 選択ジョブツリーアイテムを返します。
-	 * 
-	 * @return ジョブツリーアイテム
+	 * 選択ジョブツリーアイテムリストを返します。
+	 *
+	 * @return ジョブツリーアイテムリスト
 	 */
-	public JobTreeItem getSelectJobTreeItem() {
-		return m_selectJobTreeItem;
+	public List<JobTreeItem> getSelectJobTreeItemList() {
+		return m_selectJobTreeItemList;
 	}
 
 	/**
-	 * 選択ジョブツリーアイテムを設定します。
-	 * 
-	 * @param jobTreeItem ジョブツリーアイテム
+	 * 選択ジョブツリーアイテムリストを設定します。
+	 *
+	 * @param jobTreeItemList ジョブツリーアイテムリスト
 	 */
-	public void setSelectJobTreeItem(JobTreeItem jobTreeItem) {
-		m_selectJobTreeItem = jobTreeItem;
+	public void setSelectJobTreeItemList(List<JobTreeItem> jobTreeItemList) {
+		m_selectJobTreeItemList = jobTreeItemList;
 	}
 
 	/**
 	 * ジョブツリー情報を返します。
-	 * 
+	 *
 	 * @return ジョブツリー情報
 	 */
 	public JobTreeItem getJobTreeItem() {
@@ -184,7 +185,7 @@ public class JobListComposite extends Composite {
 
 	/**
 	 * ジョブツリー情報を設定します。
-	 * 
+	 *
 	 * @param jobTreeItem ジョブツリー情報
 	 */
 	public void setJobTreeItem(JobTreeItem jobTreeItem) {
@@ -193,58 +194,84 @@ public class JobListComposite extends Composite {
 
 	/**
 	 * 引数にて指定されたジョブツリーアイテムからジョブ一覧情報を作成する
-	 * 
+	 *
 	 * @param item ジョブツリー情報
 	 * @return ジョブ一覧情報（Objectの2次元配列）
 	 */
-	private ArrayList getJobList(JobTreeItem item) {
-		ArrayList jobList = new ArrayList();
+	private ArrayList<?> getJobList(JobTreeItem item) {
+		ArrayList<Object> jobList = new ArrayList<Object>();
 
 		if (item != null) {
-			List<JobTreeItem> items = item.getChildren();
-
-			for (int i = 0; i < items.size(); i++) {
-				ArrayList line = new ArrayList();
-				JobPropertyUtil.setJobFull(items.get(i).getData());
-				line.add(items.get(i).getData().getId());
-				line.add(items.get(i).getData().getName());
-				line.add(new Integer(items.get(i).getData().getType()));
-
-				JobCommandInfo exec = items.get(i).getData().getCommand();
-				if (exec instanceof JobCommandInfo) {
-					line.add(exec.getFacilityID());
-					line.add(exec.getScope());
-				} else {
-					line.add(null);
-					line.add(null);
+			if(item.getData().getType() == JobConstant.TYPE_COMPOSITE) {
+				//トップ("ジョブ")を選択した場合
+				for(JobTreeItem t : item.getChildren()) {
+					ArrayList<Object> list = new ArrayList<Object>();
+					JobInfo data = t.getData();
+					list.add(data.getName());
+					int size = GetJobTableDefine.get().size();
+					for(int i = 0; i<size; i++) {
+						list.add("");
+					}
+					jobList.add(list);
 				}
-				JobWaitRuleInfo waitRule = items.get(i).getData().getWaitRule();
-				if (waitRule instanceof JobWaitRuleInfo) {
-					if (waitRule.getObject() != null
-							&& waitRule.getObject().size() > 0) {
-						line.add(new Integer(YesNoConstant.TYPE_YES));
+				return jobList;
+			} else {
+				List<JobTreeItem> items = new ArrayList<JobTreeItem>();
+				JobTreeItem managerTree = JobTreeItemUtil.getManager(item);
+				String managerName = managerTree.getData().getName();
+				items = item.getChildren();
+				
+				// FullJob
+				List<JobInfo> list = new ArrayList<JobInfo>();
+				for (JobTreeItem info : items) {
+					list.add(info.getData());
+				}
+				JobPropertyUtil.setJobFullList(managerName, list);
+				
+				for (int i = 0; i < items.size(); i++) {
+					ArrayList<Object> line = new ArrayList<Object>();
+					line.add(managerName);
+					line.add(items.get(i).getData().getId());
+					line.add(items.get(i).getData().getName());
+					line.add(new Integer(items.get(i).getData().getType()));
+
+					JobCommandInfo exec = items.get(i).getData().getCommand();
+					if (exec instanceof JobCommandInfo) {
+						line.add(exec.getFacilityID());
+						line.add(exec.getScope());
+					} else {
+						line.add(null);
+						line.add(null);
+					}
+					JobWaitRuleInfo waitRule = items.get(i).getData().getWaitRule();
+					if (waitRule instanceof JobWaitRuleInfo) {
+						if (waitRule.getObject() != null
+								&& waitRule.getObject().size() > 0) {
+							line.add(new Integer(YesNoConstant.TYPE_YES));
+						} else {
+							line.add(new Integer(YesNoConstant.TYPE_NO));
+						}
 					} else {
 						line.add(new Integer(YesNoConstant.TYPE_NO));
 					}
-				} else {
-					line.add(new Integer(YesNoConstant.TYPE_NO));
-				}
-				line.add(items.get(i).getData().getOwnerRoleId());
-				line.add(items.get(i).getData().getCreateUser());
-				Long createTime = items.get(i).getData().getCreateTime();
-				if(createTime == null){
+					line.add(items.get(i).getData().getOwnerRoleId());
+					line.add(items.get(i).getData().getCreateUser());
+					Long createTime = items.get(i).getData().getCreateTime();
+					if(createTime == null){
+						line.add(null);
+					}else{
+						line.add(new Date(items.get(i).getData().getCreateTime()));
+					}
+					line.add(items.get(i).getData().getUpdateUser());
+					Long updateTime = items.get(i).getData().getUpdateTime();
+					if(updateTime == null){
+						line.add(null);
+					}else{
+						line.add(new Date(items.get(i).getData().getUpdateTime()));
+					}
 					line.add(null);
-				}else{
-					line.add(new Date(items.get(i).getData().getCreateTime()));
+					jobList.add(line);
 				}
-				line.add(items.get(i).getData().getUpdateUser());
-				Long updateTime = items.get(i).getData().getUpdateTime();
-				if(updateTime == null){
-					line.add(null);
-				}else{
-					line.add(new Date(items.get(i).getData().getUpdateTime()));
-				}
-				jobList.add(line);
 			}
 		} else {
 			return null;
@@ -253,9 +280,9 @@ public class JobListComposite extends Composite {
 	}
 
 	/**
-	 * @return 選択されているアイテムを返します。
+	 * @return 選択されているアイテムリストを返します。
 	 */
-	public JobTreeItem getSelectItem() {
-		return this.m_selectJobTreeItem;
+	public List<JobTreeItem> getSelectItemList() {
+		return this.m_selectJobTreeItemList;
 	}
-}
\ No newline at end of file
+}
