@@ -48,10 +48,11 @@ import com.clustercontrol.jobmanagement.bean.OperationConstant;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.TimeTo48hConverter;
 import com.clustercontrol.ws.jobmanagement.JobWaitRuleInfo;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * 開始遅延タブ用のコンポジットクラスです。
- * 
+ *
  * @version 2.1.0
  * @since 2.1.0
  */
@@ -91,10 +92,10 @@ public class StartDelayComposite extends Composite {
 
 	/**
 	 * コンストラクタ
-	 * 
+	 *
 	 * @param parent 親コンポジット
 	 * @param style スタイル
-	 * 
+	 *
 	 * @see org.eclipse.swt.SWT
 	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
 	 * @see #initialize()
@@ -116,17 +117,18 @@ public class StartDelayComposite extends Composite {
 		layout.fill = true;
 		this.setLayout(layout);
 
-		Composite composite = null;
 		RowLayout rowLayout = null;
 		Label label = null;
 
 		//開始遅延
-		composite = new Composite(this, SWT.NONE);
+		Composite startDelayStartComposite = new Composite(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "start", startDelayStartComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
-		composite.setLayout(rowLayout);
+		startDelayStartComposite.setLayout(rowLayout);
 
-		m_startDelayCondition = new Button(composite, SWT.CHECK);
+		m_startDelayCondition = new Button(startDelayStartComposite, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "conditioncheck", m_startDelayCondition);
 		m_startDelayCondition.setText(Messages.getString("start.delay"));
 		m_startDelayCondition.setLayoutData(new RowData(200,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -134,7 +136,7 @@ public class StartDelayComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
-
+				WidgetTestUtil.setTestId(this, null, check);
 				//開始遅延コンポジットのオブジェクトの使用不可を設定
 				setStartDelayEnabled(check.getSelection());
 				update();
@@ -146,7 +148,8 @@ public class StartDelayComposite extends Composite {
 			}
 		});
 
-		m_startDelayConditionGroup = new Group(composite, SWT.NONE);
+		m_startDelayConditionGroup = new Group(startDelayStartComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "condition", m_startDelayConditionGroup);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
 		rowLayout.marginWidth = 5;
@@ -155,22 +158,25 @@ public class StartDelayComposite extends Composite {
 		m_startDelayConditionGroup.setLayout(rowLayout);
 
 		//判定対象一覧
-		Group group = new Group(m_startDelayConditionGroup, SWT.NONE);
-		group.setText(Messages.getString("object.list"));
+		Group startDelayJudgementGroup = new Group(m_startDelayConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "objectlist", startDelayJudgementGroup);
+		startDelayJudgementGroup.setText(Messages.getString("object.list"));
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
 		rowLayout.marginWidth = 5;
 		rowLayout.marginHeight = 5;
 		rowLayout.spacing = 1;
-		group.setLayout(rowLayout);
+		startDelayJudgementGroup.setLayout(rowLayout);
 
 		//セッション開始後の時間
-		composite = new Composite(group, SWT.NONE);
+		Composite startDelayAfterSessionComposite= new Composite(startDelayJudgementGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "aftersession", startDelayAfterSessionComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		m_sessionCondition = new Button(composite, SWT.CHECK);
+		startDelayAfterSessionComposite.setLayout(rowLayout);
+		m_sessionCondition = new Button(startDelayAfterSessionComposite, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "sessionconditioncheck", m_sessionCondition);
 		m_sessionCondition.setText(Messages.getString("time.after.session.start") + " : ");
 		m_sessionCondition.setLayoutData(new RowData(220,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -178,6 +184,7 @@ public class StartDelayComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_sessionValue.setEnabled(true);
 				} else {
@@ -192,7 +199,8 @@ public class StartDelayComposite extends Composite {
 			}
 		});
 		//セッション開始後の時間の値
-		m_sessionValue = new Text(composite, SWT.BORDER);
+		m_sessionValue = new Text(startDelayAfterSessionComposite, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "sessionvalue", m_sessionValue);
 		m_sessionValue.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		m_sessionValue.addVerifyListener(
@@ -207,12 +215,14 @@ public class StartDelayComposite extends Composite {
 				);
 
 		//時刻
-		composite = new Composite(group, SWT.NONE);
+		Composite startDelayTimeComposite= new Composite(startDelayJudgementGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "timecomposite", startDelayTimeComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		m_timeCondition = new Button(composite, SWT.CHECK);
+		startDelayTimeComposite.setLayout(rowLayout);
+		m_timeCondition = new Button(startDelayTimeComposite, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "timeconditioncheck", m_timeCondition);
 		m_timeCondition.setText(Messages.getString("wait.rule.time.example") + " : ");
 		m_timeCondition.setLayoutData(new RowData(220,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -220,6 +230,7 @@ public class StartDelayComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_timeValue.setEnabled(true);
 				} else {
@@ -234,7 +245,8 @@ public class StartDelayComposite extends Composite {
 			}
 		});
 		//時刻の値
-		m_timeValue = new Text(composite, SWT.BORDER);
+		m_timeValue = new Text(startDelayTimeComposite, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "timevalue", m_timeValue);
 		m_timeValue.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		m_timeValue.addVerifyListener(new TimeVerifyListener());
@@ -247,46 +259,55 @@ public class StartDelayComposite extends Composite {
 				}
 				);
 		//判定対象の条件関係
-		group = new Group(m_startDelayConditionGroup, SWT.NONE);
-		group.setText(Messages.getString("condition.between.objects"));
+		Group startDelayBetweenConditionGroup = new Group(m_startDelayConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "betweencondition", startDelayBetweenConditionGroup);
+		startDelayBetweenConditionGroup.setText(Messages.getString("condition.between.objects"));
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
 		rowLayout.marginWidth = 5;
 		rowLayout.marginHeight = 5;
 		rowLayout.spacing = 1;
-		group.setLayout(rowLayout);
+		startDelayBetweenConditionGroup.setLayout(rowLayout);
 
-		composite = new Composite(group, SWT.NONE);
+		Composite startDelayConditionComposite= new Composite(startDelayBetweenConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "conditioncomposite", startDelayConditionComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		m_andCondition = new Button(composite, SWT.RADIO);
+		startDelayConditionComposite.setLayout(rowLayout);
+		m_andCondition = new Button(startDelayConditionComposite, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "andcondition", m_andCondition);
 		m_andCondition.setText(Messages.getString("and"));
 		m_andCondition.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
-		m_orCondition = new Button(composite, SWT.RADIO);
+		m_orCondition = new Button(startDelayConditionComposite, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "orcondition", m_orCondition);
 		m_orCondition.setText(Messages.getString("or"));
 		m_orCondition.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
-		label = new Label(composite, SWT.NONE);
+		label = new Label(startDelayConditionComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "startdelaycondition1", label);
 		label.setLayoutData(new RowData(77, SizeConstant.SIZE_LABEL_HEIGHT));
 
-		composite = new Composite(m_startDelayConditionGroup, SWT.NONE);
+		Composite startDelayDummyComposite= new Composite(m_startDelayConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "dummy", startDelayDummyComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		label = new Label(composite, SWT.NONE);
+		startDelayDummyComposite.setLayout(rowLayout);
+		label = new Label(startDelayDummyComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "startdelaycondition2", label);
 		label.setLayoutData(new RowData(5, SizeConstant.SIZE_LABEL_HEIGHT));
 
 		//通知
-		composite = new Composite(m_startDelayConditionGroup, SWT.NONE);
+		Composite startDelayNotificationComposite= new Composite(m_startDelayConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "notification", startDelayNotificationComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		m_notifyCondition = new Button(composite, SWT.CHECK);
+		startDelayNotificationComposite.setLayout(rowLayout);
+		m_notifyCondition = new Button(startDelayNotificationComposite, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "notifycondition", m_notifyCondition);
 		m_notifyCondition.setText(Messages.getString("notify.attribute") + " : ");
 		m_notifyCondition.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -294,6 +315,7 @@ public class StartDelayComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_notifyPriority.setEnabled(true);
 				} else {
@@ -307,7 +329,8 @@ public class StartDelayComposite extends Composite {
 			}
 		});
 		//通知の重要度
-		m_notifyPriority = new Combo(composite, SWT.CENTER | SWT.READ_ONLY);
+		m_notifyPriority = new Combo(startDelayNotificationComposite, SWT.CENTER | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "notifypriority", m_notifyPriority);
 		m_notifyPriority.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_COMBO_HEIGHT));
 		m_notifyPriority.add(PriorityConstant.STRING_INFO);
@@ -316,12 +339,14 @@ public class StartDelayComposite extends Composite {
 		m_notifyPriority.add(PriorityConstant.STRING_UNKNOWN);
 
 		//操作
-		composite = new Composite(m_startDelayConditionGroup, SWT.NONE);
+		Composite startDelayOptComposite= new Composite(m_startDelayConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "opt", startDelayOptComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		m_operationCondition = new Button(composite, SWT.CHECK);
+		startDelayOptComposite.setLayout(rowLayout);
+		m_operationCondition = new Button(startDelayOptComposite, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "optcondition", m_operationCondition);
 		m_operationCondition.setText(Messages.getString("operations"));
 		m_operationCondition.setLayoutData(new RowData(220,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -329,6 +354,7 @@ public class StartDelayComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_operationType.setEnabled(true);
 
@@ -357,6 +383,7 @@ public class StartDelayComposite extends Composite {
 		});
 
 		m_operationConditionGroup = new Group(m_startDelayConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "optcondition", m_operationConditionGroup);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
 		rowLayout.marginWidth = 5;
@@ -365,16 +392,19 @@ public class StartDelayComposite extends Composite {
 		m_operationConditionGroup.setLayout(rowLayout);
 
 		//操作の名前
-		composite = new Composite(m_operationConditionGroup, SWT.NONE);
+		Composite startDelayOptNameComposite= new Composite(m_operationConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "optname", startDelayOptNameComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		label = new Label(composite, SWT.NONE);
+		startDelayOptNameComposite.setLayout(rowLayout);
+		label = new Label(startDelayOptNameComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "name", label);
 		label.setText(Messages.getString("name") + " : ");
 		label.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_LABEL_HEIGHT));
-		m_operationType = new Combo(composite, SWT.CENTER | SWT.READ_ONLY);
+		m_operationType = new Combo(startDelayOptNameComposite, SWT.CENTER | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "opttype", m_operationType);
 		m_operationType.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_COMBO_HEIGHT));
 		m_operationType.add(OperationConstant.STRING_STOP_SKIP);
@@ -383,7 +413,7 @@ public class StartDelayComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Combo check = (Combo) e.getSource();
-
+				WidgetTestUtil.setTestId(this, null, check);
 				int type = getSelectOperationName(check);
 				if (type == OperationConstant.TYPE_STOP_SKIP) {
 					m_operationStatus.setEnabled(true);
@@ -402,16 +432,19 @@ public class StartDelayComposite extends Composite {
 		});
 
 		//操作の終了状態
-		composite = new Composite(m_operationConditionGroup, SWT.NONE);
+		Composite startDelayOptEndStatusComposite= new Composite(m_operationConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "optendstatus", startDelayOptEndStatusComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		label = new Label(composite, SWT.NONE);
+		startDelayOptEndStatusComposite.setLayout(rowLayout);
+		label = new Label(startDelayOptEndStatusComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "endstatus", label);
 		label.setText(Messages.getString("end.status") + " : ");
 		label.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_LABEL_HEIGHT));
-		m_operationStatus = new Combo(composite, SWT.CENTER | SWT.READ_ONLY);
+		m_operationStatus = new Combo(startDelayOptEndStatusComposite, SWT.CENTER | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "optstatus", m_operationStatus);
 		m_operationStatus.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_COMBO_HEIGHT));
 		m_operationStatus.add(EndStatusConstant.STRING_NORMAL);
@@ -419,16 +452,19 @@ public class StartDelayComposite extends Composite {
 		m_operationStatus.add(EndStatusConstant.STRING_ABNORMAL);
 
 		//操作の終了値
-		composite = new Composite(m_operationConditionGroup, SWT.NONE);
+		Composite startDelayOptEndValueComposite= new Composite(m_operationConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "optendvalue", startDelayOptEndValueComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		label = new Label(composite, SWT.NONE);
+		startDelayOptEndValueComposite.setLayout(rowLayout);
+		label = new Label(startDelayOptEndValueComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "endvalue", label);
 		label.setText(Messages.getString("end.value") + " : ");
 		label.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_LABEL_HEIGHT));
-		m_operationValue = new Text(composite, SWT.BORDER);
+		m_operationValue = new Text(startDelayOptEndValueComposite, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "optvalue", m_operationValue);
 		m_operationValue.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		m_operationValue.addVerifyListener(
@@ -441,7 +477,8 @@ public class StartDelayComposite extends Composite {
 					}
 				}
 				);
-		label = new Label(composite, SWT.NONE);
+		label = new Label(startDelayOptEndValueComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, label);
 		label.setLayoutData(new RowData(70, SizeConstant.SIZE_LABEL_HEIGHT));
 	}
 
@@ -471,7 +508,7 @@ public class StartDelayComposite extends Composite {
 
 	/**
 	 * ジョブ待ち条件情報をコンポジットに反映します。
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.JobWaitRuleInfo
 	 */
 	public void reflectWaitRuleInfo() {
@@ -534,7 +571,7 @@ public class StartDelayComposite extends Composite {
 
 	/**
 	 * ジョブ待ち条件情報を設定します。
-	 * 
+	 *
 	 * @param start ジョブ待ち条件情報
 	 */
 	public void setWaitRuleInfo(JobWaitRuleInfo start) {
@@ -543,7 +580,7 @@ public class StartDelayComposite extends Composite {
 
 	/**
 	 * ジョブ待ち条件情報を返します。
-	 * 
+	 *
 	 * @return ジョブ待ち条件情報
 	 */
 	public JobWaitRuleInfo getWaitRuleInfo() {
@@ -552,7 +589,7 @@ public class StartDelayComposite extends Composite {
 
 	/**
 	 * コンポジットの情報から、ジョブ待ち条件情報を作成します。
-	 * 
+	 *
 	 * @return 入力値の検証結果
 	 */
 	public ValidateResult createWaitRuleInfo() {
@@ -666,7 +703,7 @@ public class StartDelayComposite extends Composite {
 
 	/**
 	 * コンポジットに配置したオブジェクトの使用可・使用不可を設定します。
-	 * 
+	 *
 	 * @param enabled true：開始遅延を使用する、false：開始遅延を使用しない
 	 */
 	private void setStartDelayEnabled(boolean enabled) {
@@ -750,10 +787,10 @@ public class StartDelayComposite extends Composite {
 
 	/**
 	 * 指定した重要度に該当する開始遅延通知重要度用コンボボックスの項目を選択します。
-	 * 
+	 *
 	 * @param combo 開始遅延通知重要度用コンボボックスのインスタンス
 	 * @param priority 重要度
-	 * 
+	 *
 	 * @see com.clustercontrol.bean.PriorityConstant
 	 */
 	private void setSelectPriority(Combo combo, int priority) {
@@ -782,10 +819,10 @@ public class StartDelayComposite extends Composite {
 
 	/**
 	 * 開始遅延通知重要度用コンボボックスにて選択している重要度を取得します。
-	 * 
+	 *
 	 * @param combo 開始遅延通知重要度用コンボボックスのインスタンス
 	 * @return 重要度
-	 * 
+	 *
 	 * @see com.clustercontrol.bean.PriorityConstant
 	 */
 	private int getSelectPriority(Combo combo) {
@@ -808,10 +845,10 @@ public class StartDelayComposite extends Composite {
 
 	/**
 	 * 指定したジョブ操作種別に該当する開始遅延操作用コンボボックスの項目を選択します。
-	 * 
+	 *
 	 * @param combo コンボボックスのインスタンス
 	 * @param operation ジョブ操作種別
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.OperationConstant
 	 */
 	private void setSelectOperationName(Combo combo, int operation) {
@@ -834,10 +871,10 @@ public class StartDelayComposite extends Composite {
 
 	/**
 	 * 開始遅延操作用コンボボックスにて選択しているジョブ操作種別を取得します。
-	 * 
+	 *
 	 * @param combo コンボボックスのインスタンス
 	 * @return ジョブ操作種別
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.OperationConstant
 	 */
 	private int getSelectOperationName(Combo combo) {
@@ -854,7 +891,7 @@ public class StartDelayComposite extends Composite {
 
 	/**
 	 * 指定した重要度に該当する開始遅延終了状態用コンボボックスの項目を選択します。
-	 * 
+	 *
 	 */
 	private void setSelectOperationEndStatus(Combo combo, int status) {
 		String select = "";
@@ -872,13 +909,13 @@ public class StartDelayComposite extends Composite {
 
 	/**
 	 * 開始遅延通知終了状態用コンボボックスにて選択している項目を取得します。
-	 * 
+	 *
 	 */
 	private int getSelectOperationEndStatus(Combo combo) {
 		String select = combo.getText();
 		return EndStatusConstant.stringToType(select);
 	}
-	
+
 	/**
 	 * 読み込み専用時にグレーアウトします。
 	 */
@@ -899,4 +936,4 @@ public class StartDelayComposite extends Composite {
 		m_operationValue.setEnabled(enabled);
 		m_startDelayCondition.setEnabled(enabled);
 	}
-}
\ No newline at end of file
+}
