@@ -20,6 +20,8 @@ import java.util.Date;
 import java.util.HashMap;
 import java.util.List;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.swt.SWT;
@@ -56,14 +58,17 @@ import com.clustercontrol.viewer.CommonTableViewer;
 import com.clustercontrol.ws.jobmanagement.JobObjectInfo;
 import com.clustercontrol.ws.jobmanagement.JobTreeItem;
 import com.clustercontrol.ws.jobmanagement.JobWaitRuleInfo;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * 待ち条件タブ用のコンポジットクラスです。
- * 
+ *
  * @version 2.1.0
  * @since 1.0.0
  */
 public class WaitRuleComposite extends Composite {
+	/** ログ出力のインスタンス */
+	private static Log m_log = LogFactory.getLog( WaitRuleComposite.class );
 	/** テーブルビューア */
 	private CommonTableViewer m_viewer = null;
 	/** 判定対象の条件関係 AND用ラジオボタン */
@@ -89,16 +94,16 @@ public class WaitRuleComposite extends Composite {
 	/** シェル */
 	private Shell m_shell = null;
 	/** 選択アイテム */
-	private ArrayList m_selectItem = null;
+	private ArrayList<Object> m_selectItem = null;
 
 	private JobTreeItem m_jobTreeItem = null;
 
 	/**
 	 * コンストラクタ
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param style スタイル
-	 * 
+	 *
 	 * @see org.eclipse.swt.SWT
 	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
 	 * @see #initialize()
@@ -121,47 +126,52 @@ public class WaitRuleComposite extends Composite {
 		layout.fill = true;
 		this.setLayout(layout);
 
-		Composite composite = null;
 		RowLayout rowLayout = null;
 
-		composite = new Composite(this, SWT.NONE);
+		Composite waitRuleListComposite = new Composite(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "list", waitRuleListComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
-		composite.setLayout(rowLayout);
+		waitRuleListComposite.setLayout(rowLayout);
 
-		Label tableTitle = new Label(composite, SWT.NONE);
+		Label tableTitle = new Label(waitRuleListComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "objectlist", tableTitle);
 		tableTitle.setText(Messages.getString("object.list"));
 
-		Table table = new Table(composite, SWT.BORDER | SWT.H_SCROLL
+		Table table = new Table(waitRuleListComposite, SWT.BORDER | SWT.H_SCROLL
 				| SWT.V_SCROLL | SWT.FULL_SELECTION | SWT.SINGLE);
+		WidgetTestUtil.setTestId(this, null, table);
 		table.setHeaderVisible(true);
 		table.setLinesVisible(true);
 		table.setLayoutData(new RowData(430, 130));
 
-		composite = new Composite(composite, SWT.NONE);
+		Composite waitRuleDummyComposite = new Composite(waitRuleListComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "dummy", waitRuleDummyComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 5;
-		composite.setLayout(rowLayout);
+		waitRuleDummyComposite.setLayout(rowLayout);
 
 		//判定対象の追加
-		Label dummy1 = new Label(composite, SWT.NONE);
+		Label dummy1 = new Label(waitRuleDummyComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "dummy1", dummy1);
 		dummy1.setLayoutData(new RowData(190, SizeConstant.SIZE_LABEL_HEIGHT));
-		m_createCondition = new Button(composite, SWT.NONE);
+		m_createCondition = new Button(waitRuleDummyComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "createcondition", m_createCondition);
 		m_createCondition.setText(Messages.getString("add"));
 		m_createCondition.setLayoutData(new RowData(80,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_createCondition.addSelectionListener(new SelectionAdapter() {
 			@Override
-			@SuppressWarnings("unchecked")
 			public void widgetSelected(SelectionEvent e) {
+				m_log.debug("widgetSelected");
 				WaitRuleDialog dialog = new WaitRuleDialog(m_shell, m_jobTreeItem);
 				if (dialog.open() == IDialogConstants.OK_ID) {
 
 					// 待ち条件を追加するかどうかを示すフラグ
 					boolean addWaitRule = true;
 
-					ArrayList info = dialog.getInputData();
+					ArrayList<Integer> info = (ArrayList<Integer>)dialog.getInputData();
 					ArrayList<ArrayList<Integer>> list = (ArrayList<ArrayList<Integer>>) m_viewer.getInput();
 					if (list == null) {
 						list = new ArrayList<ArrayList<Integer>>();
@@ -173,7 +183,9 @@ public class WaitRuleComposite extends Composite {
 						if (newWaitRuleType == JudgmentObjectConstant.TYPE_TIME){
 
 							for (ArrayList<Integer> waitRule : list) {
+								m_log.debug("WaitRuleComposite_initialize_info = " + info);
 								int rule = waitRule.get(GetWaitRuleTableDefine.JUDGMENT_OBJECT);
+								m_log.debug("WaitRuleComposite_initialize_rule = " + rule);
 								if (rule == JudgmentObjectConstant.TYPE_TIME) {
 									addWaitRule = false;
 
@@ -193,7 +205,8 @@ public class WaitRuleComposite extends Composite {
 		});
 
 		//判定対象の変更
-		m_modifyCondition = new Button(composite, SWT.NONE);
+		m_modifyCondition = new Button(waitRuleDummyComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "modifycondition", m_modifyCondition);
 		m_modifyCondition.setText(Messages.getString("modify"));
 		m_modifyCondition.setLayoutData(new RowData(80,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -205,8 +218,8 @@ public class WaitRuleComposite extends Composite {
 					dialog.setInputData(m_selectItem);
 					if (dialog.open() == IDialogConstants.OK_ID) {
 
-						ArrayList info = dialog.getInputData();
-						ArrayList<ArrayList> list = (ArrayList<ArrayList>) m_viewer.getInput();
+						ArrayList<?> info = dialog.getInputData();
+						ArrayList<ArrayList<?>> list = (ArrayList<ArrayList<?>>) m_viewer.getInput();
 
 						list.remove(m_selectItem);
 						list.add(info);
@@ -221,14 +234,15 @@ public class WaitRuleComposite extends Composite {
 		});
 
 		//判定対象の削除
-		m_deleteCondition = new Button(composite, SWT.NONE);
+		m_deleteCondition = new Button(waitRuleDummyComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "deletecondition", m_deleteCondition);
 		m_deleteCondition.setText(Messages.getString("delete"));
 		m_deleteCondition.setLayoutData(new RowData(80,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_deleteCondition.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
-				ArrayList list = (ArrayList) m_viewer.getInput();
+				ArrayList<?> list = (ArrayList<?>) m_viewer.getInput();
 				list.remove(m_selectItem);
 				m_selectItem = null;
 				m_viewer.setInput(list);
@@ -237,6 +251,7 @@ public class WaitRuleComposite extends Composite {
 
 		//判定対象の条件関係
 		Group group = new Group(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, group);
 		group.setText(Messages.getString("condition.between.objects"));
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
@@ -245,37 +260,42 @@ public class WaitRuleComposite extends Composite {
 		rowLayout.spacing = 1;
 		group.setLayout(rowLayout);
 
-		composite = new Composite(group, SWT.NONE);
+		Composite waitRuleConditionComposite = new Composite(group, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "condition", waitRuleConditionComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		m_andCondition = new Button(composite, SWT.RADIO);
+		waitRuleConditionComposite.setLayout(rowLayout);
+		m_andCondition = new Button(waitRuleConditionComposite, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "andcondition", m_andCondition);
 		m_andCondition.setText(Messages.getString("and"));
 		m_andCondition.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
-		m_orCondition = new Button(composite, SWT.RADIO);
+		m_orCondition = new Button(waitRuleConditionComposite, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "orcondition", m_orCondition);
 		m_orCondition.setText(Messages.getString("or"));
 		m_orCondition.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 
-		composite = new Composite(this, SWT.NONE);
+		Composite waitRuleEndComposite = new Composite(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "end", waitRuleEndComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
-		composite.setLayout(rowLayout);
+		waitRuleEndComposite.setLayout(rowLayout);
 
 		//条件を満たさないときに終了
-		Label dummy2 = new Label(composite, SWT.NONE);
+		Label dummy2 = new Label(waitRuleEndComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "dummy2", dummy2);
 		dummy2.setLayoutData(new RowData(190, SizeConstant.SIZE_LABEL_HEIGHT));
-		m_endCondition = new Button(composite, SWT.CHECK);
-		m_endCondition
-		.setText(Messages.getString("end.if.condition.unmatched"));
-		m_endCondition.setLayoutData(new RowData(220,
-				SizeConstant.SIZE_BUTTON_HEIGHT));
+		m_endCondition = new Button(waitRuleEndComposite, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "endcondition", m_endCondition);
+		m_endCondition.setText(Messages.getString("end.if.condition.unmatched"));
+		m_endCondition.setLayoutData(new RowData(220, SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_endCondition.addSelectionListener(new SelectionListener() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_endConditionGroup.setEnabled(true);
 					m_endStatus.setEnabled(true);
@@ -295,6 +315,7 @@ public class WaitRuleComposite extends Composite {
 		});
 
 		m_endConditionGroup = new Group(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "endcondition", m_endConditionGroup);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
 		rowLayout.marginWidth = 5;
@@ -303,16 +324,19 @@ public class WaitRuleComposite extends Composite {
 		m_endConditionGroup.setLayout(rowLayout);
 
 		// 終了状態
-		composite = new Composite(m_endConditionGroup, SWT.NONE);
+		Composite waitRuleEndStatusComposite = new Composite(m_endConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "endstatus", waitRuleEndStatusComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		Label endStatusTitle = new Label(composite, SWT.LEFT);
+		waitRuleEndStatusComposite.setLayout(rowLayout);
+		Label endStatusTitle = new Label(waitRuleEndStatusComposite, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "endstatus", endStatusTitle);
 		endStatusTitle.setText(Messages.getString("end.status") + " : ");
 		endStatusTitle.setLayoutData(new RowData(80,
 				SizeConstant.SIZE_LABEL_HEIGHT));
-		m_endStatus = new Combo(composite, SWT.CENTER | SWT.READ_ONLY);
+		m_endStatus = new Combo(waitRuleEndStatusComposite, SWT.CENTER | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "endstatus", m_endStatus);
 		m_endStatus.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_COMBO_HEIGHT));
 		m_endStatus.add(EndStatusConstant.STRING_NORMAL);
@@ -320,16 +344,19 @@ public class WaitRuleComposite extends Composite {
 		m_endStatus.add(EndStatusConstant.STRING_ABNORMAL);
 
 		// 終了値
-		composite = new Composite(m_endConditionGroup, SWT.NONE);
+		Composite waitRuleEndValueComposite = new Composite(m_endConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "endvalue", waitRuleEndValueComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		Label endValueTitle = new Label(composite, SWT.LEFT);
+		waitRuleEndValueComposite.setLayout(rowLayout);
+		Label endValueTitle = new Label(waitRuleEndValueComposite, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "endvalue", endValueTitle);
 		endValueTitle.setText(Messages.getString("end.value") + " : ");
 		endValueTitle.setLayoutData(new RowData(80,
 				SizeConstant.SIZE_LABEL_HEIGHT));
-		m_endValue = new Text(composite, SWT.BORDER);
+		m_endValue = new Text(waitRuleEndValueComposite, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "endvalue", m_endValue);
 		m_endValue.setLayoutData(new RowData(100, SizeConstant.SIZE_TEXT_HEIGHT));
 		m_endValue.addVerifyListener(
 				new NumberVerifyListener(DataRangeConstant.SMALLINT_LOW, DataRangeConstant.SMALLINT_HIGH));
@@ -362,19 +389,20 @@ public class WaitRuleComposite extends Composite {
 
 	/**
 	 * ジョブ待ち条件情報をコンポジットに反映します。
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.JobWaitRuleInfo
 	 */
-	@SuppressWarnings("unchecked")
 	public void reflectWaitRuleInfo() {
 		if (m_waitRule != null) {
 			//判定対象と開始条件値設定
 			List<JobObjectInfo> list = m_waitRule.getObject();
+			m_log.debug("reflectWaitRuleInfo_JobObjectInfo.size() = " + list.size());
 			if(list != null){
-				ArrayList tableData = new ArrayList();
+				ArrayList<Object> tableData = new ArrayList<Object>();
 				for (int i = 0; i < list.size(); i++) {
+					m_log.debug("loop count = " + i);
 					JobObjectInfo info = list.get(i);
-					ArrayList tableLineData = new ArrayList();
+					ArrayList<Object> tableLineData = new ArrayList<Object>();
 					tableLineData.add(new Integer(info.getType()));
 					if (info.getType() == JudgmentObjectConstant.TYPE_JOB_END_STATUS) {
 						tableLineData.add(info.getJobId());
@@ -386,7 +414,7 @@ public class WaitRuleComposite extends Composite {
 						tableLineData.add(new Integer(info.getValue()));
 						tableData.add(tableLineData);
 					}
-					else {
+					else if (info.getType() == JudgmentObjectConstant.TYPE_TIME) {
 						if (info.getTime() != null) {
 							tableLineData.add("");
 							tableLineData.add(new Date(info.getTime()));
@@ -394,7 +422,17 @@ public class WaitRuleComposite extends Composite {
 						} else {
 						}
 					}
+					else if (info.getType() == JudgmentObjectConstant.TYPE_START_MINUTE) {
+						m_log.debug("reflectWaitRuleInfo_JobObjectInfo of line is  DELAY");
+						if (info.getValue() != null) {
+							tableLineData.add("");
+							tableLineData.add(new Integer(info.getStartMinute()));
+							tableData.add(tableLineData);
+						} else {
+						}
+					}
 				}
+				m_log.debug("reflectWaitRuleInfo_tableData.size() = " + tableData.size());
 				m_viewer.setInput(tableData);
 			}
 
@@ -432,7 +470,7 @@ public class WaitRuleComposite extends Composite {
 
 	/**
 	 * ジョブ待ち条件情報を設定します。
-	 * 
+	 *
 	 * @param start ジョブ待ち条件情報
 	 */
 	public void setWaitRuleInfo(JobWaitRuleInfo start) {
@@ -441,14 +479,14 @@ public class WaitRuleComposite extends Composite {
 
 	/**
 	 * ジョブ待ち条件情報を返します。
-	 * 
+	 *
 	 * @return ジョブ待ち条件情報
 	 */
 	public JobWaitRuleInfo getWaitRuleInfo() {
 		return m_waitRule;
 	}
 
-	public static JobObjectInfo array2JobObjectInfo(ArrayList tableLineData) {
+	public static JobObjectInfo array2JobObjectInfo(ArrayList<?> tableLineData) {
 		Integer type = (Integer) tableLineData.get(GetWaitRuleTableDefine.JUDGMENT_OBJECT);
 		JobObjectInfo info = new JobObjectInfo();
 		info.setValue(0);
@@ -467,36 +505,43 @@ public class WaitRuleComposite extends Composite {
 					.get(GetWaitRuleTableDefine.START_VALUE);
 			info.setValue(value);
 		}
-		else {
+		else if (info.getType() == JudgmentObjectConstant.TYPE_TIME) {
 			Date value = (Date) tableLineData
 					.get(GetWaitRuleTableDefine.START_VALUE);
 			info.setTime(value.getTime());
 		}
+		else if (info.getType() == JudgmentObjectConstant.TYPE_START_MINUTE) {
+			Integer startMinute = (Integer) tableLineData
+					.get(GetWaitRuleTableDefine.START_VALUE);
+			info.setStartMinute(startMinute);
+		}
 		return info;
 	}
 
 	/**
 	 * コンポジットの情報から、ジョブ待ち条件情報を作成します。
-	 * 
+	 *
 	 * @return 入力値の検証結果
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.JobWaitRuleInfo
 	 */
 	public ValidateResult createWaitRuleInfo() {
+		m_log.debug("createWaitRuleInfo");
 		ValidateResult result = null;
 
 		//判定対象と開始条件値取得
 		ArrayList<JobObjectInfo> list = new ArrayList<JobObjectInfo>();
-		ArrayList tableData = (ArrayList) m_viewer.getInput();
+		ArrayList<?> tableData = (ArrayList<?>) m_viewer.getInput();
 		HashMap<String, Integer> map = new HashMap<String, Integer>();
+
 		for (int i = 0; i < tableData.size(); i++) {
-			ArrayList tableLineData = (ArrayList) tableData.get(i);
+			ArrayList<?> tableLineData = (ArrayList<?>) tableData.get(i);
 			JobObjectInfo info = array2JobObjectInfo(tableLineData);
 			// 重複チェックをしてから、リストに追加する。
 			if (info.getType() == JudgmentObjectConstant.TYPE_JOB_END_STATUS) {
 				Integer checkValue = map.get(info.getJobId() + info.getType());
 				if (checkValue == null
-						|| checkValue != info.getValue()) {
+						|| !checkValue.equals(info.getValue())) {
 					list.add(info);
 					map.put(info.getJobId() + info.getType(), new Integer(info.getValue()));
 				}
@@ -509,12 +554,20 @@ public class WaitRuleComposite extends Composite {
 					map.put(info.getJobId() + info.getType(), new Integer(info.getValue()));
 				}
 			}
-			else {
+			else if (info.getType() == JudgmentObjectConstant.TYPE_TIME) {
 				if (map.get("TIME") == null) {
 					list.add(info);
 					map.put("TIME", 1);
 				}
 			}
+			else if (info.getType() == JudgmentObjectConstant.TYPE_START_MINUTE) {
+				m_log.debug("info.getType="  + info.getType());
+				m_log.debug("info.getStartMinute="  + info.getStartMinute());
+				if (map.get(info.getType().toString()) == null) {
+					list.add(info);
+					map.put(info.getType().toString(), new Integer(info.getValue()));
+				}
+			}
 		}
 		List<JobObjectInfo> jobObjectInfoList = m_waitRule.getObject();
 		jobObjectInfoList.clear();
@@ -550,10 +603,10 @@ public class WaitRuleComposite extends Composite {
 
 	/**
 	 * 選択アイテムを設定します。
-	 * 
+	 *
 	 * @param selectItem 選択アイテム
 	 */
-	public void setSelectItem(ArrayList selectItem) {
+	public void setSelectItem(ArrayList<Object> selectItem) {
 		m_selectItem = selectItem;
 	}
 
@@ -563,7 +616,7 @@ public class WaitRuleComposite extends Composite {
 
 	/**
 	 * 指定した重要度に該当するカレンダ終了状態用コンボボックスの項目を選択します。
-	 * 
+	 *
 	 */
 	private void setSelectEndStatus(Combo combo, int status) {
 		String select = "";
@@ -581,13 +634,13 @@ public class WaitRuleComposite extends Composite {
 
 	/**
 	 * カレンダ終了状態用コンボボックスにて選択している項目を取得します。
-	 * 
+	 *
 	 */
 	private int getSelectEndStatus(Combo combo) {
 		String select = combo.getText();
 		return EndStatusConstant.stringToType(select);
 	}
-	
+
 	/**
 	 * 読み込み専用時にグレーアウトします。
 	 */
@@ -604,4 +657,4 @@ public class WaitRuleComposite extends Composite {
 		m_modifyCondition.setEnabled(enabled);
 		m_deleteCondition.setEnabled(enabled);
 	}
-}
\ No newline at end of file
+}
