@@ -36,12 +36,14 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.calendar.composite.CalendarIdListComposite;
+import com.clustercontrol.composite.ManagerListComposite;
 import com.clustercontrol.composite.RoleIdListComposite;
 import com.clustercontrol.composite.RoleIdListComposite.Mode;
 import com.clustercontrol.composite.action.StringVerifyListener;
@@ -64,7 +66,7 @@ import com.clustercontrol.ws.repository.FacilityTreeItem;
 
 /**
  * ジョブ[ファイルチェックの作成・変更]ダイアログクラスです。
- * 
+ *
  * @version 4.1.0
  * @since 4.1.0
  */
@@ -129,6 +131,9 @@ public class FileCheckDialog extends CommonDialog {
 	/** オーナーロールID用テキスト */
 	private RoleIdListComposite cmpOwnerRoleId = null;
 
+	/** マネージャ名コンボボックス用コンポジット */
+	private ManagerListComposite m_managerComposite = null;
+
 	/** シェル */
 	private Shell m_shell = null;
 
@@ -151,29 +156,26 @@ public class FileCheckDialog extends CommonDialog {
 	/** 実行契機ID*/
 	private String m_JobKickId = null;
 
-	/**
-	 * コンストラクタ
-	 * 作成時
-	 * @param parent 親シェル
-	 */
-	public FileCheckDialog(Shell parent) {
-		super(parent);
-	}
+	/** マネージャ名 */
+	private String managerName = null;
+
 	/**
 	 * コンストラクタ
 	 * 変更時、コピー時
 	 * @param parent
+	 * @param managerName
 	 * @param id
 	 */
-	public FileCheckDialog(Shell parent, String id, int mode){
+	public FileCheckDialog(Shell parent, String managerName, String id, int mode){
 		super(parent);
 		this.m_JobKickId = id;
 		this.mode = mode;
+		this.managerName = managerName;
 	}
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親コンポジット
 	 */
 	@Override
@@ -192,24 +194,62 @@ public class FileCheckDialog extends CommonDialog {
 		//一番下のレイヤー
 		parent.setLayout(baseLayout);
 
-		Composite composite = null;
 		GridData gridData= null;
-		/*
-		 * ファイルチェックID
-		 */
-		composite = new Composite(parent, SWT.NONE);
+
+		// マネージャ
+		Composite fileCheckComposite = new Composite(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, fileCheckComposite);
 		GridLayout layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
 		layout.numColumns =12;
-		composite.setLayout(layout);
+		fileCheckComposite.setLayout(layout);
 		gridData = new GridData();
 		gridData.horizontalSpan = 12;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		composite.setLayoutData(gridData);
+		fileCheckComposite.setLayoutData(gridData);
+
+		Label labelManager = new Label(fileCheckComposite, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "manager", labelManager);
+		gridData = new GridData();
+		gridData.horizontalSpan = 4;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		labelManager.setLayoutData(gridData);
+		labelManager.setText(Messages.getString("facility.manager") + " : ");
+		if(this.mode == PropertyDefineConstant.MODE_MODIFY){
+			this.m_managerComposite = new ManagerListComposite(fileCheckComposite, SWT.NONE, false);
+		} else {
+			this.m_managerComposite = new ManagerListComposite(fileCheckComposite, SWT.NONE, true);
+		}
+		WidgetTestUtil.setTestId(this, "managerComposite", this.m_managerComposite);
+		gridData = new GridData();
+		gridData.horizontalSpan = 6;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		this.m_managerComposite.setLayoutData(gridData);
+
+		if(this.managerName != null) {
+			this.m_managerComposite.setText(this.managerName);
+		}
+		if(this.mode != PropertyDefineConstant.MODE_MODIFY) {
+			this.m_managerComposite.getComboManagerName().addSelectionListener(new SelectionAdapter() {
+				@Override
+				public void widgetSelected(SelectionEvent e) {
+					String managerName = m_managerComposite.getText();
+					cmpOwnerRoleId.createRoleIdList(managerName);
+					updateCalendarId();
+				}
+			});
+		}
+
+		/*
+		 * ファイルチェックID
+		 */
 		//ラベル
-		Label labelScheduleId = new Label(composite, SWT.LEFT);
+		Label labelScheduleId = new Label(fileCheckComposite, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "scheduleid", labelScheduleId);
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -220,7 +260,8 @@ public class FileCheckDialog extends CommonDialog {
 		/*
 		 * テキスト
 		 */
-		txtJobKickId = new Text(composite, SWT.BORDER);
+		txtJobKickId = new Text(fileCheckComposite, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "jobkickid", txtJobKickId);
 		txtJobKickId.addVerifyListener(
 				new StringVerifyListener(DataRangeConstant.VARCHAR_64));
 		gridData = new GridData();
@@ -238,7 +279,8 @@ public class FileCheckDialog extends CommonDialog {
 		 * ファイルチェック名
 		 */
 		//ラベル
-		Label labelScheduleName = new Label(composite, SWT.LEFT);
+		Label labelScheduleName = new Label(fileCheckComposite, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "jobkickname", labelScheduleName);
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -246,7 +288,8 @@ public class FileCheckDialog extends CommonDialog {
 		labelScheduleName.setText(Messages.getString("jobkick.name") + " : ");
 		labelScheduleName.setLayoutData(gridData);
 		//テキスト
-		this.txtJobKickName = new Text(composite, SWT.BORDER);
+		this.txtJobKickName = new Text(fileCheckComposite, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "jobkickname", txtJobKickName);
 		gridData = new GridData();
 		gridData.horizontalSpan = 6;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -264,7 +307,8 @@ public class FileCheckDialog extends CommonDialog {
 		/*
 		 * オーナーロールID
 		 */
-		Label labelRoleId = new Label(composite, SWT.LEFT);
+		Label labelRoleId = new Label(fileCheckComposite, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "roleid", labelRoleId);
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -273,21 +317,19 @@ public class FileCheckDialog extends CommonDialog {
 		labelRoleId.setText(Messages.getString("owner.role.id") + " : ");
 		if (this.mode == PropertyDefineConstant.MODE_ADD
 				|| this.mode == PropertyDefineConstant.MODE_COPY) {
-			this.cmpOwnerRoleId = new RoleIdListComposite(composite, SWT.NONE, true, Mode.OWNER_ROLE);
+			this.cmpOwnerRoleId = new RoleIdListComposite(fileCheckComposite,
+					SWT.NONE, this.managerName, true, Mode.OWNER_ROLE);
 			this.cmpOwnerRoleId.getComboRoleId().addSelectionListener(new SelectionAdapter() {
 				@Override
 				public void widgetSelected(SelectionEvent e) {
-					cmpCalendarId.setOwnerRoleId(cmpOwnerRoleId.getText());
-					txtJobId.setText("");
-					txtJobName.setText("");
-					setJobunitId(null);
-					m_facilityId = "";
-					txtScope.setText(m_facilityId);
+					updateCalendarId();
 				}
 			});
 		} else {
-			this.cmpOwnerRoleId = new RoleIdListComposite(composite, SWT.NONE, false, Mode.OWNER_ROLE);
+			this.cmpOwnerRoleId = new RoleIdListComposite(fileCheckComposite,
+					SWT.NONE, this.managerName, false, Mode.OWNER_ROLE);
 		}
+		WidgetTestUtil.setTestId(this, "cmpownerownerroleid", cmpOwnerRoleId);
 		gridData = new GridData();
 		gridData.horizontalSpan = 6;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -298,7 +340,8 @@ public class FileCheckDialog extends CommonDialog {
 		 * ジョブID
 		 */
 		//ラベル
-		Label labelJobId = new Label(composite, SWT.LEFT);
+		Label labelJobId = new Label(fileCheckComposite, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "jobid", labelJobId);
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -306,7 +349,8 @@ public class FileCheckDialog extends CommonDialog {
 		labelJobId.setText(Messages.getString("job.id") + " : ");
 		labelJobId.setLayoutData(gridData);
 		//テキスト
-		this.txtJobId = new Text(composite, SWT.READ_ONLY | SWT.BORDER);
+		this.txtJobId = new Text(fileCheckComposite, SWT.READ_ONLY | SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "jobid", txtJobId);
 		gridData = new GridData();
 		gridData.horizontalSpan = 6;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -319,7 +363,8 @@ public class FileCheckDialog extends CommonDialog {
 			}
 		});
 		//ボタン
-		btnJobSelect = new Button(composite, SWT.NONE);
+		btnJobSelect = new Button(fileCheckComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "jobselect", btnJobSelect);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -329,9 +374,9 @@ public class FileCheckDialog extends CommonDialog {
 		btnJobSelect.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
-				JobTreeDialog dialog = new JobTreeDialog(m_shell, cmpOwnerRoleId.getText(), true);
+				JobTreeDialog dialog = new JobTreeDialog(m_shell, m_managerComposite.getText(), cmpOwnerRoleId.getText(), true);
 				if (dialog.open() == IDialogConstants.OK_ID) {
-					JobTreeItem selectItem = dialog.getSelectItem();
+					JobTreeItem selectItem = dialog.getSelectItem().get(0);
 					if (selectItem.getData().getType() != JobConstant.TYPE_COMPOSITE) {
 						txtJobId.setText(selectItem.getData().getId());
 						txtJobName.setText(selectItem.getData().getName());
@@ -348,7 +393,8 @@ public class FileCheckDialog extends CommonDialog {
 		 * ジョブ名
 		 */
 		//ラベル
-		Label labelJobName = new Label(composite, SWT.LEFT);
+		Label labelJobName = new Label(fileCheckComposite, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "jobname", labelJobName);
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -356,7 +402,8 @@ public class FileCheckDialog extends CommonDialog {
 		labelJobName.setText(Messages.getString("job.name") + " : ");
 		labelJobName.setLayoutData(gridData);
 		//テキスト
-		txtJobName = new Text(composite, SWT.BORDER | SWT.READ_ONLY);
+		txtJobName = new Text(fileCheckComposite, SWT.BORDER | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "jobname", txtJobName);
 		gridData = new GridData();
 		gridData.horizontalSpan = 6;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -366,7 +413,8 @@ public class FileCheckDialog extends CommonDialog {
 		 * カレンダID
 		 */
 		//ラベル
-		Label labelCalendarId = new Label(composite, SWT.LEFT);
+		Label labelCalendarId = new Label(fileCheckComposite, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "calendarid", labelCalendarId);
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -374,7 +422,8 @@ public class FileCheckDialog extends CommonDialog {
 		labelCalendarId.setText(Messages.getString("calendar.id") + " : ");
 		labelCalendarId.setLayoutData(gridData);
 		//コンボボックス
-		cmpCalendarId = new CalendarIdListComposite(composite, SWT.NONE, false);
+		cmpCalendarId = new CalendarIdListComposite(fileCheckComposite, SWT.NONE, false);
+		WidgetTestUtil.setTestId(this, "calendaridlist", cmpCalendarId);
 		gridData = new GridData();
 		gridData.horizontalSpan = 6;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -385,6 +434,7 @@ public class FileCheckDialog extends CommonDialog {
 		createFileCheck(parent);
 
 		Group groupValidOrInvalid = new Group(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "validorinvalid", groupValidOrInvalid);
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
@@ -400,6 +450,7 @@ public class FileCheckDialog extends CommonDialog {
 
 		//有効ボタン
 		btnValid = new Button(groupValidOrInvalid, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "valid", btnValid);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -409,6 +460,7 @@ public class FileCheckDialog extends CommonDialog {
 		btnValid.setSelection(true);
 		//無効ボタン
 		btnInvalid = new Button(groupValidOrInvalid, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "invalid", btnInvalid);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -431,6 +483,7 @@ public class FileCheckDialog extends CommonDialog {
 		 * ファイルチェック設定グループ
 		 */
 		Group groupFileCheck = new Group(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "filecheck", groupFileCheck);
 		// 変数として利用されるラベル
 		Label label = null;
 		// 変数として利用されるグリッドデータ
@@ -451,6 +504,7 @@ public class FileCheckDialog extends CommonDialog {
 		 */
 		// ラベル
 		label = new Label(groupFileCheck, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "scope", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -460,6 +514,7 @@ public class FileCheckDialog extends CommonDialog {
 
 		// テキスト
 		txtScope =  new Text(groupFileCheck, SWT.READ_ONLY | SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "scope", txtScope);
 		gridData = new GridData();
 		gridData.horizontalSpan = 6;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -474,6 +529,7 @@ public class FileCheckDialog extends CommonDialog {
 
 		// 参照ボタン
 		btnScopeSelect = new Button(groupFileCheck, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "scopeselect", btnScopeSelect);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -483,7 +539,7 @@ public class FileCheckDialog extends CommonDialog {
 		btnScopeSelect.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
-				ScopeTreeDialog dialog = new ScopeTreeDialog(m_shell, cmpOwnerRoleId.getText());
+				ScopeTreeDialog dialog = new ScopeTreeDialog(m_shell, m_managerComposite.getText(), cmpOwnerRoleId.getText());
 				if (dialog.open() == IDialogConstants.OK_ID) {
 					FacilityTreeItem selectItem = dialog.getSelectItem();
 					FacilityInfo info = selectItem.getData();
@@ -498,6 +554,7 @@ public class FileCheckDialog extends CommonDialog {
 		 */
 		// ラベル
 		label = new Label(groupFileCheck, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "filecheckdirectory", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -506,6 +563,7 @@ public class FileCheckDialog extends CommonDialog {
 		label.setText(Messages.getString("file.check.directory") + " : ");
 		// テキスト
 		txtDirectory = new Text(groupFileCheck, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "directory", txtDirectory);
 		txtDirectory.addVerifyListener(
 				new StringVerifyListener(DataRangeConstant.VARCHAR_1024));
 		gridData = new GridData();
@@ -524,6 +582,7 @@ public class FileCheckDialog extends CommonDialog {
 		 */
 		// ラベル
 		label = new Label(groupFileCheck, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "filename", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -532,6 +591,7 @@ public class FileCheckDialog extends CommonDialog {
 		label.setText(Messages.getString("file.name") + "(" + Messages.getString("regex") + ") : ");
 		// テキスト
 		txtFileName = new Text(groupFileCheck, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "filename", txtFileName);
 		txtFileName.addVerifyListener(
 				new StringVerifyListener(DataRangeConstant.VARCHAR_64));
 		gridData = new GridData();
@@ -549,6 +609,7 @@ public class FileCheckDialog extends CommonDialog {
 		 * チェック種別
 		 */
 		Group groupCheck = new Group(groupFileCheck, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "check", groupCheck);
 		// 変数として利用されるグリッドデータ
 		layout = new GridLayout(1, true);
 		layout.numColumns = 4;
@@ -561,6 +622,7 @@ public class FileCheckDialog extends CommonDialog {
 		groupCheck.setLayoutData(gridData);
 		//作成
 		btnTypeCreate = new Button(groupCheck, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "typecreate", btnTypeCreate);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -572,6 +634,7 @@ public class FileCheckDialog extends CommonDialog {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 				}
 				update();
@@ -582,16 +645,18 @@ public class FileCheckDialog extends CommonDialog {
 		});
 		//削除
 		btnTypeDelete = new Button(groupCheck, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "typedelete", btnTypeDelete);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		gridData.horizontalSpan = 4;
-		btnTypeDelete.setText(Messages.getString("delete2"));
+		btnTypeDelete.setText(Messages.getString("delete"));
 		btnTypeDelete.setLayoutData(gridData);
 		btnTypeDelete.addSelectionListener(new SelectionListener() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 				}
 				update();
@@ -602,16 +667,18 @@ public class FileCheckDialog extends CommonDialog {
 		});
 		//変更
 		btnTypeModify = new Button(groupCheck, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "typemodify", btnTypeModify);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		gridData.horizontalSpan = 4;
-		btnTypeModify.setText(Messages.getString("modify2"));
+		btnTypeModify.setText(Messages.getString("modify"));
 		btnTypeModify.setLayoutData(gridData);
 		btnTypeModify.addSelectionListener(new SelectionListener() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 				}
 				update();
@@ -620,19 +687,21 @@ public class FileCheckDialog extends CommonDialog {
 			public void widgetDefaultSelected(SelectionEvent e) {
 			}
 		});
-		Composite composite = new Composite(groupCheck, SWT.NONE);
+		Composite fileCheckCreateComposite = new Composite(groupCheck, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "create", fileCheckCreateComposite);
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
 		layout.numColumns =12;
-		composite.setLayout(layout);
+		fileCheckCreateComposite.setLayout(layout);
 		gridData = new GridData();
 		gridData.horizontalSpan = 12;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		composite.setLayoutData(gridData);
+		fileCheckCreateComposite.setLayoutData(gridData);
 		//空白ラベル
-		Label spaceLabel = new Label(composite, SWT.LEFT);
+		Label spaceLabel = new Label(fileCheckCreateComposite, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "space", spaceLabel);
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -640,7 +709,8 @@ public class FileCheckDialog extends CommonDialog {
 		spaceLabel.setLayoutData(gridData);
 
 		//変更 - タイムスタンプ
-		btnTypeTimeStamp = new Button(composite, SWT.RADIO);
+		btnTypeTimeStamp = new Button(fileCheckCreateComposite, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "typetimestamp", btnTypeTimeStamp);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -652,6 +722,7 @@ public class FileCheckDialog extends CommonDialog {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 				}
 				update();
@@ -661,7 +732,8 @@ public class FileCheckDialog extends CommonDialog {
 			}
 		});
 		//変更 - ファイルサイズ
-		btnTypeFileSize = new Button(composite, SWT.RADIO);
+		btnTypeFileSize = new Button(fileCheckCreateComposite, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "typefilesize", btnTypeFileSize);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -672,6 +744,7 @@ public class FileCheckDialog extends CommonDialog {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 				}
 				update();
@@ -687,7 +760,7 @@ public class FileCheckDialog extends CommonDialog {
 	}
 	/**
 	 * ダイアログエリアを調整します。
-	 * 
+	 *
 	 */
 	private void adjustDialog(){
 		// サイズを最適化
@@ -702,7 +775,7 @@ public class FileCheckDialog extends CommonDialog {
 	}
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	public void update(){
 		/*
@@ -756,7 +829,7 @@ public class FileCheckDialog extends CommonDialog {
 
 	/**
 	 * ダイアログにスケジュール情報を反映します。
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.ScheduleTableDefine
 	 */
 	private void reflectJobFileCheck() {
@@ -766,7 +839,7 @@ public class FileCheckDialog extends CommonDialog {
 		//変更時、コピー時
 		if(mode == PropertyDefineConstant.MODE_MODIFY
 				|| mode == PropertyDefineConstant.MODE_COPY){
-			jobFileCheck = GetJobKick.getJobFileCheck(this.m_JobKickId);
+			jobFileCheck = GetJobKick.getJobFileCheck(this.managerName, this.m_JobKickId);
 		}else {
 			jobFileCheck = new JobFileCheck();
 		}
@@ -777,7 +850,7 @@ public class FileCheckDialog extends CommonDialog {
 			this.cmpOwnerRoleId.setText(jobFileCheck.getOwnerRoleId());
 		}
 		// 他CompositeへのオーナーロールIDの設定
-		this.cmpCalendarId.setOwnerRoleId(cmpOwnerRoleId.getText());
+		this.cmpCalendarId.createCalIdCombo(this.managerName, cmpOwnerRoleId.getText());
 
 		//実行契機IDを設定
 		if(jobFileCheck.getId() != null){
@@ -807,10 +880,6 @@ public class FileCheckDialog extends CommonDialog {
 		}
 		//カレンダIDを設定
 		if (jobFileCheck.getCalendarId() != null) {
-			if (!cmpCalendarId.getEnabled()) {
-				// カレンダー参照権限が無い場合
-				cmpCalendarId.addText(jobFileCheck.getCalendarId());
-			}
 			this.cmpCalendarId.setText(jobFileCheck.getCalendarId());
 		}
 
@@ -881,9 +950,9 @@ public class FileCheckDialog extends CommonDialog {
 
 	/**
 	 * ダイアログの情報からスケジュール情報を作成します。
-	 * 
+	 *
 	 * @return 入力値の検証結果
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.GetJobKickTableDefine
 	 */
 	private ValidateResult createJobFileCheck() {
@@ -1015,7 +1084,7 @@ public class FileCheckDialog extends CommonDialog {
 
 	/**
 	 * ＯＫボタンテキスト取得
-	 * 
+	 *
 	 * @return ＯＫボタンのテキスト
 	 */
 	@Override
@@ -1025,7 +1094,7 @@ public class FileCheckDialog extends CommonDialog {
 
 	/**
 	 * キャンセルボタンテキスト取得
-	 * 
+	 *
 	 * @return キャンセルボタンのテキスト
 	 */
 	@Override
@@ -1036,9 +1105,9 @@ public class FileCheckDialog extends CommonDialog {
 	/**
 	 * 入力値を保持したプロパティを返します。<BR>
 	 * プロパティオブジェクトのコピーを返します。
-	 * 
+	 *
 	 * @return プロパティ
-	 * 
+	 *
 	 * @see com.clustercontrol.util.PropertyUtil#copy(Property)
 	 */
 	@Override
@@ -1071,17 +1140,21 @@ public class FileCheckDialog extends CommonDialog {
 	protected boolean action() {
 		boolean result = false;
 		try {
+			String managerName = this.m_managerComposite.getText();
 			//変更時
+			JobEndpointWrapper wrapper = JobEndpointWrapper.getWrapper(managerName);
 			if(mode == PropertyDefineConstant.MODE_MODIFY){
-				JobEndpointWrapper.modifyFileCheck(m_jobFileCheck);
+				wrapper.modifyFileCheck(m_jobFileCheck);
+				Object[] arg = {managerName};
 				MessageDialog.openInformation(null, Messages.getString("successful"),
-						Messages.getString("message.job.77"));
+						Messages.getString("message.job.77",  arg));
 			}
 			//作成時、コピー時
 			else {
-				JobEndpointWrapper.addFileCheck(m_jobFileCheck);
+				wrapper.addFileCheck(m_jobFileCheck);
+				Object[] arg = {managerName};
 				MessageDialog.openInformation(null, Messages.getString("successful"),
-						Messages.getString("message.job.79"));
+						Messages.getString("message.job.79", arg));
 			}
 			result = true;
 		} catch (InvalidRole_Exception e) {
@@ -1115,4 +1188,13 @@ public class FileCheckDialog extends CommonDialog {
 		}
 		return result;
 	}
-}
\ No newline at end of file
+
+	private void updateCalendarId() {
+		cmpCalendarId.createCalIdCombo(this.m_managerComposite.getText(), cmpOwnerRoleId.getText());
+		txtJobId.setText("");
+		txtJobName.setText("");
+		setJobunitId(null);
+		m_facilityId = "";
+		txtScope.setText(m_facilityId);
+	}
+}
