@@ -609,10 +609,16 @@ public class JobDialog extends CommonDialog {
 			m_editButton.setEnabled(m_readOnly);
 		}
 		
-		m_jobIdText.setEnabled(!m_readOnly);
+		if (info.getType() == JobConstant.TYPE_JOBUNIT && info.getCreateTime() != null) {
+			// すでにマネージャに登録してあるジョブユニットはIDを変更できない
+			m_jobIdText.setEnabled(false);
+		} else {
+			// それ以外の場合は編集モードの有無で判定する
+			m_jobIdText.setEnabled(!m_readOnly);
+		}
+		
 		m_jobNameText.setEnabled(!m_readOnly);
 		m_jobAnnotationText.setEnabled(!m_readOnly);
-		m_ownerRoleId.setEnabled(!m_readOnly);
 		if (m_startComposite != null)
 			m_startComposite.setEnabled(!m_readOnly);
 		if (m_controlComposite != null)
@@ -697,12 +703,6 @@ public class JobDialog extends CommonDialog {
 				m_jobIdText.setText("");
 			}
 
-			JobEditState JobEditState = JobEditStateUtil.getJobEditState( m_managerName );
-			if (info.getType() == JobConstant.TYPE_JOBUNIT && JobEditState.getLockedJobunitBackup(info) != null) {
-				// すでにマネージャに登録してあるジョブユニットはIDを変更できない
-				m_jobIdText.setEditable(false);
-			}
-
 			//ジョブ名設定
 			if (info.getName() != null) {
 				m_jobNameText.setText(info.getName());
@@ -730,10 +730,7 @@ public class JobDialog extends CommonDialog {
 					}
 				}
 			}
-			// すでにマネージャに登録してあるオーナロールIDを変更できない
-			if( JobEditState.getLockedJobunitBackup(info) != null ){
-				this.m_ownerRoleId.setEnabled(false);
-			}
+
 			//参照タブ以外
 			if( info.getType() != JobConstant.TYPE_REFERJOB ){
 				this.m_messageComposite.getNotifyId().setOwnerRoleId(m_ownerRoleId.getText(), false);
