@@ -39,6 +39,7 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.bean.DayOfWeekConstant;
 import com.clustercontrol.bean.Property;
@@ -47,6 +48,7 @@ import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.ScheduleConstant;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.calendar.composite.CalendarIdListComposite;
+import com.clustercontrol.composite.ManagerListComposite;
 import com.clustercontrol.composite.RoleIdListComposite;
 import com.clustercontrol.composite.RoleIdListComposite.Mode;
 import com.clustercontrol.composite.action.ComboModifyListener;
@@ -67,7 +69,7 @@ import com.clustercontrol.ws.jobmanagement.JobTreeItem;
 
 /**
  * ジョブ[スケジュールの作成・変更]ダイアログクラスです。
- * 
+ *
  * @version 4.0.0
  * @since 1.0.0
  */
@@ -120,6 +122,9 @@ public class ScheduleDialog extends CommonDialog {
 	private RoleIdListComposite cmpOwnerRoleId = null;
 	/** シェル */
 	private Shell m_shell = null;
+	/** マネージャ名コンボボックス用コンポジット */
+	private ManagerListComposite m_managerComposite = null;
+
 	/**
 	 * 作成：MODE_ADD = 0;
 	 * 変更：MODE_MODIFY = 1;
@@ -133,14 +138,8 @@ public class ScheduleDialog extends CommonDialog {
 	/** 実行契機ID */
 	private String m_jobKickId;
 
-	/**
-	 * コンストラクタ
-	 * 作成時
-	 * @param parent 親シェル
-	 */
-	public ScheduleDialog(Shell parent) {
-		super(parent);
-	}
+	/** マネージャ名 */
+	private String m_managerName;
 
 	/**
 	 * コンストラクタ
@@ -148,14 +147,15 @@ public class ScheduleDialog extends CommonDialog {
 	 * @param parent
 	 * @param scheduleId
 	 */
-	public ScheduleDialog(Shell parent, String scheduleId, int mode){
+	public ScheduleDialog(Shell parent, String managerName, String scheduleId, int mode){
 		super(parent);
+		this.m_managerName = managerName;
 		this.m_jobKickId = scheduleId;
 		this.mode = mode;
 	}
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親コンポジット
 	 */
 	@Override
@@ -177,10 +177,9 @@ public class ScheduleDialog extends CommonDialog {
 
 		Composite composite = null;
 		GridData gridData= null;
-		/*
-		 * 実行契機ID
-		 */
+
 		composite = new Composite(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, composite);
 		GridLayout layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
@@ -191,8 +190,48 @@ public class ScheduleDialog extends CommonDialog {
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		composite.setLayoutData(gridData);
+
+		// マネージャ
+		Label labelManager = new Label(composite, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "manager", labelManager);
+		gridData = new GridData();
+		gridData.horizontalSpan = 3;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		labelManager.setLayoutData(gridData);
+		labelManager.setText(Messages.getString("facility.manager") + " : ");
+		if(this.mode == PropertyDefineConstant.MODE_MODIFY){
+			this.m_managerComposite = new ManagerListComposite(composite, SWT.NONE, false);
+		} else {
+			this.m_managerComposite = new ManagerListComposite(composite, SWT.NONE, true);
+		}
+		WidgetTestUtil.setTestId(this, "managerComposite", this.m_managerComposite);
+		gridData = new GridData();
+		gridData.horizontalSpan = 5;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		this.m_managerComposite.setLayoutData(gridData);
+
+		if(this.m_managerName != null) {
+			this.m_managerComposite.setText(this.m_managerName);
+		}
+		if(this.mode != PropertyDefineConstant.MODE_MODIFY) {
+			this.m_managerComposite.getComboManagerName().addSelectionListener(new SelectionAdapter() {
+				@Override
+				public void widgetSelected(SelectionEvent e) {
+					String managerName = m_managerComposite.getText();
+					cmpOwnerRoleId.createRoleIdList(managerName);
+					updateCalendarId();
+				}
+			});
+		}
+
+		/*
+		 * 実行契機ID
+		 */
 		//ラベル
 		Label labelScheduleId = new Label(composite, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "scheduleid", labelScheduleId);
 		gridData = new GridData();
 		gridData.horizontalSpan = 3;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -204,6 +243,7 @@ public class ScheduleDialog extends CommonDialog {
 		 * テキスト
 		 */
 		this.txtJobKickId = new Text(composite, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "jobkickid", txtJobKickId);
 		this.txtJobKickId.addVerifyListener(
 				new StringVerifyListener(DataRangeConstant.VARCHAR_64));
 		gridData = new GridData();
@@ -222,6 +262,7 @@ public class ScheduleDialog extends CommonDialog {
 		 */
 		//ラベル
 		Label labelScheduleName = new Label(composite, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "schedulename", labelScheduleName);
 		gridData = new GridData();
 		gridData.horizontalSpan = 3;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -230,6 +271,7 @@ public class ScheduleDialog extends CommonDialog {
 		labelScheduleName.setLayoutData(gridData);
 		//テキスト
 		this.txtJobKickName = new Text(composite, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "jobkickname", txtJobKickName);
 		gridData = new GridData();
 		gridData.horizontalSpan = 5;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -248,6 +290,7 @@ public class ScheduleDialog extends CommonDialog {
 		 * オーナーロールID
 		 */
 		Label labelRoleId = new Label(composite, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "roleid", labelRoleId);
 		gridData = new GridData();
 		gridData.horizontalSpan = 3;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -256,19 +299,22 @@ public class ScheduleDialog extends CommonDialog {
 		labelRoleId.setText(Messages.getString("owner.role.id") + " : ");
 		if (this.mode == PropertyDefineConstant.MODE_ADD
 				|| this.mode == PropertyDefineConstant.MODE_COPY) {
-			this.cmpOwnerRoleId = new RoleIdListComposite(composite, SWT.NONE, true, Mode.OWNER_ROLE);
+			this.cmpOwnerRoleId = new RoleIdListComposite(composite, SWT.NONE,
+					this.m_managerName, true, Mode.OWNER_ROLE);
 			this.cmpOwnerRoleId.getComboRoleId().addSelectionListener(new SelectionAdapter() {
 				@Override
 				public void widgetSelected(SelectionEvent e) {
-					cmpCalendarId.setOwnerRoleId(cmpOwnerRoleId.getText());
+					cmpCalendarId.createCalIdCombo(m_managerName, cmpOwnerRoleId.getText());
 					txtJobId.setText("");
 					txtJobName.setText("");
 					setJobunitId(null);
 				}
 			});
 		} else {
-			this.cmpOwnerRoleId = new RoleIdListComposite(composite, SWT.NONE, false, Mode.OWNER_ROLE);
+			this.cmpOwnerRoleId = new RoleIdListComposite(composite, SWT.NONE,
+					this.m_managerName, false, Mode.OWNER_ROLE);
 		}
+		WidgetTestUtil.setTestId(this, "ownerroleidlist", cmpOwnerRoleId);
 		gridData = new GridData();
 		gridData.horizontalSpan = 5;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -280,6 +326,7 @@ public class ScheduleDialog extends CommonDialog {
 		 */
 		//ラベル
 		Label labelJobId = new Label(composite, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "jobid", labelJobId);
 		gridData = new GridData();
 		gridData.horizontalSpan = 3;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -288,6 +335,7 @@ public class ScheduleDialog extends CommonDialog {
 		labelJobId.setLayoutData(gridData);
 		//テキスト
 		this.txtJobId = new Text(composite, SWT.READ_ONLY | SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "jobid", txtJobId);
 		gridData = new GridData();
 		gridData.horizontalSpan = 5;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -301,6 +349,7 @@ public class ScheduleDialog extends CommonDialog {
 		});
 		//ボタン
 		btnJobSelect = new Button(composite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "jobselect", btnJobSelect);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -310,10 +359,10 @@ public class ScheduleDialog extends CommonDialog {
 		btnJobSelect.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
-				JobTreeDialog dialog = new JobTreeDialog(m_shell, cmpOwnerRoleId.getText(), true);
+				JobTreeDialog dialog = new JobTreeDialog(m_shell, m_managerComposite.getText(), cmpOwnerRoleId.getText(), true);
 				if (dialog.open() == IDialogConstants.OK_ID) {
-					JobTreeItem selectItem = dialog.getSelectItem();
-					if (selectItem.getData().getType() != JobConstant.TYPE_COMPOSITE) {
+					JobTreeItem selectItem = dialog.getSelectItem().isEmpty() ? null : dialog.getSelectItem().get(0);
+					if (selectItem != null && selectItem.getData().getType() != JobConstant.TYPE_COMPOSITE) {
 						txtJobId.setText(selectItem.getData().getId());
 						txtJobName.setText(selectItem.getData().getName());
 						setJobunitId(selectItem.getData().getJobunitId());
@@ -330,6 +379,7 @@ public class ScheduleDialog extends CommonDialog {
 		 */
 		//ラベル
 		Label labelJobName = new Label(composite, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "jobname", labelJobName);
 		gridData = new GridData();
 		gridData.horizontalSpan = 3;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -338,6 +388,7 @@ public class ScheduleDialog extends CommonDialog {
 		labelJobName.setLayoutData(gridData);
 		//テキスト
 		txtJobName = new Text(composite, SWT.BORDER | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "jobname", txtJobName);
 		gridData = new GridData();
 		gridData.horizontalSpan = 5;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -348,6 +399,7 @@ public class ScheduleDialog extends CommonDialog {
 		 */
 		//ラベル
 		Label labelCalendarId = new Label(composite, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "calendarid", labelCalendarId);
 		gridData = new GridData();
 		gridData.horizontalSpan = 3;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -356,6 +408,7 @@ public class ScheduleDialog extends CommonDialog {
 		labelCalendarId.setLayoutData(gridData);
 		//コンボボックス
 		cmpCalendarId = new CalendarIdListComposite(composite, SWT.NONE, false);
+		WidgetTestUtil.setTestId(this, "calendarid", cmpCalendarId);
 		gridData = new GridData();
 		gridData.horizontalSpan = 6;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -366,6 +419,7 @@ public class ScheduleDialog extends CommonDialog {
 		 * スケジュール設定グループ
 		 */
 		Group groupSchedule = new Group(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "setting", groupSchedule);
 		// 変数として利用されるグリッドデータ
 		gridData = null;
 		layout = new GridLayout(1, true);
@@ -385,6 +439,7 @@ public class ScheduleDialog extends CommonDialog {
 		createType3(groupSchedule);
 
 		Group groupValidOrInvalid = new Group(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "validorinvalid", groupValidOrInvalid);
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
@@ -400,6 +455,7 @@ public class ScheduleDialog extends CommonDialog {
 
 		//有効ボタン
 		btnValid = new Button(groupValidOrInvalid, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "valid", btnValid);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -409,6 +465,7 @@ public class ScheduleDialog extends CommonDialog {
 		btnValid.setSelection(true);
 		//無効ボタン
 		btnInvalid = new Button(groupValidOrInvalid, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "invalid", btnInvalid);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -425,7 +482,7 @@ public class ScheduleDialog extends CommonDialog {
 
 	/**
 	 * ダイアログエリアを調整します。
-	 * 
+	 *
 	 */
 	private void adjustDialog(){
 		// サイズを最適化
@@ -442,11 +499,12 @@ public class ScheduleDialog extends CommonDialog {
 
 	/**
 	 * スケジュール日時指定を生成します。
-	 * 
+	 *
 	 * @param parent 親グループ
 	 */
 	private void createType1(Group parent) {
 		btnType1 = new Button(parent, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "type1", btnType1);
 
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = 4;
@@ -467,6 +525,7 @@ public class ScheduleDialog extends CommonDialog {
 
 		//空白ラベル
 		Label label = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space", label);
 		label.setText(Messages.getString(""));
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
@@ -475,6 +534,7 @@ public class ScheduleDialog extends CommonDialog {
 		label.setLayoutData(gridData);
 
 		cmbHours1 = new Combo(parent, SWT.READ_ONLY | SWT.NONE);
+		WidgetTestUtil.setTestId(this, "hours1", cmbHours1);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -498,6 +558,7 @@ public class ScheduleDialog extends CommonDialog {
 		});
 
 		Label labelHours = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "hours", labelHours);
 		labelHours.setText(Messages.getString("hr"));
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
@@ -506,6 +567,7 @@ public class ScheduleDialog extends CommonDialog {
 		labelHours.setLayoutData(gridData);
 
 		cmbMinutes1 = new Combo(parent, SWT.READ_ONLY | SWT.NONE);
+		WidgetTestUtil.setTestId(this, "minutes1", cmbMinutes1);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -528,6 +590,7 @@ public class ScheduleDialog extends CommonDialog {
 		});
 
 		Label labelMinutes = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "minutes", labelMinutes);
 		labelMinutes.setText(Messages.getString("min"));
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
@@ -538,11 +601,12 @@ public class ScheduleDialog extends CommonDialog {
 
 	/**
 	 * スケジュール曜日指定を生成します。
-	 * 
+	 *
 	 * @param parent 親グループ
 	 */
 	private void createType2(Group parent) {
 		btnType2 = new Button(parent, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "type2", btnType2);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -562,6 +626,7 @@ public class ScheduleDialog extends CommonDialog {
 		});
 
 		cmbDayOfWeek = new Combo(parent, SWT.READ_ONLY | SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "dayofweek", cmbDayOfWeek);
 		gridData = new GridData();
 		gridData.horizontalSpan =4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -584,6 +649,7 @@ public class ScheduleDialog extends CommonDialog {
 			}
 		});
 		cmbHours2 = new Combo(parent, SWT.READ_ONLY | SWT.NONE);
+		WidgetTestUtil.setTestId(this, "hour2", cmbHours2);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -607,6 +673,7 @@ public class ScheduleDialog extends CommonDialog {
 		});
 
 		Label labelHours = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "hours", labelHours);
 		labelHours.setText(Messages.getString("hr"));
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
@@ -615,6 +682,7 @@ public class ScheduleDialog extends CommonDialog {
 		labelHours.setLayoutData(gridData);
 
 		cmbMinutes2 = new Combo(parent, SWT.READ_ONLY | SWT.NONE);
+		WidgetTestUtil.setTestId(this, "minutes2", cmbMinutes2);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -637,6 +705,7 @@ public class ScheduleDialog extends CommonDialog {
 		});
 
 		Label labelMinutes = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "minutes2", labelMinutes);
 		labelMinutes.setText(Messages.getString("min"));
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
@@ -652,6 +721,7 @@ public class ScheduleDialog extends CommonDialog {
 	private void createType3(Group parent) {
 
 		btnType3 = new Button(parent, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "type3", btnType3);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -669,6 +739,7 @@ public class ScheduleDialog extends CommonDialog {
 		});
 
 		cmbMinutesP = new Combo(parent, SWT.READ_ONLY | SWT.NONE);
+		WidgetTestUtil.setTestId(this, "minutesp", cmbMinutesP);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -687,6 +758,7 @@ public class ScheduleDialog extends CommonDialog {
 		});
 
 		Label labelMinutesFrom = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "minutesfrom", labelMinutesFrom);
 		labelMinutesFrom.setText(Messages.getString("schedule.min.start.time"));
 		gridData = new GridData();
 		gridData.horizontalSpan = 5;
@@ -695,6 +767,7 @@ public class ScheduleDialog extends CommonDialog {
 		labelMinutesFrom.setLayoutData(gridData);
 
 		cmbMinutesQ = new Combo(parent, SWT.READ_ONLY | SWT.NONE);
+		WidgetTestUtil.setTestId(this, "minutesq", cmbMinutesQ);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -710,21 +783,27 @@ public class ScheduleDialog extends CommonDialog {
 		cmbMinutesQ.add(format.format(15));
 		cmbMinutesQ.add(format.format(20));
 		cmbMinutesQ.add(format.format(30));
-		cmbMinutesQ.select(0);
+		cmbMinutesQ.add(format.format(60));
+		cmbMinutesQ.select(5);
 
 		this.cmbMinutesQ.addModifyListener(new ModifyListener(){
 			@Override
 			public void modifyText(ModifyEvent arg0) {
 				DecimalFormat format = new DecimalFormat("00");
 				int tmp = new Integer(cmbMinutesP.getSelectionIndex());
+				int minutesQ = 0;
 				try {
-					int minutesQ = Integer.parseInt(cmbMinutesQ.getText());
+					minutesQ = Integer.parseInt(cmbMinutesQ.getText());
 					cmbMinutesP.removeAll();
 					for (int minutes = 0; minutes < minutesQ; minutes++) {
 						cmbMinutesP.add(format.format(minutes));
 					}
 				}catch (NumberFormatException e){
-					cmbMinutesQ.setText("05");
+					// 初期表示の場合にしかこの例外は発生しない
+					cmbMinutesQ.setText("60");
+				}
+				if (minutesQ > 0) {
+					tmp = tmp%minutesQ;
 				}
 				if(cmbMinutesP.getItemCount() > tmp){
 					cmbMinutesP.select(tmp);
@@ -737,6 +816,7 @@ public class ScheduleDialog extends CommonDialog {
 			cmbMinutesP.add(format.format(minutes));
 		}
 		Label labelMinutesTo = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "minutesto", labelMinutesTo);
 		labelMinutesTo.setText(Messages.getString("schedule.min.execution.interval"));
 		gridData = new GridData();
 		gridData.horizontalSpan = 7;
@@ -747,7 +827,7 @@ public class ScheduleDialog extends CommonDialog {
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	public void update(){
 		// 必須項目を明示
@@ -835,7 +915,7 @@ public class ScheduleDialog extends CommonDialog {
 
 	/**
 	 * ダイアログにスケジュール情報を反映します。
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.ScheduleTableDefine
 	 */
 	private void reflectJobSchedule() {
@@ -844,7 +924,7 @@ public class ScheduleDialog extends CommonDialog {
 		//if(this.m_jobKickId!= null){
 		if(mode == PropertyDefineConstant.MODE_MODIFY
 				|| mode == PropertyDefineConstant.MODE_COPY){
-			jobschedule = GetJobKick.getJobSchedule(this.m_jobKickId);
+			jobschedule = GetJobKick.getJobSchedule(this.m_managerName, this.m_jobKickId);
 		}else {
 			jobschedule = new JobSchedule();
 			btnType1.setSelection(true);
@@ -861,7 +941,7 @@ public class ScheduleDialog extends CommonDialog {
 			this.cmpOwnerRoleId.setText(jobschedule.getOwnerRoleId());
 		}
 		// 他CompositeへのオーナーロールIDの設定
-		this.cmpCalendarId.setOwnerRoleId(cmpOwnerRoleId.getText());
+		this.cmpCalendarId.createCalIdCombo(this.m_managerComposite.getText(), cmpOwnerRoleId.getText());
 
 		//実行契機IDを設定
 		if(jobschedule.getId() != null){
@@ -891,10 +971,6 @@ public class ScheduleDialog extends CommonDialog {
 		}
 		//カレンダIDを設定
 		if (jobschedule.getCalendarId() != null) {
-			if (!cmpCalendarId.getEnabled()) {
-				// カレンダー参照権限が無い場合
-				cmpCalendarId.addText(jobschedule.getCalendarId());
-			}
 			this.cmpCalendarId.setText(jobschedule.getCalendarId());
 		}
 
@@ -1010,9 +1086,9 @@ public class ScheduleDialog extends CommonDialog {
 
 	/**
 	 * ダイアログの情報からスケジュール情報を作成します。
-	 * 
+	 *
 	 * @return 入力値の検証結果
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.GetJobKickTableDefine
 	 */
 	private ValidateResult createJobSchedule() {
@@ -1167,7 +1243,7 @@ public class ScheduleDialog extends CommonDialog {
 
 	/**
 	 * ＯＫボタンテキスト取得
-	 * 
+	 *
 	 * @return ＯＫボタンのテキスト
 	 */
 	@Override
@@ -1177,7 +1253,7 @@ public class ScheduleDialog extends CommonDialog {
 
 	/**
 	 * キャンセルボタンテキスト取得
-	 * 
+	 *
 	 * @return キャンセルボタンのテキスト
 	 */
 	@Override
@@ -1188,9 +1264,9 @@ public class ScheduleDialog extends CommonDialog {
 	/**
 	 * 入力値を保持したプロパティを返します。<BR>
 	 * プロパティオブジェクトのコピーを返します。
-	 * 
+	 *
 	 * @return プロパティ
-	 * 
+	 *
 	 * @see com.clustercontrol.util.PropertyUtil#copy(Property)
 	 */
 	@Override
@@ -1225,30 +1301,20 @@ public class ScheduleDialog extends CommonDialog {
 	protected boolean action() {
 		boolean result = false;
 		try {
-			/*
-			//変更時
-			if (m_mode) {
-				JobEndpointWrapper.modifySchedule(m_jobSchedule);
-				MessageDialog.openInformation(null, Messages.getString("successful"),
-						Messages.getString("message.job.77"));
-			}
-			//作成時
-			else {
-				JobEndpointWrapper.addSchedule(m_jobSchedule);
-				MessageDialog.openInformation(null, Messages.getString("successful"),
-						Messages.getString("message.job.79"));
-			}
-			 */
+			String managerName = this.m_managerComposite.getText();
 
+			JobEndpointWrapper wrapper = JobEndpointWrapper.getWrapper(managerName);
 			if(mode == PropertyDefineConstant.MODE_MODIFY){
-				JobEndpointWrapper.modifySchedule(m_jobSchedule);
+				wrapper.modifySchedule(m_jobSchedule);
+				Object[] arg = {managerName};
 				MessageDialog.openInformation(null, Messages.getString("successful"),
-						Messages.getString("message.job.77"));
+						Messages.getString("message.job.77", arg));
 			}
 			else {//
-				JobEndpointWrapper.addSchedule(m_jobSchedule);
+				wrapper.addSchedule(m_jobSchedule);
+				Object[] arg = {managerName};
 				MessageDialog.openInformation(null, Messages.getString("successful"),
-						Messages.getString("message.job.79"));
+						Messages.getString("message.job.79", arg));
 			}
 			result = true;
 		} catch (InvalidRole_Exception e) {
@@ -1282,4 +1348,11 @@ public class ScheduleDialog extends CommonDialog {
 		}
 		return result;
 	}
-}
\ No newline at end of file
+
+	private void updateCalendarId() {
+		cmpCalendarId.createCalIdCombo(this.m_managerComposite.getText(), cmpOwnerRoleId.getText());
+		txtJobId.setText("");
+		txtJobName.setText("");
+		setJobunitId(null);
+	}
+}
