@@ -66,22 +66,21 @@ public class JobSessionImpl {
 	 * @throws FacilityNotFound 
 	 */
 	public void runningCheck(String sessionId) throws JobInfoNotFound, InvalidRole, HinemosUnknown, FacilityNotFound {
-		runningCheck(sessionId, StatusConstant.TYPE_RUNNING);
-		runningCheck(sessionId, StatusConstant.TYPE_WAIT);
-	}
-
-	public void runningCheck(String sessionId, int status) throws JobInfoNotFound, InvalidRole, HinemosUnknown, FacilityNotFound {
 		m_log.info("runningCheck() start : sessionid = " + sessionId);
 
 		JobSessionJobImpl.maxCheckDate(sessionId);
 
 		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		m_log.debug("_runJob() start : sessionId = " + sessionId);
-		//実行状態が実行中のセッションジョブを取得
+		//実行状態が実行中、待機のセッションジョブを取得
+		List<Integer> statuses = new ArrayList<Integer>();
+		statuses.add(StatusConstant.TYPE_RUNNING);
+		statuses.add(StatusConstant.TYPE_WAIT);
+		
 		Collection<JobSessionJobEntity> collection = null;
-		collection = em.createNamedQuery("JobSessionJobEntity.findBySessionStatus", JobSessionJobEntity.class)
+		collection = em.createNamedQuery("JobSessionJobEntity.findBySessionStatuses", JobSessionJobEntity.class)
 				.setParameter("sessionId", sessionId)
-				.setParameter("status", status)
+				.setParameter("statuses", statuses)
 				.getResultList();
 
 		for (JobSessionJobEntity sessionJob : collection){
