@@ -15,20 +15,21 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.jobmanagement.factory;
 
+import java.io.Serializable;
 import java.sql.Timestamp;
 import java.text.ParseException;
 import java.util.Date;
 
 import javax.persistence.EntityExistsException;
-import javax.persistence.EntityManager;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.quartz.SchedulerException;
 
 import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.ObjectPrivilegeMode;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.commons.scheduler.QuartzUtil;
-import com.clustercontrol.commons.util.EmptyJpaTransactionCallback; 
+import com.clustercontrol.commons.util.EmptyJpaTransactionCallback;
 import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.fault.HinemosUnknown;
@@ -37,10 +38,10 @@ import com.clustercontrol.fault.JobInfoNotFound;
 import com.clustercontrol.fault.JobKickDuplicate;
 import com.clustercontrol.fault.ObjectPrivilege_InvalidRole;
 import com.clustercontrol.jobmanagement.bean.JobFileCheck;
+import com.clustercontrol.jobmanagement.bean.JobSchedule;
 import com.clustercontrol.jobmanagement.bean.JobTriggerInfo;
 import com.clustercontrol.jobmanagement.bean.JobTriggerTypeConstant;
 import com.clustercontrol.jobmanagement.bean.QuartzConstant;
-import com.clustercontrol.jobmanagement.bean.JobSchedule;
 import com.clustercontrol.jobmanagement.model.JobFileCheckEntity;
 import com.clustercontrol.jobmanagement.model.JobScheduleEntity;
 import com.clustercontrol.jobmanagement.session.JobControllerBean;
@@ -59,14 +60,14 @@ public class ModifyJobKick {
 
 	/**
 	 * スケジュール情報をDBに反映し、スケジューラにジョブを登録します。<BR>
-	 * 
+	 *
 	 * @param info スケジュール情報
 	 * @param user ユーザID
 	 * @throws JobKickDuplicate
 	 * @throws InvalidSetting
 	 * @throws ParseException
 	 * @throws SchedulerException
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.QuartzConstant
 	 * @see com.clustercontrol.jobmanagement.bean.JobTriggerInfo
 	 * @see com.clustercontrol.jobmanagement.util.QuartzUtil#getQuartzManager()
@@ -111,40 +112,40 @@ public class ModifyJobKick {
 			throw new HinemosUnknown(e.getMessage(), e);
 		}
 		
-		jtm.addCallback(new EmptyJpaTransactionCallback() { 
+		jtm.addCallback(new EmptyJpaTransactionCallback() {
 			@Override
 			public void postCommit() {
 				//実行契機情報の作成
 				JobTriggerInfo triggerInfo = new JobTriggerInfo();
 				triggerInfo.setTrigger_type(JobTriggerTypeConstant.TYPE_SCHEDULE);
 				triggerInfo.setTrigger_info(info.getName()+"("+info.getId()+")");
-
+				
 				//JobDetailに呼び出すメソッドの引数を設定
-				Object[] jdArgs = new Object[QuartzConstant.ARGS_NUM];
-				Class[] jdArgsType = new Class[QuartzConstant.ARGS_NUM];
+				Serializable[] jdArgs = new Serializable[QuartzConstant.ARGS_NUM];
+				Class<? extends Serializable>[] jdArgsType = new Class[QuartzConstant.ARGS_NUM];
 				//ジョブユニットIDを設定
 				jdArgs[QuartzConstant.INDEX_JOBUNIT_ID] = info.getJobunitId();
 				jdArgsType[QuartzConstant.INDEX_JOBUNIT_ID] = String.class;
-
+				
 				//ジョブIDを設定
 				jdArgs[QuartzConstant.INDEX_JOB_ID] = info.getJobId();
 				jdArgsType[QuartzConstant.INDEX_JOB_ID] = String.class;
-
+				
 				//カレンダIDを設定
 				jdArgs[QuartzConstant.INDEX_CALENDAR_ID] = info.getCalendarId();
 				jdArgsType[QuartzConstant.INDEX_CALENDAR_ID] = String.class;
-
+				
 				//実行契機情報を設定
 				jdArgs[QuartzConstant.INDEX_TRIGGER_INFO] = triggerInfo;
 				jdArgsType[QuartzConstant.INDEX_TRIGGER_INFO] = JobTriggerInfo.class;
-
+				
 				//Cron表記へ変換
 				String cronString = QuartzUtil.getCronString(info.getScheduleType(),
 						info.getWeek(),info.getHour(),info.getMinute(),
 						info.getFromXminutes(),info.getEveryXminutes());
-
+				
 				m_log.trace("CronString =" + cronString);
-
+				
 				// スケジュール定義を登録
 				try {
 					SchedulerPlugin.scheduleCronJob(SchedulerType.DBMS, info.getId(), QuartzConstant.GROUP_NAME, new Date(System.currentTimeMillis() + 15 * 1000), cronString,
@@ -160,14 +161,14 @@ public class ModifyJobKick {
 	}
 	/**
 	 * ファイルチェック情報をDBに反映します。<BR>
-	 * 
+	 *
 	 * @param info ファイルチェック情報
 	 * @param user ユーザID
 	 * @throws JobKickDuplicate
 	 * @throws InvalidSetting
 	 * @throws ParseException
 	 * @throws SchedulerException
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.QuartzConstant
 	 * @see com.clustercontrol.jobmanagement.bean.JobTriggerInfo
 	 * @see com.clustercontrol.jobmanagement.util.QuartzUtil#getQuartzManager()
@@ -192,8 +193,8 @@ public class ModifyJobKick {
 				jobFileCheckEntity.setCalendarId(info.getCalendarId());
 			}
 			jobFileCheckEntity.setFacilityId(info.getFacilityId());
-			jobFileCheckEntity.setDirectory(info.getDirectory());
 			jobFileCheckEntity.setFileName(info.getFileName());
+			jobFileCheckEntity.setDirectory(info.getDirectory());
 			jobFileCheckEntity.setEventType(info.getEventType());
 			jobFileCheckEntity.setModifyType(info.getModifyType());
 
@@ -219,7 +220,7 @@ public class ModifyJobKick {
 
 		//JobDetailに呼び出すメソッドの引数を設定
 		Object[] jdArgs = new Object[QuartzConstant.ARGS_NUM];
-		Class[] jdArgsType = new Class[QuartzConstant.ARGS_NUM];
+		Class<?>[] jdArgsType = new Class[QuartzConstant.ARGS_NUM];
 		//ジョブユニットIDを設定
 		jdArgs[QuartzConstant.INDEX_JOBUNIT_ID] = info.getJobunitId();
 		jdArgsType[QuartzConstant.INDEX_JOBUNIT_ID] = String.class;
@@ -247,13 +248,13 @@ public class ModifyJobKick {
 	public void modifySchedule(final JobSchedule info, String loginUser) throws HinemosUnknown, JobInfoNotFound, ObjectPrivilege_InvalidRole{
 		m_log.debug("modifySchedule() : id=" + info.getId() + ", jobId=" + info.getJobId());
 		JpaTransactionManager jtm = new JpaTransactionManager();
-		EntityManager em = jtm.getEntityManager();
+		HinemosEntityManager em = jtm.getEntityManager();
 		//最終更新日時を設定
 		Timestamp now = new Timestamp(new Date().getTime());
 		// DBにスケジュール情報を保存
 		try {
-			JobScheduleEntity bean  = ((HinemosEntityManager)em).find(JobScheduleEntity.class, info.getId(), 
-					ObjectPrivilegeMode.WRITE);
+			JobScheduleEntity bean  = em.find(JobScheduleEntity.class, info.getId(),
+					ObjectPrivilegeMode.MODIFY);
 			if (bean == null) {
 				JobInfoNotFound e = new JobInfoNotFound("JobScheduleEntity.findByPrimaryKey");
 				m_log.info(e.getClass().getSimpleName() + ", " + e.getMessage());
@@ -294,40 +295,40 @@ public class ModifyJobKick {
 			throw new HinemosUnknown(e.getMessage(), e);
 		}
 		
-		jtm.addCallback(new EmptyJpaTransactionCallback() { 
+		jtm.addCallback(new EmptyJpaTransactionCallback() {
 			@Override
 			public void postCommit() {
 				//実行契機情報の作成
 				JobTriggerInfo triggerInfo = new JobTriggerInfo();
 				triggerInfo.setTrigger_type(JobTriggerTypeConstant.TYPE_SCHEDULE);
 				triggerInfo.setTrigger_info(info.getName()+"("+info.getId()+")");
-
+				
 				//JobDetailに呼び出すメソッドの引数を設定
-				Object[] jdArgs = new Object[QuartzConstant.ARGS_NUM];
-				Class[] jdArgsType = new Class[QuartzConstant.ARGS_NUM];
+				Serializable[] jdArgs = new Serializable[QuartzConstant.ARGS_NUM];
+				Class<? extends Serializable>[] jdArgsType = new Class[QuartzConstant.ARGS_NUM];
 				//ジョブユニットIDを設定
 				jdArgs[QuartzConstant.INDEX_JOBUNIT_ID] = info.getJobunitId();
 				jdArgsType[QuartzConstant.INDEX_JOBUNIT_ID] = String.class;
-
+				
 				//ジョブIDを設定
 				jdArgs[QuartzConstant.INDEX_JOB_ID] = info.getJobId();
 				jdArgsType[QuartzConstant.INDEX_JOB_ID] = String.class;
-
+				
 				//カレンダIDを設定
 				jdArgs[QuartzConstant.INDEX_CALENDAR_ID] = info.getCalendarId();
 				jdArgsType[QuartzConstant.INDEX_CALENDAR_ID] = String.class;
-
+				
 				//実行契機情報を設定
 				jdArgs[QuartzConstant.INDEX_TRIGGER_INFO] = triggerInfo;
 				jdArgsType[QuartzConstant.INDEX_TRIGGER_INFO] = JobTriggerInfo.class;
-
+				
 				//Cron表記へ変換
 				String cronString = QuartzUtil.getCronString(info.getScheduleType(),
 						info.getWeek(),info.getHour(),info.getMinute(),
 						info.getFromXminutes(),info.getEveryXminutes());
-
+				
 				m_log.trace("CronString =" + cronString);
-
+				
 				// スケジュール定義を登録
 				try {
 					SchedulerPlugin.scheduleCronJob(SchedulerType.DBMS, info.getId(), QuartzConstant.GROUP_NAME, new Date(System.currentTimeMillis() + 15 * 1000), cronString,
@@ -340,7 +341,8 @@ public class ModifyJobKick {
 				}
 			}
 		});
-		
+
+
 	}
 	/**
 	 * DBのファイルチェック情報を変更します。<BR>
@@ -352,13 +354,13 @@ public class ModifyJobKick {
 	public void modifyFileCheck(JobFileCheck info, String loginUser) throws HinemosUnknown, JobInfoNotFound, ObjectPrivilege_InvalidRole{
 		m_log.debug("modifyFileCheck() : scheduleId=" + info.getId());
 		JpaTransactionManager jtm = new JpaTransactionManager();
-		EntityManager em = jtm.getEntityManager();
+		HinemosEntityManager em = jtm.getEntityManager();
 		//最終更新日時を設定
 		Timestamp now = new Timestamp(new Date().getTime());
 		// DBにファイルチェック情報を保存
 		try {
-			JobFileCheckEntity bean  = ((HinemosEntityManager)em).find(JobFileCheckEntity.class, info.getId(), 
-					ObjectPrivilegeMode.WRITE);
+			JobFileCheckEntity bean  = em.find(JobFileCheckEntity.class, info.getId(),
+					ObjectPrivilegeMode.MODIFY);
 			if (bean == null) {
 				JobInfoNotFound e = new JobInfoNotFound("JobFileCheckEntity.findByPrimaryKey");
 				m_log.info(e.getClass().getSimpleName() + ", " + e.getMessage());
@@ -404,7 +406,7 @@ public class ModifyJobKick {
 
 		//JobDetailに呼び出すメソッドの引数を設定
 		Object[] jdArgs = new Object[QuartzConstant.ARGS_NUM];
-		Class[] jdArgsType = new Class[QuartzConstant.ARGS_NUM];
+		Class<?>[] jdArgsType = new Class[QuartzConstant.ARGS_NUM];
 		//ジョブユニットIDを設定
 		jdArgs[QuartzConstant.INDEX_JOBUNIT_ID] = info.getJobunitId();
 		jdArgsType[QuartzConstant.INDEX_JOBUNIT_ID] = String.class;
@@ -423,11 +425,11 @@ public class ModifyJobKick {
 	}
 	/**
 	 * スケジュール情報を基にQuartzに登録したジョブを削除します。
-	 * 
+	 *
 	 * @param scheduleId スケジュールID
 	 * @throws JobInfoNotFound
 	 * @throws SchedulerException
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.QuartzConstant
 	 * @see com.clustercontrol.jobmanagement.util.QuartzUtil#getQuartzManager()
 	 * @see com.clustercontrol.quartzmanager.ejb.session.QuartzManager#deleteSchedule(java.lang.String, java.lang.String)
@@ -437,12 +439,12 @@ public class ModifyJobKick {
 		m_log.debug("deleteSchedule() : id=" + scheduleId);
 
 		JpaTransactionManager jtm = new JpaTransactionManager();
-		EntityManager em = jtm.getEntityManager();
+		HinemosEntityManager em = jtm.getEntityManager();
 		// DBのスケジュール情報を削除
 		try {
 			//削除対象を検索
-			JobScheduleEntity jobScheduleEntity = ((HinemosEntityManager)em).find(JobScheduleEntity.class, scheduleId, 
-					ObjectPrivilegeMode.WRITE);
+			JobScheduleEntity jobScheduleEntity = em.find(JobScheduleEntity.class, scheduleId,
+					ObjectPrivilegeMode.MODIFY);
 			if (jobScheduleEntity == null) {
 				JobInfoNotFound e = new JobInfoNotFound("JobScheduleEntity.findByPrimaryKey");
 				m_log.info(e.getClass().getSimpleName() + ", " + e.getMessage());
@@ -466,10 +468,11 @@ public class ModifyJobKick {
 				try {
 					SchedulerPlugin.deleteJob(SchedulerType.DBMS, scheduleId, QuartzConstant.GROUP_NAME);
 				} catch (HinemosUnknown e) {
-					 m_log.error(e); 
+					m_log.error(e);
 				}
 			}
 		});
+
 	}
 	public void deleteFileCheck(String scheduleId) throws HinemosUnknown, JobInfoNotFound, ObjectPrivilege_InvalidRole {
 		// ファイルチェック定義を削除
@@ -477,13 +480,13 @@ public class ModifyJobKick {
 		JpaTransactionManager jtm = null;
 
 		jtm = new JpaTransactionManager();
-		EntityManager em = jtm.getEntityManager();
+		HinemosEntityManager em = jtm.getEntityManager();
 
 		// DBのファイルチェック情報を削除
 		try {
 			//削除対象を検索
-			JobFileCheckEntity jobFileCheckEntity = ((HinemosEntityManager)em).find(JobFileCheckEntity.class, scheduleId,
-					ObjectPrivilegeMode.WRITE);
+			JobFileCheckEntity jobFileCheckEntity = em.find(JobFileCheckEntity.class, scheduleId,
+					ObjectPrivilegeMode.MODIFY);
 			if (jobFileCheckEntity == null) {
 				JobInfoNotFound e = new JobInfoNotFound("JobFileCheckEntity.findByPrimaryKey");
 				m_log.info(e.getClass().getSimpleName() + ", " + e.getMessage());
