@@ -15,8 +15,6 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.jobmanagement.factory;
 
-import java.io.File;
-import java.io.FileInputStream;
 import java.text.DateFormat;
 import java.util.ArrayList;
 import java.util.Collection;
@@ -27,9 +25,7 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
-import java.util.Properties;
 
-import javax.persistence.EntityManager;
 import javax.persistence.TypedQuery;
 
 import net.sf.jpasecurity.jpql.parser.JpqlBrackets;
@@ -47,12 +43,6 @@ import net.sf.jpasecurity.jpql.parser.ToStringVisitor;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.fault.HinemosUnknown;
-import com.clustercontrol.fault.InvalidRole;
-import com.clustercontrol.fault.JobInfoNotFound;
-import com.clustercontrol.fault.JobMasterNotFound;
-import com.clustercontrol.fault.NotifyNotFound;
-import com.clustercontrol.fault.UserNotFound;
 import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.ObjectPrivilegeMode;
 import com.clustercontrol.accesscontrol.jpql.compile.QueryPreparator;
 import com.clustercontrol.accesscontrol.model.ObjectPrivilegeEntity;
@@ -64,6 +54,12 @@ import com.clustercontrol.bean.YesNoConstant;
 import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.commons.util.HinemosSessionContext;
 import com.clustercontrol.commons.util.JpaTransactionManager;
+import com.clustercontrol.fault.HinemosUnknown;
+import com.clustercontrol.fault.InvalidRole;
+import com.clustercontrol.fault.JobInfoNotFound;
+import com.clustercontrol.fault.JobMasterNotFound;
+import com.clustercontrol.fault.NotifyNotFound;
+import com.clustercontrol.fault.UserNotFound;
 import com.clustercontrol.jobmanagement.bean.JobCommandInfo;
 import com.clustercontrol.jobmanagement.bean.JobConstant;
 import com.clustercontrol.jobmanagement.bean.JobDetailInfo;
@@ -75,7 +71,6 @@ import com.clustercontrol.jobmanagement.bean.JobHistoryFilter;
 import com.clustercontrol.jobmanagement.bean.JobHistoryList;
 import com.clustercontrol.jobmanagement.bean.JobInfo;
 import com.clustercontrol.jobmanagement.bean.JobNodeDetail;
-import com.clustercontrol.jobmanagement.bean.JobNotificationsInfo;
 import com.clustercontrol.jobmanagement.bean.JobObjectInfo;
 import com.clustercontrol.jobmanagement.bean.JobParameterInfo;
 import com.clustercontrol.jobmanagement.bean.JobTreeItem;
@@ -85,7 +80,6 @@ import com.clustercontrol.jobmanagement.bean.JudgmentObjectConstant;
 import com.clustercontrol.jobmanagement.model.JobEndInfoEntity;
 import com.clustercontrol.jobmanagement.model.JobInfoEntity;
 import com.clustercontrol.jobmanagement.model.JobMstEntity;
-import com.clustercontrol.jobmanagement.model.JobNoticeInfoEntity;
 import com.clustercontrol.jobmanagement.model.JobParamInfoEntity;
 import com.clustercontrol.jobmanagement.model.JobSessionEntity;
 import com.clustercontrol.jobmanagement.model.JobSessionJobEntity;
@@ -93,6 +87,7 @@ import com.clustercontrol.jobmanagement.model.JobSessionNodeEntity;
 import com.clustercontrol.jobmanagement.model.JobStartJobInfoEntity;
 import com.clustercontrol.jobmanagement.util.JobUtil;
 import com.clustercontrol.jobmanagement.util.QueryUtil;
+import com.clustercontrol.maintenance.util.HinemosPropertyUtil;
 import com.clustercontrol.notify.bean.NotifyRelationInfo;
 import com.clustercontrol.notify.session.NotifyControllerBean;
 import com.clustercontrol.repository.session.RepositoryControllerBean;
@@ -111,38 +106,6 @@ public class SelectJob {
 	private static Log m_log = LogFactory.getLog( SelectJob.class );
 	/** 最大表示数 */
 	private final static int MAX_DISPLAY_NUMBER = 500;
-	/** ファイル転送ジョブ展開表示 */
-	private static Boolean m_openForwardFileJob = null;
-
-	/**
-	 * コンストラクタ
-	 * <P>
-	 * ジョブ管理プロパティファイルから、ファイル転送ジョブ展開表示設定を取得します。
-	 */
-	public SelectJob(){
-		if(m_openForwardFileJob == null){
-			try {
-				Properties properties = new Properties();
-				String etcdir = System.getProperty("hinemos.manager.etc.dir");
-				String propertyFile = etcdir + File.separator + "hinemos.properties";
-
-				// プロパティファイルからキーと値のリストを読み込みます
-				properties.load(new FileInputStream(propertyFile));
-
-				String mode = properties.getProperty("job.open.forward.file.job", "false");
-				if(mode.equalsIgnoreCase("true")){
-					m_openForwardFileJob = true;
-				}
-				else {
-					m_openForwardFileJob = false;
-				}
-			} catch (Exception e) {
-				m_log.warn("SelectJob() : "
-						+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
-				m_openForwardFileJob = false;
-			}
-		}
-	}
 
 	/**
 	 * ジョブツリー情報を取得します。
@@ -156,7 +119,7 @@ public class SelectJob {
 	 *   <li>ジョブマスタとジョブツリー情報のルートを渡して、ジョブツリー情報の作成を行います。</li>
 	 *   </ol>
 	 * </ol>
-	 * 
+	 *
 	 * @param treeOnly true=ジョブ情報を含まない, false=ジョブ情報含む
 	 * @param locale ロケール情報
 	 * @param userId ログインユーザのユーザID
@@ -164,13 +127,13 @@ public class SelectJob {
 	 * @throws NotifyNotFound
 	 * @throws JobMasterNotFound
 	 * @throws UserNotFound
-	 * 
+	 *
 	 * @see com.clustercontrol.bean.JobConstant
 	 * @see com.clustercontrol.jobmanagement.factory.SelectJob#createJobTree(JobMasterLocal, JobTreeItem, boolean)
 	 */
 	public JobTreeItem getJobTree(String ownerRoleId, boolean treeOnly, Locale locale, String userId) throws NotifyNotFound, JobMasterNotFound, UserNotFound {
 
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 
 		//JobTreeItemの最上位インスタンスを作成
 		JobInfo info = new JobInfo("", "", JobConstant.STRING_COMPOSITE, JobConstant.TYPE_COMPOSITE);
@@ -183,7 +146,7 @@ public class SelectJob {
 		//親ジョブIDが"TOP"のジョブリレーションを取得
 		Collection<JobMstEntity> ct = null;
 		if (ownerRoleId != null && !ownerRoleId.isEmpty()) {
-			ct = ((HinemosEntityManager)em).createNamedQuery_OR("JobMstEntity.findByParentJobunitIdAndJobId", JobMstEntity.class, ownerRoleId)
+			ct = em.createNamedQuery_OR("JobMstEntity.findByParentJobunitIdAndJobId", JobMstEntity.class, ownerRoleId)
 					.setParameter("parentJobunitId", CreateJobSession.TOP_JOBUNIT_ID)
 					.setParameter("parentJobId", CreateJobSession.TOP_JOB_ID)
 					.getResultList();
@@ -213,7 +176,7 @@ public class SelectJob {
 	 * @return Map<parent_id, List<job_id>>
 	 */
 	private HashMap<String, ArrayList<JobMstEntity>> getJobunitMap(String jobunitId) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 
 		HashMap<String, ArrayList<JobMstEntity>> map = new HashMap<String, ArrayList<JobMstEntity>>();
 		Collection<JobMstEntity> ct =
@@ -247,7 +210,7 @@ public class SelectJob {
 	 *   <li>ジョブマスタとジョブツリー情報のルートを渡して、ジョブツリー情報の作成を行います。</li>
 	 *   </ol>
 	 * </ol>
-	 * 
+	 *
 	 * @param job ジョブマスタ
 	 * @param parent 親ジョブツリー情報
 	 * @param treeOnly treeOnly true=ジョブ情報を含まない, false=ジョブ情報含む
@@ -281,7 +244,7 @@ public class SelectJob {
 	/**
 	 * ジョブ情報{@link com.clustercontrol.jobmanagement.bean.JobInfo}を作成します。<BR>
 	 * ジョブマスタを基に、ジョブ情報を作成します。
-	 * 
+	 *
 	 * @param job ジョブマスタ
 	 * @param treeOnly treeOnly true=ジョブ情報を含まない, false=ジョブ情報含む
 	 * @return ジョブ情報
@@ -321,13 +284,13 @@ public class SelectJob {
 	 *  </ol>
 	 *  <li>履歴情報一覧，全履歴数を、ビュー一覧情報（{@link com.clustercontrol.jobmanagement.bean.JobHistoryList}）にセットし返します。</li>
 	 * </ol>
-	 * 
+	 *
 	 * @param userId ログインユーザのユーザID
 	 * @param property 検索条件
 	 * @param histories 表示履歴数
 	 * @return ジョブ履歴一覧情報
 	 * @throws JobInfoNotFound
-	 * 
+	 *
 	 * @see com.clustercontrol.bean.JobConstant
 	 */
 	public JobHistoryList getHistoryList(String userId, JobHistoryFilter property, int histories) throws JobInfoNotFound {
@@ -488,21 +451,21 @@ public class SelectJob {
 	 * <li>テーブルツリー情報のルート(最上位)のインスタンスを作成します。</li>
 	 * <li>セッションジョブとテーブルツリー情報のルートを渡して、ジョブ詳細一覧情報の作成を行います。</li>
 	 * </ol>
-	 * 
+	 *
 	 * @param sessionId セッションID
 	 * @return ジョブ詳細一覧情報
 	 * @throws JobInfoNotFound
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.factory.SelectJob#createDetailTree(JobSessionJobLocal, CommonTableTreeItem)
 	 */
 	public JobTreeItem getDetailList(String sessionId) throws JobInfoNotFound, InvalidRole {
 
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		JobTreeItem tree = null;
 
 
 		//セッションをセッションIDで検索し取得
-		JobSessionEntity session = em.find(JobSessionEntity.class, sessionId);
+		JobSessionEntity session = em.find(JobSessionEntity.class, sessionId, ObjectPrivilegeMode.READ);
 		if (session == null) {
 			JobInfoNotFound je = new JobInfoNotFound("JobSessionEntity.findByPrimaryKey"
 					+ ", sessionId = " + sessionId);
@@ -514,11 +477,14 @@ public class SelectJob {
 
 		//セッションジョブを取得
 		JobSessionJobEntity sessionJob = QueryUtil.getJobSessionJobPK(session.getSessionId(), session.getJobunitId(), session.getJobId());
+		m_log.debug("sessionJob = " + sessionJob);
 
 		//CommonTableTreeItemの最上位インスタンスを作成
 		tree = new JobTreeItem();
 		//ジョブ詳細ツリーを作成
+		m_log.debug("createDetailTree start");
 		createDetailTree(sessionJob, tree);
+		m_log.debug("createDetailTree end");
 
 		return tree;
 	}
@@ -537,12 +503,12 @@ public class SelectJob {
 	 *  <li>セッションジョブとテーブルツリー情報を渡して、ジョブ詳細一覧情報の作成を行います。</li>
 	 *  </ol>
 	 * </ol>
-	 * 
+	 *
 	 * @param sessionJob セッションジョブ
 	 * @param parent 親テーブルツリー情報
-	 * 
+	 *
 	 * @throws JobInfoNotFound
-	 * 
+	 *
 	 * @see com.clustercontrol.bean.JobConstant
 	 * @see com.clustercontrol.jobmanagement.factory.SelectJob#createJobDetail(JobSessionJobLocal)
 	 */
@@ -552,20 +518,24 @@ public class SelectJob {
 
 		//セッションジョブからジョブ詳細一覧の１行を作成
 		JobInfo info = createJobInfo(sessionJob);
+		m_log.debug("info = " + info);
 		JobDetailInfo detail = createJobDetail(sessionJob);
+		m_log.debug("detail = " + detail);
 
 		//CommonTableTreeItemを作成
 		JobTreeItem item = new JobTreeItem(parent, info);
 		item.setDetail(detail);
 
 		JobInfoEntity job = sessionJob.getJobInfoEntity();
+		/** ファイル転送ジョブ展開表示 */
+		boolean m_openForwardFileJob = HinemosPropertyUtil.getHinemosPropertyBool("job.open.forward.file.job", false);
 		if(m_openForwardFileJob || job.getJobType() != JobConstant.TYPE_FILEJOB){
 
 			//ジョブリレーションを親ジョブIDで検索
-			List<JobSessionJobEntity> collection 
+			List<JobSessionJobEntity> collection
 			= QueryUtil.getChildJobSessionJob(
-							sessionJob.getId().getSessionId(), 
-							sessionJob.getId().getJobunitId(), 
+							sessionJob.getId().getSessionId(),
+							sessionJob.getId().getJobunitId(),
 							sessionJob.getId().getJobId());
 			if (collection == null) {
 				JobInfoNotFound je = new JobInfoNotFound("JobSessionJobEntity.findByParentJobId"
@@ -583,7 +553,7 @@ public class SelectJob {
 				public int compare(JobSessionJobEntity o1, JobSessionJobEntity o2) {
 					return o1.getId().getJobId().compareTo(o2.getId().getJobId());
 				}
-				
+
 			});
 			if(collection != null && collection.size() > 0){
 				Iterator<JobSessionJobEntity> itr = collection.iterator();
@@ -605,10 +575,10 @@ public class SelectJob {
 	 * <li>1セッションジョブの情報をテーブルのカラム順（{@link com.clustercontrol.jobmanagement.bean.JobDetailTableDefine}）に、リスト（{@link ArrayList}）にセットします。</li>
 	 * <li>ジョブ詳細情報を返します。</li>
 	 * </ol>
-	 * 
+	 *
 	 * @param sessionJob セッションジョブ
 	 * @return ジョブ詳細情報
-	 * 
+	 *
 	 * @see com.clustercontrol.bean.JobConstant
 	 */
 	private JobDetailInfo createJobDetail(JobSessionJobEntity sessionJob) {
@@ -626,6 +596,11 @@ public class SelectJob {
 			if(jobInfo.getStartTime() != null){
 				detail.setWaitRuleTime(jobInfo.getStartTime().getTime());
 			}
+			//待ち条件（セッション開始時の時間（分））を取得
+			m_log.debug("createJobDetail >>>>>>>>>>>>>>>>>>>>> jobInfo.getStartDelaySession = " + jobInfo.getStartDelaySession());
+			if (jobInfo.getStartMinute() != null) {
+				detail.setStartMinute(jobInfo.getStartMinute());
+			}
 		}
 		if (sessionJob.getStartDate() != null){
 			detail.setStartDate(sessionJob.getStartDate().getTime());
@@ -639,6 +614,7 @@ public class SelectJob {
 
 	private JobInfo createJobInfo(JobSessionJobEntity sessionJob) {
 
+		m_log.debug("createJobInfo>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>");
 		//セッションジョブからジョブ詳細一覧の１行を作成
 		JobInfoEntity jobInfo = sessionJob.getJobInfoEntity();
 		JobInfo info = new JobInfo();
@@ -741,6 +717,16 @@ public class SelectJob {
 			objectList.add(objectInfo);
 		}
 
+		//待ち条件（セッション開始時の時間（分））を取得
+		m_log.debug("createJobInfo job.getStartMinute() = " + jobInfo.getStartMinute());
+		if (jobInfo.getStartMinute() != null) {
+			JobObjectInfo objectInfo = new JobObjectInfo();
+			objectInfo.setType(JudgmentObjectConstant.TYPE_START_MINUTE);
+			objectInfo.setStartMinute(jobInfo.getStartMinute());
+			m_log.debug("objectList = " + objectList);
+			objectList.add(objectInfo);
+		}
+
 		waitRule.setObject(objectList);
 		info.setWaitRule(waitRule);
 
@@ -763,7 +749,7 @@ public class SelectJob {
 	 *  </ol>
 	 * <li>取得したジョブ情報の種別がファイル転送ジョブの場合、ファイル転送ジョブのノード詳細一覧情報を作成します。</li>
 	 * </ol>
-	 * 
+	 *
 	 * @param sessionId セッションID
 	 * @param jobunitId 所属ジョブユニットのジョブID
 	 * @param jobId ジョブID
@@ -772,7 +758,7 @@ public class SelectJob {
 	 * @throws JobInfoNotFound
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
-	 * 
+	 *
 	 * @see com.clustercontrol.bean.JobConstant
 	 * @see com.clustercontrol.jobmanagement.factory.SelectJob#getFileJobNodeDetailList(String, String, Locale)
 	 */
@@ -836,7 +822,7 @@ public class SelectJob {
 	 *   </dl>
 	 *  </ol>
 	 * </ol>
-	 * 
+	 *
 	 * @param sessionId セッションID
 	 * @param jobunitId 所属ジョブユニットのジョブID
 	 * @param jobId ジョブID
@@ -845,7 +831,7 @@ public class SelectJob {
 	 * @throws JobInfoNotFound
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
-	 * 
+	 *
 	 * @see com.clustercontrol.bean.JobConstant
 	 * @see com.clustercontrol.jobmanagement.factory.SelectJob#getFileJobDetailMessage(String, String, String, String, int, Locale)
 	 */
@@ -867,10 +853,10 @@ public class SelectJob {
 		if(job.getJobType() != JobConstant.TYPE_FILEJOB){
 			return nodeDetail;
 		}
-		
+
 		//ファイル転送ジョブの場合
 		//ジョブリレーションを親ジョブIDで検索
-		Collection<JobSessionJobEntity> collection 
+		Collection<JobSessionJobEntity> collection
 		= QueryUtil.getChildJobSessionJob(
 					sessionJob.getId().getSessionId(),
 					sessionJob.getId().getJobunitId(),
@@ -937,7 +923,7 @@ public class SelectJob {
 
 	/**
 	 * ファイル転送ジョブのノード詳細一覧情報のメッセージを取得します。
-	 * 
+	 *
 	 * @param sessionId セッションID
 	 * @param jobId ジョブID
 	 * @param jobunitId ジョブユニットID
@@ -1295,7 +1281,7 @@ public class SelectJob {
 	 *   </dl>
 	 *  </ol>
 	 * </ol>
-	 * 
+	 *
 	 * @param sessionId セッションID
 	 * @param jobunitId 所属ジョブユニットのジョブID
 	 * @param jobId ジョブID
@@ -1303,7 +1289,7 @@ public class SelectJob {
 	 * @throws JobInfoNotFound
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
-	 * 
+	 *
 	 * @see com.clustercontrol.bean.JobConstant
 	 * @see com.clustercontrol.jobmanagement.factory.SelectJob#getForwardFileListInfo(String, String, String, String, String, String, int)
 	 */
@@ -1320,7 +1306,7 @@ public class SelectJob {
 		if(job.getJobType() != JobConstant.TYPE_FILEJOB){
 			return ret;
 		}
-		
+
 		//ファシリティパスを取得
 		String srcFacilityId = job.getSrcFacilityId();
 		String srcFacilityName = new RepositoryControllerBean().getFacilityPath(srcFacilityId, null);
@@ -1377,7 +1363,7 @@ public class SelectJob {
 	 *   </dl>
 	 *  </ol>
 	 * </ol>
-	 * 
+	 *
 	 * @param sessionId セッションID
 	 * @param jobId 親ジョブユニットID
 	 * @param jobId 親ジョブID
@@ -1411,7 +1397,7 @@ public class SelectJob {
 				jobId != null && jobId.length() > 0){
 
 			//ジョブリレーションを親ジョブIDで検索
-			Collection<JobSessionJobEntity> collection 
+			Collection<JobSessionJobEntity> collection
 			= QueryUtil.getChildJobSessionJobOrderByStartDate(sessionId, jobunitId, jobId);
 			if (collection == null) {
 				JobInfoNotFound je = new JobInfoNotFound("JobSessionJobEntity.findByStartDate"
@@ -1423,12 +1409,12 @@ public class SelectJob {
 				je.setParentJobId(jobId);
 				throw je;
 			}
-		
+
 			HashMap<String, Object> jobIdMap = new HashMap<String, Object>();
 
 			for (JobSessionJobEntity childSessionJob : collection) {
 				//セッションジョブを取得
-				
+
 				JobInfoEntity job = childSessionJob.getJobInfoEntity();
 
 				//ファイル転送が開始の場合
@@ -1522,7 +1508,7 @@ public class SelectJob {
 					jobIdMap.put(fileJobId + END_DATE, childSessionJob.getEndDate());
 					jobIdMap.put(fileJobId + FILE, job.getArgument());
 					jobIdMap.put(fileJobId + START_DATE, childSessionJob.getStartDate());
-					
+
 					Object obj;
 					obj = jobIdMap.get(fileJobId + START_DATE);
 					Long startDate = null;
@@ -1553,7 +1539,7 @@ public class SelectJob {
 
 	/**
 	 * ジョブツリー情報を取得します。
-	 * 
+	 *
 	 * @param sessionId セッションID
 	 * @param jobunitId　所属ジョブユニットのジョブID
 	 * @param jobId ジョブID
@@ -1583,17 +1569,18 @@ public class SelectJob {
 
 	/**
 	 * セッションジョブ情報作成
-	 * 
+	 *
 	 * @param job ジョブ情報
 	 * @return ジョブ情報
 	 * @throws JobInfoNotFound
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.JobInfo
 	 */
 	private JobInfo createSessionJobData(JobInfoEntity job) throws JobInfoNotFound, InvalidRole, HinemosUnknown {
 
+		m_log.debug("createSessionJobData>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>" );
 		//JobInfoを作成
 		JobInfo info = new JobInfo(job.getId().getJobunitId(), job.getId().getJobId(), job.getJobName(), job.getJobType());
 
@@ -1692,12 +1679,21 @@ public class SelectJob {
 		}
 
 		//待ち条件（時刻）を取得
-		JobObjectInfo objectInfo = new JobObjectInfo();
-		objectInfo.setType(JudgmentObjectConstant.TYPE_TIME);
 		if (job.getStartTime() != null) {
+			JobObjectInfo objectInfo = new JobObjectInfo();
+			objectInfo.setType(JudgmentObjectConstant.TYPE_TIME);
 			objectInfo.setTime(job.getStartTime().getTime());
+			objectList.add(objectInfo);
+		}
+
+		//待ち条件（セッション開始時の時間（分））を取得
+		m_log.debug("createSessionJobData job.getStartMinute() = " + job.getStartMinute() );
+		if (job.getStartMinute() != null) {
+			JobObjectInfo objectInfo = new JobObjectInfo();
+			objectInfo.setType(JudgmentObjectConstant.TYPE_START_MINUTE);
+			objectInfo.setStartMinute(job.getStartMinute());
+			objectList.add(objectInfo);
 		}
-		objectList.add(objectInfo);
 		/*
 		 * ソート処理
 		 */
@@ -1717,8 +1713,10 @@ public class SelectJob {
 			commandInfo.setSpecifyUser(job.getSpecifyUser());
 			commandInfo.setUser(job.getEffectiveUser());
 			commandInfo.setMessageRetry(job.getMessageRetry());
-			commandInfo.setErrorEndFlg(job.getErrorEndFlg());
-			commandInfo.setErrorEndValue(job.getErrorEndValue());
+			commandInfo.setMessageRetryEndFlg(job.getMessageRetryEndFlg());
+			commandInfo.setMessageRetryEndValue(job.getMessageRetryEndValue());
+			commandInfo.setCommandRetryFlg(job.getCommandRetryFlg());
+			commandInfo.setCommandRetry(job.getCommandRetry());
 			try {
 				//ファシリティパスを取得
 				commandInfo.setScope(new RepositoryControllerBean().getFacilityPath(job.getFacilityId(), null));
@@ -1746,6 +1744,9 @@ public class SelectJob {
 			fileInfo.setSpecifyUser(job.getSpecifyUser());
 			fileInfo.setUser(job.getEffectiveUser());
 			fileInfo.setMessageRetry(job.getMessageRetry());
+			fileInfo.setMessageRetryEndValue(job.getMessageRetryEndValue());
+			fileInfo.setCommandRetry(job.getCommandRetry());
+			fileInfo.setCommandRetryFlg(job.getCommandRetryFlg());
 			try {
 				//ファシリティパスを取得
 				fileInfo.setSrcScope(new RepositoryControllerBean().getFacilityPath(job.getSrcFacilityId(), null));
@@ -1759,39 +1760,15 @@ public class SelectJob {
 		}
 		if (job.getJobType() != JobConstant.TYPE_REFERJOB) {
 			//通知メッセージを取得
-			ArrayList<JobNotificationsInfo> noticeList = new ArrayList<JobNotificationsInfo>();
-			Collection<JobNoticeInfoEntity> notices = job.getJobNoticeInfoEntities();
+			info.setBeginPriority(job.getBeginPriority());
+			info.setNormalPriority(job.getNormalPriority());
+			info.setWarnPriority(job.getWarnPriority());
+			info.setAbnormalPriority(job.getAbnormalPriority());
 
-			if(notices != null){
-				Iterator<JobNoticeInfoEntity> itr = notices.iterator();
-				while(itr.hasNext()){
-					JobNoticeInfoEntity notice = itr.next();
-					JobNotificationsInfo notificationsInfo = new JobNotificationsInfo();
-					notificationsInfo.setType(notice.getId().getNoticeType());
-					notificationsInfo.setPriority(notice.getPriority());
-					notificationsInfo.setNotifyGroupId(notice.getNotifyGroupId());
-
-					//通知タイプが正常の時のみ通知情報を設定する。
-					if(notificationsInfo.getType() == EndStatusConstant.TYPE_NORMAL){
-						ArrayList<NotifyRelationInfo> nriList =  new ArrayList<NotifyRelationInfo>();
-						nriList = new NotifyControllerBean().getNotifyRelation(notice.getNotifyGroupId());
-						if (nriList != null) {
-							/*
-							 * ソート処理
-							 */
-							Collections.sort(nriList);
-							notificationsInfo.setNotifyId(nriList);
-						}
-						//notificationsInfo.setNotifyId(new NotifyControllerBean().getNotifyRelation(notice.getNotifyGroupId()));
-					}
-					noticeList.add(notificationsInfo);
-				}
-				/*
-				 * ソート処理
-				 */
-				Collections.sort(noticeList);
-			}
-			info.setNotifications(noticeList);
+			ArrayList<NotifyRelationInfo> nriList =  new ArrayList<NotifyRelationInfo>();
+			nriList = new NotifyControllerBean().getNotifyRelation(job.getNotifyGroupId());
+			Collections.sort(nriList);
+			info.setNotifyRelationInfos(nriList);
 
 			//終了状態を取得
 			ArrayList<JobEndStatusInfo> endList = new ArrayList<JobEndStatusInfo>();
@@ -1844,7 +1821,7 @@ public class SelectJob {
 
 	/**
 	 * TypedQuery作成
-	 * 
+	 *
 	 * @param startFromDate
 	 * @param startToDate
 	 * @param endFromDate
@@ -1854,7 +1831,7 @@ public class SelectJob {
 	 * @param triggerType
 	 * @param triggerInfo
 	 * @param isCount true:件数を取得する
-	 * 
+	 *
 	 * @return typedQuery
 	 */
 	private TypedQuery<?> getHistoryFilterQuery(
@@ -1891,7 +1868,7 @@ public class SelectJob {
 				+ ", " + ownerRoleId
 				+ ", " + isCount + "]");
 
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 
 		StringBuffer sbJpql = new StringBuffer();
 		sbJpql.append("SELECT");
@@ -1930,15 +1907,15 @@ public class SelectJob {
 		if(triggerInfo != null && triggerInfo.length() > 0) {
 			sbJpql.append(" AND b.triggerInfo like :triggerInfo");
 		}
-		
+
 		// TODO:次期バージョンでは、アノテーションによる制御を行う方が望ましい
 		// オブジェクト権限チェック
 		sbJpql = getJpql(sbJpql);
-		
+
 		TypedQuery<?> typedQuery = null;
 		m_log.debug("getHistoryFilterQuery() jpql = " + sbJpql.toString());
 		if (isCount) {
-			typedQuery = ((HinemosEntityManager)em).createQuery(sbJpql.toString(), Long.class, JobSessionJobEntity.class);
+			typedQuery = em.createQuery(sbJpql.toString(), Long.class, JobSessionJobEntity.class);
 		} else {
 			sbJpql.append(" ORDER BY a.id.sessionId DESC");
 			typedQuery = em.createQuery(sbJpql.toString(), JobSessionJobEntity.class);
@@ -1969,63 +1946,63 @@ public class SelectJob {
 			typedQuery = typedQuery.setParameter("triggerType", triggerType);
 		}
 		if(triggerInfo != null && triggerInfo.length() > 0) {
-			typedQuery = typedQuery.setParameter("triggerInfo", "%" + triggerInfo + "%");
+			typedQuery = typedQuery.setParameter("triggerInfo", triggerInfo);
 		}
-		
+
 		// TODO:次期バージョンでは、アノテーションによる制御を行う方が望ましい
 		// オブジェクト権限チェック
 		typedQuery = setObjectPrivilegeParameter(typedQuery);
-		
+
 		return typedQuery;
 	}
-	
-	
+
+
 	private StringBuffer getJpql(StringBuffer sbJpql){
-		
+
 		// ADMINISTRATORSロールに所属している場合はオブジェクト権限チェックはしない
 		Boolean isAdministrator = (Boolean)HinemosSessionContext.instance().getProperty(HinemosSessionContext.IS_ADMINISTRATOR);
 		if (isAdministrator != null && isAdministrator) {
 			return sbJpql;
 		}
-		
+
 		// ログインユーザから、所属ロールの一覧を取得
 		String loginUser = (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID);
 		// ユーザ情報が取得できない場合は、そのまま返す
 		if (loginUser == null || "".equals(loginUser.trim())) {
 			return sbJpql;
 		}
-		
-		// オブジェクト権限チェックを含むJPQLに変換	
+
+		// オブジェクト権限チェックを含むJPQLに変換
 		String afterJpql = getObjectPrivilegeJPQL(sbJpql.toString(), HinemosModuleConstant.JOB, ObjectPrivilegeMode.READ);
 		List<String> roleIds = UserRoleCache.getRoleIdList(loginUser);
 		afterJpql = afterJpql.replaceAll(":roleIds", HinemosEntityManager.getParamNameString("roleId", roleIds.toArray(new String[roleIds.size()])));
-		
+
 		return new StringBuffer(afterJpql);
 	}
-	
+
 	private TypedQuery<?> setObjectPrivilegeParameter(TypedQuery<?> typedQuery) {
-		
+
 		// ADMINISTRATORSロールに所属している場合はオブジェクト権限チェックはしない
 		Boolean isAdministrator = (Boolean)HinemosSessionContext.instance().getProperty(HinemosSessionContext.IS_ADMINISTRATOR);
 		if (isAdministrator != null && isAdministrator) {
 			return typedQuery;
 		}
-		
+
 		// ログインユーザから、所属ロールの一覧を取得
 		String loginUser = (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID);
 		// ユーザ情報が取得できない場合は、そのまま返す
 		if (loginUser == null || "".equals(loginUser.trim())) {
 			return typedQuery;
 		}
-		
+
 		List<String> roleIds = UserRoleCache.getRoleIdList(loginUser);
 		return HinemosEntityManager.appendParam(typedQuery, "roleId", roleIds.toArray(new String[roleIds.size()]));
 	}
-	
-	
+
+
 	/**
 	 * JPQLにオブジェクト権限チェックを入れて返す<br/>
-	 * 
+	 *
 	 * @param jpqlString JPQL文
 	 * @param entityClass オブジェクト権限チェック対象のEntityクラス
 	 * @param mode オブジェクト権限(READ, WRITE, EXEC)
@@ -2041,9 +2018,9 @@ public class SelectJob {
 			JpqlFrom jpqlFrom = null;
 			JpqlWhere jpqlWhere = null;
 			JpqlStatement statement = jpqlParser.parseQuery(jpqlString);
-			
+
 			if (statement.jjtGetChild(0) instanceof JpqlSelect ) {
-			
+
 				JpqlSelect jpqlSelect = (JpqlSelect)statement.jjtGetChild(0);
 				for(int i=0 ; i<jpqlSelect.jjtGetNumChildren() ; i++ ) {
 					if (jpqlSelect.jjtGetChild(i) instanceof JpqlFrom) {
@@ -2085,12 +2062,12 @@ public class SelectJob {
 		}
 		return rtnString;
 	}
-	
-	
+
+
 	/**
 	 * オブジェクト権限チェックを行うJPQLのノードを返す
 	 * ログインユーザIDでチェックを行う。
-	 * 
+	 *
 	 * @param objectType オブジェクトタイプ
 	 * @param mode オブジェクト権限(READ, WRITE, EXEC)
 	 * @return オブジェクト権限チェックを行うJPQLのノード
@@ -2105,10 +2082,10 @@ public class SelectJob {
 		JpqlIn in = QueryPreparator.createIn(QueryPreparator.createPath(privilegeAlias + ".id.roleId"), QueryPreparator.createNamedParameter("roleIds"));
 		JpqlExists node1 = QueryPreparator.createExists(
 				QueryPreparator.createSubselect(
-										QueryPreparator.createSelectClause(privilegeAlias), 
-										QueryPreparator.createFrom(ObjectPrivilegeEntity.class.getSimpleName(), privilegeAlias), 
+										QueryPreparator.createSelectClause(privilegeAlias),
+										QueryPreparator.createFrom(ObjectPrivilegeEntity.class.getSimpleName(), privilegeAlias),
 										QueryPreparator.createWhere(QueryPreparator.createAnd(QueryPreparator.createAnd(QueryPreparator.createAnd(equals1, equals2), equals3), in))));
-		
+
 		JpqlIn node2 = QueryPreparator.createIn(QueryPreparator.createPath(objectAlias + ".ownerRoleId"), QueryPreparator.createNamedParameter("roleIds"));
 		Node node = null;
 		if (objectType.equals(HinemosModuleConstant.JOB_MST)) {
