@@ -29,7 +29,6 @@ import com.clustercontrol.ws.jobmanagement.JobDetailInfo;
 import com.clustercontrol.ws.jobmanagement.JobEndStatusInfo;
 import com.clustercontrol.ws.jobmanagement.JobFileInfo;
 import com.clustercontrol.ws.jobmanagement.JobInfo;
-import com.clustercontrol.ws.jobmanagement.JobNotificationsInfo;
 import com.clustercontrol.ws.jobmanagement.JobObjectInfo;
 import com.clustercontrol.ws.jobmanagement.JobParameterInfo;
 import com.clustercontrol.ws.jobmanagement.JobTreeItem;
@@ -39,8 +38,8 @@ import com.clustercontrol.ws.notify.NotifyRelationInfo;
 
 /**
  * JobItemTreeユーティリティクラス
- * 
- * 
+ *
+ *
  * @version 2.0.0
  * @since 2.0.0
  */
@@ -66,7 +65,7 @@ public class JobTreeItemUtil {
 	 * </ul>
 	 * <p>
 	 * 結果 ： "料金システム>顧客管理>WEB"。<BR>
-	 * 
+	 *
 	 * @return パス文字列
 	 */
 	public static String getPath(JobTreeItem jobTreeItem) {
@@ -191,8 +190,10 @@ public class JobTreeItemUtil {
 
 			if (orgInfo.getCommand() != null) {
 				JobCommandInfo jobCommandInfo = new JobCommandInfo();
-				jobCommandInfo.setErrorEndFlg(orgInfo.getCommand().getErrorEndFlg());
-				jobCommandInfo.setErrorEndValue(orgInfo.getCommand().getErrorEndValue());
+				jobCommandInfo.setMessageRetryEndFlg(orgInfo.getCommand().getMessageRetryEndFlg());
+				jobCommandInfo.setMessageRetryEndValue(orgInfo.getCommand().getMessageRetryEndValue());
+				jobCommandInfo.setCommandRetry(orgInfo.getCommand().getCommandRetry());
+				jobCommandInfo.setCommandRetryFlg(orgInfo.getCommand().getCommandRetryFlg());
 				jobCommandInfo.setFacilityID(orgInfo.getCommand().getFacilityID());
 				jobCommandInfo.setProcessingMethod(orgInfo.getCommand().getProcessingMethod());
 				jobCommandInfo.setScope(orgInfo.getCommand().getScope());
@@ -232,32 +233,25 @@ public class JobTreeItemUtil {
 				jobFileInfo.setUser(orgInfo.getFile().getUser());
 				jobFileInfo.setSpecifyUser(orgInfo.getFile().getSpecifyUser());
 				jobFileInfo.setMessageRetry(orgInfo.getFile().getMessageRetry());
+				jobFileInfo.setMessageRetryEndFlg(orgInfo.getFile().getMessageRetryEndFlg());
+				jobFileInfo.setMessageRetryEndValue(orgInfo.getFile().getMessageRetryEndValue());
+				jobFileInfo.setCommandRetry(orgInfo.getFile().getCommandRetry());
+				jobFileInfo.setCommandRetryFlg(orgInfo.getFile().getCommandRetryFlg());
 				jobInfo.setFile(jobFileInfo);
 			}
 
-			if (orgInfo.getNotifications() != null) {
-				for(JobNotificationsInfo item : orgInfo.getNotifications()) {
-					JobNotificationsInfo jobNotificationsInfo = new JobNotificationsInfo();
-					jobNotificationsInfo.setNotifyGroupId(item.getNotifyGroupId());
-					jobNotificationsInfo.setPriority(item.getPriority());
-					jobNotificationsInfo.setType(item.getType());
+			jobInfo.setBeginPriority(orgInfo.getBeginPriority());
+			jobInfo.setNormalPriority(orgInfo.getNormalPriority());
+			jobInfo.setWarnPriority(orgInfo.getWarnPriority());
+			jobInfo.setAbnormalPriority(orgInfo.getAbnormalPriority());
 
-					if (item.getNotifyId() != null) {
-						for(NotifyRelationInfo subitem : item.getNotifyId()) {
-							NotifyRelationInfo notifyRelationInfo = new NotifyRelationInfo();
-							if (subitem.getNotifyFlg() != null) {
-								notifyRelationInfo.setNotifyFlg(subitem.getNotifyFlg());
-							}
-							notifyRelationInfo.setNotifyGroupId(subitem.getNotifyGroupId());
-							notifyRelationInfo.setNotifyId(subitem.getNotifyId());
-							if (subitem.getNotifyType() != null) {
-								notifyRelationInfo.setNotifyType(subitem.getNotifyType());
-							}
-							jobNotificationsInfo.getNotifyId().add(notifyRelationInfo);
-						}
-					}
-					jobInfo.getNotifications().add(jobNotificationsInfo);
-				}
+			for (NotifyRelationInfo relationInfo : orgInfo.getNotifyRelationInfos()) {
+				NotifyRelationInfo notifyRelationInfo = new NotifyRelationInfo();
+				notifyRelationInfo.setNotifyGroupId(relationInfo.getNotifyGroupId());
+				notifyRelationInfo.setNotifyId(relationInfo.getNotifyId());
+				notifyRelationInfo.setNotifyType(relationInfo.getNotifyType());
+
+				jobInfo.getNotifyRelationInfos().add(relationInfo);
 			}
 
 			if (orgInfo.getParam() != null) {
@@ -328,6 +322,9 @@ public class JobTreeItemUtil {
 						if (item.getTime() != null) {
 							jobObjectInfo.setTime(item.getTime());
 						}
+						if (item.getStartMinute() != null) {
+							jobObjectInfo.setStartMinute(item.getStartMinute());
+						}
 						jobObjectInfo.setType(item.getType());
 						jobObjectInfo.setValue(item.getValue());
 						jobWaitRuleInfo.getObject().add(jobObjectInfo);
@@ -401,4 +398,22 @@ public class JobTreeItemUtil {
 			}
 		}
 	}
-}
\ No newline at end of file
+
+	public static String getManagerName(JobTreeItem item) {
+		JobTreeItem managerItem = getManager(item);
+		if(null != managerItem){
+			return managerItem.getData().getName();
+		}else{
+			return null;
+		}
+	}
+
+	public static JobTreeItem getManager(JobTreeItem item) {
+		if (item == null) {
+			return null;
+		} else if (item.getData().getType() == JobConstant.TYPE_MANAGER) {
+			return item;
+		}
+		return getManager(item.getParent());
+	}
+}
