@@ -18,18 +18,11 @@ package com.clustercontrol.jobmanagement.util;
 
 import java.util.ArrayList;
 import java.util.Collection;
-
-import javax.persistence.EntityManager;
+import java.util.Collections;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.fault.FacilityNotFound;
-import com.clustercontrol.fault.HinemosUnknown;
-import com.clustercontrol.fault.InvalidRole;
-import com.clustercontrol.fault.InvalidSetting;
-import com.clustercontrol.fault.JobInfoNotFound;
-import com.clustercontrol.fault.JobInvalid;
 import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.ObjectPrivilegeMode;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.ScheduleConstant;
@@ -37,13 +30,18 @@ import com.clustercontrol.bean.YesNoConstant;
 import com.clustercontrol.commons.util.CommonValidator;
 import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.commons.util.JpaTransactionManager;
+import com.clustercontrol.fault.FacilityNotFound;
+import com.clustercontrol.fault.HinemosUnknown;
+import com.clustercontrol.fault.InvalidRole;
+import com.clustercontrol.fault.InvalidSetting;
+import com.clustercontrol.fault.JobInfoNotFound;
+import com.clustercontrol.fault.JobInvalid;
 import com.clustercontrol.jobmanagement.bean.JobCommandInfo;
 import com.clustercontrol.jobmanagement.bean.JobConstant;
 import com.clustercontrol.jobmanagement.bean.JobEndStatusInfo;
 import com.clustercontrol.jobmanagement.bean.JobFileCheck;
 import com.clustercontrol.jobmanagement.bean.JobFileInfo;
 import com.clustercontrol.jobmanagement.bean.JobInfo;
-import com.clustercontrol.jobmanagement.bean.JobNotificationsInfo;
 import com.clustercontrol.jobmanagement.bean.JobObjectInfo;
 import com.clustercontrol.jobmanagement.bean.JobSchedule;
 import com.clustercontrol.jobmanagement.bean.JobTreeItem;
@@ -54,6 +52,7 @@ import com.clustercontrol.jobmanagement.bean.SystemParameterConstant;
 import com.clustercontrol.jobmanagement.model.JobFileCheckEntity;
 import com.clustercontrol.jobmanagement.model.JobMstEntityPK;
 import com.clustercontrol.jobmanagement.model.JobScheduleEntity;
+import com.clustercontrol.notify.bean.NotifyRelationInfo;
 import com.clustercontrol.repository.util.FacilityTreeCache;
 import com.clustercontrol.util.Messages;
 
@@ -116,7 +115,7 @@ public class JobValidator {
 			if (qMinute != null) {
 				if (qMinute <= 0 || 60 < qMinute || qMinute <= pMinute ||
 						!(qMinute == 5 || qMinute == 10 || qMinute == 15 ||
-						qMinute == 20 || qMinute == 30 )) { 
+						qMinute == 20 || qMinute == 30 || qMinute == 60)) { 
 					InvalidSetting e = new InvalidSetting(Messages.getString("message.job.95"));
 					m_log.info("validateJobSchedule() : "
 							+ e.getClass().getSimpleName() + ", " + e.getMessage());
@@ -327,7 +326,7 @@ public class JobValidator {
 	 */
 	public static void validateJobMaster() throws InvalidSetting, HinemosUnknown, JobInfoNotFound, InvalidRole {
 
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 
 		m_log.debug("validateJobMaster()");
 
@@ -335,10 +334,10 @@ public class JobValidator {
 		m_log.debug("validateJobMaster() jobschedule check start");
 		try{
 			//ジョブスケジュール
-			Collection<JobScheduleEntity> jobScheduleList = 
-					((HinemosEntityManager)em).createNamedQuery("JobScheduleEntity.findAll", 
+			Collection<JobScheduleEntity> jobScheduleList =
+					em.createNamedQuery("JobScheduleEntity.findAll",
 							JobScheduleEntity.class, ObjectPrivilegeMode.NONE).getResultList();
-			
+
 			if (jobScheduleList == null) {
 				JobInfoNotFound je = new JobInfoNotFound("JobScheduleEntity.findAll");
 				m_log.info("validateJobMaster() : "
@@ -349,7 +348,7 @@ public class JobValidator {
 				String jobunitId = jobSchedule.getJobunitId();
 				String jobId = jobSchedule.getJobId();
 
-				m_log.debug("validateJobMaster() target jobschedule " + jobSchedule.getScheduleId() + 
+				m_log.debug("validateJobMaster() target jobschedule " + jobSchedule.getScheduleId() +
 						", jobunitId = " + jobunitId + ", jobId = " + jobId);
 				try{
 					// jobunitId,jobidの存在チェック
@@ -367,10 +366,10 @@ public class JobValidator {
 				}
 			}
 			//ジョブファイルチェック
-			Collection<JobFileCheckEntity> jobFileChekckList = 
-					((HinemosEntityManager)em).createNamedQuery("JobFileCheckEntity.findAll", 
+			Collection<JobFileCheckEntity> jobFileChekckList =
+					em.createNamedQuery("JobFileCheckEntity.findAll",
 							JobFileCheckEntity.class, ObjectPrivilegeMode.NONE).getResultList();
-			
+
 			if (jobFileChekckList == null) {
 				JobInfoNotFound je = new JobInfoNotFound("JobFileCheckEntity.findAll");
 				m_log.info("validateJobMaster() : "
@@ -381,7 +380,7 @@ public class JobValidator {
 				String jobunitId = jobFileCheck.getJobunitId();
 				String jobId = jobFileCheck.getJobId();
 
-				m_log.debug("validateJobMaster() target jobfileCheck " + jobFileCheck.getScheduleId() + 
+				m_log.debug("validateJobMaster() target jobfileCheck " + jobFileCheck.getScheduleId() +
 						", jobunitId = " + jobunitId + ", jobId = " + jobId);
 				try{
 					// jobunitId,jobidの存在チェック
@@ -418,7 +417,7 @@ public class JobValidator {
 	 * @throws InvalidSetting
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
-	 * @throws JobInvalid 
+	 * @throws JobInvalid
 	 */
 	public static void validateJobUnit(JobTreeItem item) throws InvalidSetting, InvalidRole, HinemosUnknown, JobInvalid {
 		validateJobInfo(item);
@@ -426,7 +425,7 @@ public class JobValidator {
 		validateWaitRule(item);
 		validateReferJob(item);
 	}
-	
+
 	private static void validateJobInfo(JobTreeItem item) throws InvalidSetting, InvalidRole, HinemosUnknown{
 
 		if(item == null || item.getData() == null){
@@ -453,7 +452,7 @@ public class JobValidator {
 		CommonValidator.validateString(Messages.getString("description"), description, true, 0, 256);
 
 		// ownerRoleId
-		CommonValidator.validateOwnerRoleId(jobInfo.getOwnerRoleId(), true, 
+		CommonValidator.validateOwnerRoleId(jobInfo.getOwnerRoleId(), true,
 				new JobMstEntityPK(jobunitId, jobId), HinemosModuleConstant.JOB);
 
 		// ジョブユニットの場合は、jobIdとjobunitIdは一緒。
@@ -569,7 +568,7 @@ public class JobValidator {
 				throw e;
 			}
 		}
-		
+
 		int type = jobInfo.getType();
 		if (type == JobConstant.TYPE_JOB ||
 				type == JobConstant.TYPE_JOBNET ||
@@ -587,26 +586,40 @@ public class JobValidator {
 				m_log.info(message);
 				throw new InvalidSetting(message);
 			}
-			
-			ArrayList<JobNotificationsInfo> notificationsList = item.getData().getNotifications();
-			if (notificationsList == null) {
-				String message = "JobNotifications is null [" + item.getData().getId() + "]";
+
+			if (jobInfo.getBeginPriority() == null
+					|| jobInfo.getNormalPriority() == null
+					|| jobInfo.getWarnPriority() == null
+					|| jobInfo.getAbnormalPriority() == null) {
+				String message = "the priorities of JobInfo less than 4 [" + jobInfo.getId() + "]";
 				m_log.info(message);
 				throw new InvalidSetting(message);
 			}
-			if (notificationsList.size() != 4) {
-				String message = "the number of JobNotifications is too few [" + item.getData().getId() + "] " +
-						endStatusList.size();
-				m_log.info(message);
-				throw new InvalidSetting(message);
+
+			// 通知の権限チェック
+			if (jobInfo.getNotifyRelationInfos() != null) {
+				for(NotifyRelationInfo notifyInfo : jobInfo.getNotifyRelationInfos()){
+					CommonValidator.validateNotifyId(notifyInfo.getNotifyId(), true, jobInfo.getOwnerRoleId());
+				}
 			}
 		}
+
+		if (type == JobConstant.TYPE_JOB ||
+				type == JobConstant.TYPE_FILEJOB ||
+				type == JobConstant.TYPE_JOBNET) {
+
+			// カレンダの権限チェック
+			if (jobInfo.getWaitRule().getCalendar() == YesNoConstant.TYPE_YES) {
+				CommonValidator.validateCalenderId(jobInfo.getWaitRule().getCalendarId(), true, jobInfo.getOwnerRoleId());
+			}
+		}
+
 		//子JobTreeItemを取得
 		for(JobTreeItem child : item.getChildren()){
 			validateJobInfo(child);
 		}
 	}
-	
+
 	/**
 	 * 重複しているIDをチェック
 	 * @param item
@@ -617,24 +630,20 @@ public class JobValidator {
 		if(item == null || item.getData() == null) {
 			return;
 		}
-		ArrayList<String> list = getJobIdList(item);
-		for (String jobId1 : list) {
-			int count = 0;
-			for (String jobId2 : list) {
-				if (jobId2.equals(jobId1)) {
-					count ++;
-					if (count > 1) {
-						Object[] args = {item.getData().getJobunitId(), jobId1};
-						JobInvalid e = new JobInvalid(Messages.getString("message.job.65", args));
-						m_log.info("findDuplicateJobId() : "
-								+ e.getClass().getSimpleName() + ", " + e.getMessage());
-						throw e;
-					}
-				}
+
+		ArrayList<String> jobList = getJobIdList(item);
+		Collections.sort(jobList);
+		for (int i = 0; i < jobList.size() - 1; i++) {
+			if (jobList.get(i).equals(jobList.get(i + 1))) {
+				Object[] args = {item.getData().getJobunitId(), jobList.get(i)};
+				JobInvalid e = new JobInvalid(Messages.getString("message.job.65", args));
+				m_log.info("findDuplicateJobId() : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage());
+				throw e;
 			}
 		}
 	}
-	
+
 	private static ArrayList<String> getJobIdList(JobTreeItem item) {
 		if(item == null || item.getData() == null) {
 			return new ArrayList<String>();
@@ -663,7 +672,10 @@ public class JobValidator {
 		if(waitRule != null && waitRule instanceof JobWaitRuleInfo &&
 				waitRule.getObject() != null && waitRule.getObject().size() > 0){
 			for (JobObjectInfo objectInfo : waitRule.getObject()) {
-				if(objectInfo.getType() != JudgmentObjectConstant.TYPE_TIME){
+				m_log.debug("objectInfo=" + objectInfo);
+
+				if(objectInfo.getType() != JudgmentObjectConstant.TYPE_TIME && objectInfo.getType() != JudgmentObjectConstant.TYPE_START_MINUTE){
+					m_log.debug("Not Time and Not Delay");
 					//判定対象のジョブIDが同一階層に存在するかチェック
 					boolean find = false;
 					String targetJobId = objectInfo.getJobId();
@@ -693,7 +705,7 @@ public class JobValidator {
 		}
 		return;
 	}
-	
+
 	/**
 	 * 参照ジョブにて指定された参照先のジョブ情報をチェックする
 	 * 
@@ -703,7 +715,7 @@ public class JobValidator {
 		if(item == null || item.getData() == null) {
 			return;
 		}
-		
+
 		//配下に存在する参照ジョブのみを取得する
 		ArrayList<JobInfo> referJobList = JobUtil.findReferJob(item);
 		m_log.trace("ReferJob count : " + referJobList.size());
