@@ -15,6 +15,8 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.jobmanagement.util;
 
+import com.clustercontrol.commons.bean.SettingUpdateInfo;
+import com.clustercontrol.hinemosagent.bean.AgentInfo;
 import com.clustercontrol.hinemosagent.bean.TopicInfo;
 import com.clustercontrol.hinemosagent.util.AgentConnectUtil;
 import com.clustercontrol.jobmanagement.bean.RunInstructionInfo;
@@ -30,14 +32,27 @@ public class SendTopic {
 
 	/**
 	 * 引数で指定されたメッセージをキューへ送信します。
-	 * 
+	 *
 	 * @param info 実行指示情報
 	 * @throws JMSException
 	 */
-	public void put(RunInstructionInfo info) {
+	public static AgentInfo put(RunInstructionInfo info) {
 		TopicInfo topicInfo = new TopicInfo();
 		topicInfo.setRunInstructionInfo(info);
 
-		AgentConnectUtil.setTopic(info.getFacilityId(), topicInfo);
+		return AgentConnectUtil.setTopic(info.getFacilityId(), topicInfo);
+	}
+
+	/**
+	 * ファイルチェックの再取得を促すためのトピック。
+	 * @param facilityId
+	 */
+	public static void putFileCheck(String facilityId) {
+		SettingUpdateInfo.getInstance().setJobFileCheckUpdateTime(System.currentTimeMillis());
+
+		TopicInfo topicInfo = new TopicInfo();
+		topicInfo.setFileCheckChanged(true);
+
+		AgentConnectUtil.setTopic(facilityId, topicInfo);
 	}
 }
\ No newline at end of file
