@@ -24,5 +24,5 @@ import com.clustercontrol.ws.jobmanagement.JobTreeItem;
  * 
  */
 public interface JobMapViewIF extends IViewPart {
-	public void update(String sessionId, JobTreeItem jobTreeItem);
+	public void update(String managerName, String sessionId, JobTreeItem jobTreeItem);
 }
