@@ -15,12 +15,17 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.jobmanagement.view.action;
 
-import org.eclipse.jface.action.IAction;
+import org.eclipse.core.commands.AbstractHandler;
+import org.eclipse.core.commands.Command;
+import org.eclipse.core.commands.ExecutionEvent;
+import org.eclipse.core.commands.ExecutionException;
+import org.eclipse.core.commands.State;
 import org.eclipse.jface.dialogs.IDialogConstants;
-import org.eclipse.jface.viewers.ISelection;
-import org.eclipse.ui.IViewActionDelegate;
-import org.eclipse.ui.IViewPart;
-import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.IWorkbenchPart;
+import org.eclipse.ui.IWorkbenchWindow;
+import org.eclipse.ui.commands.ICommandService;
+import org.eclipse.ui.handlers.HandlerUtil;
+import org.eclipse.ui.handlers.RegistryToggleState;
 
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.jobmanagement.dialog.HistoryFilterDialog;
@@ -28,24 +33,24 @@ import com.clustercontrol.jobmanagement.view.JobHistoryView;
 
 /**
  * ジョブ[履歴]ビューの「フィルタ処理」のクライアント側アクションクラス<BR>
- * 
- * @version 1.0.0
+ *
+ * @version 5.0.0
  * @since 1.0.0
  */
-public class HistoryFilterAction implements IViewActionDelegate {
+public class HistoryFilterAction extends AbstractHandler {
+	/** アクションID */
+	public static final String ID = HistoryFilterAction.class.getName();
+	private IWorkbenchWindow window;
 	/** ビュー */
-	private IViewPart m_view;
+	private IWorkbenchPart viewPart;
 
 	/**
-	 * ビューを保持します。ワークベンチにロードされた際に呼ばれます。
-	 * 
-	 * @param view ビューのインスタンス
-	 * 
-	 * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
+	 * Dispose
 	 */
 	@Override
-	public void init(IViewPart view) {
-		m_view = view;
+	public void dispose() {
+		this.viewPart = null;
+		this.window = null;
 	}
 
 	/**
@@ -56,20 +61,28 @@ public class HistoryFilterAction implements IViewActionDelegate {
 	 * <li>ジョブ[履歴]ビューにフィルタ条件を設定します。</li>
 	 * <li>ジョブ[履歴]ビューを更新します。</li>
 	 * </ol>
-	 * 
-	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
+	 *
+	 * @see org.eclipse.core.commands.IHandler#execute
 	 * @see com.clustercontrol.jobmanagement.view.JobHistoryView
 	 * @see com.clustercontrol.jobmanagement.dialog.HistoryFilterDialog
 	 * @see com.clustercontrol.bean.Property
 	 */
 	@Override
-	public void run(IAction action) {
-		if (action.isChecked()) { // ボタンが押された場合
+	public Object execute(ExecutionEvent event) throws ExecutionException {
+		this.window = HandlerUtil.getActiveWorkbenchWindow(event);
 
-			HistoryFilterDialog dialog = new HistoryFilterDialog(PlatformUI
-					.getWorkbench().getActiveWorkbenchWindow().getShell());
+		// 選択アイテムの取得
+		this.viewPart = HandlerUtil.getActivePart(event);
 
-			JobHistoryView view = (JobHistoryView) m_view
+		ICommandService commandService = (ICommandService)window.getService(ICommandService.class);
+		Command command = commandService.getCommand(ID);
+		boolean isChecked = !HandlerUtil.toggleCommandState(command);
+
+		if (isChecked) { // ボタンが押された場合
+
+			HistoryFilterDialog dialog = new HistoryFilterDialog(HandlerUtil.getActiveWorkbenchWindow( event ).getShell());
+
+			JobHistoryView view = (JobHistoryView) viewPart
 					.getAdapter(JobHistoryView.class);
 
 			//ジョブ履歴フィルタダイアログを表示
@@ -79,22 +92,16 @@ public class HistoryFilterAction implements IViewActionDelegate {
 				view.setFilterCondition(property);
 				view.update();
 			} else {
-				action.setChecked(false);
+				State state = command.getState(RegistryToggleState.STATE_ID);
+				state.setValue(false);
 			}
 		} else { // ボタンが戻った場合
 			// ジョブ履歴ビューを通常モードで表示
-			JobHistoryView view = (JobHistoryView) m_view
+			JobHistoryView view = (JobHistoryView) viewPart
 					.getAdapter(JobHistoryView.class);
 			view.setFilterCondition(null);
 			view.update();
 		}
+		return null;
 	}
-
-	/* (non-Javadoc)
-	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction, org.eclipse.jface.viewers.ISelection)
-	 */
-	@Override
-	public void selectionChanged(IAction action, ISelection selection) {
-
-	}
-}
\ No newline at end of file
+}
