@@ -19,16 +19,22 @@ import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Locale;
+import java.util.Map;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.eclipse.jface.action.IAction;
+import org.eclipse.core.commands.AbstractHandler;
+import org.eclipse.core.commands.ExecutionEvent;
+import org.eclipse.core.commands.ExecutionException;
 import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.jface.dialogs.MessageDialog;
-import org.eclipse.jface.viewers.ISelection;
-import org.eclipse.ui.IViewActionDelegate;
-import org.eclipse.ui.IViewPart;
+import org.eclipse.ui.IWorkbenchPage;
+import org.eclipse.ui.IWorkbenchPart;
+import org.eclipse.ui.IWorkbenchWindow;
 import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.commands.IElementUpdater;
+import org.eclipse.ui.handlers.HandlerUtil;
+import org.eclipse.ui.menus.UIElement;
 
 import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.bean.EndStatusConstant;
@@ -50,138 +56,43 @@ import com.clustercontrol.ws.jobmanagement.InvalidRole_Exception;
 
 /**
  * ジョブ[履歴]・ジョブ[ジョブ詳細]・ジョブ[ノード詳細]ビューの「停止」のクライアント側アクションクラス<BR>
- * 
- * @version 1.0.0
+ *
+ * @version 5.0.0
  * @since 1.0.0
  */
-public class StopJobAction implements IViewActionDelegate {
+public class StopJobAction extends AbstractHandler implements IElementUpdater {
 
 	// ログ
-	private static Log m_log = LogFactory.getLog( StartJobAction.class );
+	protected static Log m_log = LogFactory.getLog( StartJobAction.class );
 
 	/** アクションID */
-	public static final String ID = "com.clustercontrol.jobmanagement.view.action.StopJobAction";
+	public static final String ID = StopJobAction.class.getName();
+
+	private IWorkbenchWindow window;
 	/** ビュー */
-	private IViewPart m_view;
+	private IWorkbenchPart viewPart;
 
 	/**
-	 * ビューを保持します。ワークベンチにロードされた際に呼ばれます。
-	 * 
-	 * @param view ビューのインスタンス
-	 * 
-	 * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
+	 * Dispose
 	 */
 	@Override
-	public void init(IViewPart view) {
-		m_view = view;
+	public void dispose() {
+		this.viewPart = null;
+		this.window = null;
 	}
 
-	/**
-	 * ジョブ[履歴]・ジョブ[ジョブ詳細]・ジョブ[ノード詳細]ビューの「停止」が押された場合に、ジョブの停止操作を行います。
-	 * <p>
-	 * <ol>
-	 * <li>ジョブ[履歴]・ジョブ[ジョブ詳細]ビューの場合、ビューからセッションID・ジョブIDを取得します。</li>
-	 * <li>ジョブ[ノード詳細]ビューの場合、ビューから、セッションID・ジョブID・ファシリティIDを取得します。</li>
-	 * <li>ジョブ停止操作用プロパティを取得します。</li>
-	 * <li>ジョブ[停止]ダイアログを表示します。</li>
-	 * <li>ジョブ[停止]ダイアログからジョブ停止操作用プロパティを取得します。</li>
-	 * <li>ジョブ停止操作用プロパティを元にジョブ停止操作を行います。</li>
-	 * </ol>
-	 * 
-	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
-	 * @see com.clustercontrol.jobmanagement.view.JobHistoryView
-	 * @see com.clustercontrol.jobmanagement.view.JobDetailView
-	 * @see com.clustercontrol.jobmanagement.view.JobNodeDetailView
-	 * @see com.clustercontrol.jobmanagement.dialog.JobOperationDialog
-	 * @see com.clustercontrol.jobmanagement.action.OperationJob#operationJob(Property)
-	 */
-	@Override
-	public void run(IAction action) {
-		String sessionId = null;
-		String jobunitId = null;
-		String jobId = null;
-		String facilityId = null;
-
-		if (m_view instanceof JobHistoryView) { // ボタンが押された場合
-			JobHistoryView view = (JobHistoryView) m_view
-					.getAdapter(JobHistoryView.class);
-			HistoryComposite historyComposite = view.getComposite();
-			//セッションID取得
-			sessionId = historyComposite.getSessionId();
-			//ジョブユニットID取得
-			jobunitId = historyComposite.getJobunitId();
-			//ジョブID取得
-			jobId = historyComposite.getJobId();
-		} else if (m_view instanceof JobDetailView) { // ボタンが押された場合
-			JobDetailView view = (JobDetailView) m_view
-					.getAdapter(JobDetailView.class);
-			DetailComposite detailComposite = view.getComposite();
-			//セッションID取得
-			sessionId = detailComposite.getSessionId();
-			//ジョブユニットID取得
-			jobunitId = detailComposite.getJobunitId();
-			//ジョブID取得
-			jobId = detailComposite.getJobId();
-		} else if (m_view instanceof JobNodeDetailView) { // ボタンが押された場合
-			JobNodeDetailView view = (JobNodeDetailView) m_view
-					.getAdapter(JobNodeDetailView.class);
-			NodeDetailComposite nodeDetailComposite = view.getComposite();
-			//セッションID取得
-			sessionId = nodeDetailComposite.getSessionId();
-			//ジョブユニットID取得
-			jobunitId = nodeDetailComposite.getJobunitId();
-			//ジョブID取得
-			jobId = nodeDetailComposite.getJobId();
-			//ファシリティID取得
-			facilityId = nodeDetailComposite.getFacilityId();
-			if (facilityId == null) {
-				sessionId = null;
-				jobunitId = null;
-				jobId = null;
-			}
-		}
-
-		if (sessionId != null && sessionId.length() > 0 && jobunitId != null
-				&& jobunitId.length() > 0 && jobId != null
-				&& jobId.length() > 0) {
-
-			JobOperationDialog dialog = new JobOperationDialog(PlatformUI
-					.getWorkbench().getActiveWorkbenchWindow().getShell());
-
-			//プロパティ設定
-			dialog.setProperty(getStopProperty(sessionId, jobunitId, jobId, facilityId));
-			dialog.setTitleText(Messages.getString("job") + "["
-					+ Messages.getString("stop") + "]");
-
-			//ダイアログ表示
-			if (dialog.open() == IDialogConstants.OK_ID) {
-				//ジョブ停止
-				OperationJob operation = new OperationJob();
-				operation.operationJob(dialog.getProperty());
-			}
-		}
-	}
-
-	/* (non-Javadoc)
-	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction, org.eclipse.jface.viewers.ISelection)
-	 */
-	@Override
-	public void selectionChanged(IAction action, ISelection selection) {
-
-	}
-
-
 	/**
 	 * 停止用プロパティ取得
-	 * 
+	 *
+	 * @param managerName マネージャ名
 	 * @param sessionId セッションID
 	 * @param jobunitId 所属ジョブユニットのジョブID
 	 * @param jobId ジョブID
 	 * @param facilityId ファシリティID
 	 * @return ジョブ停止操作用プロパティ
-	 * 
+	 *
 	 */
-	private Property getStopProperty(String sessionId, String jobunitId, String jobId, String facilityId) {
+	private Property getStopProperty(String managerName, String sessionId, String jobunitId, String jobId, String facilityId) {
 		Locale locale = Locale.getDefault();
 
 		//セッションID
@@ -240,7 +151,8 @@ public class StopJobAction implements IViewActionDelegate {
 		forceEndMap.put("property", endList);
 		List<String> values1 = null;
 		try {
-			values1 = JobEndpointWrapper.getAvailableStopOperation(sessionId, jobunitId, jobId, facilityId);
+			JobEndpointWrapper wrapper = JobEndpointWrapper.getWrapper(managerName);
+			values1 = wrapper.getAvailableStopOperation(sessionId, jobunitId, jobId, facilityId);
 		} catch (InvalidRole_Exception e) {
 			MessageDialog.openInformation(null, Messages.getString("message"),
 					Messages.getString("message.accesscontrol.16"));
@@ -311,4 +223,141 @@ public class StopJobAction implements IViewActionDelegate {
 
 		return property;
 	}
-}
\ No newline at end of file
+
+	/**
+	 * ジョブ[履歴]・ジョブ[ジョブ詳細]・ジョブ[ノード詳細]ビューの「停止」が押された場合に、ジョブの停止操作を行います。
+	 * <p>
+	 * <ol>
+	 * <li>ジョブ[履歴]・ジョブ[ジョブ詳細]ビューの場合、ビューからセッションID・ジョブIDを取得します。</li>
+	 * <li>ジョブ[ノード詳細]ビューの場合、ビューから、セッションID・ジョブID・ファシリティIDを取得します。</li>
+	 * <li>ジョブ停止操作用プロパティを取得します。</li>
+	 * <li>ジョブ[停止]ダイアログを表示します。</li>
+	 * <li>ジョブ[停止]ダイアログからジョブ停止操作用プロパティを取得します。</li>
+	 * <li>ジョブ停止操作用プロパティを元にジョブ停止操作を行います。</li>
+	 * </ol>
+	 *
+	 * @see org.eclipse.core.commands.IHandler#execute
+	 * @see com.clustercontrol.jobmanagement.view.JobHistoryView
+	 * @see com.clustercontrol.jobmanagement.view.JobDetailView
+	 * @see com.clustercontrol.jobmanagement.view.JobNodeDetailView
+	 * @see com.clustercontrol.jobmanagement.dialog.JobOperationDialog
+	 * @see com.clustercontrol.jobmanagement.action.OperationJob#operationJob(Property)
+	 */
+	@Override
+	public Object execute(ExecutionEvent event) throws ExecutionException {
+		String managerName = null;
+		String sessionId = null;
+		String jobunitId = null;
+		String jobId = null;
+		String facilityId = null;
+
+		this.window = HandlerUtil.getActiveWorkbenchWindow(event);
+		// In case this action has been disposed
+		if( null == this.window || !isEnabled() ){
+			return null;
+		}
+
+		// 選択アイテムの取得
+		this.viewPart = HandlerUtil.getActivePart(event);
+
+		if (viewPart instanceof JobHistoryView) { // ボタンが押された場合
+			JobHistoryView view = (JobHistoryView) viewPart
+					.getAdapter(JobHistoryView.class);
+			HistoryComposite historyComposite = view.getComposite();
+			//マネージャ名取得
+			managerName = historyComposite.getManagerName();
+			//セッションID取得
+			sessionId = historyComposite.getSessionId();
+			//ジョブユニットID取得
+			jobunitId = historyComposite.getJobunitId();
+			//ジョブID取得
+			jobId = historyComposite.getJobId();
+		} else if (viewPart instanceof JobDetailView) { // ボタンが押された場合
+			JobDetailView view = (JobDetailView) viewPart
+					.getAdapter(JobDetailView.class);
+			DetailComposite detailComposite = view.getComposite();
+			//マネージャ名取得
+			managerName = detailComposite.getManagerName();
+			//セッションID取得
+			sessionId = detailComposite.getSessionId();
+			//ジョブユニットID取得
+			jobunitId = detailComposite.getJobunitId();
+			//ジョブID取得
+			jobId = detailComposite.getJobId();
+		} else if (viewPart instanceof JobNodeDetailView) { // ボタンが押された場合
+			JobNodeDetailView view = (JobNodeDetailView) viewPart
+					.getAdapter(JobNodeDetailView.class);
+			NodeDetailComposite nodeDetailComposite = view.getComposite();
+			//マネージャ名取得
+			managerName = nodeDetailComposite.getManagerName();
+			//セッションID取得
+			sessionId = nodeDetailComposite.getSessionId();
+			//ジョブユニットID取得
+			jobunitId = nodeDetailComposite.getJobunitId();
+			//ジョブID取得
+			jobId = nodeDetailComposite.getJobId();
+			//ファシリティID取得
+			facilityId = nodeDetailComposite.getFacilityId();
+			if (facilityId == null) {
+				sessionId = null;
+				jobunitId = null;
+				jobId = null;
+			}
+		}
+
+		if (sessionId != null && sessionId.length() > 0 && jobunitId != null
+				&& jobunitId.length() > 0 && jobId != null
+				&& jobId.length() > 0) {
+
+			JobOperationDialog dialog = new JobOperationDialog(this.window.getShell());
+
+			//プロパティ設定
+			dialog.setProperty(getStopProperty(managerName, sessionId, jobunitId, jobId, facilityId));
+			dialog.setTitleText(Messages.getString("job") + "["
+					+ Messages.getString("stop") + "]");
+
+			//ダイアログ表示
+			if (dialog.open() == IDialogConstants.OK_ID) {
+				//ジョブ停止
+				OperationJob operation = new OperationJob();
+				operation.operationJob(managerName, dialog.getProperty());
+			}
+		}
+
+		return null;
+	}
+
+	@Override
+	public void updateElement(UIElement element, @SuppressWarnings("rawtypes") Map parameters) {
+		IWorkbenchWindow window = PlatformUI.getWorkbench().getActiveWorkbenchWindow();
+		// page may not start at state restoring
+		if( null != window ){
+			IWorkbenchPage page = window.getActivePage();
+			if( null != page ){
+				IWorkbenchPart part = page.getActivePart();
+
+				boolean editEnable = false;
+				if(part instanceof JobHistoryView){
+					// Enable button when 1 item is selected
+					JobHistoryView view = (JobHistoryView)part;
+					if(view.getSelectedNum() > 0) {
+						editEnable = true;
+					}
+				} else if(part instanceof JobDetailView) {
+					JobDetailView view = (JobDetailView)part;
+					if(view.getSelectedNum() > 0) {
+						editEnable = true;
+					}
+				} else if(part instanceof JobNodeDetailView) {
+					JobNodeDetailView view = (JobNodeDetailView)part;
+					if(view.getSelectedNum() > 0) {
+						editEnable = true;
+					}
+				}
+				this.setBaseEnabled( editEnable );
+			} else {
+				this.setBaseEnabled(false);
+			}
+		}
+	}
+}
