@@ -70,8 +70,12 @@ public class ControlLogfileInfo {
 		logfile.setMonitorId(m_monitorId);
 		logfile.setDirectory(entity.getDirectory());
 		logfile.setFileName(entity.getFileName());
+		logfile.setFileEncoding(entity.getFileEncoding());
+		logfile.setFileReturnCode(entity.getFileReturnCode());
 		m_log.trace("get() : logfile.getDirectory = " + logfile.getDirectory());
 		m_log.trace("get() : logfile.getFileName = " + logfile.getFileName());
+		m_log.trace("get() : logfile.getFileEncoding = " + logfile.getFileEncoding());
+		m_log.trace("get() : logfile.getFileReturnCode = " + logfile.getFileReturnCode());
 		return logfile;
 	}
 
@@ -96,8 +100,12 @@ public class ControlLogfileInfo {
 		MonitorLogfileInfoEntity entity = new MonitorLogfileInfoEntity(monitorEntity);
 		entity.setDirectory(logfile.getDirectory());
 		entity.setFileName(logfile.getFileName());
+		entity.setFileEncoding(logfile.getFileEncoding());
+		entity.setFileReturnCode(logfile.getFileReturnCode());
 		m_log.trace("add() : entity.getDirectory = " + entity.getDirectory());
 		m_log.trace("add() : entity.getFileName = " + entity.getFileName());
+		m_log.trace("add() : entity.getFileEncoding = " + entity.getFileEncoding());
+		m_log.trace("add() : entity.getFileReturnCode = " + entity.getFileReturnCode());
 
 		return true;
 	}
@@ -119,8 +127,12 @@ public class ControlLogfileInfo {
 		// ログファイル監視情報を設定
 		entity.setDirectory(logfile.getDirectory());
 		entity.setFileName(logfile.getFileName());
+		entity.setFileEncoding(logfile.getFileEncoding());
+		entity.setFileReturnCode(logfile.getFileReturnCode());
 		m_log.trace("modify() : entity.getDirectory = " + entity.getDirectory());
 		m_log.trace("modify() : entity.getFileName = " + entity.getFileName());
+		m_log.trace("modify() : entity.getFileEncoding = " + entity.getFileEncoding());
+		m_log.trace("modify() : entity.getFileReturnCode = " + entity.getFileReturnCode());
 		return true;
 	}
 }
