@@ -36,9 +36,6 @@ public class MaintenanceTypeMstConstant {
 	public static final String DELETE_JOB_HISTORY_ALL = "DELETE_JOB_HISTORY_ALL";
 	public static final String DELETE_JOB_HISTORY = "DELETE_JOB_HISTORY";
 
-	public static final String DELETE_CRUN_HISTORY_ALL = "DELETE_CRUN_HISTORY_ALL";
-	public static final String DELETE_CRUN_HISTORY = "DELETE_CRUN_HISTORY";
-
 	public static final String DELETE_RERF_DATA_ALL = "DELETE_RERF_DATA_ALL";
 	public static final String DELETE_RERF_DATA = "DELETE_RERF_DATA";
 
