@@ -15,44 +15,22 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.maintenance.etc.action;
 
-import org.eclipse.jface.action.IAction;
-import org.eclipse.jface.viewers.ISelection;
+import org.eclipse.core.commands.AbstractHandler;
+import org.eclipse.core.commands.ExecutionEvent;
+import org.eclipse.core.commands.ExecutionException;
 import org.eclipse.ui.IWorkbenchPage;
-import org.eclipse.ui.IWorkbenchWindow;
-import org.eclipse.ui.IWorkbenchWindowActionDelegate;
 import org.eclipse.ui.PartInitException;
-import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.handlers.HandlerUtil;
 
 import com.clustercontrol.maintenance.view.MaintenanceListView;
 
 /**
  * メンテナンス[一覧]ビューを表示するクライアント側アクションクラス<BR>
  * 
- * @version 4.0.0
+ * @version 5.0.0
  * @since 4.0.0
  */
-public class OpenMaintenanceListViewAction implements IWorkbenchWindowActionDelegate {
-
-	/**
-	 * メンテナンス[一覧]ビューを表示します。
-	 * 
-	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
-	 * @see com.clustercontrol.notify.view.NotifyListView
-	 */
-	@Override
-	public void run(IAction action) {
-		// アクティブページ取得
-		IWorkbenchPage page = PlatformUI.getWorkbench()
-				.getActiveWorkbenchWindow().getActivePage();
-
-		// ビューを表示する
-		try {
-			MaintenanceListView view = (MaintenanceListView) page.showView(MaintenanceListView.ID);
-
-			view.setFocus();
-		} catch (PartInitException e) {
-		}
-	}
+public class OpenMaintenanceListViewAction extends AbstractHandler {
 
 	/**
 	 * 終了する際に呼ばれます。
@@ -63,22 +41,18 @@ public class OpenMaintenanceListViewAction implements IWorkbenchWindowActionDele
 	public void dispose() {
 	}
 
-	/**
-	 * ワークベンチにロードされた際に呼ばれます。
-	 * 
-	 * @see org.eclipse.ui.IWorkbenchWindowActionDelegate#init(org.eclipse.ui.IWorkbenchWindow)
-	 */
 	@Override
-	public void init(IWorkbenchWindow window) {
-	}
+	public Object execute(ExecutionEvent event) throws ExecutionException {
+		// アクティブページ取得
+		IWorkbenchPage page = HandlerUtil.getActiveWorkbenchWindow( event ).getActivePage();
 
-	/**
-	 * 選択を変更した際に呼ばれます。
-	 * 
-	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
-	 *      org.eclipse.jface.viewers.ISelection)
-	 */
-	@Override
-	public void selectionChanged(IAction action, ISelection selection) {
+		// ビューを表示する
+		try {
+			MaintenanceListView view = (MaintenanceListView) page.showView(MaintenanceListView.ID);
+
+			view.setFocus();
+		} catch (PartInitException e) {
+		}
+		return null;
 	}
-}
\ No newline at end of file
+}
