@@ -15,6 +15,7 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.maintenance.factory;
 
+import java.io.Serializable;
 import java.rmi.RemoteException;
 import java.text.ParseException;
 import java.util.Date;
@@ -24,6 +25,8 @@ import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.commons.scheduler.QuartzUtil;
+import com.clustercontrol.commons.util.EmptyJpaTransactionCallback;
+import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.maintenance.bean.QuartzConstant;
 import com.clustercontrol.maintenance.bean.MaintenanceInfo;
@@ -54,24 +57,34 @@ public class ModifySchedule {
 	 * @see com.clustercontrol.jobmanagement.bean.QuartzConstant
 	 * @see com.clustercontrol.jobmanagement.util.QuartzUtil#getQuartzManager()
 	 */
-	public void addSchedule(MaintenanceInfo info, String user) throws HinemosUnknown {
+	public void addSchedule(final MaintenanceInfo info, String user) throws HinemosUnknown {
 		m_log.debug("addSchedule() : id=" + info.getMaintenanceId());
-
-		//JobDetailに呼び出すメソッドの引数を設定
-		//ジョブIDを設定
-		Object[] jdArgs = new Object[2];
-		Class[] jdArgsType = new Class[2];
-		jdArgs[0] = info.getMaintenanceId();
-		jdArgsType[0] = String.class;
-		//カレンダIDを設定
-		jdArgs[1] = info.getCalendarId();
-		jdArgsType[1] = String.class;
-
-		SchedulerPlugin.scheduleCronJob(SchedulerType.DBMS, info.getMaintenanceId(), QuartzConstant.GROUP_NAME, new Date(System.currentTimeMillis() + 15 * 1000),
-				QuartzUtil.getCronString(info.getSchedule()), true, MaintenanceControllerBean.class.getName(), QuartzConstant.METHOD_NAME, jdArgsType, jdArgs);
-		if (! ValidConstant.typeToBoolean(info.getValidFlg())) {
-			SchedulerPlugin.pauseJob(SchedulerType.DBMS, info.getMaintenanceId(), QuartzConstant.GROUP_NAME);
-		}
+		
+		JpaTransactionManager jtm = new JpaTransactionManager();
+		jtm.addCallback(new EmptyJpaTransactionCallback() {
+			@Override
+			public void postCommit() {
+				//JobDetailに呼び出すメソッドの引数を設定
+				//ジョブIDを設定
+				Serializable[] jdArgs = new Serializable[2];
+				Class<? extends Serializable>[] jdArgsType = new Class[2];
+				jdArgs[0] = info.getMaintenanceId();
+				jdArgsType[0] = String.class;
+				//カレンダIDを設定
+				jdArgs[1] = info.getCalendarId();
+				jdArgsType[1] = String.class;
+				
+				try {
+					SchedulerPlugin.scheduleCronJob(SchedulerType.DBMS, info.getMaintenanceId(), QuartzConstant.GROUP_NAME, new Date(System.currentTimeMillis() + 15 * 1000),
+							QuartzUtil.getCronString(info.getSchedule()), true, MaintenanceControllerBean.class.getName(), QuartzConstant.METHOD_NAME, jdArgsType, jdArgs);
+					if (! ValidConstant.typeToBoolean(info.getValidFlg())) {
+						SchedulerPlugin.pauseJob(SchedulerType.DBMS, info.getMaintenanceId(), QuartzConstant.GROUP_NAME);
+					}
+				} catch (HinemosUnknown e) {
+					m_log.error(e);
+				}
+			}
+		});
 	}
 
 	/**
@@ -85,9 +98,19 @@ public class ModifySchedule {
 	 * @see com.clustercontrol.jobmanagement.util.QuartzUtil#getQuartzManager()
 	 * @see com.clustercontrol.quartzmanager.ejb.session.QuartzManager#deleteSchedule(java.lang.String, java.lang.String)
 	 */
-	public void deleteSchedule(String scheduleId) throws HinemosUnknown {
+	public void deleteSchedule(final String scheduleId) throws HinemosUnknown {
 		m_log.debug("deleteSchedule() : id=" + scheduleId);
 
-		SchedulerPlugin.deleteJob(SchedulerType.DBMS, scheduleId, QuartzConstant.GROUP_NAME);
+		JpaTransactionManager jtm = new JpaTransactionManager();
+		jtm.addCallback(new EmptyJpaTransactionCallback() {
+			@Override
+			public void postCommit() {
+				try {
+					SchedulerPlugin.deleteJob(SchedulerType.DBMS, scheduleId, QuartzConstant.GROUP_NAME);
+				} catch (HinemosUnknown e) {
+					m_log.error(e);
+				}
+			}
+		});
 	}
 }
