@@ -38,7 +38,6 @@ import com.clustercontrol.maintenance.bean.MaintenanceInfo;
 import com.clustercontrol.maintenance.bean.MaintenanceTypeMst;
 import com.clustercontrol.maintenance.factory.AddMaintenance;
 import com.clustercontrol.maintenance.factory.DeleteMaintenance;
-import com.clustercontrol.maintenance.factory.MaintenanceCrun;
 import com.clustercontrol.maintenance.factory.MaintenanceEvent;
 import com.clustercontrol.maintenance.factory.MaintenanceJob;
 import com.clustercontrol.maintenance.factory.MaintenancePerf;
@@ -391,14 +390,15 @@ public class MaintenanceControllerBean {
 	 * 
 	 * @param dataRetentionPeriod 保存期間(日)
 	 * @param status 削除対象のステータス(true=全イベント、false=確認済みイベント)
+	 * @param ownerRoleId オーナーロールID
 	 * @return 削除件数
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
 	 * 
 	 * 時間を要する処理のため、NotSupportedを採用してJTAの管理下から除外する
 	 */
-	public int deleteEventLog(int dataRetentionPeriod, boolean status) throws InvalidRole, HinemosUnknown {
-		m_log.debug("deleteEventLog() : dataRetentionPeriod = " + dataRetentionPeriod + ", status = " + status);
+	public int deleteEventLog(int dataRetentionPeriod, boolean status, String ownerRoleId) throws InvalidRole, HinemosUnknown {
+		m_log.debug("deleteEventLog() : dataRetentionPeriod = " + dataRetentionPeriod + ", status = " + status + ", ownerRoleId = " + ownerRoleId);
 
 		JpaTransactionManager jtm = null;
 		MaintenanceEvent event = new MaintenanceEvent();
@@ -407,7 +407,7 @@ public class MaintenanceControllerBean {
 			jtm = new JpaTransactionManager();
 			jtm.begin();
 
-			ret = event.delete(dataRetentionPeriod, status);
+			ret = event.delete(dataRetentionPeriod, status, ownerRoleId);
 
 			jtm.commit();
 		} catch (ObjectPrivilege_InvalidRole e) {
@@ -431,14 +431,15 @@ public class MaintenanceControllerBean {
 	 * 
 	 * @param dataRetentionPeriod 保存期間(日)
 	 * @param status 削除対象のステータス(true=全履歴、false=実行状態が「終了」または「変更済み」の履歴)
+	 * @param ownerRoleId オーナーロールID
 	 * @return 削除件数
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
 	 * 
 	 * 時間を要する処理のため、NotSupportedを採用してJTAの管理下から除外する
 	 */
-	public int deleteJobHistory(int dataRetentionPeriod, boolean status) throws InvalidRole, HinemosUnknown {
-		m_log.debug("deleteJobHistory() : dataRetentionPeriod = " + dataRetentionPeriod + ", status = " + status);
+	public int deleteJobHistory(int dataRetentionPeriod, boolean status, String ownerRoleId) throws InvalidRole, HinemosUnknown {
+		m_log.debug("deleteJobHistory() : dataRetentionPeriod = " + dataRetentionPeriod + ", status = " + status + ", ownerRoleId = " + ownerRoleId);
 
 		JpaTransactionManager jtm = null;
 		MaintenanceJob job = new MaintenanceJob();
@@ -448,7 +449,7 @@ public class MaintenanceControllerBean {
 			jtm = new JpaTransactionManager();
 			jtm.begin();
 
-			ret = job.delete(dataRetentionPeriod, status);
+			ret = job.delete(dataRetentionPeriod, status, ownerRoleId);
 
 			jtm.commit();
 		} catch (ObjectPrivilege_InvalidRole e) {
@@ -471,6 +472,7 @@ public class MaintenanceControllerBean {
 	 * 
 	 * @param dataRetentionPeriod 保存期間(日)
 	 * @param status 削除対象のステータス(true=全履歴、false=実行状態が「終了」または「変更済み」の履歴)
+	 * @param ownerRoleId オーナーロールID
 	 * @return 削除件数
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
@@ -478,8 +480,8 @@ public class MaintenanceControllerBean {
 	 * 時間を要する処理のため、NotSupportedを採用してJTAの管理下から除外する
 	 * 
 	 */
-	public int deletePerfData(int dataRetentionPeriod, boolean status) throws InvalidRole, HinemosUnknown {
-		m_log.debug("deletePerfData() : dataRetentionPeriod = " + dataRetentionPeriod + ", status = " + status);
+	public int deletePerfData(int dataRetentionPeriod, boolean status, String ownerRoleId) throws InvalidRole, HinemosUnknown {
+		m_log.debug("deletePerfData() : dataRetentionPeriod = " + dataRetentionPeriod + ", status = " + status + ", ownerRoleId = " + ownerRoleId);
 
 		JpaTransactionManager jtm = null;
 		MaintenancePerf perf = new MaintenancePerf();
@@ -489,7 +491,7 @@ public class MaintenanceControllerBean {
 			jtm = new JpaTransactionManager();
 			jtm.begin();
 
-			ret = perf.delete(dataRetentionPeriod, status);
+			ret = perf.delete(dataRetentionPeriod, status, ownerRoleId);
 
 			jtm.commit();
 		} catch (ObjectPrivilege_InvalidRole e) {
@@ -507,46 +509,6 @@ public class MaintenanceControllerBean {
 		return ret;
 	}
 
-	/**
-	 * 
-	 * 一括制御履歴を削除します。
-	 * 
-	 * @param dataRetentionPeriod 保存期間(日)
-	 * @param status 削除対象のステータス(true=全履歴、false=実行状態が「終了」の履歴)
-	 * @return 削除件数
-	 * @throws InvalidRole
-	 * @throws HinemosUnknown
-	 * 
-	 * 時間を要する処理のため、NotSupportedを採用してJTAの管理下から除外する
-	 */
-	public int deleteCollectiveRunHistory(int dataRetentionPeriod, boolean status) throws InvalidRole, HinemosUnknown {
-		m_log.debug("deleteCollectiveRunHistory() : dataRetentionPeriod = " + dataRetentionPeriod + ", status = " + status);
-
-		JpaTransactionManager jtm = null;
-		MaintenanceCrun crun = new MaintenanceCrun();
-		int ret = 0;
-
-		try{
-			jtm = new JpaTransactionManager();
-			jtm.begin();
-
-			ret = crun.delete(dataRetentionPeriod, status);
-
-			jtm.commit();
-		} catch (ObjectPrivilege_InvalidRole e) {
-			jtm.rollback();
-			throw new InvalidRole(e.getMessage(), e);
-		} catch(Exception e){
-			m_log.warn("deleteCollectiveRunHistory() : "
-					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
-			jtm.rollback();
-			throw new HinemosUnknown(e.getMessage(), e);
-		} finally {
-			jtm.close();
-		}
-
-		return ret;
-	}
 
 	/**
 	 * 
