@@ -18,12 +18,7 @@ package com.clustercontrol.maintenance.view;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.eclipse.jface.action.ActionContributionItem;
-import org.eclipse.jface.action.IMenuListener;
-import org.eclipse.jface.action.IMenuManager;
-import org.eclipse.jface.action.IToolBarManager;
 import org.eclipse.jface.action.MenuManager;
-import org.eclipse.jface.action.Separator;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.SelectionChangedEvent;
@@ -36,7 +31,9 @@ import org.eclipse.swt.widgets.Menu;
 import org.eclipse.ui.IViewPart;
 import org.eclipse.ui.IWorkbenchPage;
 import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.commands.ICommandService;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.accesscontrol.util.ObjectBean;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.Property;
@@ -48,25 +45,27 @@ import com.clustercontrol.maintenance.view.action.MaintenanceDeleteAction;
 import com.clustercontrol.maintenance.view.action.MaintenanceDisableAction;
 import com.clustercontrol.maintenance.view.action.MaintenanceEnableAction;
 import com.clustercontrol.maintenance.view.action.MaintenanceModifyAction;
+import com.clustercontrol.maintenance.view.action.MaintenanceRefreshAction;
+import com.clustercontrol.maintenance.view.action.ObjectPrivilegeMaintenanceListAction;
 import com.clustercontrol.view.CommonViewPart;
 import com.clustercontrol.view.ObjectPrivilegeTargetListView;
 
 /**
  * メンテナンス[一覧]ビュークラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 4.0.0
  */
 public class MaintenanceListView extends CommonViewPart implements ObjectPrivilegeTargetListView {
 
 	/** メンテナンス[一覧]ビューID */
-	public static final String ID = "com.clustercontrol.maintenance.view.MaintenanceListView";
+	public static final String ID = MaintenanceListView.class.getName();
 
 	/** メンテナンス[一覧]コンポジット */
 	private MaintenanceListComposite composite = null;
 
-	/** 検索条件 */
-	private Property condition = null;
+	/** 選択レコード数 */
+	private int rowNum = 0;
 
 	/**
 	 * コンストラクタ
@@ -77,7 +76,7 @@ public class MaintenanceListView extends CommonViewPart implements ObjectPrivile
 
 	/**
 	 * ViewPartへのコントロール作成処理<BR>
-	 * 
+	 *
 	 * @see org.eclipse.ui.IWorkbenchPart#createPartControl(org.eclipse.swt.widgets.Composite)
 	 */
 	@Override
@@ -88,6 +87,7 @@ public class MaintenanceListView extends CommonViewPart implements ObjectPrivile
 		layout.marginWidth = 0;
 
 		composite = new MaintenanceListComposite(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, composite);
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -122,71 +122,23 @@ public class MaintenanceListView extends CommonViewPart implements ObjectPrivile
 
 	/**
 	 * コンテキストメニューを作成します。
-	 * 
+	 *
 	 * @see org.eclipse.jface.action.MenuManager
 	 * @see org.eclipse.swt.widgets.Menu
 	 */
 	private void createContextMenu() {
 		MenuManager menuManager = new MenuManager();
 		menuManager.setRemoveAllWhenShown(true);
-		menuManager.addMenuListener(new IMenuListener() {
-			/* (non-Javadoc)
-			 * @see org.eclipse.jface.action.IMenuListener#menuAboutToShow(org.eclipse.jface.action.IMenuManager)
-			 */
-			@Override
-			public void menuAboutToShow(IMenuManager manager) {
-				//メニュー項目設定
-				fillContextMenu(manager);
-			}
-		});
 
 		Menu menu = menuManager.createContextMenu(composite.getTable());
+		WidgetTestUtil.setTestId(this, null, menu);
 		composite.getTable().setMenu(menu);
-	}
-
-	/**
-	 * コンテキストメニューに項目を追加します。
-	 * 
-	 * @param manager メニューマネージャ
-	 * 
-	 * @see org.eclipse.jface.action.IToolBarManager
-	 * @see org.eclipse.jface.action.IMenuManager
-	 */
-	private void fillContextMenu(IMenuManager manager) {
-		//ビューのアクションのインスタンスを取得
-		IToolBarManager toolbar =
-				this.getViewSite().getActionBars().getToolBarManager();
-		ActionContributionItem maintenanceAdd =
-				(ActionContributionItem) toolbar.find(MaintenanceAddAction.ID);
-		ActionContributionItem maintenanceModify =
-				(ActionContributionItem) toolbar.find(MaintenanceModifyAction.ID);
-		ActionContributionItem maintenanceDelete =
-				(ActionContributionItem) toolbar.find(MaintenanceDeleteAction.ID);
-		ActionContributionItem maintenanceCopy =
-				(ActionContributionItem) toolbar.find(MaintenanceCopyAction.ID);
-		ActionContributionItem maintenanceEnable =
-				(ActionContributionItem) toolbar.find(MaintenanceEnableAction.ID);
-		ActionContributionItem maintenanceDisable =
-				(ActionContributionItem) toolbar.find(MaintenanceDisableAction.ID);
-//		ActionContributionItem objPrivilege =
-//				(ActionContributionItem) toolbar.find(ObjectPrivilegeAction.ID);
-
-		//ポップアップメニューにアクションを追加
-		manager.add(maintenanceAdd.getAction());
-		manager.add(maintenanceModify.getAction());
-		manager.add(maintenanceDelete.getAction());
-		manager.add(new Separator());
-		manager.add(maintenanceCopy.getAction());
-		manager.add(new Separator());
-		manager.add(maintenanceEnable.getAction());
-		manager.add(maintenanceDisable.getAction());
-//		manager.add(new Separator());
-//		manager.add(objPrivilege.getAction());
+		getSite().registerContextMenu( menuManager, this.composite.getTableViewer() );
 	}
 
 	/**
 	 * 追加コンポジットを返します。
-	 * 
+	 *
 	 * @return 追加コンポジット
 	 */
 	public Composite getListComposite() {
@@ -196,22 +148,20 @@ public class MaintenanceListView extends CommonViewPart implements ObjectPrivile
 	/**
 	 * 検索条件にヒットした監視設定の一覧を表示します。
 	 * <p>
-	 * 
+	 *
 	 * conditionがnullの場合、全監視設定を表示します。
-	 * 
+	 *
 	 * @param condition
 	 *            検索条件
 	 */
 	public void update(Property condition) {
-		this.condition = condition;
-
 		this.update();
 	}
 
 	/**
 	 * ビューを更新します。
 	 * <p>
-	 * 
+	 *
 	 * 検索条件が事前に設定されている場合、その条件にヒットする監視設定の一覧を 表示します <br>
 	 * 検索条件が設定されていない場合は、全監視設定を表示します。
 	 */
@@ -220,49 +170,46 @@ public class MaintenanceListView extends CommonViewPart implements ObjectPrivile
 		this.composite.update();
 	}
 
+	/**
+	 * 選択レコード数を返します。
+	 * @return rowNum
+	 */
+	public int getSelectedNum(){
+		return this.rowNum;
+	}
+
 	/**
 	 * ビューのアクションの有効/無効を設定します。
-	 * 
+	 *
 	 * @param num 選択イベント数
 	 * @param selection ボタン（アクション）を有効にするための情報
 	 */
 	public void setEnabledAction(int num, ISelection selection) {
+		this.rowNum = num;
+
 		//ビューアクションの使用可/不可を設定
-//		super.setEnabledAction(ObjectPrivilegeAction.ID, selection);
-		super.setEnabledAction(MaintenanceCopyAction.ID, selection);
-		super.setEnabledAction(MaintenanceDeleteAction.ID, selection);
-		super.setEnabledAction(MaintenanceModifyAction.ID, selection);
-		super.setEnabledAction(MaintenanceEnableAction.ID, selection);
-		super.setEnabledAction(MaintenanceDisableAction.ID, selection);
+		ICommandService service = (ICommandService) PlatformUI.getWorkbench().getService( ICommandService.class );
+		if( null != service ){
+			service.refreshElements(ObjectPrivilegeMaintenanceListAction.ID, null);
+			service.refreshElements(MaintenanceAddAction.ID, null);
+			service.refreshElements(MaintenanceModifyAction.ID, null);
+			service.refreshElements(MaintenanceDeleteAction.ID, null);
+			service.refreshElements(MaintenanceCopyAction.ID, null);
+			service.refreshElements(MaintenanceEnableAction.ID, null);
+			service.refreshElements(MaintenanceDisableAction.ID, null);
+			service.refreshElements(MaintenanceRefreshAction.ID, null);
 
-		if (num > 0){
-			super.setEnabledAction(MaintenanceEnableAction.ID, true);
-			super.setEnabledAction(MaintenanceDisableAction.ID, true);
-//			super.setEnabledAction(ObjectPrivilegeAction.ID, true);
-
-			if(num == 1){
-				super.setEnabledAction(MaintenanceCopyAction.ID, true);
-				super.setEnabledAction(MaintenanceDeleteAction.ID, true);
-				super.setEnabledAction(MaintenanceModifyAction.ID, true);
-			} else {
-				super.setEnabledAction(MaintenanceCopyAction.ID, false);
-				super.setEnabledAction(MaintenanceDeleteAction.ID, false);
-				super.setEnabledAction(MaintenanceModifyAction.ID, false);
-			}
-		} else {
-//			super.setEnabledAction(ObjectPrivilegeAction.ID, false);
-			super.setEnabledAction(MaintenanceCopyAction.ID, false);
-			super.setEnabledAction(MaintenanceDeleteAction.ID, false);
-			super.setEnabledAction(MaintenanceModifyAction.ID, false);
-			super.setEnabledAction(MaintenanceEnableAction.ID, false);
-			super.setEnabledAction(MaintenanceDisableAction.ID, false);
+			// Update ToolBar after elements refreshed
+			// WARN : Both ToolBarManager must be updated after updateActionBars(), otherwise icon won't change.
+			getViewSite().getActionBars().updateActionBars();
+			getViewSite().getActionBars().getToolBarManager().update(false);
 		}
 	}
 
 	public String getSelectedId() {
 		StructuredSelection selection = (StructuredSelection) this.composite.getTableViewer().getSelection();
 
-		List list = (List) selection.getFirstElement();
+		List<?> list = (List<?>) selection.getFirstElement();
 		String id = null;
 		if (list != null) {
 			id = (String) list.get(GetMaintenanceListTableDefine.MAINTENANCE_ID);
@@ -275,12 +222,14 @@ public class MaintenanceListView extends CommonViewPart implements ObjectPrivile
 		StructuredSelection selection = (StructuredSelection) this.composite.getTableViewer().getSelection();
 		Object [] objs = selection.toArray();
 
+		String managerName = null;
 		String objectType = HinemosModuleConstant.SYSYTEM_MAINTENANCE;
 		String objectId = null;
 		List<ObjectBean> objectBeans = new ArrayList<ObjectBean>();
 		for (Object obj : objs) {
-			objectId = (String) ((List)obj).get(GetMaintenanceListTableDefine.MAINTENANCE_ID);
-			ObjectBean objectBean = new ObjectBean(objectType, objectId);
+			managerName = (String) ((List<?>)obj).get(GetMaintenanceListTableDefine.MANAGER_NAME);
+			objectId = (String) ((List<?>)obj).get(GetMaintenanceListTableDefine.MAINTENANCE_ID);
+			ObjectBean objectBean = new ObjectBean(managerName, objectType, objectId);
 			objectBeans.add(objectBean);
 		}
 		return objectBeans;
@@ -290,7 +239,7 @@ public class MaintenanceListView extends CommonViewPart implements ObjectPrivile
 	public String getSelectedOwnerRoleId() {
 		StructuredSelection selection = (StructuredSelection) this.composite.getTableViewer().getSelection();
 
-		List list = (List) selection.getFirstElement();
+		List<?> list = (List<?>) selection.getFirstElement();
 		String id = null;
 		if (list != null) {
 			id = (String) list.get(GetMaintenanceListTableDefine.OWNER_ROLE);
