@@ -14,15 +14,17 @@ PURPOSE.  See the GNU General Public License for more details.
  */
 package com.clustercontrol.monitor.action;
 
+import java.util.List;
+
 /**
  * 監視設定削除クラス用インタフェース
- * 
+ *
  * @version 4.0.0
  * @since 4.0.0
  */
 public interface DeleteInterface {
 
 	// 監視設定の削除
-	public boolean delete(String monitorId) throws Exception;
+	public boolean delete(String managerName, List<String> monitorIdList) throws Exception;
 
 }
