@@ -32,8 +32,8 @@ public class MonitorPreferenceInitializer extends AbstractPreferenceInitializer
 		store.setDefault(MonitorPreferencePage.P_STATUS_UPDATE_CYCLE, 10);
 		store.setDefault(MonitorPreferencePage.P_EVENT_UPDATE_FLG, true);
 		store.setDefault(MonitorPreferencePage.P_EVENT_UPDATE_CYCLE, 10);
-		store.setDefault(MonitorPreferencePage.P_EVENT_MESSAGE_FLG, true);
+		store.setDefault(MonitorPreferencePage.P_EVENT_MESSAGE_FLG, false);
 		store.setDefault(MonitorPreferencePage.P_EVENT_MAX, 100);
+		store.setDefault(MonitorPreferencePage.P_MAX_TRAP_OID, 100);
 	}
 }
-
