@@ -31,6 +31,7 @@ import com.clustercontrol.monitor.run.bean.TruthConstant;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.monitor.MonitorInfo;
 import com.clustercontrol.ws.monitor.MonitorTruthValueInfo;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * 真偽値監視の判定情報（重要度）コンポジットクラス<BR>
@@ -69,13 +70,13 @@ public class TruthValueInfoComposite extends Composite {
 	 * インスタンスを返します。
 	 * <p>
 	 * 初期処理を呼び出し、コンポジットを配置します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param style スタイル
 	 * @param rangeFlg 範囲判定フラグ
 	 * @param itemTrue 項目名（真）
 	 * @param itemFalse 項目名（偽）
-	 * 
+	 *
 	 * @see org.eclipse.swt.SWT
 	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
 	 * @see #initialize()
@@ -115,6 +116,7 @@ public class TruthValueInfoComposite extends Composite {
 		// ラベル
 		// 空白
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space1", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TITLE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -123,6 +125,7 @@ public class TruthValueInfoComposite extends Composite {
 
 		// 重要度
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "priority", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TITLE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -132,6 +135,7 @@ public class TruthValueInfoComposite extends Composite {
 
 		// 空白
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space2", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 5;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -143,6 +147,7 @@ public class TruthValueInfoComposite extends Composite {
 		 */
 		// 空白
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space3", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TITLE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -152,6 +157,7 @@ public class TruthValueInfoComposite extends Composite {
 
 		// 重要度
 		this.m_comboTrue = new Combo(this, SWT.DROP_DOWN | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "true", m_comboTrue);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TITLE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -165,6 +171,7 @@ public class TruthValueInfoComposite extends Composite {
 
 		// 空白
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space4", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 5;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -176,6 +183,7 @@ public class TruthValueInfoComposite extends Composite {
 		 */
 		// 空白
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space5", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TITLE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -185,6 +193,7 @@ public class TruthValueInfoComposite extends Composite {
 
 		// 重要度
 		this.m_comboFalse = new Combo(this, SWT.DROP_DOWN | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "false", m_comboTrue);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TITLE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -198,6 +207,7 @@ public class TruthValueInfoComposite extends Composite {
 
 		// 空白
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space6", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 5;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -207,7 +217,7 @@ public class TruthValueInfoComposite extends Composite {
 
 	/**
 	 * 引数で指定された監視情報の値を、各項目に設定します。
-	 * 
+	 *
 	 * @param info 設定値として用いる監視情報
 	 */
 	public void setInputData(MonitorInfo info) {
@@ -233,7 +243,7 @@ public class TruthValueInfoComposite extends Composite {
 
 	/**
 	 * 引数で指定された監視情報に、入力値を設定します。
-	 * 
+	 *
 	 * @param info 入力値を設定する監視情報
 	 * @return 検証結果
 	 */
@@ -274,7 +284,7 @@ public class TruthValueInfoComposite extends Composite {
 
 	/**
 	 * 無効な入力値の情報を設定します。
-	 * 
+	 *
 	 * @param id ID
 	 * @param message メッセージ
 	 * @return 認証結果
@@ -288,4 +298,4 @@ public class TruthValueInfoComposite extends Composite {
 
 		return validateResult;
 	}
-}
\ No newline at end of file
+}
