@@ -27,10 +27,11 @@ import com.clustercontrol.monitor.run.action.GetStringFilterTableDefine;
 import com.clustercontrol.monitor.run.bean.MonitorTypeConstant;
 import com.clustercontrol.monitor.run.composite.StringValueInfoComposite;
 import com.clustercontrol.ws.monitor.MonitorInfo;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * 文字列系監視設定共通ダイアログクラス<BR>
- * 
+ *
  */
 public class CommonMonitorStringDialog extends CommonMonitorDialog {
 
@@ -44,19 +45,21 @@ public class CommonMonitorStringDialog extends CommonMonitorDialog {
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のシェルオブジェクト
+	 * @param managerName
+	 *            マネージャ名
 	 */
-	public CommonMonitorStringDialog(Shell parent) {
-		super(parent);
+	public CommonMonitorStringDialog(Shell parent, String managerName) {
+		super(parent, managerName);
 	}
 
 	// ----- instance メソッド ----- //
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親のインスタンス
 	 */
 	@Override
@@ -70,6 +73,7 @@ public class CommonMonitorStringDialog extends CommonMonitorDialog {
 		// 文字列判定定義情報
 		ArrayList<TableColumnInfo> tableDefine = GetStringFilterTableDefine.get();
 		this.m_stringValueInfo = new StringValueInfoComposite(groupDetermine, SWT.NONE, tableDefine, logLineFlag);
+		WidgetTestUtil.setTestId(this, null, m_stringValueInfo);
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -81,7 +85,7 @@ public class CommonMonitorStringDialog extends CommonMonitorDialog {
 
 	/**
 	 * 監視エリアを有効/無効化します。
-	 * 
+	 *
 	 */
 	@Override
 	protected void setMonitorEnabled(boolean enabled){
@@ -91,7 +95,7 @@ public class CommonMonitorStringDialog extends CommonMonitorDialog {
 
 	/**
 	 * 入力値を用いて通知情報を生成します。
-	 * 
+	 *
 	 * @return 入力値を保持した通知情報
 	 */
 	@Override
@@ -107,4 +111,4 @@ public class CommonMonitorStringDialog extends CommonMonitorDialog {
 		return monitorInfo;
 	}
 
-}
\ No newline at end of file
+}
