@@ -15,7 +15,6 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.monitor.run.dialog;
 
-import java.util.Collection;
 import java.util.regex.Pattern;
 import java.util.regex.PatternSyntaxException;
 
@@ -42,14 +41,13 @@ import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
-import com.clustercontrol.monitor.run.util.StringValueInfoManager;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.monitor.MonitorStringValueInfo;
-import com.clustercontrol.ws.notify.NotifyRelationInfo;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * フィルタ[作成・変更]ダイアログクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 2.1.0
  */
@@ -67,12 +65,6 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 	/** 入力値の正当性を保持するオブジェクト。 */
 	private ValidateResult m_validateResult = null;
 
-	/** 変更対象の識別キー。 */
-	private String m_identifier = null;
-
-	/** 変更対象の順序。 */
-	private int m_order = Integer.MAX_VALUE;
-
 	/** 説明。 */
 	private Text m_textDescription = null;
 
@@ -102,34 +94,40 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
 	 */
 	public StringValueInfoCreateDialog(Shell parent, boolean logLineFlag) {
 		super(parent);
 		this.logLineFlag = logLineFlag;
+
+		// 識別子が指定されている場合、その情報を初期表示する。
+		MonitorStringValueInfo info = new MonitorStringValueInfo();
+		info.setProcessType(ProcessConstant.TYPE_YES);
+		info.setValidFlg(ValidConstant.BOOLEAN_VALID);
+
+		m_inputData = info;
 	}
 
 	/**
 	 * 変更用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
 	 * @param identifier 変更する文字列監視の判定情報の識別キー
 	 */
-	public StringValueInfoCreateDialog(Shell parent, String identifier) {
+	public StringValueInfoCreateDialog(Shell parent, MonitorStringValueInfo info) {
 		super(parent);
-
-		this.m_identifier = identifier;
+		m_inputData = info;
 	}
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
-	 * 
+	 *
 	 * @see com.clustercontrol.notify.composite.NotifyIdListComposite#NotifyIdListComposite(Composite, int, boolean)
 	 * @see com.clustercontrol.monitor.run.composite.StringRunJobComposite#StringRunJobComposite(Composite, int)
-	 * @see com.clustercontrol.monitor.run.util.StringValueInfoManager#get(String)
+	 * @see com.clustercontrol.monitor.run.util.StringValueInfoManager#getJobEditState(String)
 	 * @see com.clustercontrol.monitor.run.bean.MonitorStringValueInfo
 	 * @see #setInputData(MonitorStringValueInfo)
 	 */
@@ -165,6 +163,7 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 		label.setText(Messages.getString("description") + " : ");
 		// テキスト
 		this.m_textDescription = new Text(parent, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "description", m_textDescription);
 		gridData = new GridData();
 		gridData.horizontalSpan = 10;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -182,6 +181,7 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 		 */
 		// グループ
 		Group monitorRuleGroup = new Group(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "monitorrule", monitorRuleGroup);
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
@@ -207,6 +207,7 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 		label.setText(Messages.getString("pattern.matching.expression") + " : ");
 		// テキスト
 		this.m_textPattern = new Text(monitorRuleGroup, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "pattern", m_textPattern);
 		gridData = new GridData();
 		gridData.horizontalSpan = 10;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -225,6 +226,7 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 
 		// 条件に一致したら処理する
 		this.m_radioProcess = new Button(monitorRuleGroup, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "process", m_radioProcess);
 		gridData = new GridData();
 		gridData.horizontalSpan = 7;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -249,6 +251,7 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 
 		// 大文字・小文字をチェックしない
 		this.m_checkCaseSensitive = new Button(monitorRuleGroup, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "casesensitive", m_checkCaseSensitive);
 		gridData = new GridData();
 		gridData.horizontalSpan = 7;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -258,6 +261,7 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 
 		// 条件に一致したら処理しない
 		this.m_radioNotProcess = new Button(monitorRuleGroup, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "notprocess", m_radioNotProcess);
 		gridData = new GridData();
 		gridData.horizontalSpan = 7;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -284,6 +288,7 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 		 * 処理グループ
 		 */
 		Group executeGroup = new Group(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "execute", executeGroup);
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
@@ -309,6 +314,7 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 		label.setText(Messages.getString("priority") + " : ");
 		// コンボボックス
 		this.m_comboPriority = new Combo(executeGroup, SWT.DROP_DOWN | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "priority", m_comboPriority);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_VALUE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -340,6 +346,7 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 		label.setText(Messages.getString("message") + " : ");
 		// テキスト
 		this.m_textMessage = new Text(executeGroup, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "message", m_textMessage);
 		gridData = new GridData();
 		gridData.horizontalSpan = 10;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -360,6 +367,7 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 		 * 有効／無効
 		 */
 		this.m_buttonValid = new Button(parent, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "valid", m_buttonValid);
 		gridData = new GridData();
 		gridData.horizontalSpan = 15;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -384,23 +392,14 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 		Display display = shell.getDisplay();
 		shell.setLocation((display.getBounds().width - shell.getSize().x) / 2,
 				(display.getBounds().height - shell.getSize().y) / 2);
-		Collection<NotifyRelationInfo> modifyNotify = null;
 
-		// 識別子が指定されている場合、その情報を初期表示する。
-		MonitorStringValueInfo info = StringValueInfoManager.getInstance().get(this.m_identifier);
-		if (info == null) {
-			info = new MonitorStringValueInfo();
-			info.setOrderNo(Integer.MAX_VALUE);
-			info.setProcessType(ProcessConstant.TYPE_YES);
-			info.setValidFlg(ValidConstant.BOOLEAN_VALID);
-		}
-
-		this.setInputData(info, modifyNotify);
+		update();
+		setInputData();
 	}
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	public void update(){
 		// 必須項目を可視化
@@ -420,7 +419,7 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 
 	/**
 	 * 入力値を保持した文字列監視の判定情報を返します。
-	 * 
+	 *
 	 * @return 判定情報
 	 */
 	public MonitorStringValueInfo getInputData() {
@@ -429,50 +428,44 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 
 	/**
 	 * 引数で指定された判定情報の値を、各項目に設定します。
-	 * 
+	 *
 	 * @param info 設定値として用いる判定情報
 	 */
-	protected void setInputData(MonitorStringValueInfo info, Collection<NotifyRelationInfo> modifyNotify) {
-
-		this.m_inputData = info;
-
-		// 各項目に反映
-		this.m_identifier = info.getIdentifier();
-		this.m_order = info.getOrderNo();
+	protected void setInputData() {
 
 		// 説明
-		if (info.getDescription() != null) {
-			this.m_textDescription.setText(info.getDescription());
+		if (m_inputData.getDescription() != null) {
+			this.m_textDescription.setText(m_inputData.getDescription());
 		}
 
 		// パターンマッチ表現
-		if (info.getPattern() != null) {
-			this.m_textPattern.setText(info.getPattern());
+		if (m_inputData.getPattern() != null) {
+			this.m_textPattern.setText(m_inputData.getPattern());
 		}
 
 		// 処理する／しない
-		if (info.getProcessType() == ProcessConstant.TYPE_YES) {
+		if (m_inputData.getProcessType() == ProcessConstant.TYPE_YES) {
 			this.m_radioProcess.setSelection(true);
 		} else {
 			this.m_radioNotProcess.setSelection(true);
 		}
 
 		// 大文字・小文字を区別しない
-		if (info.isCaseSensitivityFlg()){
+		if (m_inputData.isCaseSensitivityFlg()){
 			this.m_checkCaseSensitive.setSelection(true);
 		}
 
 		// 重要度
-		this.m_comboPriority.setText(PriorityConstant.typeToString(info.getPriority()));
+		this.m_comboPriority.setText(PriorityConstant.typeToString(m_inputData.getPriority()));
 
 		// メッセージ
-		if (info.getMessage() != null) {
-			this.m_textMessage.setText(info.getMessage());
+		if (m_inputData.getMessage() != null) {
+			this.m_textMessage.setText(m_inputData.getMessage());
 		}
 
 
 		// 有効／無効
-		if (info.isValidFlg() == ValidConstant.BOOLEAN_VALID) {
+		if (m_inputData.isValidFlg() == ValidConstant.BOOLEAN_VALID) {
 			this.m_buttonValid.setSelection(true);
 		}
 
@@ -488,16 +481,14 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 	 * 引数で指定された判定情報に、入力値を設定します。
 	 * <p>
 	 * 入力値チェックを行い、不正な場合は<code>null</code>を返します。
-	 * 
+	 *
 	 * @return 判定情報
-	 * 
+	 *
 	 * @see #setValidateResult(String, String)
 	 */
 	private MonitorStringValueInfo createInputData() {
 		MonitorStringValueInfo info = new MonitorStringValueInfo();
 
-		info.setIdentifier(this.m_identifier);
-		info.setOrderNo(this.m_order);
 
 		// 説明
 		if (this.m_textDescription.getText() != null
@@ -567,9 +558,9 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 
 	/**
 	 * 無効な入力値をチェックをします。
-	 * 
+	 *
 	 * @return 検証結果
-	 * 
+	 *
 	 * @see #createInputData()
 	 */
 	@Override
@@ -586,7 +577,7 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 
 	/**
 	 * ＯＫボタンのテキストを返します。
-	 * 
+	 *
 	 * @return ＯＫボタンのテキスト
 	 */
 	@Override
@@ -596,7 +587,7 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 
 	/**
 	 * キャンセルボタンのテキストを返します。
-	 * 
+	 *
 	 * @return キャンセルボタンのテキスト
 	 */
 	@Override
@@ -606,7 +597,7 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 
 	/**
 	 * コンポジットの選択可/不可を設定します。
-	 * 
+	 *
 	 * @param enable 選択可の場合、<code> true </code>
 	 */
 	protected void setEnabled(boolean enable) {
@@ -616,7 +607,7 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 
 	/**
 	 * 無効な入力値の情報を設定します。
-	 * 
+	 *
 	 * @param id ID
 	 * @param message メッセージ
 	 */
@@ -630,9 +621,9 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 
 	/**
 	 * 入力値の判定を行います。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -646,4 +637,4 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 
 		return result;
 	}
-}
\ No newline at end of file
+}
