@@ -93,6 +93,9 @@ abstract public class RunMonitor {
 
 	/** 監視対象ファシリティID。 */
 	protected String m_facilityId;
+	
+	/** 監視対象のノードのID（スコープ配下の個別のノード、本プロパティはプロセス監視でのみ使用される）*/
+	protected String m_nodeId;
 
 	/**
 	 * 値取得の失敗時の重要度。
@@ -290,6 +293,7 @@ abstract public class RunMonitor {
 					runMonitor.setJudgementInfo();
 					runMonitor.nodeInfo = this.nodeInfo;
 					runMonitor.setCheckInfo();
+					runMonitor.m_nodeId = facilityId;
 					
 					ecs.submit(new CallableTask(runMonitor, facilityId));
 					taskCount++;
