@@ -7,22 +7,28 @@ import java.util.regex.PatternSyntaxException;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.bean.DataRangeConstant;
+import com.clustercontrol.bean.HinemosModuleConstant;
+import com.clustercontrol.bean.ProcessConstant;
+import com.clustercontrol.bean.RunIntervalConstant;
+import com.clustercontrol.bean.SnmpVersionConstant;
+import com.clustercontrol.bean.ValidConstant;
+import com.clustercontrol.bean.YesNoConstant;
+import com.clustercontrol.commons.util.CommonValidator;
+import com.clustercontrol.custom.bean.CustomCheckInfo;
+import com.clustercontrol.custom.bean.CustomConstant;
 import com.clustercontrol.fault.CollectorNotFound;
 import com.clustercontrol.fault.FacilityNotFound;
 import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.InvalidSetting;
 import com.clustercontrol.fault.MonitorNotFound;
-import com.clustercontrol.bean.DataRangeConstant;
-import com.clustercontrol.bean.HinemosModuleConstant;
-import com.clustercontrol.bean.ProcessConstant;
-import com.clustercontrol.bean.RunIntervalConstant;
-import com.clustercontrol.bean.ValidConstant;
-import com.clustercontrol.bean.YesNoConstant;
-import com.clustercontrol.commons.util.CommonValidator;
-import com.clustercontrol.custom.bean.CustomCheckInfo;
 import com.clustercontrol.http.bean.HttpCheckInfo;
+import com.clustercontrol.http.bean.HttpScenarioCheckInfo;
+import com.clustercontrol.http.bean.Page;
+import com.clustercontrol.http.bean.Variable;
+import com.clustercontrol.http.util.GetHttpResponse;
+import com.clustercontrol.jmx.bean.JmxCheckInfo;
 import com.clustercontrol.logfile.bean.LogfileCheckInfo;
-import com.clustercontrol.custom.bean.CustomConstant;
 import com.clustercontrol.monitor.run.bean.MonitorInfo;
 import com.clustercontrol.monitor.run.bean.MonitorStringValueInfo;
 import com.clustercontrol.monitor.run.bean.MonitorTypeConstant;
@@ -35,6 +41,9 @@ import com.clustercontrol.repository.util.FacilityTreeCache;
 import com.clustercontrol.snmp.bean.SnmpCheckInfo;
 import com.clustercontrol.snmptrap.bean.MonitorTrapConstant;
 import com.clustercontrol.snmptrap.bean.TrapCheckInfo;
+import com.clustercontrol.snmptrap.bean.TrapValueInfo;
+import com.clustercontrol.snmptrap.bean.VarBindPattern;
+import com.clustercontrol.snmptrap.model.MonitorTrapValueInfoEntityPK;
 import com.clustercontrol.sql.bean.SqlCheckInfo;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.winevent.bean.WinEventCheckInfo;
@@ -64,7 +73,11 @@ public class MonitorValidator {
 		}else if(monitorType == MonitorTypeConstant.TYPE_STRING){
 			validateMonitorStringSettings(monitorInfo);
 		}else if(monitorType == MonitorTypeConstant.TYPE_TRAP){
-			validateMonitorTrapSettings(monitorInfo);
+			// validateSnmptrap() で纏めて validate。
+		}else if(monitorType == MonitorTypeConstant.TYPE_SCENARIO){
+			// validateHttpScenario() で纏めて validate。
+		}else if(monitorType == MonitorTypeConstant.TYPE_SCENARIO){
+			// validateHttpScenario() で纏めて validate。
 		}else{
 			InvalidSetting e = new InvalidSetting("validateMonitorInfo() Invalid Monitor Type. monitorType = "
 					+ monitorInfo.getMonitorType());
@@ -77,18 +90,12 @@ public class MonitorValidator {
 		String monitorTypeId = monitorInfo.getMonitorTypeId();
 		if(HinemosModuleConstant.MONITOR_AGENT.equals(monitorTypeId)){
 			validateHinemosAgent(monitorInfo);
-		}else if(HinemosModuleConstant.MONITOR_HTTP.equals(monitorTypeId)){
-			if(monitorType == MonitorTypeConstant.TYPE_NUMERIC) {
-				validateHttpNumeric(monitorInfo);
-			} else if (monitorType == MonitorTypeConstant.TYPE_STRING){
-				validateHttp(monitorInfo);
-			}else{
-				InvalidSetting e = new InvalidSetting("This monitorTypeId = "
-						+ monitorTypeId + ", but unknown monitorType = " + monitorType);
-				m_log.info("validateMonitorInfo() : "
-						+ e.getClass().getSimpleName() + ", " + e.getMessage());
-				throw e;
-			}
+		}else if (HinemosModuleConstant.MONITOR_HTTP_N.equals(monitorTypeId)) {
+			validateHttpNumeric(monitorInfo);
+		}else if (HinemosModuleConstant.MONITOR_HTTP_S.equals(monitorTypeId)) {
+			validateHttp(monitorInfo);
+		}else if (HinemosModuleConstant.MONITOR_HTTP_SCENARIO.equals(monitorTypeId)) {
+			validateHttpScenario(monitorInfo);
 		}else if(HinemosModuleConstant.MONITOR_PERFORMANCE.equals(monitorTypeId)){
 			validatePerformance(monitorInfo);
 		}else if(HinemosModuleConstant.MONITOR_PING.equals(monitorTypeId)){
@@ -97,30 +104,14 @@ public class MonitorValidator {
 			validatePort(monitorInfo);
 		}else if(HinemosModuleConstant.MONITOR_PROCESS.equals(monitorTypeId)){
 			validateProcess(monitorInfo);
-		}else if(HinemosModuleConstant.MONITOR_SNMP.equals(monitorTypeId)){
-			if(monitorType == MonitorTypeConstant.TYPE_NUMERIC) {
-				validateSnmpNumeric(monitorInfo);
-			} else if (monitorType == MonitorTypeConstant.TYPE_STRING){
-				validateSnmp(monitorInfo);
-			}else{
-				InvalidSetting e = new InvalidSetting("This monitorTypeId = "
-						+ monitorTypeId + ", but unknown monitorType = " + monitorType);
-				m_log.info("validateMonitorInfo() : "
-						+ e.getClass().getSimpleName() + ", " + e.getMessage());
-				throw e;
-			}
-		}else if(HinemosModuleConstant.MONITOR_SQL.equals(monitorTypeId)){
-			if(monitorType == MonitorTypeConstant.TYPE_NUMERIC) {
-				validateSqlNumeric(monitorInfo);
-			} else if (monitorType == MonitorTypeConstant.TYPE_STRING){
-				validateSql(monitorInfo);
-			}else{
-				InvalidSetting e = new InvalidSetting("This monitorTypeId = "
-						+ monitorTypeId + ", but unknown monitorType = " + monitorType);
-				m_log.info("validateMonitorInfo() : "
-						+ e.getClass().getSimpleName() + ", " + e.getMessage());
-				throw e;
-			}
+		}else if (HinemosModuleConstant.MONITOR_SNMP_N.equals(monitorTypeId)){
+			validateSnmpNumeric(monitorInfo);
+		}else if (HinemosModuleConstant.MONITOR_SNMP_S.equals(monitorTypeId)) {
+			validateSnmp(monitorInfo);
+		}else if (HinemosModuleConstant.MONITOR_SQL_N.equals(monitorTypeId)) {
+			validateSqlNumeric(monitorInfo);
+		}else if (HinemosModuleConstant.MONITOR_SQL_S.equals(monitorTypeId)) {
+			validateSql(monitorInfo);
 		}else if(HinemosModuleConstant.MONITOR_SYSTEMLOG.equals(monitorTypeId)){
 			validateSystemlog(monitorInfo);
 		}else if(HinemosModuleConstant.MONITOR_LOGFILE.equals(monitorTypeId)){
@@ -133,10 +124,12 @@ public class MonitorValidator {
 			validateWinService(monitorInfo);
 		}else if(HinemosModuleConstant.MONITOR_WINEVENT.equals(monitorTypeId)){
 			validateWinEvent(monitorInfo);
+		}else if(HinemosModuleConstant.MONITOR_JMX.equals(monitorTypeId)){
+			validateJMX(monitorInfo);
 		}else {
-			
+
 			// クラウド管理オプションの専用肝機能追加のため、本例外処理をコメントアプトする
-			
+
 			/*
 			InvalidSetting e = new InvalidSetting("Invalid monitorTypeId. monitorTypeId = " + monitorInfo.getMonitorTypeId());
 			m_log.info("validateMonitorInfo() : "
@@ -180,7 +173,7 @@ public class MonitorValidator {
 
 		// monitorTypeId
 		// monitorType
-		
+
 		// クラウド管理オプションの専用肝機能追加のため、本例外処理をコメントアプトする
 		/*
 		boolean flag = true;
@@ -202,10 +195,10 @@ public class MonitorValidator {
 
 		// description : not implemented
 		CommonValidator.validateString(Messages.getString("description"),
-				monitorInfo.getDescription(), false, 1, 256);
-		
+				monitorInfo.getDescription(), false, 0, 256);
+
 		// ownerRoleId
-		CommonValidator.validateOwnerRoleId(monitorInfo.getOwnerRoleId(), true, 
+		CommonValidator.validateOwnerRoleId(monitorInfo.getOwnerRoleId(), true,
 				monitorInfo.getMonitorId(), HinemosModuleConstant.MONITOR);
 
 		// facilityId
@@ -267,14 +260,14 @@ public class MonitorValidator {
 		// monitorFlg : not implemented
 		// collectorFlg
 		if(monitorInfo.getCollectorFlg() == YesNoConstant.TYPE_YES){
-			if(monitorInfo.getMonitorType() != MonitorTypeConstant.TYPE_NUMERIC){
+			if(monitorInfo.getMonitorType() != MonitorTypeConstant.TYPE_NUMERIC && monitorInfo.getMonitorType() != MonitorTypeConstant.TYPE_SCENARIO){
 				InvalidSetting e = new InvalidSetting("CollectorFlg is true. but this monitorType is not numeric.");
 				m_log.info("validateMonitorCommonSettings() : "
 						+ e.getClass().getSimpleName() + ", " + e.getMessage());
 				throw e;
 			}
 		}
-		
+
 	}
 
 	/**
@@ -298,12 +291,13 @@ public class MonitorValidator {
 					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 			throw e;
 		}else{
+			int orderNo = 0;
 			for(MonitorStringValueInfo info : stringValueInfoList){
 
 				// monitorId : not implemented
 
-				// orderNo : not implemented
-
+				// orderNo
+				++orderNo;
 				// description : not implemented
 				String description = info.getDescription();
 				if (description != null) {
@@ -316,13 +310,13 @@ public class MonitorValidator {
 				// pattern
 				if(info.getPattern() == null ){
 					InvalidSetting e = new InvalidSetting("Pattern is not defined. monitorId = "
-							+ monitorInfo.getMonitorId() + ", orderNo = " + info.getOrderNo());
+							+ monitorInfo.getMonitorId() + ", orderNo = " + orderNo);
 					m_log.info("validateMonitorStringSettings() : "
 							+ e.getClass().getSimpleName() + ", " + e.getMessage());
 					throw e;
 				} else if ("".equals(info.getPattern()) && info.getProcessType() == ProcessConstant.TYPE_YES){
 					InvalidSetting e = new InvalidSetting("Pattern is empty string. monitorId = "
-							+ monitorInfo.getMonitorId() + ", orderNo = " + info.getOrderNo());
+							+ monitorInfo.getMonitorId() + ", orderNo = " + orderNo);
 					m_log.info("validateMonitorStringSettings() : "
 							+ e.getClass().getSimpleName() + ", " + e.getMessage());
 					throw e;
@@ -335,7 +329,7 @@ public class MonitorValidator {
 				}
 				catch(PatternSyntaxException e){
 					InvalidSetting e1 = new InvalidSetting("Pattern is not regular expression. monitorId = "
-							+ monitorInfo.getMonitorId() + ", orderNo = " + info.getOrderNo(), e);
+							+ monitorInfo.getMonitorId() + ", orderNo = " + orderNo, e);
 					m_log.info("validateMonitorStringSettings() : "
 							+ e1.getClass().getSimpleName() + ", " + e1.getMessage());
 					throw e1;
@@ -345,6 +339,8 @@ public class MonitorValidator {
 				// message
 				if(info.getProcessType() == ProcessConstant.TYPE_YES){
 					CommonValidator.validateString(Messages.getString("message"), info.getMessage(), true, 1, 256);
+				} else {
+					CommonValidator.validateString(Messages.getString("message"), info.getMessage(), false, 0, 256);
 				}
 
 				// caseSensitivityFlg : not implemented
@@ -367,13 +363,16 @@ public class MonitorValidator {
 					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 			throw e;
 		}
-		// itemName
+		boolean nullCheck = false;
 		if(monitorInfo.getCollectorFlg() == YesNoConstant.TYPE_YES){
-			CommonValidator.validateString(Messages.getString("collection.display.name"), monitorInfo.getItemName(), true, 1, 64);
-
-			// measure
-			CommonValidator.validateString(Messages.getString("collection.unit"), monitorInfo.getMeasure(), true, 1, 64);
+			nullCheck = true;
 		}
+		
+		// itemName
+		CommonValidator.validateString(Messages.getString("collection.display.name"), monitorInfo.getItemName(), nullCheck, 1, 256);
+
+		// measure
+		CommonValidator.validateString(Messages.getString("collection.unit"), monitorInfo.getMeasure(), nullCheck, 1, 64);
 	}
 
 	private static void validateNumeric(MonitorInfo monitorInfo, int timeout)
@@ -480,24 +479,6 @@ public class MonitorValidator {
 		m_log.debug("validateMonitorTruthSettings() is not implemented. ");
 	}
 
-
-
-	/**
-	 * TRAp用監視設定(MonitorInfo)の基本設定の妥当性チェック（関連テーブルへのリンク & NULL CHECK）
-	 * @param monitorInfo
-	 * @throws InvalidSetting
-	 */
-	private static void validateMonitorTrapSettings(MonitorInfo monitorInfo) throws InvalidSetting {
-		if(monitorInfo == null){
-			InvalidSetting e = new InvalidSetting("MonitorInfo is not defined.");
-			m_log.info("validateMonitorTrapSettings() : "
-					+ e.getClass().getSimpleName() + ", " + e.getMessage());
-			throw e;
-		}
-		m_log.debug("validateMonitorTrapSettings() monitorId = " + monitorInfo.getMonitorId());
-		m_log.debug("validateMonitorTrapSettings() is not implemented. ");
-	}
-
 	/**
 	 * Hinemosエージェント監視設定(MonitorInfo)の基本設定の妥当性チェック（関連テーブルへのリンク & NULL CHECK）
 	 * @param monitorInfo
@@ -565,7 +546,8 @@ public class MonitorValidator {
 		}
 
 		// monitorType
-		if(!HinemosModuleConstant.MONITOR_HTTP.equals(monitorInfo.getMonitorTypeId())){
+		if (!HinemosModuleConstant.MONITOR_HTTP_N.equals(monitorInfo.getMonitorTypeId())
+				&& !HinemosModuleConstant.MONITOR_HTTP_S.equals(monitorInfo.getMonitorTypeId())) {
 			InvalidSetting e = new InvalidSetting("This is HTTP Monitor Setting. But MonitorTypeId = " + monitorInfo.getMonitorTypeId());
 			m_log.info("validateHttp() : "
 					+ e.getClass().getSimpleName() + ", " + e.getMessage());
@@ -616,6 +598,179 @@ public class MonitorValidator {
 		// proxyPort : not implemented
 	}
 
+
+
+
+	private static void validateHttpScenario(MonitorInfo monitorInfo) throws InvalidSetting {
+		if(monitorInfo == null){
+			InvalidSetting e = new InvalidSetting("MonitorInfo is not defined.");
+			m_log.info("validateHttpScenario() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
+			throw e;
+		}
+		m_log.debug("validateHttp() monitorId = " + monitorInfo.getMonitorId());
+
+		// CheckInfo
+		HttpScenarioCheckInfo checkInfo = monitorInfo.getHttpScenarioCheckInfo();
+		if(checkInfo == null){
+			InvalidSetting e = new InvalidSetting("HTTP Scenario Monitor Setting is not defined. monitorId = "
+					+ monitorInfo.getMonitorId());
+			m_log.info("validateHttpScenario() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
+			throw e;
+		}
+
+		// monitorType
+		if (!HinemosModuleConstant.MONITOR_HTTP_SCENARIO.equals(monitorInfo.getMonitorTypeId())) {
+			InvalidSetting e = new InvalidSetting("This is HTTP Scenario Monitor Setting. But MonitorTypeId = " + monitorInfo.getMonitorTypeId());
+			m_log.info("validateHttpScenario() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
+			throw e;
+		}
+
+		// monitorType
+		if (checkInfo.getAuthType() != null) {
+			boolean match = false;
+			for (GetHttpResponse.AuthType at: GetHttpResponse.AuthType.values()) {
+				if (at.name().equals(checkInfo.getAuthType())) {
+					match = true;
+					break;
+				}
+			}
+			if (!match) {
+				InvalidSetting e = new InvalidSetting("This is HTTP Scenario Monitor Setting. But AuthType = " + checkInfo.getAuthType());
+				m_log.info("validateHttpScenario() : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage());
+				throw e;
+			}
+		}
+
+		if (checkInfo.getAuthUser() != null) {
+			CommonValidator.validateString(Messages.getString("monitor.http.scenario.authuser"), checkInfo.getAuthUser(), false, 0, 64);
+		}
+		if (checkInfo.getAuthPassword() != null) {
+			CommonValidator.validateString(Messages.getString("monitor.http.scenario.authpassword"), checkInfo.getAuthPassword(), false, 0, 64);
+		}
+		if (checkInfo.getProxyFlg()) {
+			if ("".equals(checkInfo.getProxyUrl())){
+				InvalidSetting e = new InvalidSetting(Messages.getString("message.http.1"));
+				m_log.info("validateHttpScenario() : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage());
+				throw e;
+			}
+			else {
+				String url = checkInfo.getProxyUrl();
+				// format check
+				if (url.length() > 0 && (!url.startsWith("http://") && !url.startsWith("https://"))) {
+					InvalidSetting e = new InvalidSetting(Messages.getString("monitor.http.scenario.proxyurl"));
+					m_log.info("validateHttpScenario() : "
+							+ e.getClass().getSimpleName() + ", " + e.getMessage());
+					throw e;
+				}
+				else if((url.startsWith("http://") && url.length() == 7) || (url.startsWith("https://") && url.length() == 8)){
+					InvalidSetting e = new InvalidSetting(Messages.getString("monitor.http.scenario.proxyurl"));
+					m_log.info("validateHttpScenario() : "
+							+ e.getClass().getSimpleName() + ", " + e.getMessage());
+					throw e;
+				}
+			}
+			CommonValidator.validateString(Messages.getString("monitor.http.scenario.proxyurl"), checkInfo.getProxyUrl(), false, 0, 1024);
+			if (checkInfo.getProxyPort() != null) {
+				CommonValidator.validateInt(Messages.getString("monitor.http.scenario.proxyport"), checkInfo.getProxyPort(), 0, 65535);
+			} else {
+				InvalidSetting e = new InvalidSetting(Messages.getString("monitor.http.scenario.proxyport"));
+				m_log.info("validateHttpScenario() : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage());
+				throw e;
+			}
+		}
+		if (checkInfo.getProxyUser() != null) {
+			CommonValidator.validateString(Messages.getString("monitor.http.scenario.proxyuser"), checkInfo.getProxyUser(), false, 0, 64);
+		}
+		if (checkInfo.getProxyPassword() != null) {
+			CommonValidator.validateString(Messages.getString("monitor.http.scenario.proxypassword"), checkInfo.getProxyPassword(), false, 0, 64);
+		}
+		
+		// checkInfo.getMonitoringPerPageFlg();
+		if (checkInfo.getUserAgent() != null) {
+			CommonValidator.validateString(Messages.getString("monitor.http.scenario.userAgent"), checkInfo.getUserAgent(), false, 0, 1024);
+		}
+		// checkInfo.getCancelProxyCacheFlg();
+		if (checkInfo.getConnectTimeout() == null) {
+			InvalidSetting e = new InvalidSetting(Messages.getString("monitor.http.scenario.connecttimeout"));
+			m_log.info("validateHttpScenario() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
+			throw e;
+		}
+		if (checkInfo.getConnectTimeout() != null) {
+			CommonValidator.validateInt(Messages.getString("monitor.http.scenario.connecttimeout"), checkInfo.getConnectTimeout(), 0, 60 * 60 * 1000);
+		}
+		if (checkInfo.getRequestTimeout() != null) {
+			CommonValidator.validateInt(Messages.getString("monitor.http.scenario.requesttimeout"), checkInfo.getRequestTimeout(), 0, 60 * 60 * 1000);
+		}
+
+		if (checkInfo.getPages().isEmpty()) {
+			InvalidSetting e = new InvalidSetting(Messages.getString("message.http.scenario.must.specify.more.than.one.pattern"));
+			m_log.info("validateHttpScenario() : " + e.getClass().getSimpleName() + ", " + e.getMessage());
+			throw e;
+		}
+		else {
+			for (Page p: checkInfo.getPages()) {
+				if (p.getUrl() == null && "".equals(p.getUrl())){
+					InvalidSetting e = new InvalidSetting(Messages.getString("monitor.http.scenario.page.url"));
+					m_log.info("validateHttpScenario() : "
+							+ e.getClass().getSimpleName() + ", " + e.getMessage());
+					throw e;
+				}
+				else {
+					String url = p.getUrl();
+					// format check
+					if (url.length() > 0 && (!url.startsWith("http://") && !url.startsWith("https://"))) {
+						InvalidSetting e = new InvalidSetting(Messages.getString("monitor.http.scenario.page.url"));
+						m_log.info("validateHttpScenario() : "
+								+ e.getClass().getSimpleName() + ", " + e.getMessage());
+						throw e;
+					}
+					else if((url.startsWith("http://") && url.length() == 7) || (url.startsWith("https://") && url.length() == 8)){
+						InvalidSetting e = new InvalidSetting(Messages.getString("monitor.http.scenario.page.url"));
+						m_log.info("validateHttpScenario() : "
+								+ e.getClass().getSimpleName() + ", " + e.getMessage());
+						throw e;
+					}
+				}
+				CommonValidator.validateString(Messages.getString("monitor.http.scenario.page.url"), p.getUrl(), false, 0, 1024);
+				CommonValidator.validateString(Messages.getString("monitor.http.scenario.page.description"), p.getDescription(), false, 0, 1024);
+				if (p.getStatusCode() != null) {
+					if (!Pattern.matches("^(\\s*\\d+,)*\\s*\\d+\\s*$", p.getStatusCode())) {
+						InvalidSetting e = new InvalidSetting(Messages.getString("monitor.http.scenario.page.statuscode"));
+						m_log.info("validateHttpScenario() : "
+								+ e.getClass().getSimpleName() + ", " + e.getMessage());
+						throw e;
+					}
+				}
+				CommonValidator.validateString(Messages.getString("monitor.http.scenario.pape.post"), p.getPost(), false, 0, 1024);
+
+				for (com.clustercontrol.http.bean.Pattern pt: p.getPatterns()) {
+					CommonValidator.validateString(Messages.getString("monitor.http.scenario.pattern.pattern"), pt.getPattern(), false, 0, 1024);
+					CommonValidator.validateString(Messages.getString("monitor.http.scenario.pattern.description"), pt.getDescription(), false, 0, 256);
+					// processType : not implemented pt.getProcessType();
+					// pt.getCaseSensitivityFlg();
+					// pt.getValidFlg();
+				}
+
+				for (Variable v: p.getVariables()) {
+					CommonValidator.validateString(Messages.getString("monitor.http.scenario.variable.name"), v.getName(), true, 0, 1024);
+					CommonValidator.validateString(Messages.getString("monitor.http.scenario.variable.value"), v.getValue(), true, 0, 1024);
+					// v.getMatchingWithResponseFlg();
+				}
+			}
+		}
+	}
+
+
+
+
+
 	/**
 	 * ログファイル監視設定(MonitorInfo)の基本設定の妥当性チェック（関連テーブルへのリンク & NULL CHECK）
 	 * @param monitorInfo
@@ -661,8 +816,25 @@ public class MonitorValidator {
 					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 			throw e;
 		}
+		//FileEncoding
+		if(checkInfo.getFileEncoding() == null || "".equals(checkInfo.getFileEncoding())){
+			InvalidSetting e = new InvalidSetting(Messages.getString("message.logfile.4"));
+			m_log.info("validateLogfile() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
+			throw e;
+		}
+		//FileReturnCode
+		if(checkInfo.getFileReturnCode() == null || "".equals(checkInfo.getFileReturnCode())){
+			InvalidSetting e = new InvalidSetting(Messages.getString("message.logfile.5"));
+			m_log.info("validateLogfile() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
+			throw e;
+		}
+
 		CommonValidator.validateString(Messages.getString("directory"), checkInfo.getDirectory(), true, 1, 1024);
 		CommonValidator.validateString(Messages.getString("file.name"), checkInfo.getFileName(), true, 1, 1024);
+		CommonValidator.validateString(Messages.getString("file.encoding"), checkInfo.getFileEncoding(), true, 1, 32);
+		CommonValidator.validateString(Messages.getString("file.returncode"), checkInfo.getFileEncoding(), true, 1, 16);
 	}
 
 	/**
@@ -754,9 +926,25 @@ public class MonitorValidator {
 			throw e;
 		}
 
-		// runCount : not implemented
+		// runCount : implement
+		if(checkInfo.getRunCount() == null) {
+			InvalidSetting e = new InvalidSetting(Messages.getString("message.monitor.custom.msg.runcount.undef"));
+			m_log.info("validatePing() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
+			throw e;
+		}
+		CommonValidator.validateInt(Messages.getString("run.count"),
+				checkInfo.getRunCount(), 1, 9);
 
-		// runInterval : not implemented
+		// runInterval : implement
+		if(checkInfo.getRunInterval() == null) {
+			InvalidSetting e = new InvalidSetting(Messages.getString("message.monitor.custom.msg.runinterval.undef"));
+			m_log.info("validatePing() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
+			throw e;
+		}
+		CommonValidator.validateInt(Messages.getString("run.interval"),
+				checkInfo.getRunInterval(), 0, 5  * 1000);
 
 		// timeout
 		if(checkInfo.getTimeout() == null) {
@@ -834,7 +1022,15 @@ public class MonitorValidator {
 		}
 		CommonValidator.validateInt(Messages.getString("port.number"), checkInfo.getPortNo(), 1, 65535);
 
-		// runCount : not implemented
+		// runCount : implement
+		if(checkInfo.getRunCount() == null) {
+			InvalidSetting e = new InvalidSetting(Messages.getString("message.port.1"));
+			m_log.info("validatePing() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
+			throw e;
+		}
+		CommonValidator.validateInt(Messages.getString("run.count"),
+				checkInfo.getRunCount(), 1, 9);
 
 		// runInterval : not implemented
 		if(checkInfo.getRunInterval() == null) {
@@ -843,6 +1039,8 @@ public class MonitorValidator {
 					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 			throw e;
 		}
+		CommonValidator.validateInt(Messages.getString("run.interval"),
+				checkInfo.getRunInterval(), 0, 5  * 1000);
 
 		// timeout
 		if(checkInfo.getTimeout() == null) {
@@ -978,12 +1176,15 @@ public class MonitorValidator {
 
 		// monitorType
 		if(!HinemosModuleConstant.MONITOR_SNMPTRAP.equals(monitorInfo.getMonitorTypeId())){
-			InvalidSetting e = new InvalidSetting("This is SNMP Monitor Setting. But MonitorTypeId = " + monitorInfo.getMonitorTypeId());
+			InvalidSetting e = new InvalidSetting("This is SNMP Trap Monitor Setting. But MonitorTypeId = " + monitorInfo.getMonitorTypeId());
 			m_log.info("validateSnmptrap() : "
 					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 			throw e;
 		}
 
+		CommonValidator.validateString(Messages.getString("community.name"),
+				checkInfo.getCommunityName(), false, 0, 64);
+
 		// communityName
 		if(checkInfo.getCommunityCheck() == MonitorTrapConstant.COMMUNITY_CHECK_ON){
 			if(checkInfo.getCommunityName() == null || "".equals(checkInfo.getCommunityName())){
@@ -992,15 +1193,8 @@ public class MonitorValidator {
 						+ e.getClass().getSimpleName() + ", " + e.getMessage());
 				throw e;
 			}
-			CommonValidator.validateString(Messages.getString("community.name"),
-					checkInfo.getCommunityName(), true, 1, 64);
 		}
 
-		// checkMode : not implemented
-
-		// communityCheck : not implemented
-
-		// charsetConvert : not implemented
 		CommonValidator.validateString(Messages.getString("charset.snmptrap.code"), checkInfo.getCharsetName(),
 				false, 1, 64);
 
@@ -1013,8 +1207,79 @@ public class MonitorValidator {
 				throw e;
 			}
 		}
+
+		// PriorityUnspecified : not implemented
+
+		ArrayList<MonitorTrapValueInfoEntityPK> pkList = new ArrayList<MonitorTrapValueInfoEntityPK>();
+		for (TrapValueInfo v: checkInfo.getTrapValueInfos()) {
+			CommonValidator.validateString(Messages.getString("monitor.snmptrap.value.mib"), v.getMib(), true, 1, 1024);
+			CommonValidator.validateString(Messages.getString("trap.name"), v.getUei(), true, 1, 256);
+			CommonValidator.validateString(Messages.getString("trap.oid"), v.getTrapOid(), true, 1, 1024);
+			
+			//.と[0-9]以外はNG
+			char c = 'a';
+			for (int i = 0; i < v.getTrapOid().length(); i++) {
+				c = v.getTrapOid().charAt(i);
+				if (c != '.' && !('0' <= c && c <= '9')) {
+					InvalidSetting e = new InvalidSetting(Messages.getString("message.snmptrap.trapoid.invalid", new String[]{v.getTrapOid()}));
+					m_log.info("validateSnmptrap() : "
+							+ e.getClass().getSimpleName() + ", " + e.getMessage());
+					throw e;
+				}
+			}
+			
+			// GenericId
+			// SpecificId
+			// トラップ定義の重複チェック
+			MonitorTrapValueInfoEntityPK entityPk = new MonitorTrapValueInfoEntityPK(
+					checkInfo.getMonitorId(), 
+					v.getMib(),
+					v.getTrapOid(), 
+					v.getGenericId(),
+					v.getSpecificId());
+			if (pkList.contains(entityPk)) {
+				String arg;
+				if (v.getVersion() == SnmpVersionConstant.TYPE_V1) {
+					arg = new String("MIB="+v.getMib()+",OID="+v.getTrapOid()+",generic_id="+v.getGenericId()+",specific_id="+v.getSpecificId());
+				} else {
+					arg = new String("MIB="+v.getMib()+",OID="+v.getTrapOid());
+				}
+				InvalidSetting e = new InvalidSetting(Messages.getString("message.snmptrap.trapoid.overlaps", new String[]{arg}));
+				m_log.info("validateSnmptrap() : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage());
+				throw e;
+			}
+			pkList.add(entityPk);
+
+
+			// Logmsg : not implemented
+			// Description : not implemented
+
+			switch (v.getProcessingVarbindType()) {
+			case MonitorTrapConstant.PROC_VARBIND_SPECIFIED:
+				if (v.getVarBindPatterns().isEmpty()) {
+					InvalidSetting e = new InvalidSetting(Messages.getString("message.snmptrap.value.must.specify.more.than.one.pattern"));
+					m_log.info("validateSnmptrap() : " + e.getClass().getSimpleName() + ", " + e.getMessage());
+					throw e;
+				}
+				break;
+			case MonitorTrapConstant.PROC_VARBIND_ANY:
+				break;
+			}
+			CommonValidator.validateString(Messages.getString("monitor.snmptrap.value.varbindpattern"), v.getFormatVarBinds(), false, 0, 128);
+
+			for (VarBindPattern p: v.getVarBindPatterns()) {
+				CommonValidator.validateString(Messages.getString("pattern.matching.expression"), p.getPattern(), false, 0, 1024);
+				CommonValidator.validateString(Messages.getString("monitor.snmptrap.value.pattern.description"), p.getDescription(), false, 0, 256);
+				// processType : not implemented
+				// caseSensitivityFlg : not implemented
+				// validFlg : not implemented
+				// priority : not implemented
+			}
+		}
 	}
 
+
 	/**
 	 * SNMP監視設定(MonitorInfo)の基本設定の妥当性チェック（関連テーブルへのリンク & NULL CHECK）
 	 * @param monitorInfo
@@ -1050,7 +1315,8 @@ public class MonitorValidator {
 		}
 
 		// monitorType
-		if(!HinemosModuleConstant.MONITOR_SNMP.equals(monitorInfo.getMonitorTypeId())){
+		if (!HinemosModuleConstant.MONITOR_SNMP_N.equals(monitorInfo.getMonitorTypeId())
+				&& !HinemosModuleConstant.MONITOR_SNMP_S.equals(monitorInfo.getMonitorTypeId())) {
 			InvalidSetting e = new InvalidSetting("This is SNMP Monitor Setting. But MonitorTypeId = " + monitorInfo.getMonitorTypeId());
 			m_log.info("validateSnmp() : "
 					+ e.getClass().getSimpleName() + ", " + e.getMessage());
@@ -1129,7 +1395,8 @@ public class MonitorValidator {
 		}
 
 		// monitorType
-		if(!HinemosModuleConstant.MONITOR_SQL.equals(monitorInfo.getMonitorTypeId())){
+		if (!HinemosModuleConstant.MONITOR_SQL_N.equals(monitorInfo.getMonitorTypeId())
+				&& !HinemosModuleConstant.MONITOR_SQL_S.equals(monitorInfo.getMonitorTypeId())) {
 			InvalidSetting e = new InvalidSetting("This is SQL Monitor Setting. But MonitorTypeId = "
 					+ monitorInfo.getMonitorTypeId());
 			m_log.info("validateSql() : "
@@ -1417,7 +1684,7 @@ public class MonitorValidator {
 					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 			throw e;
 		}
-		
+
 		////
 		// Length Check
 		////
@@ -1426,26 +1693,71 @@ public class MonitorValidator {
 		for(String logName : checkInfo.getLogName()){
 			CommonValidator.validateString(Messages.getString("winevent.log") + ":" + logName,logName, true, 1, 256);
 		}
-		
+
 		//source : character varying(256)（winevent.source）
 		for(String source : checkInfo.getSource()){
 			CommonValidator.validateString(Messages.getString("winevent.source") + ":" + source,source, true, 1, 256);
 		}
-		
+
 		//eventId : smallint(winevent.id)
 		for(Integer eventId : checkInfo.getEventId()){
 			CommonValidator.validateInt(Messages.getString("winevent.id") + ":" + eventId, eventId, 0, 32767);
 		}
-		
+
 		//category : smallint（winevent.category）
 		for(Integer category : checkInfo.getCategory()){
 			CommonValidator.validateInt(Messages.getString("winevent.category") + ":" + category, category, 0, 32767);
 		}
-		
+
 		//keywaord : bigint(winevent.keywords)
 		for(Long keyword : checkInfo.getKeywords()){
 			CommonValidator.validateDouble(Messages.getString("winevent.keywords") + ":" + keyword, keyword, 0, Long.MAX_VALUE);
 		}
 
 	}
+
+	/**
+	 * Windowsサービス監視設定(MonitorInfo)の基本設定の妥当性チェック（関連テーブルへのリンク & NULL CHECK）
+	 * @param monitorInfo
+	 * @throws InvalidSetting
+	 */
+	private static void validateJMX(MonitorInfo monitorInfo) throws InvalidSetting {
+		if(monitorInfo == null){
+			InvalidSetting e = new InvalidSetting("MonitorInfo is not defined.");
+			m_log.info("validateJMX() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
+			throw e;
+		}
+		m_log.debug("validateJMX() monitorId = " + monitorInfo.getMonitorId());
+
+		// CheckInfo
+		JmxCheckInfo checkInfo = monitorInfo.getJmxCheckInfo();
+		if(checkInfo == null){
+			InvalidSetting e = new InvalidSetting("JMX Monitor Setting is not defined. monitorId = "
+					+ monitorInfo.getMonitorId());
+			m_log.info("validateJMX() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
+			throw e;
+		}
+
+		// monitorType
+		if(!HinemosModuleConstant.MONITOR_JMX.equals(monitorInfo.getMonitorTypeId())){
+			InvalidSetting e = new InvalidSetting("This is JMX Monitor Setting. But MonitorTypeId = "
+					+ monitorInfo.getMonitorTypeId());
+			m_log.info("validateJMX() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
+			throw e;
+		}
+
+		if (checkInfo.getAuthPassword() != null) {
+			CommonValidator.validateString(Messages.getString("monitor.jmx.authpassword"), checkInfo.getAuthPassword(), false, 0, 64);
+		}
+
+		if (checkInfo.getPort() == null) {
+			InvalidSetting e = new InvalidSetting("JMX Monitor Setting must hava a destination port. monitorId = " + monitorInfo.getMonitorId());
+			m_log.info("validateJMX() : " + e.getClass().getSimpleName() + ", " + e.getMessage());
+			throw e;
+		}
+		CommonValidator.validateInt(Messages.getString("monitor.jmx.port"), checkInfo.getPort(), 0, 65535);
+	}
 }
