@@ -15,12 +15,10 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.monitor.view;
 
-import org.eclipse.jface.action.ActionContributionItem;
-import org.eclipse.jface.action.IMenuListener;
-import org.eclipse.jface.action.IMenuManager;
-import org.eclipse.jface.action.IToolBarManager;
+import java.util.ArrayList;
+import java.util.List;
+
 import org.eclipse.jface.action.MenuManager;
-import org.eclipse.jface.action.Separator;
 import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.swt.SWT;
@@ -28,8 +26,14 @@ import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Menu;
+import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.commands.ICommandService;
 
 import com.clustercontrol.ClusterControlPlugin;
+import com.clustercontrol.repository.bean.FacilityConstant;
+import com.clustercontrol.repository.util.ScopePropertyUtil;
+import com.clustercontrol.util.EndpointManager;
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.monitor.bean.ConfirmConstant;
 import com.clustercontrol.monitor.composite.EventListComposite;
@@ -37,23 +41,24 @@ import com.clustercontrol.monitor.composite.action.EventListSelectionChangedList
 import com.clustercontrol.monitor.preference.MonitorPreferencePage;
 import com.clustercontrol.monitor.view.action.EventConfirmAction;
 import com.clustercontrol.monitor.view.action.EventDetailAction;
+import com.clustercontrol.monitor.view.action.EventModifyMonitorSettingAction;
+import com.clustercontrol.monitor.view.action.EventOpenJobHistoryAction;
 import com.clustercontrol.monitor.view.action.EventUnconfirmAction;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.view.ScopeListBaseView;
+import com.clustercontrol.ws.repository.FacilityInfo;
 import com.clustercontrol.ws.repository.FacilityTreeItem;
 
-
-
 /**
  * 監視[イベント]ビュークラス<BR>
- * 
- * @version 1.0.0
+ *
+ * @version 5.0.0
  * @since 1.0.0
  */
 public class EventView extends ScopeListBaseView {
 
 	/** 監視[イベント]ビューID */
-	public static final String ID = "com.clustercontrol.monitor.view.EventView";
+	public static final String ID = EventView.class.getName();
 
 	/** イベント情報一覧コンポジット */
 	private EventListComposite tableComposite = null;
@@ -61,6 +66,11 @@ public class EventView extends ScopeListBaseView {
 	/** 検索条件 */
 	private Property condition = null;
 
+	/** 確認/未確認の種別 */
+	private int confirmType = ConfirmConstant.TYPE_UNCONFIRMED;
+
+	/** プラグインID */
+	private String pluginId;
 
 	/**
 	 * イベント情報一覧テーブルを作成・追加します。
@@ -73,10 +83,10 @@ public class EventView extends ScopeListBaseView {
 	 * <li>プレファレンスページの設定より、監視[イベント]ビューの自動更新フラグを取得し、このビューにセットします。</li>
 	 * <li>イベント情報一覧テーブルを返します。</li>
 	 * </ol>
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @return イベント情報一覧テーブルコンポジット
-	 * 
+	 *
 	 * @see com.clustercontrol.monitor.composite.EventListComposite#EventListComposite(Composite, int)
 	 * @see #createContextMenu()
 	 * @see #update()
@@ -89,6 +99,7 @@ public class EventView extends ScopeListBaseView {
 		layout.marginWidth = 0;
 
 		this.tableComposite = new EventListComposite(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, tableComposite);
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -100,11 +111,9 @@ public class EventView extends ScopeListBaseView {
 		createContextMenu();
 
 		// 設定情報反映
-		IPreferenceStore store = ClusterControlPlugin.getDefault()
-				.getPreferenceStore();
+		IPreferenceStore store = ClusterControlPlugin.getDefault().getPreferenceStore();
 
-		this.setInterval(store
-				.getInt(MonitorPreferencePage.P_EVENT_UPDATE_CYCLE));
+		this.setInterval(store.getInt(MonitorPreferencePage.P_EVENT_UPDATE_CYCLE));
 
 		if (store.getBoolean(MonitorPreferencePage.P_EVENT_UPDATE_FLG)) {
 			this.startAutoReload();
@@ -118,9 +127,9 @@ public class EventView extends ScopeListBaseView {
 
 	/**
 	 * スコープツリーでアイテムを選択した際に呼ばれ、ビューを更新します。
-	 * 
+	 *
 	 * @param item スコープツリーアイテム
-	 * 
+	 *
 	 * @see #update()
 	 */
 	@Override
@@ -134,44 +143,11 @@ public class EventView extends ScopeListBaseView {
 	private void createContextMenu() {
 		MenuManager menuManager = new MenuManager();
 		menuManager.setRemoveAllWhenShown(true);
-		menuManager.addMenuListener(new IMenuListener() {
-			/*
-			 * (non-Javadoc)
-			 * 
-			 * @see org.eclipse.jface.action.IMenuListener#menuAboutToShow(org.eclipse.jface.action.IMenuManager)
-			 */
-			@Override
-			public void menuAboutToShow(IMenuManager manager) {
-				//メニュー項目設定
-				fillContextMenu(manager);
-			}
-		});
 
 		Menu menu = menuManager.createContextMenu(tableComposite.getTable());
+		WidgetTestUtil.setTestId(this, null, menu);
 		tableComposite.getTable().setMenu(menu);
-	}
-
-	/**
-	 * ポップアップメニューに項目を追加します。
-	 * 
-	 * @param manager ポップアップメニューオブジェクト
-	 */
-	private void fillContextMenu(IMenuManager manager) {
-		//ビューのアクションのインスタンスを取得
-		IToolBarManager toolbar = this.getViewSite().getActionBars()
-				.getToolBarManager();
-		ActionContributionItem confirmAction = (ActionContributionItem) toolbar
-				.find(EventConfirmAction.ID);
-		ActionContributionItem unconfirmAction = (ActionContributionItem) toolbar
-				.find(EventUnconfirmAction.ID);
-		ActionContributionItem detailAction = (ActionContributionItem) toolbar
-				.find(EventDetailAction.ID);
-
-		//ポップアップメニューにアクションを追加
-		manager.add(detailAction.getAction());
-		manager.add(new Separator());
-		manager.add(confirmAction.getAction());
-		manager.add(unconfirmAction.getAction());
+		getSite().registerContextMenu( menuManager, this.tableComposite.getTableViewer() );
 	}
 
 	/**
@@ -183,7 +159,7 @@ public class EventView extends ScopeListBaseView {
 	 * <li>ファシリティIDをキーに、イベント情報を更新します。
 	 *     検索条件が<code>null</code>ではない場合は、検索条件も指定します。</li>
 	 * </ol>
-	 * 
+	 *
 	 * @see com.clustercontrol.composite.FacilityTreeComposite#getSelectItem()
 	 * @see com.clustercontrol.bean.FacilityInfo#getFacilityId()
 	 * @see com.clustercontrol.monitor.composite.EventListComposite#update(String)
@@ -191,11 +167,33 @@ public class EventView extends ScopeListBaseView {
 	 */
 	@Override
 	public void update() {
-
-		FacilityTreeItem item = this.getScopeTreeComposite().getSelectItem();
+		FacilityTreeItem item = getScopeTreeComposite().getSelectItem();
 		String facilityId = null;
-		if (item != null) {
-			facilityId = item.getData().getFacilityId();
+		List<String> managerList = new ArrayList<String>();
+		int type = 0;
+
+		// Select root if nothing selected
+		if( item == null && 0 < getScopeTreeComposite().getTree().getItemCount() ){
+			item = (FacilityTreeItem) getScopeTreeComposite().getTree().getItem(0).getData();
+		}
+
+		if( item != null ){
+			FacilityInfo itemData = item.getData();
+
+			if(itemData.getFacilityType() == FacilityConstant.TYPE_COMPOSITE){
+				type = FacilityConstant.TYPE_COMPOSITE;
+				managerList = EndpointManager.getActiveManagerNameList();
+			} else if(itemData.getFacilityType() == FacilityConstant.TYPE_MANAGER) {
+				String managerName = itemData.getFacilityId();
+				type = FacilityConstant.TYPE_MANAGER;
+				managerList.add(managerName);
+			} else {
+				type = FacilityConstant.TYPE_SCOPE;
+				facilityId = item.getData().getFacilityId();
+				FacilityTreeItem manager = ScopePropertyUtil.getManager(item);
+				String managerName = manager.getData().getFacilityId();
+				managerList.add(managerName);
+			}
 		}
 
 		if (this.condition == null) {
@@ -205,18 +203,27 @@ public class EventView extends ScopeListBaseView {
 				.setText(Messages.getString("scope") + " : ");
 				this.getPathLabel().pack();
 			}
-			this.tableComposite.update(facilityId);
+			if(type == FacilityConstant.TYPE_COMPOSITE){
+				//スコープが選択された
+				this.tableComposite.update(null, null, managerList);
+			} else if (type == FacilityConstant.TYPE_MANAGER) {
+				//マネージャが選択された
+				this.tableComposite.update(null, null, managerList);
+			} else {
+				//それ以外
+				this.tableComposite.update(facilityId, null, managerList);
+			}
 		} else {
 			this.getPathLabel().setText(Messages.getString("filtered.list"));
 			this.getPathLabel().pack();
-			this.tableComposite.update(facilityId, this.condition);
+			this.tableComposite.update(facilityId, this.condition, managerList);
 		}
 	}
 
 	/**
 	 * 検索条件を設定します。
 	 * <p>設定後の<code>update</code>は、この検索条件の結果が表示されます。
-	 * 
+	 *
 	 * @param condition 検索条件
 	 */
 	public void setCondition(Property condition) {
@@ -233,53 +240,45 @@ public class EventView extends ScopeListBaseView {
 		this.setCondition(null);
 	}
 
-	/**
-	 * ビューのアクションの有効/無効を設定します。
-	 * 
-	 * @param eventNum 表示イベント数
-	 * @param selection ボタン（アクション）を有効にするための情報
-	 * 
-	 * @see com.clustercontrol.bean.FacilityConstant
-	 */
-	public void setEnabledAction(int eventNum) {
-		//ビューアクションの使用可/不可を設定
-		//表示イベントが一つも存在しない場合
-		if (eventNum == 0) {
-			super.setEnabledAction(EventConfirmAction.ID, false);
-			super.setEnabledAction(EventUnconfirmAction.ID, false);
-			super.setEnabledAction(EventDetailAction.ID, false);
+	public void initButton(){
+		setEnabledAction(ConfirmConstant.TYPE_ALL, null, null);
+	}
 
-		}
+	public int getConfirmType() {
+		return this.confirmType;
+	}
+
+	public String getPluginId() {
+		return this.pluginId;
 	}
 
 	/**
 	 * ビューのアクションの有効/無効を設定します。
-	 * 
+	 *
 	 * @param confirmType 確認/未確認の種別
+	 * @param pluginId プラグインID
 	 * @param selection ボタン（アクション）を有効にするための情報
-	 * 
+	 *
 	 * @see com.clustercontrol.bean.FacilityConstant
 	 */
-	public void setEnabledAction(int confirmType, ISelection selection) {
-
-		super.setEnabledAction(EventConfirmAction.ID, selection);
-		super.setEnabledAction(EventUnconfirmAction.ID, selection);
-		super.setEnabledAction(EventDetailAction.ID, selection);
+	public void setEnabledAction(int confirmType, String pluginId, ISelection selection) {
+		this.confirmType = confirmType;
+		this.pluginId = pluginId;
 
 		//ビューアクションの使用可/不可を設定
-		if (confirmType == ConfirmConstant.TYPE_CONFIRMED) {
-			super.setEnabledAction(EventConfirmAction.ID, false);
-			super.setEnabledAction(EventUnconfirmAction.ID, true);
+		ICommandService service = (ICommandService) PlatformUI.getWorkbench().getService( ICommandService.class );
+		if( null != service ){
+			service.refreshElements(EventConfirmAction.ID, null);
+			service.refreshElements(EventUnconfirmAction.ID, null);
+			service.refreshElements(EventDetailAction.ID, null);
+			service.refreshElements(EventModifyMonitorSettingAction.ID, null);
+			service.refreshElements(EventOpenJobHistoryAction.ID, null);
 
-		} else if (confirmType == ConfirmConstant.TYPE_UNCONFIRMED) {
-			super.setEnabledAction(EventConfirmAction.ID, true);
-			super.setEnabledAction(EventUnconfirmAction.ID, false);
-
-			//両方含まれている場合
-		} else {
-			super.setEnabledAction(EventConfirmAction.ID, true);
-			super.setEnabledAction(EventUnconfirmAction.ID, true);
+			// Update ToolBar after elements refreshed
+			// WARN : Both ToolBarManager must be updated after updateActionBars(), otherwise icon won't change.
+			getViewSite().getActionBars().updateActionBars();
+			getViewSite().getActionBars().getToolBarManager().update(false);
 
 		}
 	}
-}
\ No newline at end of file
+}
