@@ -19,15 +19,14 @@ import java.util.Collections;
 import java.util.List;
 
 import javax.persistence.EntityExistsException;
-import javax.persistence.EntityManager;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-
 import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.ObjectPrivilegeMode;
 import com.clustercontrol.accesscontrol.util.ObjectPrivilegeUtil;
 import com.clustercontrol.bean.HinemosModuleConstant;
+import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.commons.util.HinemosSessionContext;
 import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.fault.BgFileNotFound;
@@ -38,6 +37,11 @@ import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.NodeMapNotFound;
 import com.clustercontrol.fault.ObjectPrivilege_InvalidRole;
 import com.clustercontrol.nodemap.NodeMapException;
+import com.clustercontrol.nodemap.bean.Association;
+import com.clustercontrol.nodemap.bean.FacilityElement;
+import com.clustercontrol.nodemap.bean.NodeElement;
+import com.clustercontrol.nodemap.bean.NodeMapModel;
+import com.clustercontrol.nodemap.bean.ScopeElement;
 import com.clustercontrol.nodemap.model.MapAssociationEntity;
 import com.clustercontrol.nodemap.model.MapAssociationEntityPK;
 import com.clustercontrol.nodemap.model.MapBgImageEntity;
@@ -48,12 +52,7 @@ import com.clustercontrol.nodemap.model.MapPositionEntityPK;
 import com.clustercontrol.nodemap.util.QueryUtil;
 import com.clustercontrol.nodemap.util.SearchConnectionExecutor;
 import com.clustercontrol.nodemap.util.SearchConnectionProperties;
-import com.clustercontrol.nodemap.bean.Association;
-import com.clustercontrol.nodemap.bean.FacilityElement;
-import com.clustercontrol.nodemap.bean.NodeMapModel;
-import com.clustercontrol.nodemap.bean.NodeElement;
-import com.clustercontrol.nodemap.bean.ScopeElement;
-import com.clustercontrol.poller.impl.SnmpPollerImpl;
+import com.clustercontrol.poller.impl.Snmp4jPollerImpl;
 import com.clustercontrol.repository.bean.FacilityConstant;
 import com.clustercontrol.repository.bean.FacilityInfo;
 import com.clustercontrol.repository.bean.FacilityTreeAttributeConstant;
@@ -63,6 +62,7 @@ import com.clustercontrol.repository.model.NodeEntity;
 import com.clustercontrol.repository.session.RepositoryControllerBean;
 import com.clustercontrol.repository.util.FacilityTreeCache;
 import com.clustercontrol.sharedtable.DataTable;
+import com.clustercontrol.util.Messages;
 
 /**
  *
@@ -126,16 +126,16 @@ public class NodeMapControllerBean {
 				parentFacilityId = getParentId(facilityId);
 				m_log.debug("parentFacilityId = " + parentFacilityId);
 			}
-			
+
 			boolean builtin = false;
 			// 組み込みスコープか否かを取得する
-			if(FacilityConstant.STRING_COMPOSITE.equals(facilityId)){ 
+			if(FacilityConstant.STRING_COMPOSITE.equals(facilityId)){
 				// トップスコープは組み込みスコープ扱い
 				builtin = true;
 			} else {
 				builtin = FacilityTreeCache.getFacilityInfo(facilityId).isBuiltInFlg();
 				m_log.debug("builtin = " + builtin);
-			} 
+			}
 
 			// 新規にマップを生成する
 			map = new NodeMapModel(parentFacilityId, facilityId, facilityName, facilityPath, ownerRoleId, builtin);
@@ -176,10 +176,10 @@ public class NodeMapControllerBean {
 		try {
 			jtm = new JpaTransactionManager();
 			jtm.begin();
-			EntityManager em = jtm.getEntityManager();
+			HinemosEntityManager em = jtm.getEntityManager();
 
 			// オブジェクト権限チェック
-			ObjectPrivilegeUtil.getObjectPrivilegeObject(HinemosModuleConstant.PLATFORM_REPOSITORY, map.getMapId(), ObjectPrivilegeMode.WRITE);
+			ObjectPrivilegeUtil.getObjectPrivilegeObject(HinemosModuleConstant.PLATFORM_REPOSITORY, map.getMapId(), ObjectPrivilegeMode.MODIFY);
 
 			// 登録時は、該当のマップの関係（コネクション）と要素を全て削除した後、登録する。
 			try {
@@ -343,7 +343,7 @@ public class NodeMapControllerBean {
 				}
 			}
 			jtm.commit();
-			
+
 			// キャッシュをリフレッシュする
 			FacilityTreeCache.refresh();
 		} catch (ObjectPrivilege_InvalidRole e) {
@@ -616,7 +616,7 @@ public class NodeMapControllerBean {
 		if (filename != null && filename.length() > MAX_FILENAME) {
 			String[] args = { Integer.toString(MAX_FILENAME) };
 			NodeMapException e =  new NodeMapException(
-					com.clustercontrol.nodemap.util.Messages.getString("file.name.too.long", args));
+					Messages.getString("nodemap.file.name.too.long", args));
 			m_log.info("setBgImage() : "
 					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 			throw e;
@@ -767,7 +767,7 @@ public class NodeMapControllerBean {
 		if (filename != null && filename.length() > MAX_FILENAME) {
 			String[] args = { Integer.toString(MAX_FILENAME) };
 			NodeMapException e = new NodeMapException(
-					com.clustercontrol.nodemap.util.Messages.getString("file.name.too.long", args));
+					Messages.getString("nodemap.file.name.too.long", args));
 			m_log.info("setIconImage() : "
 					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 			throw e;
@@ -891,7 +891,7 @@ public class NodeMapControllerBean {
 			jtm = new JpaTransactionManager();
 			jtm.begin();
 
-			Collection<FacilityEntity> parentBeanCol 
+			Collection<FacilityEntity> parentBeanCol
 			= com.clustercontrol.repository.util.QueryUtil.getParentFacilityEntity(targetId);
 
 			/*
@@ -908,7 +908,7 @@ public class NodeMapControllerBean {
 			}
 			FacilityEntity parentBean = (parentBeanCol.toArray(new FacilityEntity[0]))[0];
 			facilityId = parentBean.getFacilityId();
-			
+
 			jtm.commit();
 		} catch (Exception e) {
 			m_log.warn("getParentId() : "
@@ -927,13 +927,13 @@ public class NodeMapControllerBean {
 
 		try {
 			String userId = (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID);
-			
+
 			FacilityTreeItem item = FacilityTreeCache.getFacilityTreeByUserId(userId);
 			if (!isExistTreeItem(item, fid)) {
 				m_log.info("cannot refer facilityInfo, userId="+userId+", facilityId=" + fid);
 				throw new InvalidRole("cannot refer facilityInfo, userId="+userId+", facilityId=" + fid);
 			}
-			
+
 			facilityInfo = FacilityTreeCache.getFacilityInfo(fid);
 			// 見つからなかったらFacilityNotFoundを投げる
 			if (facilityInfo == null) {
@@ -965,19 +965,19 @@ public class NodeMapControllerBean {
 			element = new ScopeElement(parentId, fid, facilityName, iconImage, ownerRoleId, builtin, true);
 		} else {  // ノードの場合
 			m_log.debug("Node : " + facilityName + "(" + fid + ")");
-			
+
 			Integer ipAddressVersion = null;
 			String ipAddressV4 = "-";
 			String ipAddressV6 = "-";
 			String nodeName = "-";
-			
+
 			NodeEntity nodeEntity = null;
 			try {
 				nodeEntity = new RepositoryControllerBean().getNodeEntityByPK(fid);
 				ipAddressVersion = nodeEntity.getIpAddressVersion();
 				ipAddressV4 = nodeEntity.getIpAddressV4();
 				ipAddressV6 = nodeEntity.getIpAddressV6();
-				nodeName = nodeEntity.getNodeName();				
+				nodeName = nodeEntity.getNodeName();
 			} catch (FacilityNotFound e) {
 				throw e;
 			} catch (InvalidRole e) {
@@ -1005,7 +1005,7 @@ public class NodeMapControllerBean {
 
 		return element;
 	}
-	
+
 	public List<Association>getL2ConnectionMap(String scopeId) {
 		List<Association> result = null;
 
@@ -1014,10 +1014,10 @@ public class NodeMapControllerBean {
 		} catch (Exception e) {
 			m_log.error(e.getMessage());
 		}
-		
+
 		return result;
 	}
-	
+
 	public List<Association>getL3ConnectionMap(String scopeId) {
 		List<Association> result = null;
 
@@ -1026,42 +1026,46 @@ public class NodeMapControllerBean {
 		} catch (Exception e) {
 			m_log.error(e.getMessage());
 		}
-		
+
 		return result;
 	}
-	
+
 	// ツリーに指定したfacilityIdのfacilityInfoが存在するか再帰的に調べる
 	private boolean isExistTreeItem(FacilityTreeItem item, String facilityId) {
 		// 自身が一致するか
 		if (item.getData().getFacilityId().equals(facilityId)) {
 			return true;
 		}
-		
+
 		// 一致する子が存在するか
 		for (FacilityTreeItem child : item.getChildrenArray()) {
 			if (isExistTreeItem(child, facilityId)) {
 				return true;
 			}
 		}
-		
+
 		return false;
 	}
-	
+
 	public static void main(String[] args) {
-		SnmpPollerImpl poller = new SnmpPollerImpl();
 		List<String> oidList = new ArrayList<String>();
 		oidList.add(SearchConnectionProperties.DEFAULT_OID_FDB);
 		oidList.add(SearchConnectionProperties.DEFAULT_OID_ARP);
-		DataTable tmpTable = poller.polling(
+		DataTable tmpTable = Snmp4jPollerImpl.getInstance().polling(
 				"172.26.98.5",
-				161, 
+				161,
 				1,
 				"public",
 				3,
 				5000,
 				oidList,
-				false);
-		
+				null,
+				null,
+				null,
+				null,
+				null,
+				null);
+
 		for (String key : tmpTable.keySet()) {
 			System.out.println("key:"+key+",value:"+tmpTable.getValue(key).getValue());
 		}
