@@ -1,5 +1,7 @@
 package com.clustercontrol.nodemap.util;
 
+import java.util.ArrayList;
+
 
 /**
  * SNMPでL2、L3の接続状況を検出する際の定義情報のクラス<BR>
@@ -10,4 +12,13 @@ package com.clustercontrol.nodemap.util;
 public class SearchConnectionProperties {
 	public static final String DEFAULT_OID_FDB = ".1.3.6.1.2.1.17.4.3.1.1";
 	public static final String DEFAULT_OID_ARP = ".1.3.6.1.2.1.4.22.1.2";
+
+	public static ArrayList<String> getOidList(){
+		ArrayList<String> oidList = new ArrayList<String>();
+
+		oidList.add(DEFAULT_OID_FDB);
+		oidList.add(DEFAULT_OID_ARP);
+
+		return oidList;
+	}
 }
