@@ -28,6 +28,7 @@ import org.eclipse.swt.widgets.Group;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Text;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.notify.bean.RenotifyTypeConstant;
@@ -46,7 +47,7 @@ import com.clustercontrol.ws.notify.NotifyInfo;
  *  <dd>「回数で抑制する」 ラジオボタン</dd>
  *  <dd>「重要度で抑制する」 ラジオボタン</dd>
  * </dl>
- * 
+ *
  * @version 4.0.0
  * @since 3.0.0
  */
@@ -88,10 +89,10 @@ public class NotifyInhibitionComposite extends Composite {
 	 * インスタンスを返します。
 	 * <p>
 	 * 初期処理を呼び出し、コンポジットを配置します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param style スタイル
-	 * 
+	 *
 	 * @see org.eclipse.swt.SWT
 	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
 	 * @see #initialize()
@@ -123,6 +124,7 @@ public class NotifyInhibitionComposite extends Composite {
 		 * グループ
 		 */
 		Group groupInhibition = new Group(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, groupInhibition);
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
@@ -137,6 +139,7 @@ public class NotifyInhibitionComposite extends Composite {
 
 		// ラジオボタン（「常に通知する」）
 		this.m_radioRenotifyAlways = new Button(groupInhibition, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "renotifyalways", m_radioRenotifyAlways);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_ALL;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -146,6 +149,7 @@ public class NotifyInhibitionComposite extends Composite {
 
 		// ラジオボタン（「前回通知から」）
 		this.m_radioRenotifyPeriod = new Button(groupInhibition, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "renotifyperiod", m_radioRenotifyPeriod);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TITLE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -161,6 +165,7 @@ public class NotifyInhibitionComposite extends Composite {
 
 		// テキストボックス（期間で抑制する）
 		this.m_textRenotifyPeriod = new Text(groupInhibition, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "renotifyperiod", m_textRenotifyPeriod);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_VALUE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -174,6 +179,7 @@ public class NotifyInhibitionComposite extends Composite {
 		});
 		// ラベル（「分間は同一重要度の通知はしない」）
 		label = new Label(groupInhibition, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "timeinterval", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_BLANK;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -183,8 +189,9 @@ public class NotifyInhibitionComposite extends Composite {
 
 		// ラジオボタン（「通知しない」）
 		this.m_radioRenotifyNo = new Button(groupInhibition, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "renotifyno", m_radioRenotifyNo);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_ALL;
+		gridData.horizontalSpan = WIDTH_TITLE;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_radioRenotifyNo.setLayoutData(gridData);
@@ -199,7 +206,7 @@ public class NotifyInhibitionComposite extends Composite {
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	@Override
 	public void update(){
@@ -214,7 +221,7 @@ public class NotifyInhibitionComposite extends Composite {
 
 	/**
 	 * 引数で指定された通知情報の値を、各項目に設定します。
-	 * 
+	 *
 	 * @param notify 設定値として用いる通知情報
 	 */
 	public void setInputData(NotifyInfo notify) {
@@ -241,10 +248,10 @@ public class NotifyInhibitionComposite extends Composite {
 	 * <p>
 	 * 入力値チェックを行い、不正な場合は認証結果を返します。
 	 * 不正ではない場合は、<code>null</code>を返します。
-	 * 
+	 *
 	 * @param info 入力値を設定する通知情報
 	 * @return 検証結果
-	 * 
+	 *
 	 */
 	public ValidateResult createInputData(NotifyInfo info) {
 
@@ -290,7 +297,7 @@ public class NotifyInhibitionComposite extends Composite {
 
 	/**
 	 * 無効な入力値の情報を設定します。
-	 * 
+	 *
 	 * @param id ID
 	 * @param message メッセージ
 	 * @return 認証結果
@@ -304,4 +311,4 @@ public class NotifyInhibitionComposite extends Composite {
 
 		return validateResult;
 	}
-}
\ No newline at end of file
+}
