@@ -17,8 +17,6 @@ package com.clustercontrol.notify.composite.action;
 
 import java.util.ArrayList;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.jface.viewers.DoubleClickEvent;
 import org.eclipse.jface.viewers.IDoubleClickListener;
@@ -30,21 +28,18 @@ import com.clustercontrol.notify.view.action.NotifyModifyAction;
 
 /**
  * 通知[一覧]ビュー用のテーブルビューア用のDoubleClickListenerクラスです。
- * 
+ *
  * @version 4.0.0
  * @since 4.0.0
  */
 public class NotifyDoubleClickListener implements IDoubleClickListener {
 
-	// ログ
-	private static Log m_log = LogFactory.getLog( NotifyDoubleClickListener.class );
-
 	/** 通知[一覧]ビュー用のコンポジット */
 	private Composite m_composite;
 
 	/**
 	 * コンストラクタ
-	 * 
+	 *
 	 * @param composite 通知[一覧]ビュー用のコンポジット
 	 */
 	public NotifyDoubleClickListener(Composite composite) {
@@ -59,20 +54,22 @@ public class NotifyDoubleClickListener implements IDoubleClickListener {
 	 * <li>イベントから選択行を取得し、選択行から通知IDを取得します。</li>
 	 * <li>通知IDから通知情報を取得し、ダイアログで表示します。</li>
 	 * </ol>
-	 * 
+	 *
 	 * @param event イベント
-	 * 
+	 *
 	 * @see com.clustercontrol.calendar.dialog.CalendarDialog
 	 * @see org.eclipse.jface.viewers.IDoubleClickListener#doubleClick(org.eclipse.jface.viewers.DoubleClickEvent)
 	 */
 	@Override
 	public void doubleClick(DoubleClickEvent event) {
+		String managerName = null;
 		String notifyId = null;
 		Integer notifyType = null;
 
 		//通知IDを取得
 		if (((StructuredSelection) event.getSelection()).getFirstElement() != null) {
-			ArrayList info = (ArrayList) ((StructuredSelection) event.getSelection()).getFirstElement();
+			ArrayList<?> info = (ArrayList<?>) ((StructuredSelection) event.getSelection()).getFirstElement();
+			managerName = (String) info.get(NotifyTableDefineNoCheckBox.MANAGER_NAME);
 			notifyId = (String) info.get(NotifyTableDefineNoCheckBox.NOTIFY_ID);
 			notifyType = (Integer) info.get(NotifyTableDefineNoCheckBox.NOTIFY_TYPE);
 		}
@@ -81,7 +78,7 @@ public class NotifyDoubleClickListener implements IDoubleClickListener {
 			// ダイアログ名を取得
 			NotifyModifyAction action = new NotifyModifyAction();
 			// ダイアログにて変更が選択された場合、入力内容をもって登録を行う。
-			if (action.openDialog(m_composite.getShell(), notifyId, notifyType) ==
+			if (action.openDialog(m_composite.getShell(), managerName, notifyId, notifyType) ==
 					IDialogConstants.OK_ID) {
 				m_composite.update();
 			}
