@@ -16,7 +16,6 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.notify.dialog;
 
 import java.util.ArrayList;
-import java.util.List;
 
 import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.swt.SWT;
@@ -35,8 +34,8 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.PriorityColorConstant;
-import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.composite.TextWithParameterComposite;
@@ -45,12 +44,12 @@ import com.clustercontrol.notify.action.AddNotify;
 import com.clustercontrol.notify.action.GetNotify;
 import com.clustercontrol.notify.action.ModifyNotify;
 import com.clustercontrol.util.Messages;
-import com.clustercontrol.ws.notify.NotifyInfo;
 import com.clustercontrol.ws.notify.NotifyCommandInfo;
+import com.clustercontrol.ws.notify.NotifyInfo;
 
 /**
  * 通知（コマンド）作成・変更ダイアログクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 3.0.0
  */
@@ -73,14 +72,11 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 通知タイプ
-	 * 
+	 *
 	 * @see com.clustercontrol.bean.NotifyTypeConstant
 	 */
 	private final int TYPE_COMMAND = 5;
 
-	/** 入力値を保持するオブジェクト。 */
-	private NotifyInfo inputData = null;
-
 	/** 入力値の正当性を保持するオブジェクト。 */
 	protected ValidateResult validateResult = null;
 
@@ -115,7 +111,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のシェルオブジェクト
 	 */
@@ -123,33 +119,31 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		super(parent);
 	}
 
-	public NotifyCommandCreateDialog(Shell parent, int notifyIdType) {
-		super(parent, notifyIdType);
-	}
-
 	/**
 	 * 変更用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のシェルオブジェクト
+	 * @param managerName
+	 *            マネージャ名
 	 * @param notifyId
 	 *            変更する通知情報の通知ID
 	 * @param updateFlg
 	 *            更新フラグ（true:更新する）
 	 */
-	public NotifyCommandCreateDialog(Shell parent, String notifyId,
+	public NotifyCommandCreateDialog(Shell parent, String managerName, String notifyId,
 			boolean updateFlg) {
-		super(parent, notifyId, updateFlg);
+		super(parent, managerName, notifyId, updateFlg);
 	}
 
 	// ----- instance メソッド ----- //
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のコンポジット
-	 * 
+	 *
 	 * @see com.clustercontrol.notify.dialog.NotifyBasicCreateDialog#customizeDialog(Composite)
 	 * @see com.clustercontrol.notify.action.GetNotify#getNotify(String)
 	 * @see #setInputData(NotifyInfo)
@@ -162,7 +156,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		// 通知IDが指定されている場合、その情報を初期表示する。
 		NotifyInfo info = null;
 		if (this.notifyId != null) {
-			info = new GetNotify().getNotify(this.notifyId);
+			info = new GetNotify().getNotify(this.managerName, this.notifyId);
 		} else {
 			info = new NotifyInfo();
 		}
@@ -172,10 +166,10 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 親のクラスから呼ばれ、各通知用のダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のコンポジット
-	 * 
+	 *
 	 * @see com.clustercontrol.notify.dialog.NotifyBasicCreateDialog#customizeDialog(Composite)
 	 */
 	@Override
@@ -202,6 +196,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		 */
 		// コマンド設定グループ
 		Group groupComamnd = new Group(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "command", groupComamnd);
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
@@ -219,6 +214,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		 */
 		// ラベル（重要度）
 		label = new Label(groupComamnd, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "priority", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_PRIORITY;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -228,6 +224,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 		// ラベル（実行）
 		label = new Label(groupComamnd, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "notifyattribute", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_CHECK;
 		gridData.horizontalAlignment = GridData.CENTER;
@@ -237,6 +234,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 		// ラベル（ユーザ入力欄）
 		label = new Label(groupComamnd, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "effectiveuser", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_COMMAND_USER;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -246,6 +244,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 		// ラベル（コマンド入力欄）
 		label = new Label(groupComamnd, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "command", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_COMMAND_TEXT;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -257,8 +256,11 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		label = this.getLabelPriority(groupComamnd, Messages.getString("info"),
 				PriorityColorConstant.COLOR_INFO);
 		this.m_checkExecInfo = this.getCheckBox(groupComamnd);
+		WidgetTestUtil.setTestId(this, "execinfo", m_checkExecInfo);
 		this.m_textUserInfo = this.getTextUser(groupComamnd);
+		WidgetTestUtil.setTestId(this, "userinfo", m_textUserInfo);
 		this.m_textCommandInfo = this.getTextCommand(groupComamnd);
+		WidgetTestUtil.setTestId(this, "commandinfo", m_textCommandInfo);
 		this.m_checkExecInfo.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
@@ -273,8 +275,11 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		label = this.getLabelPriority(groupComamnd, Messages
 				.getString("warning"), PriorityColorConstant.COLOR_WARNING);
 		this.m_checkExecWarning = this.getCheckBox(groupComamnd);
+		WidgetTestUtil.setTestId(this, "execwarning", m_checkExecWarning);
 		this.m_textUserWarning = this.getTextUser(groupComamnd);
+		WidgetTestUtil.setTestId(this, "userwarning", m_textUserWarning);
 		this.m_textCommandWarning = this.getTextCommand(groupComamnd);
+		WidgetTestUtil.setTestId(this, "commandwarning", m_textCommandWarning);
 		this.m_checkExecWarning.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
@@ -289,8 +294,11 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		label = this.getLabelPriority(groupComamnd, Messages
 				.getString("critical"), PriorityColorConstant.COLOR_CRITICAL);
 		this.m_checkExecCritical = this.getCheckBox(groupComamnd);
+		WidgetTestUtil.setTestId(this, "execcritical", m_checkExecCritical);
 		this.m_textUserCritical = this.getTextUser(groupComamnd);
+		WidgetTestUtil.setTestId(this, "usercritical", m_textUserCritical);
 		this.m_textCommandCritical = this.getTextCommand(groupComamnd);
+		WidgetTestUtil.setTestId(this, "commandcritical", m_textCommandCritical);
 		this.m_checkExecCritical
 		.addSelectionListener(new SelectionAdapter() {
 			@Override
@@ -306,8 +314,11 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		label = this.getLabelPriority(groupComamnd, Messages
 				.getString("unknown"), PriorityColorConstant.COLOR_UNKNOWN);
 		this.m_checkExecUnknown = this.getCheckBox(groupComamnd);
+		WidgetTestUtil.setTestId(this, "execunknown", m_checkExecUnknown);
 		this.m_textUserUnknown = this.getTextUser(groupComamnd);
+		WidgetTestUtil.setTestId(this, "userunknown", m_textUserUnknown);
 		this.m_textCommandUnknown = this.getTextCommand(groupComamnd);
+		WidgetTestUtil.setTestId(this, "commandunknown", m_textCommandUnknown);
 		this.m_checkExecUnknown
 		.addSelectionListener(new SelectionAdapter() {
 			@Override
@@ -323,7 +334,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	public void update(){
 		// 必須項目を明示
@@ -404,7 +415,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 入力値を保持した通知情報を返します。
-	 * 
+	 *
 	 * @return 通知情報
 	 */
 	@Override
@@ -414,75 +425,18 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 引数で指定された通知情報の値を、各項目に設定します。
-	 * 
+	 *
 	 * @param notify
 	 *            設定値として用いる通知情報
 	 */
 	@Override
 	protected void setInputData(NotifyInfo notify) {
-
-		this.inputData = notify;
-
-		// 通知基本情報
-		super.m_notifyBasic.setInputData(notify, this.updateFlg);
-
-		// 初回通知情報
-		super.m_notifyInitial.setInputData(notify);
-
-		// 抑制情報
-		super.m_notifyInhibition.setInputData(notify);
+		super.setInputData(notify);
 
 		// コマンド情報
-		List<NotifyCommandInfo> list = notify.getNotifyCommandInfo();
-		if (list != null && list.size() > 0) {
-			for (int index = 0; index < list.size(); index++) {
-				NotifyCommandInfo info = list.get(index);
-				if (info != null) {
-					// 通知の場合
-					if (PriorityConstant.TYPE_INFO == info.getPriority()) {
-						this.setInputDataDetail(
-								info,
-								this.m_checkExecInfo,
-								this.m_textUserInfo,
-								this.m_textCommandInfo);
-					}
-					// 警告の場合
-					else if (PriorityConstant.TYPE_WARNING == info
-							.getPriority()) {
-						this.setInputDataDetail(
-								info,
-								this.m_checkExecWarning,
-								this.m_textUserWarning,
-								this.m_textCommandWarning);
-					}
-					// 危険の場合
-					else if (PriorityConstant.TYPE_CRITICAL == info
-							.getPriority()) {
-						this.setInputDataDetail(
-								info,
-								this.m_checkExecCritical,
-								this.m_textUserCritical,
-								this.m_textCommandCritical);
-					}
-					// 不明の場合
-					else if (PriorityConstant.TYPE_UNKNOWN == info
-							.getPriority()) {
-						this.setInputDataDetail(
-								info,
-								this.m_checkExecUnknown,
-								this.m_textUserUnknown,
-								this.m_textCommandUnknown);
-					}
-				}
-			}
-		}
-
-		// 有効／無効
-		if (notify.getValidFlg() != null
-				&& notify.getValidFlg() == ValidConstant.TYPE_INVALID) {
-			this.m_confirmValid.setSelection(false);
-		} else {
-			this.m_confirmValid.setSelection(true);
+		NotifyCommandInfo info = notify.getNotifyCommandInfo();
+		if (info != null) {
+			this.setInputData(info);
 		}
 
 		// 必須項目を可視化
@@ -491,143 +445,105 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 引数で指定された通知ステータス情報の値を、各項目に設定します。
-	 * 
+	 *
 	 * @param info
 	 *            設定値として用いる通知コマンド情報
-	 * @param checkBox
-	 *            実行チェックボックス
-	 * @param textCommand
-	 *            コマンドテキストボックス
-	 * @param checkExecInhibition
-	 *            抑制チェックボックス
 	 */
-	private void setInputDataDetail(
-			NotifyCommandInfo info,
-			Button checkBox,
-			Text textUser,
-			TextWithParameterComposite textCommand) {
-		// コマンド通知
-		if (info.getValidFlg() != null) {
-			if (info.getValidFlg().intValue() == ValidConstant.TYPE_VALID) {
-				checkBox.setSelection(true);
-				setEnabled(true, textUser, textCommand);
-			} else {
-				checkBox.setSelection(false);
-				setEnabled(false, textUser, textCommand);
+	private void setInputData(NotifyCommandInfo info) {
+		Button[] checkExecs = getCheckExecs();
+		Text[] textUsers = getTextUsers();
+		TextWithParameterComposite[] textCommands = getTextCommands();
+
+		String[] effectiveUsers = new String[] {
+				info.getInfoEffectiveUser(),
+				info.getWarnEffectiveUser(),
+				info.getCriticalEffectiveUser(),
+				info.getUnknownEffectiveUser()
+		};
+		String[] commands = new String[] {
+				info.getInfoCommand(),
+				info.getWarnCommand(),
+				info.getCriticalCommand(),
+				info.getUnknownCommand()
+		};
+
+		Integer[] validFlgs = getValidFlgs(info);
+		for (int i = 0; i < validFlgs.length; i++) {
+			boolean valid = validFlgs[i] == ValidConstant.TYPE_VALID;
+			checkExecs[i].setSelection(valid);
+			setEnabled(valid, textUsers[i], textCommands[i]);
+			WidgetTestUtil.setTestId(this, "textusers" + i, textUsers[i]);
+			if (effectiveUsers[i] != null) {
+				textUsers[i].setText(effectiveUsers[i]);
+			}
+			if (commands[i] != null) {
+				textCommands[i].setText(commands[i]);
 			}
 		}
-		// 実効ユーザ
-		if (info.getCommand() != null) {
-			textUser.setText(info.getEffectiveUser());
-		}
-		// 実行コマンド
-		if (info.getCommand() != null) {
-			textCommand.setText(info.getCommand());
-		}
+	}
+
+	private TextWithParameterComposite[] getTextCommands() {
+		TextWithParameterComposite[] textCommands = new TextWithParameterComposite[] {
+				this.m_textCommandInfo,
+				this.m_textCommandWarning,
+				this.m_textCommandCritical,
+				this.m_textCommandUnknown
+		};
+		return textCommands;
+	}
+
+	private Text[] getTextUsers() {
+		Text[] textUsers = new Text[] {
+				this.m_textUserInfo,
+				this.m_textUserWarning,
+				this.m_textUserCritical,
+				this.m_textUserUnknown
+		};
+		return textUsers;
+	}
+
+	private Button[] getCheckExecs() {
+		Button[] checkExecs = new Button[] {
+				this.m_checkExecInfo,
+				this.m_checkExecWarning,
+				this.m_checkExecCritical,
+				this.m_checkExecUnknown
+		};
+		return checkExecs;
 	}
 
 	/**
 	 * 入力値を設定した通知情報を返します。<BR>
 	 * 入力値チェックを行い、不正な場合は<code>null</code>を返します。
-	 * 
+	 *
 	 * @return 通知情報
-	 * 
+	 *
 	 * @see #createInputData(ArrayList, int, Button, Text, Button)
 	 */
 	@Override
 	protected NotifyInfo createInputData() {
-		NotifyInfo info = new NotifyInfo();
+		NotifyInfo info = super.createInputData();
+		if (info == null) {
+			return null;
+		}
 
 		// 通知タイプの設定
 		info.setNotifyType(TYPE_COMMAND);
 
-		// 通知基本情報
-		validateResult = super.m_notifyBasic.createInputData(info,
-				this.notifyId);
-		if (validateResult != null) {
-			return null;
-		}
-
-		// 初回通知情報
-		validateResult = super.m_notifyInitial.createInputData(info);
-		if(validateResult != null){
-			return null;
-		}
-
-		// 抑制情報
-		validateResult = super.m_notifyInhibition.createInputData(info);
-		if (validateResult != null) {
-			return null;
-		}
-
 		// コマンド情報
-
-		List<NotifyCommandInfo> list = new ArrayList<NotifyCommandInfo>();
-
-		list = this.createInputData(
-				list,
-				info.getNotifyId(),
-				PriorityConstant.TYPE_INFO,
-				this.m_checkExecInfo,
-				this.m_textUserInfo,
-				this.m_textCommandInfo);
-		list = this.createInputData(
-				list,
-				info.getNotifyId(),
-				PriorityConstant.TYPE_WARNING,
-				this.m_checkExecWarning,
-				this.m_textUserWarning,
-				this.m_textCommandWarning);
-		list = this.createInputData(
-				list,
-				info.getNotifyId(),
-				PriorityConstant.TYPE_CRITICAL,
-				this.m_checkExecCritical,
-				this.m_textUserCritical,
-				this.m_textCommandCritical);
-		list = this.createInputData(
-				list,
-				info.getNotifyId(),
-				PriorityConstant.TYPE_UNKNOWN,
-				this.m_checkExecUnknown,
-				this.m_textUserUnknown,
-				this.m_textCommandUnknown);
-
-		if (list == null) {
-			return null;
-		}
-		List<NotifyCommandInfo> notifyCommandInfo = info.getNotifyCommandInfo();
-		notifyCommandInfo.clear();
-		notifyCommandInfo.addAll(list);
-
-		// 有効/無効
-		if (this.m_confirmValid.getSelection()) {
-			info.setValidFlg(ValidConstant.TYPE_VALID);
-		} else {
-			info.setValidFlg(ValidConstant.TYPE_INVALID);
-		}
-
+		NotifyCommandInfo notifyCommandInfo = this.createInputData(info.getNotifyId());
+		info.setNotifyCommandInfo(notifyCommandInfo);
 		return info;
 	}
 
 	/**
 	 * 入力値を設定した通知イベント情報を返します。<BR>
 	 * 入力値チェックを行い、不正な場合は<code>null</code>を返します。
-	 * 
+	 *
 	 * @return 通知コマンド情報
-	 * 
+	 *
 	 */
-	private List<NotifyCommandInfo> createInputData(
-			List<NotifyCommandInfo> list,
-			String notifyId,
-			int priority,
-			Button checkBox,
-			Text textUser,
-			TextWithParameterComposite textCommand) {
-
-		if (list == null)
-			return null;
-
+	private NotifyCommandInfo createInputData(String notifyId) {
 		NotifyCommandInfo command = new NotifyCommandInfo();
 		// 環境変数を読み込むか否かのフラグ。デフォルトは有効とする。
 		command.setSetEnvironment(ValidConstant.TYPE_VALID);
@@ -635,36 +551,49 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		// 通知IDを設定
 		command.setNotifyId(notifyId);
 
-		// 重要度
-		command.setPriority(priority);
 		// 実行チェックボックス
-		if (checkBox.getSelection()) {
-			command.setValidFlg(new Integer(ValidConstant.TYPE_VALID));
-		} else {
-			command.setValidFlg(new Integer(ValidConstant.TYPE_INVALID));
-		}
+		command.setInfoValidFlg(ValidConstant.booleanToType(m_checkExecInfo.getSelection()));
+		command.setWarnValidFlg(ValidConstant.booleanToType(m_checkExecWarning.getSelection()));
+		command.setCriticalValidFlg(ValidConstant.booleanToType(m_checkExecCritical.getSelection()));
+		command.setUnknownValidFlg(ValidConstant.booleanToType(m_checkExecUnknown.getSelection()));
+
 		// 実効ユーザ
-		if (textUser.getText() != null
-				&& !"".equals((textUser.getText()).trim())) {
-			command.setEffectiveUser(textUser.getText());
+		if (isNotNullAndBlank(m_textUserInfo.getText())) {
+			command.setInfoEffectiveUser(m_textUserInfo.getText());
+		}
+		if (isNotNullAndBlank(m_textUserWarning.getText())) {
+			command.setWarnEffectiveUser(m_textUserWarning.getText());
+		}
+		if (isNotNullAndBlank(m_textUserCritical.getText())) {
+			command.setCriticalEffectiveUser(m_textUserCritical.getText());
+		}
+		if (isNotNullAndBlank(m_textUserUnknown.getText())) {
+			command.setUnknownEffectiveUser(m_textUserUnknown.getText());
+		}
+
+		// 実行コマンド
+		if (isNotNullAndBlank(m_textCommandInfo.getText())) {
+			command.setInfoCommand(m_textCommandInfo.getText());
+		}
+		if (isNotNullAndBlank(m_textCommandWarning.getText())) {
+			command.setWarnCommand(m_textCommandWarning.getText());
+		}
+		if (isNotNullAndBlank(m_textCommandCritical.getText())) {
+			command.setCriticalCommand(m_textCommandCritical.getText());
+		}
+		if (isNotNullAndBlank(m_textCommandUnknown.getText())) {
+			command.setUnknownCommand(m_textCommandUnknown.getText());
 		}
 
 		// タイムアウト値を設定（GUI上からは設定できない）
 		command.setTimeout(15000l);
 
-		// 実行コマンド
-		if (textCommand.getText() != null
-				&& !"".equals((textCommand.getText()).trim())) {
-			command.setCommand(textCommand.getText());
-		}
-
-		list.add(command);
-		return list;
+		return command;
 	}
 
 	/**
 	 * 入力値チェックをします。
-	 * 
+	 *
 	 * @return 検証結果
 	 */
 	@Override
@@ -681,9 +610,9 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -694,10 +623,10 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		if (info != null) {
 			if (!this.updateFlg) {
 				// 作成の場合
-				result = new AddNotify().add(info);
+				result = new AddNotify().add(this.getInputManagerName(), info);
 			} else {
 				// 変更の場合
-				result = new ModifyNotify().modify(info);
+				result = new ModifyNotify().modify(this.getInputManagerName(), info);
 			}
 		}
 
@@ -706,7 +635,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * ＯＫボタンのテキストを返します。
-	 * 
+	 *
 	 * @return ＯＫボタンのテキスト
 	 */
 	@Override
@@ -716,7 +645,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * キャンセルボタンのテキストを返します。
-	 * 
+	 *
 	 * @return キャンセルボタンのテキスト
 	 */
 	@Override
@@ -726,7 +655,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * コンポジットの選択可/不可を設定します。
-	 * 
+	 *
 	 * @param enable
 	 *            選択可の場合、<code> true </code>
 	 */
@@ -741,10 +670,10 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * コマンド通知の通知関連コンポジットの選択可/不可を設定します。
-	 * 
+	 *
 	 * @param enable
 	 *            選択可の場合、<code> true </code>
-	 * 
+	 *
 	 * @see #setEnabledDetail(boolean, Button, Text, Button)
 	 */
 	protected void setEnabledDetails(boolean enable) {
@@ -762,7 +691,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * コマンド通知のコンポジットの選択可/不可を設定します。
-	 * 
+	 *
 	 * @param enable
 	 *            選択可の場合、<code> true </code>
 	 * @param checkBox
@@ -792,7 +721,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 引数で指定されたコンポジットの選択可/不可を設定します。
-	 * 
+	 *
 	 * @param enabled
 	 *            選択可の場合、</code> true </code>
 	 * @param textCommand
@@ -808,7 +737,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 無効な入力値の情報を設定します。
-	 * 
+	 *
 	 * @param id
 	 *            ID
 	 * @param message
@@ -826,10 +755,10 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 	/**
 	 * ボタンを生成します。<BR>
 	 * 参照フラグが<code> true </code>の場合は閉じるボタンを生成し、<code> false </code>の場合は、デフォルトのボタンを生成します。
-	 * 
+	 *
 	 * @param parent
 	 *            ボタンバーコンポジット
-	 * 
+	 *
 	 * @see #createButtonsForButtonBar(Composite)
 	 */
 	@Override
@@ -839,14 +768,14 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 			super.createButtonsForButtonBar(parent);
 		} else {
 			// 閉じるボタン
-			this.createButton(parent, IDialogConstants.CANCEL_ID,
-					IDialogConstants.CLOSE_LABEL, false);
+			// TODO Remove the following hard-code. IDialogConstants.*_LABEL will causes IncompatibleClassChangeError on RAP
+			this.createButton(parent, IDialogConstants.CANCEL_ID, "Close", false);
 		}
 	}
 
 	/**
 	 * 重要度のラベルを返します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のコンポジット
 	 * @param text
@@ -860,6 +789,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 		// ラベル（重要度）
 		Label label = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "labelpriority", label);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_PRIORITY;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -873,13 +803,12 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 実行チェックボックスを返します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のコンポジット
 	 * @return 生成されたチェックボックス
 	 */
 	private Button getCheckBox(Composite parent) {
-
 		// チェックボックス（実行）
 		Button button = new Button(parent, SWT.CHECK);
 		GridData gridData = new GridData();
@@ -893,15 +822,15 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 実行コマンド入力欄のテキストボックスを返します。 テキストボックスはカスタマイズされたもので、置換文字列は青色で表示されます。
-	 * 
+	 *
 	 * @param parent
 	 *            親のインスタンス
 	 * @return 生成されたテキストボックス
 	 */
 	private Text getTextUser(Composite parent) {
-
 		// テキスト
 		Text text = new Text(parent, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, null, text);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_COMMAND_USER;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -919,7 +848,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 実行コマンド入力欄のテキストボックスを返します。 テキストボックスはカスタマイズされたもので、置換文字列は青色で表示されます。
-	 * 
+	 *
 	 * @param parent
 	 *            親のインスタンス
 	 * @return 生成されたテキストボックス
@@ -927,22 +856,22 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 	private TextWithParameterComposite getTextCommand(Composite parent) {
 
 		// テキスト
-		TextWithParameterComposite text = new TextWithParameterComposite(parent, SWT.BORDER | SWT.SINGLE);
+		TextWithParameterComposite notifyCmdCreateTooltipTextWithParamComposite = new TextWithParameterComposite(parent, SWT.BORDER | SWT.SINGLE);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_COMMAND_TEXT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		text.setLayoutData(gridData);
+		notifyCmdCreateTooltipTextWithParamComposite.setLayoutData(gridData);
 
-		text.setToolTipText(Messages.getString("notify.parameter.tooltip"));
-		text.setColor(new Color(parent.getDisplay(), new RGB(0, 0, 255)));
-		text.addModifyListener(new ModifyListener(){
+		notifyCmdCreateTooltipTextWithParamComposite.setToolTipText(Messages.getString("notify.parameter.tooltip"));
+		notifyCmdCreateTooltipTextWithParamComposite.setColor(new Color(parent.getDisplay(), new RGB(0, 0, 255)));
+		notifyCmdCreateTooltipTextWithParamComposite.addModifyListener(new ModifyListener(){
 			@Override
 			public void modifyText(ModifyEvent arg0) {
 				update();
 			}
 		});
 
-		return text;
+		return notifyCmdCreateTooltipTextWithParamComposite;
 	}
-}
\ No newline at end of file
+}
