@@ -18,6 +18,7 @@ package com.clustercontrol.notify.factory;
 import java.sql.Timestamp;
 import java.util.ArrayList;
 import java.util.Date;
+import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
@@ -28,9 +29,12 @@ import org.apache.commons.logging.LogFactory;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.bean.YesNoConstant;
+import com.clustercontrol.calendar.session.CalendarControllerBean;
 import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.commons.util.JpaTransactionManager;
+import com.clustercontrol.fault.CalendarNotFound;
 import com.clustercontrol.fault.HinemosUnknown;
+import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.NotifyNotFound;
 import com.clustercontrol.maintenance.util.HinemosPropertyUtil;
 import com.clustercontrol.notify.bean.NotifyInfo;
@@ -137,6 +141,12 @@ public class NotifyDispatcher {
 		// 通知対象のリスト分の通知種別を振り分ける。
 		String notify_mode = HinemosPropertyUtil.getHinemosPropertyStr(NOTIFY_MODE_KEY, MODE_NORMAL);
 
+		// cc_monitor_statusのcounterを1増やす。
+		HashMap<OutputBasicInfo, Boolean> priorityChangeMap = new HashMap<>();
+		for (OutputBasicInfo info : outputBasicInfoList) {
+			priorityChangeMap.put(info, MonitorResultStatusUpdater.update(info));
+		}
+		
 		// 監視結果重要度ステータスを更新
 		for (String notifyId : notifyIdList) {
 			NotifyInfo notifyInfo = NotifyCache.getNotifyInfo(notifyId);
@@ -151,10 +161,15 @@ public class NotifyDispatcher {
 				m_log.debug("notifyAction() : notifyId = " + notifyId +" invalid.");
 				continue;
 			}
+			
+			if (!checkCalendar(notifyInfo.getCalendarId())) {
+				m_log.debug("notifyAction() : notifyId = " + notifyId +" calendar is disabled now.");
+				continue;
+			}
 
 			ArrayList<NotifyRequestMessage> msgList = new ArrayList<NotifyRequestMessage>();
 			for (OutputBasicInfo info : outputBasicInfoList) {
-				boolean prioityChangeFlag = MonitorResultStatusUpdater.update(info);
+				boolean prioityChangeFlag = priorityChangeMap.get(info);
 				Timestamp outputDate = new Timestamp(System.currentTimeMillis());
 
 				// デフォルトでは抑制せずに通知する（予期せぬエラーの場合は通知を行う）
@@ -448,4 +463,29 @@ public class NotifyDispatcher {
 		}
 		return entity;
 	}
+	
+	private static boolean checkCalendar(String calendarId) throws HinemosUnknown {
+		long now = new Date().getTime();
+
+		// 稼働日か否かチェック
+		try {
+			CalendarControllerBean calendar = new CalendarControllerBean();
+			if(!calendar.isRun(calendarId, now)){
+				// 非稼働日の場合は、処理終了
+				m_log.debug("checkCalendar() " + " calenderId = " + calendarId
+						+ ". The notice is not executed because of non-operating day.");
+				return false;
+			}
+		} catch (InvalidRole e) {
+			// 指定されたカレンダIDの参照権限がない場合は、処理終了
+			// 手動でない限りここは通らない。
+			// （ADMINISTRATORSロールのユーザ、もしくはユーザ未指定の場合はオブジェクト権限をしないため）
+			return false;
+		} catch (CalendarNotFound e) {
+			// 指定されたカレンダIDがすでに存在しない場合は、処理終了
+			return false;
+		}
+
+		return true;
+}
 }
\ No newline at end of file
