@@ -18,12 +18,7 @@ package com.clustercontrol.notify.mail.view;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.eclipse.jface.action.ActionContributionItem;
-import org.eclipse.jface.action.IMenuListener;
-import org.eclipse.jface.action.IMenuManager;
-import org.eclipse.jface.action.IToolBarManager;
 import org.eclipse.jface.action.MenuManager;
-import org.eclipse.jface.action.Separator;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.SelectionChangedEvent;
@@ -36,7 +31,9 @@ import org.eclipse.swt.widgets.Menu;
 import org.eclipse.ui.IViewPart;
 import org.eclipse.ui.IWorkbenchPage;
 import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.commands.ICommandService;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.accesscontrol.util.ObjectBean;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.Property;
@@ -46,26 +43,27 @@ import com.clustercontrol.notify.mail.view.action.MailTemplateAddAction;
 import com.clustercontrol.notify.mail.view.action.MailTemplateCopyAction;
 import com.clustercontrol.notify.mail.view.action.MailTemplateDeleteAction;
 import com.clustercontrol.notify.mail.view.action.MailTemplateModifyAction;
+import com.clustercontrol.notify.mail.view.action.MailTemplateRefreshAction;
+import com.clustercontrol.notify.mail.view.action.ObjectPrivilegeMailTemplateListAction;
 import com.clustercontrol.view.CommonViewPart;
 import com.clustercontrol.view.ObjectPrivilegeTargetListView;
-import com.clustercontrol.view.action.ObjectPrivilegeAction;
 
 /**
  * 監視[一覧]ビュークラス<BR>
- * 
- * @version 4.0.0
+ *
+ * @version 5.0.0
  * @since 4.0.0
  */
 public class MailTemplateListView extends CommonViewPart implements ObjectPrivilegeTargetListView {
 
 	/** 監視[一覧]ビューID */
-	public static final String ID = "com.clustercontrol.notify.mail.view.MailTemplateListView";
+	public static final String ID = MailTemplateListView.class.getName();
 
 	/** 監視設定一覧コンポジット */
 	private MailTemplateListComposite composite = null;
 
-	/** 検索条件 */
-	private Property condition = null;
+	/** 選択レコード数 */
+	private int rowNum = 0;
 
 	/**
 	 * コンストラクタ
@@ -76,7 +74,7 @@ public class MailTemplateListView extends CommonViewPart implements ObjectPrivil
 
 	/**
 	 * ViewPartへのコントロール作成処理<BR>
-	 * 
+	 *
 	 * @see org.eclipse.ui.IWorkbenchPart#createPartControl(org.eclipse.swt.widgets.Composite)
 	 */
 	@Override
@@ -87,6 +85,7 @@ public class MailTemplateListView extends CommonViewPart implements ObjectPrivil
 		layout.marginWidth = 0;
 
 		composite = new MailTemplateListComposite(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, composite);
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -125,64 +124,22 @@ public class MailTemplateListView extends CommonViewPart implements ObjectPrivil
 
 	/**
 	 * コンテキストメニューを作成します。
-	 * 
+	 *
 	 * @see org.eclipse.jface.action.MenuManager
 	 * @see org.eclipse.swt.widgets.Menu
 	 */
 	private void createContextMenu() {
 		MenuManager menuManager = new MenuManager();
 		menuManager.setRemoveAllWhenShown(true);
-		menuManager.addMenuListener(new IMenuListener() {
-			/* (non-Javadoc)
-			 * @see org.eclipse.jface.action.IMenuListener#menuAboutToShow(org.eclipse.jface.action.IMenuManager)
-			 */
-			@Override
-			public void menuAboutToShow(IMenuManager manager) {
-				//メニュー項目設定
-				fillContextMenu(manager);
-			}
-		});
-
 		Menu menu = menuManager.createContextMenu(composite.getTable());
+		WidgetTestUtil.setTestId(this, null, menu);
 		composite.getTable().setMenu(menu);
-	}
-
-	/**
-	 * コンテキストメニューに項目を追加します。
-	 * 
-	 * @param manager メニューマネージャ
-	 * 
-	 * @see org.eclipse.jface.action.IToolBarManager
-	 * @see org.eclipse.jface.action.IMenuManager
-	 */
-	private void fillContextMenu(IMenuManager manager) {
-		//ビューのアクションのインスタンスを取得
-		IToolBarManager toolbar =
-				this.getViewSite().getActionBars().getToolBarManager();
-		ActionContributionItem mailTemplateAdd =
-				(ActionContributionItem) toolbar.find(MailTemplateAddAction.ID);
-		ActionContributionItem mailTemplateModify =
-				(ActionContributionItem) toolbar.find(MailTemplateModifyAction.ID);
-		ActionContributionItem mailTemplateDelete =
-				(ActionContributionItem) toolbar.find(MailTemplateDeleteAction.ID);
-		ActionContributionItem mailTemplateCopy =
-				(ActionContributionItem) toolbar.find(MailTemplateCopyAction.ID);
-		ActionContributionItem objPrivilege =
-				(ActionContributionItem) toolbar.find(ObjectPrivilegeAction.ID);
-
-		//ポップアップメニューにアクションを追加
-		manager.add(mailTemplateAdd.getAction());
-		manager.add(mailTemplateModify.getAction());
-		manager.add(mailTemplateDelete.getAction());
-		manager.add(new Separator());
-		manager.add(mailTemplateCopy.getAction());
-		manager.add(new Separator());
-		manager.add(objPrivilege.getAction());
+		getSite().registerContextMenu( menuManager, this.composite.getTableViewer() );
 	}
 
 	/**
 	 * 追加コンポジットを返します。
-	 * 
+	 *
 	 * @return 追加コンポジット
 	 */
 	public Composite getListComposite() {
@@ -192,22 +149,20 @@ public class MailTemplateListView extends CommonViewPart implements ObjectPrivil
 	/**
 	 * 検索条件にヒットした監視設定の一覧を表示します。
 	 * <p>
-	 * 
+	 *
 	 * conditionがnullの場合、全監視設定を表示します。
-	 * 
+	 *
 	 * @param condition
 	 *            検索条件
 	 */
 	public void update(Property condition) {
-		this.condition = condition;
-
 		this.update();
 	}
 
 	/**
 	 * ビューを更新します。
 	 * <p>
-	 * 
+	 *
 	 * 検索条件が事前に設定されている場合、その条件にヒットする監視設定の一覧を 表示します <br>
 	 * 検索条件が設定されていない場合は、全監視設定を表示します。
 	 */
@@ -216,42 +171,45 @@ public class MailTemplateListView extends CommonViewPart implements ObjectPrivil
 		this.composite.update();
 	}
 
+	/**
+	 * 選択レコード数を返します。
+	 * @return rowNum
+	 */
+	public int getSelectedNum(){
+		return this.rowNum;
+	}
+
 	/**
 	 * ビューのアクションの有効/無効を設定します。
-	 * 
+	 *
 	 * @param num 選択イベント数
 	 * @param selection ボタン（アクション）を有効にするための情報
 	 */
 	public void setEnabledAction(int num, ISelection selection) {
+		this.rowNum = num;
+
 		//ビューアクションの使用可/不可を設定
-		super.setEnabledAction(ObjectPrivilegeAction.ID, selection);
-		super.setEnabledAction(MailTemplateCopyAction.ID, selection);
-		super.setEnabledAction(MailTemplateDeleteAction.ID, selection);
-		super.setEnabledAction(MailTemplateModifyAction.ID, selection);
+		ICommandService service = (ICommandService) PlatformUI.getWorkbench().getService( ICommandService.class );
+		if( null != service ){
+			service.refreshElements(ObjectPrivilegeMailTemplateListAction.ID, null);
+			service.refreshElements(MailTemplateCopyAction.ID, null);
+			service.refreshElements(MailTemplateDeleteAction.ID, null);
+			service.refreshElements(MailTemplateModifyAction.ID, null);
+			service.refreshElements(MailTemplateAddAction.ID, null);
+			service.refreshElements(MailTemplateRefreshAction.ID, null);
+
+			// Update ToolBar after elements refreshed
+			// WARN : Both ToolBarManager must be updated after updateActionBars(), otherwise icon won't change.
+			getViewSite().getActionBars().updateActionBars();
+			getViewSite().getActionBars().getToolBarManager().update(false);
 
-		if (num > 0) {
-			super.setEnabledAction(ObjectPrivilegeAction.ID, true);
-			if (num == 1){
-				super.setEnabledAction(MailTemplateCopyAction.ID, true);
-				super.setEnabledAction(MailTemplateDeleteAction.ID, true);
-				super.setEnabledAction(MailTemplateModifyAction.ID, true);
-			} else {
-				super.setEnabledAction(MailTemplateCopyAction.ID, false);
-				super.setEnabledAction(MailTemplateDeleteAction.ID, false);
-				super.setEnabledAction(MailTemplateModifyAction.ID, false);
-			}
-		} else {
-			super.setEnabledAction(ObjectPrivilegeAction.ID, false);
-			super.setEnabledAction(MailTemplateCopyAction.ID, false);
-			super.setEnabledAction(MailTemplateDeleteAction.ID, false);
-			super.setEnabledAction(MailTemplateModifyAction.ID, false);
 		}
 	}
 
 	public String getSelectedId() {
 		StructuredSelection selection = (StructuredSelection) this.composite.getTableViewer().getSelection();
 
-		List list = (List) selection.getFirstElement();
+		List<?> list = (List<?>) selection.getFirstElement();
 		String id = null;
 		if (list != null) {
 			id = (String) list.get(GetMailTemplateListTableDefine.MAIL_TEMPLATE_ID);
@@ -263,7 +221,7 @@ public class MailTemplateListView extends CommonViewPart implements ObjectPrivil
 	public String getSelectedOwnerRoleId() {
 		StructuredSelection selection = (StructuredSelection) this.composite.getTableViewer().getSelection();
 
-		List list = (List) selection.getFirstElement();
+		List<?> list = (List<?>) selection.getFirstElement();
 		String id = null;
 		if (list != null) {
 			id = (String) list.get(GetMailTemplateListTableDefine.OWNER_ROLE);
@@ -276,12 +234,14 @@ public class MailTemplateListView extends CommonViewPart implements ObjectPrivil
 		StructuredSelection selection = (StructuredSelection) this.composite.getTableViewer().getSelection();
 		Object [] objs = selection.toArray();
 
+		String managerName = null;
 		String objectType = HinemosModuleConstant.PLATFORM_MAIL_TEMPLATE;
 		String objectId = null;
 		List<ObjectBean> objectBeans = new ArrayList<ObjectBean>();
 		for (Object obj : objs) {
-			objectId = (String) ((List)obj).get(GetMailTemplateListTableDefine.MAIL_TEMPLATE_ID);
-			ObjectBean objectBean = new ObjectBean(objectType, objectId);
+			managerName = (String) ((List<?>)obj).get(GetMailTemplateListTableDefine.MANAGER_NAME);
+			objectId = (String) ((List<?>)obj).get(GetMailTemplateListTableDefine.MAIL_TEMPLATE_ID);
+			ObjectBean objectBean = new ObjectBean(managerName, objectType, objectId);
 			objectBeans.add(objectBean);
 		}
 		return objectBeans;
