@@ -17,9 +17,7 @@ package com.clustercontrol.notify.session;
 
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.Date;
 import java.util.List;
-import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 
 import org.apache.commons.logging.Log;
@@ -28,12 +26,10 @@ import org.apache.commons.logging.LogFactory;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.PluginConstant;
 import com.clustercontrol.bean.ValidConstant;
-import com.clustercontrol.calendar.session.CalendarControllerBean;
 import com.clustercontrol.commons.session.CheckFacility;
 import com.clustercontrol.commons.util.AsyncTaskPersistentConfig;
 import com.clustercontrol.commons.util.HinemosSessionContext;
 import com.clustercontrol.commons.util.JpaTransactionManager;
-import com.clustercontrol.fault.CalendarNotFound;
 import com.clustercontrol.fault.FacilityNotFound;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
@@ -1043,17 +1039,8 @@ public class NotifyControllerBean implements CheckFacility {
 					return;
 				}
 
-				//カレンダIDを取得
-				List<String> noticeList = new ArrayList<String>();
-				for (String notifyId : notifyIdList) {
-					NotifyInfo info = NotifyCache.getNotifyInfo(notifyId);
-					if (checkCalendar(info.getCalendarId())) {
-						//稼働日の場合のみ通知対象とする
-						noticeList.add(notifyId);
-					}
-				}
 				// 通知処理を行う
-				notify(notifyInfo, noticeList);
+				notify(notifyInfo, notifyIdList);
 
 				jtm.commit();
 			} catch (Exception e) {
@@ -1067,31 +1054,6 @@ public class NotifyControllerBean implements CheckFacility {
 		}
 	}
 
-	private boolean checkCalendar(String calendarId) throws HinemosUnknown {
-			long now = new Date().getTime();
-
-			// 稼働日か否かチェック
-			try {
-				CalendarControllerBean calendar = new CalendarControllerBean();
-				if(!calendar.isRun(calendarId, now)){
-					// 非稼働日の場合は、処理終了
-					m_log.debug("checkCalendar() " + " calenderId = " + calendarId
-							+ ". The notice is not executed because of non-operating day.");
-					return false;
-				}
-			} catch (InvalidRole e) {
-				// 指定されたカレンダIDの参照権限がない場合は、処理終了
-				// 手動でない限りここは通らない。
-				// （ADMINISTRATORSロールのユーザ、もしくはユーザ未指定の場合はオブジェクト権限をしないため）
-				return false;
-			} catch (CalendarNotFound e) {
-				// 指定されたカレンダIDがすでに存在しない場合は、処理終了
-				return false;
-			}
-
-			return true;
-	}
-
 	protected void notify(OutputBasicInfo notifyInfo, List<String> notifyIdList) throws HinemosUnknown {
 		// 機能毎に設定されているJMSの永続化モードを取得
 		boolean persist = AsyncTaskPersistentConfig.isPersisted(notifyInfo.getPluginId());
