@@ -16,9 +16,13 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.notify.util;
 
 import java.io.IOException;
+import java.io.OutputStream;
+import java.io.PrintWriter;
 import java.net.DatagramPacket;
 import java.net.DatagramSocket;
 import java.net.InetAddress;
+import java.net.InetSocketAddress;
+import java.net.Socket;
 import java.net.SocketException;
 import java.net.UnknownHostException;
 import java.text.SimpleDateFormat;
@@ -31,16 +35,17 @@ import java.util.Map;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.commons.util.HinemosProperties;
+import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.fault.NotifyNotFound;
+import com.clustercontrol.maintenance.util.HinemosPropertyUtil;
 import com.clustercontrol.notify.bean.ExecFacilityConstant;
 import com.clustercontrol.notify.bean.NotifyRequestMessage;
 import com.clustercontrol.notify.bean.OutputBasicInfo;
 import com.clustercontrol.notify.bean.SyslogFacilityConstant;
 import com.clustercontrol.notify.bean.SyslogSeverityConstant;
-import com.clustercontrol.notify.model.NotifyLogEscalateInfoEntity;
 import com.clustercontrol.notify.entity.NotifyLogEscalateInfoData;
+import com.clustercontrol.notify.model.NotifyLogEscalateInfoEntity;
 import com.clustercontrol.repository.bean.FacilityTreeAttributeConstant;
 import com.clustercontrol.repository.model.FacilityEntity;
 import com.clustercontrol.repository.session.RepositoryControllerBean;
@@ -55,6 +60,12 @@ import com.clustercontrol.util.apllog.AplLogger;
  * @since 3.0.0
  */
 public class SendSyslog implements Notifier {
+	private static final String PROP_HOSTNAME = "notify.log.escalate.manager.hostname";
+	private static final String PROP_PROTOCOL = "notify.log.escalate.manager.protocol";
+	private static final String PROP_RETRY_COUNT = "notify.log.escalate.manager.retry.count";
+	private static final String PROP_RETRY_INTERVAL = "notify.log.escalate.manager.retry.interval";
+	private static final String PROP_TCP_TIMEOUT = "notify.log.escalate.manager.tcp.timeout";
+
 	/** ログ出力のインスタンス。 */
 	private static Log m_log = LogFactory.getLog( SendSyslog.class );
 
@@ -73,71 +84,51 @@ public class SendSyslog implements Notifier {
 
 	private static int LIMIT_SIZE = 1024;
 
-	// プロパティファイルの読み込み
-	static{
-		try {
-			String hostname = HinemosProperties.getProperty("common.manager.hostname");
-
-			if (hostname == null) {
-				// undef hostname of syglog header
-				MODE_HOSTNAME = MODE_HOSTNAME_DEFAULT;
-			} else if ("".equals(hostname)) {
-				// invalid hostname of syslog header
-				MODE_HOSTNAME = MODE_HOSTNAME_DEFAULT;
-			} else if ("#[FACILITY_ID]".equals(hostname)) {
-				// use facility_id as hostname of syslog header
-				MODE_HOSTNAME = MODE_HOSTNAME_FACILITYID;
-			} else if ("#[NODE]".equals(hostname)) {
-				// use nodename as hostname of syslog header
-				MODE_HOSTNAME = MODE_HOSTNAME_NODENAME;
-			} else {
-				MODE_HOSTNAME = MODE_HOSTNAME_DEFINED;
-				HOSTNAME_DEFINED = hostname;
-			}
-
-			HOSTNAME_SERVER = InetAddress.getLocalHost().getHostName();
-
-			m_log.info("static()initialized syslog sender. (mode = " + MODE_HOSTNAME + ", hostname=" + HOSTNAME_DEFINED + ")");
-
-		} catch (Exception e) {
-			m_log.warn("static() : "
-					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
-		}
-	}
-
 	@Override
-	public void notify(NotifyRequestMessage message)
+	public void notify(NotifyRequestMessage requestMessage)
 			throws NotifyNotFound {
 		if(m_log.isDebugEnabled()){
-			m_log.debug("notify() " + message);
+			m_log.debug("notify() " + requestMessage);
 		}
-		sendlog(message.getOutputInfo(), message.getNotifyId());
-	}
-
-	/**
-	 * ログエスカレーション通知：
-	 * 送信先リスト(IPADDRESS)に対してsyslog送信処理をcallする
-	 * 
-	 * @param outputInfo
-	 * @param notifyId
-	 * @throws NotifyNotFound
-	 */
-	private void sendlog(OutputBasicInfo outputInfo, String notifyId)
-			throws NotifyNotFound {
+		OutputBasicInfo outputInfo = requestMessage.getOutputInfo();
+		String notifyId = requestMessage.getNotifyId();
+		
 		if(m_log.isDebugEnabled()){
 			m_log.debug("sendlog() " + outputInfo);
 		}
 		// 該当する重要度の通知情報を取得する
 		NotifyLogEscalateInfoEntity logEscalateInfo
-		= QueryUtil.getNotifyLogEscalateInfoPK(notifyId, outputInfo.getPriority());
+		= QueryUtil.getNotifyLogEscalateInfoPK(notifyId);
 
 		NotifyLogEscalateInfoData escalateInfoData = new NotifyLogEscalateInfoData();
 		escalateInfoData.setNotifyId(logEscalateInfo.getId().getNotifyId());
-		escalateInfoData.setPriority(logEscalateInfo.getId().getPriority());
-		escalateInfoData.setValidFlg(logEscalateInfo.getEscalateFlg());
-		escalateInfoData.setEscalateMessage(logEscalateInfo.getEscalateMessage());
-		escalateInfoData.setSyslogPriority(logEscalateInfo.getSyslogPriority());
-		escalateInfoData.setSyslogFacility(logEscalateInfo.getSyslogFacility());
+
+		switch (outputInfo.getPriority()) {
+		case PriorityConstant.TYPE_INFO:
+			escalateInfoData.setValidFlg(logEscalateInfo.getInfoEscalateFlg());
+			escalateInfoData.setEscalateMessage(logEscalateInfo.getInfoEscalateMessage());
+			escalateInfoData.setSyslogPriority(logEscalateInfo.getInfoSyslogPriority());
+			escalateInfoData.setSyslogFacility(logEscalateInfo.getInfoSyslogFacility());
+			break;
+		case PriorityConstant.TYPE_WARNING:
+			escalateInfoData.setValidFlg(logEscalateInfo.getWarnEscalateFlg());
+			escalateInfoData.setEscalateMessage(logEscalateInfo.getWarnEscalateMessage());
+			escalateInfoData.setSyslogPriority(logEscalateInfo.getWarnSyslogPriority());
+			escalateInfoData.setSyslogFacility(logEscalateInfo.getWarnSyslogFacility());
+		case PriorityConstant.TYPE_CRITICAL:
+			escalateInfoData.setValidFlg(logEscalateInfo.getCriticalEscalateFlg());
+			escalateInfoData.setEscalateMessage(logEscalateInfo.getCriticalEscalateMessage());
+			escalateInfoData.setSyslogPriority(logEscalateInfo.getCriticalSyslogPriority());
+			escalateInfoData.setSyslogFacility(logEscalateInfo.getCriticalSyslogFacility());
+		case PriorityConstant.TYPE_UNKNOWN:
+			escalateInfoData.setValidFlg(logEscalateInfo.getUnknownEscalateFlg());
+			escalateInfoData.setEscalateMessage(logEscalateInfo.getUnknownEscalateMessage());
+			escalateInfoData.setSyslogPriority(logEscalateInfo.getUnknownSyslogPriority());
+			escalateInfoData.setSyslogFacility(logEscalateInfo.getUnknownSyslogFacility());
+		default:
+			break;
+		}
+
 		escalateInfoData.setEscalateFacilityFlg(logEscalateInfo.getEscalateFacilityFlg());
 		escalateInfoData.setEscalateFacility(logEscalateInfo.getEscalateFacilityId());
 		escalateInfoData.setEscalatePort(logEscalateInfo.getEscalatePort() );
@@ -160,15 +151,21 @@ public class SendSyslog implements Notifier {
 		SimpleDateFormat sdf = new SimpleDateFormat(HEADER_DATE_FORMAT, Locale.US);
 		String headerTimeStamp = sdf.format(new Date());
 		if(m_log.isDebugEnabled()){
-			m_log.debug("sendlog() target message. notifyId = " + escalateInfoData.getNotifyId() + 
-					", headerTimeStamp = " + headerTimeStamp + 
+			m_log.debug("sendlog() target message. notifyId = " + escalateInfoData.getNotifyId() +
+					", headerTimeStamp = " + headerTimeStamp +
 					", facilityId = " + outputInfo.getFacilityId() +
 					", message = " + message);
 		}
-		
+
 		for(InetAddress address : ipAddresses){
 			try {
-				this.sendAfterConvertHostname(escalateInfoData, address, outputInfo.getFacilityId(), message, headerTimeStamp);
+				sendMsgWithRetry(address, 
+						escalateInfoData.getEscalatePort(),
+						escalateInfoData.getSyslogPriority() + escalateInfoData.getSyslogFacility(),
+						headerTimeStamp,
+						getSyslogHeaderHost(outputInfo.getFacilityId()),
+						message
+						);
 			} catch (IOException e) {
 				String detailMsg = e.getMessage() + " IP Address = " + address;
 				m_log.info("sendlog() " + detailMsg + " : "
@@ -183,7 +180,7 @@ public class SendSyslog implements Notifier {
 	 * 指定の通知情報をもとにsyslog送信先のノードを特定します。
 	 * NotifyLogEscalateInfoData の EscalateFacilityFlg が「ExecFacilityConstant.TYPE_GENERATION」にも
 	 * かかわらず、outputInfoがnullの場合は、要素のない空のリストを返す。
-	 * 
+	 *
 	 * @param outputInfo 通知グループ情報
 	 * @param logEscalateInfo ログエスカレーション設定
 	 * @return 送信先ノードのIPアドレス
@@ -237,16 +234,35 @@ public class SendSyslog implements Notifier {
 	// 文字列を置換する
 	private String getMessage(OutputBasicInfo outputInfo, NotifyLogEscalateInfoEntity logEscalateInfo){
 		// 文字列を置換する
+		String message = "";
+		switch (outputInfo.getPriority()) {
+		case PriorityConstant.TYPE_INFO:
+			message = logEscalateInfo.getInfoEscalateMessage();
+			break;
+		case PriorityConstant.TYPE_WARNING:
+			message = logEscalateInfo.getWarnEscalateMessage();
+			break;
+		case PriorityConstant.TYPE_CRITICAL:
+			message = logEscalateInfo.getCriticalEscalateMessage();
+			break;
+		case PriorityConstant.TYPE_UNKNOWN:
+			message = logEscalateInfo.getUnknownEscalateMessage();
+			break;
+		default:
+			break;
+		}
+
 		try {
 			Map<String, String> param = NotifyUtil.createParameter(outputInfo,
 					logEscalateInfo.getNotifyInfoEntity());
 			StringBinder binder = new StringBinder(param);
-			return binder.bindParam(logEscalateInfo.getEscalateMessage());
+
+			return binder.bindParam(message);
 		} catch (Exception e) {
 			m_log.warn("getMessage() : "
 					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 			// 例外が発生した場合は、置換前の文字列を返す
-			return logEscalateInfo.getEscalateMessage();
+			return message;
 		}
 	}
 
@@ -277,7 +293,7 @@ public class SendSyslog implements Notifier {
 	/**
 	 * 汎用syslog送信処理(ShelfCheckTask、AplLogger)：
 	 * 設定ファイルに従ってホスト名をヘッダに埋め込み、syslogパケットを送信する。<br>
-	 * 
+	 *
 	 * @param ipAddress
 	 * @param port
 	 * @param facility
@@ -292,38 +308,12 @@ public class SendSyslog implements Notifier {
 
 		// メイン処理
 		hostname = getSyslogHeaderHost(facilityId);
-		send(ipAddress, port, facility, severity, hostname, message, timeStamp);
-	}
-
-	/**
-	 * 汎用syslog送信処理(ShelfCheckTask、AplLogger)：
-	 * syslogにメッセージを送る
-	 * 
-	 * @param ipAddress 送信先のIPアドレス
-	 * @param port 送信先のポート番号
-	 * @param facility facility (kern, user, mail, daemon, auth...)
-	 * @param hostname syslogヘッダに定義するホスト名
-	 * @param severity severity (emergency, alert, critical...)
-	 * @param message メッセージ文字列
-	 */
-	private void send(String ipAddress, int port, String facility, String severity, String hostname, String message, String timeStamp) {
-		// ローカル変数
-		byte[] buf = new byte[LIMIT_SIZE];
 		InetAddress inetAddress = null;
 
 		int facilityInt = -1;
 		int severityInt = -1;
 		int priority = -1;
 
-		String transferMsg = null;
-
-		DatagramSocket soc = null;
-		DatagramPacket sendPacket = null;
-
-		if (m_log.isDebugEnabled())
-			m_log.debug("start syslog transfer. (ipAddresss=" + ipAddress + ", port=" + port + ", "
-					+ "facility=" + facility + ", severity=" + severity + ", message=" + message + ")");
-
 		// メイン処理
 		try {
 			// generate InetAddress
@@ -338,26 +328,13 @@ public class SendSyslog implements Notifier {
 			}
 			priority = facilityInt + severityInt;
 
-			// generate message
-			transferMsg = "<"+ priority + ">" + timeStamp + " " + hostname + " " + message;
-			// is over 1024 byte
-			if (transferMsg.getBytes().length > LIMIT_SIZE) {
-				buf = transferMsg.getBytes();
-				transferMsg = new String(buf, 0, LIMIT_SIZE);
-			}
-
-			// send message
-			if (m_log.isDebugEnabled())
-				m_log.debug("sending syslog. (ipAddresss=" + ipAddress + ", port=" + port + ", "
-						+ "facility=" + facility + ", severity=" + severity + ", message=" + transferMsg + ")");
-
-			soc = new DatagramSocket();
-			sendPacket = null;
-			buf = transferMsg.getBytes();
-			sendPacket = new DatagramPacket(buf, buf.length, inetAddress, port);
-			soc.send(sendPacket);
-			soc.close();
-
+			sendMsgWithRetry(inetAddress, 
+					port,
+					priority,
+					timeStamp,
+					hostname,
+					message);
+			
 		} catch (UnknownHostException e) {
 			m_log.info("sending syslog failure. syslog's host(" + ipAddress + ") is invalid."
 					+ e.getClass().getSimpleName() + ", " + e.getMessage());
@@ -368,10 +345,6 @@ public class SendSyslog implements Notifier {
 			m_log.info("sending syslog failure."
 					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 		}
-
-		if (m_log.isDebugEnabled())
-			m_log.debug("sended syslog successfully. (ipAddresss=" + ipAddress + ", port=" + port + ", "
-					+ "facility=" + facility + ", severity=" + severity + ", message=" + transferMsg + ")");
 	}
 
 	/**
@@ -382,7 +355,33 @@ public class SendSyslog implements Notifier {
 	private static String getSyslogHeaderHost(String facilityId) {
 		JpaTransactionManager jtm = null;
 		// ローカル変数
-		String hostname = "";
+		String hostname = HinemosPropertyUtil.getHinemosPropertyStr(PROP_HOSTNAME, null);
+
+		if (hostname == null) {
+			// undef hostname of syglog header
+			MODE_HOSTNAME = MODE_HOSTNAME_DEFAULT;
+		} else if ("".equals(hostname)) {
+			// invalid hostname of syslog header
+			MODE_HOSTNAME = MODE_HOSTNAME_DEFAULT;
+		} else if ("#[FACILITY_ID]".equals(hostname)) {
+			// use facility_id as hostname of syslog header
+			MODE_HOSTNAME = MODE_HOSTNAME_FACILITYID;
+		} else if ("#[NODE]".equals(hostname)) {
+			// use nodename as hostname of syslog header
+			MODE_HOSTNAME = MODE_HOSTNAME_NODENAME;
+		} else {
+			MODE_HOSTNAME = MODE_HOSTNAME_DEFINED;
+			HOSTNAME_DEFINED = hostname;
+		}
+		try {
+			HOSTNAME_SERVER = InetAddress.getLocalHost().getHostName();
+		} catch (Exception e) {
+			m_log.warn("static() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+		}
+
+		m_log.debug("syslog sender. (mode = " + MODE_HOSTNAME + ", hostname=" + HOSTNAME_DEFINED + ")");
+
 		int mode = MODE_HOSTNAME;
 		boolean isBuildinScope = false;
 
@@ -434,40 +433,13 @@ public class SendSyslog implements Notifier {
 		return hostname;
 	}
 
-	/**
-	 * ログエスカレーション通知：
-	 * 設定ファイルに従ってホスト名をヘッダに埋め込み、syslogパケットを送信する。<br>
-	 * 
-	 * @param logEscalateInfo 通知情報
-	 * @param ipAddress 送信先のIPアドレス
-	 * @param facilityId 通知情報の対象ファシリティID
-	 * @param message syslogメッセージ部
-	 * @throws IOException
-	 */
-	private void sendAfterConvertHostname(NotifyLogEscalateInfoData logEscalateInfo, InetAddress ipAddress, String facilityId, String message,String headerTimeStamp) throws IOException {
-		// ローカル変数
-		String hostname = "";
+	private void sendMsgWithRetry(InetAddress ipAddress, int port, int syslogPriority, String headerTimestamp,
+			String hostname, String message) throws IOException {
 
-		// メイン処理
-		hostname = getSyslogHeaderHost(facilityId);
-		send(logEscalateInfo, ipAddress, hostname, message, headerTimeStamp);
-	}
-
-	/**
-	 * ログエスカレーション通知：
-	 * syslogにメッセージを送る
-	 * 
-	 * @param logEscalateInfo	通知内容
-	 * @param ipAddress	IPアドレス
-	 * @throws IOException
-	 */
-	private void send(NotifyLogEscalateInfoData logEscalateInfo, InetAddress ipAddress, String hostname, String message,String headerTimeStamp) throws IOException {
-		byte[] buf = new byte[LIMIT_SIZE];		// 送受信バッファ
-		int len;	// 送信文字数
-
-		// 送信メッセージの作成
-		int syslogPriority = logEscalateInfo.getSyslogPriority() + logEscalateInfo.getSyslogFacility();
-		String sendMessage = "<"+ syslogPriority + ">" + headerTimeStamp + " " + hostname + " " + message;
+		String protocol = HinemosPropertyUtil.getHinemosPropertyStr(PROP_PROTOCOL, "udp");
+		
+		byte[] buf = new byte[LIMIT_SIZE];   // 送受信バッファ
+		String sendMessage = "<"+ syslogPriority + ">" + headerTimestamp + " " + hostname + " " + message;
 
 		// 1024バイトを超える場合は、1024バイトまでを送信する（文字化けは考慮しない）
 		if(sendMessage.getBytes().length > LIMIT_SIZE){
@@ -475,17 +447,86 @@ public class SendSyslog implements Notifier {
 			sendMessage = new String(buf, 0, LIMIT_SIZE);
 		}
 
-		// ソケットを作成してサーバに接続する。
-		DatagramSocket soc = new DatagramSocket();  // データグラムソケットを開く
-		DatagramPacket sendPacket = null;           // データグラムパケット設定
+		m_log.debug("sendMsgWithRetry. (ipAddresss=" + ipAddress + ", port=" + port +
+				", sendMessage=" + sendMessage + ")");
 
-		buf = sendMessage.getBytes();
-		len = buf.length;
-		int port = logEscalateInfo.getEscalatePort();			// ポート番号
-		sendPacket = new DatagramPacket(buf, len, ipAddress, port );
-		soc.send(sendPacket);
+		int retryCount = HinemosPropertyUtil.getHinemosPropertyNum(PROP_RETRY_COUNT, 1);
+		int retryInterval = HinemosPropertyUtil.getHinemosPropertyNum(PROP_RETRY_INTERVAL, 10000);
+		IOException lastException = null;
+		int retrytime;
+		for (retrytime = 0; retrytime < retryCount; retrytime++) {
+			try {
+				if ("udp".equals(protocol)) {
+					sendUdpMsg(ipAddress, port, sendMessage);
+				} else {
+					sendTcpMsg(ipAddress, port, sendMessage);
+				}
 
-		soc.close();
+				break;
+			} catch (IOException e) {
+				m_log.warn("sendMsgWithRetry() : " + e.getClass().getSimpleName() + 
+						", retried time=" + (retrytime + 1) +
+						", protocol=" + protocol +
+						", message=" + e.getMessage());
+
+				lastException = e;
+
+				try {
+					Thread.sleep(retryInterval);
+				} catch (InterruptedException e1) {
+				}
+			}
+		}
+
+		if (retrytime == retryCount && lastException != null) {
+			throw lastException;
+		}
+	}
+
+	private void sendTcpMsg(InetAddress ipAddress, int port, String msg)
+			throws IOException {
+		
+		Socket socket = null;
+		OutputStream os = null;
+		PrintWriter writer = null;
+		try {
+			InetSocketAddress endpoint= new InetSocketAddress(ipAddress, port); 
+			socket = new Socket() ; 
+			socket.connect(endpoint, HinemosPropertyUtil.getHinemosPropertyNum(PROP_TCP_TIMEOUT, 3000));
+			
+			os = socket.getOutputStream();
+			writer = new PrintWriter(socket.getOutputStream(), true);
+			writer.println(msg);
+			writer.flush();
+		} finally {
+			if (writer != null) {
+				writer.close();
+			}
+			if (os != null) {
+				os.close();
+			}
+			if (socket != null) {
+				socket.close();
+			}
+		}
+	}
+
+	private void sendUdpMsg(InetAddress ipAddress, int port, String msg)
+			throws IOException {
+		DatagramSocket soc = null;
+		try {
+			// ソケットを作成してサーバに接続する。
+			soc = new DatagramSocket(); // データグラムソケットを開く
+			DatagramPacket sendPacket = null; // データグラムパケット設定
+
+			sendPacket = new DatagramPacket(msg.getBytes(),
+					msg.getBytes().length, ipAddress, port);
+			soc.send(sendPacket);
+		} finally {
+			if (soc != null) {
+				soc.close();
+			}
+		}
 	}
 
 	/**
