@@ -29,7 +29,7 @@ import com.clustercontrol.performance.view.PerformanceListView;
 
 /**
  * 性能[一覧]ビューのテーブルビューア用のSelectionChangedListenerです。
- * 
+ *
  * @version 4.0.0
  * @since 4.0.0
  */
@@ -37,7 +37,7 @@ public class PerformanceListSelectionChangedListener implements ISelectionChange
 
 	/**
 	 * コンストラクタ
-	 * 
+	 *
 	 * @param list 性能[一覧]ビュー用のコンポジット
 	 */
 	public PerformanceListSelectionChangedListener() {
@@ -53,14 +53,14 @@ public class PerformanceListSelectionChangedListener implements ISelectionChange
 	 * <li>選択変更イベントから選択行を取得し、選択行からイベントの表示内容を取得します。</li>
 	 * <li>取得したイベントから性能[一覧]ビューのアクションの有効・無効を設定します。</li>
 	 * </ol>
-	 * 
+	 *
 	 * @param event 選択変更イベント
-	 * 
+	 *
 	 * @see org.eclipse.jface.viewers.ISelectionChangedListener#selectionChanged(org.eclipse.jface.viewers.SelectionChangedEvent)
 	 */
 	@Override
 	public void selectionChanged(SelectionChangedEvent event) {
-		ArrayList list = null;
+		ArrayList<?> list = null;
 
 		//性能[一覧]ビューのインスタンスを取得
 		IWorkbenchPage page = PlatformUI.getWorkbench()
@@ -73,15 +73,15 @@ public class PerformanceListSelectionChangedListener implements ISelectionChange
 		if ( viewPart != null && selection != null) {
 			PerformanceListView view = (PerformanceListView) viewPart.getAdapter(PerformanceListView.class);
 
-			list = (ArrayList) selection.getFirstElement();
+			list = (ArrayList<?>) selection.getFirstElement();
 
 			if (list != null) {
 				//性能[一覧]ビューのボタン（アクション）の使用可/不可を設定する
 				view.setEnabledAction(((Integer) list.get(GetPerformanceListTableDefine.STATUS)).intValue(), selection);
 			} else {
 				//性能[一覧]ビューのボタン（アクション）を使用不可に設定する
-				view.setEnabledAction(0);
+				view.initButton();
 			}
 		}
 	}
-}
\ No newline at end of file
+}
