@@ -55,6 +55,7 @@ import com.clustercontrol.performance.util.PerformanceDataUtil;
 import com.clustercontrol.performance.util.PollingDataManager;
 import com.clustercontrol.performance.util.code.CollectorItemCodeTable;
 import com.clustercontrol.poller.NotInitializedException;
+import com.clustercontrol.poller.PollingController;
 import com.clustercontrol.repository.bean.NodeDeviceInfo;
 import com.clustercontrol.repository.session.RepositoryControllerBean;
 import com.clustercontrol.util.Messages;
@@ -337,6 +338,15 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 							m_value = node.calcValue(itemInfo);
 							if(!Double.isNaN(m_value)){
 								ret = true;
+							} else {
+								// FIXME 5.1では下記の機構は不要になるよう設計変更をすること（センシティブな修正なので、細かくコメントを記載します）
+								//
+								// 不明となった場合、実は直前のポーリング時に管理対象フラグがたっていなかった可能性がある。
+								// そのため管理対象フラグが無効だった最後の時刻から、この情報を通知すべきか否かを検討する
+								// リソース監視なので、2回分以上前のタイミングかを確認する
+								if (PollingController.skipResourceMonitorNotifyByNodeFlagHistory(facilityId, m_runInterval)) {
+									break;
+								}
 							}
 						} catch (NotInitializedException e) {
 							m_value = Double.NaN;
@@ -388,6 +398,15 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 						m_value = node.calcValue(itemInfo);
 						if(!Double.isNaN(m_value)){
 							ret = true;
+						} else {
+							// FIXME 5.1では下記の機構は不要になるよう設計変更をすること（センシティブな修正なので、細かくコメントを記載します）
+							//
+							// 不明となった場合、実は直前のポーリング時に管理対象フラグがたっていなかった可能性がある。
+							// そのため管理対象フラグが無効だった最後の時刻から、この情報を通知すべきか否かを検討する
+							// リソース監視なので、2回分以上前のタイミングかを確認する
+							if (PollingController.skipResourceMonitorNotifyByNodeFlagHistory(facilityId, m_runInterval)) {
+								break;
+							}
 						}
 					} catch (NotInitializedException e) {
 						m_value = Double.NaN;
@@ -440,6 +459,15 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 					m_value = node.calcValue(itemInfo);
 					if(!Double.isNaN(m_value)){
 						ret = true;
+					} else {
+						// FIXME 5.1では下記の機構は不要になるよう設計変更をすること（センシティブな修正なので、細かくコメントを記載します）
+						// 
+						// 不明となった場合、実は直前のポーリング時に管理対象フラグがたっていなかった可能性がある。
+						// そのため管理対象フラグが無効だった最後の時刻から、この情報を通知すべきか否かを検討する
+						// リソース監視なので、2回分以上前のタイミングかを確認する
+						if (PollingController.skipResourceMonitorNotifyByNodeFlagHistory(facilityId, m_runInterval)) {
+							break;
+						}
 					}
 				} catch (NotInitializedException e) {
 					m_value = Double.NaN;
