@@ -15,32 +15,32 @@ GNU General Public License for more details.
 
 package com.clustercontrol.performance.session;
 
+import java.sql.Connection;
+import java.sql.ResultSet;
+import java.sql.SQLException;
+import java.sql.Statement;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Locale;
-
-import javax.persistence.EntityManager;
+import java.util.Map;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.bean.HinemosModuleConstant;
+import com.clustercontrol.commons.util.HinemosEntityManager;
+import com.clustercontrol.commons.util.HinemosSessionContext;
+import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.fault.CollectorNotFound;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.MonitorNotFound;
-import com.clustercontrol.bean.HinemosModuleConstant;
-import com.clustercontrol.commons.util.HinemosSessionContext;
-import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.monitor.run.bean.MonitorInfo;
 import com.clustercontrol.monitor.run.bean.MonitorTypeConstant;
 import com.clustercontrol.monitor.run.factory.SelectMonitor;
 import com.clustercontrol.monitor.run.model.MonitorInfoEntity;
 import com.clustercontrol.monitor.session.MonitorSettingControllerBean;
-import com.clustercontrol.performance.model.CalculatedDataEntity;
-import com.clustercontrol.performance.monitor.model.CollectorItemCodeMstEntity;
-import com.clustercontrol.performance.util.ExportCollectedDataFile;
-import com.clustercontrol.performance.util.QueryUtil;
 import com.clustercontrol.performance.bean.CollectedDataInfo;
 import com.clustercontrol.performance.bean.CollectedDataList;
 import com.clustercontrol.performance.bean.CollectedDataSet;
@@ -49,11 +49,15 @@ import com.clustercontrol.performance.bean.CollectorItemParentInfo;
 import com.clustercontrol.performance.bean.PerformanceDataSettings;
 import com.clustercontrol.performance.bean.PerformanceFilterInfo;
 import com.clustercontrol.performance.bean.PerformanceListInfo;
+import com.clustercontrol.performance.model.CalculatedDataEntity;
+import com.clustercontrol.performance.monitor.model.CollectorItemCodeMstEntity;
+import com.clustercontrol.performance.util.ExportCollectedDataFile;
+import com.clustercontrol.performance.util.QueryUtil;
 import com.clustercontrol.performance.util.code.CollectorItemCodeTable;
 import com.clustercontrol.performance.util.code.CollectorItemTreeItem;
+import com.clustercontrol.repository.bean.FacilityTreeItem;
 import com.clustercontrol.repository.factory.FacilitySelector;
 import com.clustercontrol.repository.session.RepositoryControllerBean;
-import com.clustercontrol.repository.bean.FacilityTreeItem;
 
 /**
  *　性能管理機能の管理を行うコントローラクラス
@@ -68,10 +72,6 @@ public class CollectorControllerBean {
 	//	ログ出力
 	private static Log m_log = LogFactory.getLog(CollectorControllerBean.class);
 
-	// 実績収集で1行あたりに必要な物理サイズ容量（Byte）
-	// サイズ見積り時に使われる（ヘッダサイズ ＋ timestamp + double precision）
-	private static long _fixRowSize = 24 + 8 + 8;
-
 	/**
 	 * 性能[一覧]に表示するためのリストを取得します。
 	 * 以下の条件のうちいずれかを満たす監視設定を取得します。
@@ -94,30 +94,66 @@ public class CollectorControllerBean {
 			jtm.begin();
 
 			ArrayList<MonitorInfo> monitorList = new SelectMonitor().getPerformanceMonitorList();
-			m_log.info(" 97 " + (System.currentTimeMillis()-start) + "ms");
+			m_log.info(" getPerformanceList start " + (System.currentTimeMillis()-start) + "ms");
 
-			ArrayList<CollectorItemParentInfo> itemCodeList = null;
-			List<Object[]> oldLateList = null;
 			// 収集項目ID一覧、収集項目IDに対して存在するデバイス表示名を設定
-			oldLateList = jtm.getEntityManager()
-						.createNamedQuery("CalculatedDataEntity.getLatestOldestDateByCollectorid")
-						.getResultList();
 			HashMap<String, Date> oldMap = new HashMap<String, Date>();
 			HashMap<String, Date> lateMap = new HashMap<String, Date>();
-			
-			if (oldLateList != null) {
-				for (Object[] itemCodeResult : oldLateList) {
-					String collectorId = (String)itemCodeResult[0];
-					oldMap.put(collectorId, (Date)itemCodeResult[1]);
-					lateMap.put(collectorId, (Date)itemCodeResult[2]);
+
+			// JPQLではLATERALに対応していないため、直接SQLを実行する
+			Connection conn = null;
+			JpaTransactionManager tm = null;
+			String sql =
+					"SELECT c.monitor_id, a.min, a.max "
+					+ "FROM setting.cc_monitor_info c, LATERAL "
+					+ "(SELECT min(date_time) as min, max(date_time) as max "
+					+ "FROM log.cc_calculated_data WHERE c.monitor_id = log.cc_calculated_data.collectorid)a";
+			try {
+				tm = new JpaTransactionManager();
+				conn = tm.getEntityManager().unwrap(java.sql.Connection.class);
+				conn.setAutoCommit(false);
+				Statement stmt = conn.createStatement();
+				ResultSet result = stmt.executeQuery(sql);
+				while (result.next()) {
+					String collectorId = result.getString("monitor_id");
+					Date oldDate = result.getTimestamp("min");
+					Date lateDate = result.getTimestamp("max");
+					if (oldDate == null) {
+						continue;
+					}
+					if (lateDate == null) {
+						continue; // ここには到達しないはずだが。。。
+					}
+					oldMap.put(collectorId, oldDate);
+					lateMap.put(collectorId, lateDate);
+				}
+				
+				if (! tm.isNestedEm()) {
+					conn.commit();
+				}
+			} catch (Exception e) {
+				m_log.warn(e);
+				if (conn != null) {
+					try {
+						conn.rollback();
+					} catch (SQLException e1) {
+						m_log.warn(e1);
+					}
+				}
+			} finally {
+				if (tm != null) {
+					tm.close();
 				}
 			}
-			
+
 			for (MonitorInfo monitorInfo : monitorList){
 
 				m_log.debug("getPerformanceList() target monitorId = " + monitorInfo.getMonitorId());
 
-				if (monitorInfo.getMonitorType() == MonitorTypeConstant.TYPE_NUMERIC) {
+				if (
+					monitorInfo.getMonitorType() == MonitorTypeConstant.TYPE_NUMERIC ||
+					monitorInfo.getMonitorType() == MonitorTypeConstant.TYPE_SCENARIO
+					) {
 					m_log.debug("getPerformanceList() add monitorId = " + monitorInfo.getMonitorId());
 
 					PerformanceListInfo perfListInfo = new PerformanceListInfo();
@@ -154,7 +190,7 @@ public class CollectorControllerBean {
 		}
 
 		long end = System.currentTimeMillis();
-		m_log.info("getPerformanceList " + (end-start) + "ms");
+		m_log.info("getPerformanceList end " + (end-start) + "ms");
 		return ret;
 
 	}
@@ -277,7 +313,7 @@ public class CollectorControllerBean {
 		try {
 			jtm = new JpaTransactionManager();
 			jtm.begin();
-			EntityManager em = jtm.getEntityManager();
+			HinemosEntityManager em = jtm.getEntityManager();
 
 			// 対象の監視設定の取得
 			MonitorInfoEntity monitorInfoEntity
@@ -320,6 +356,11 @@ public class CollectorControllerBean {
 						.createNamedQuery("CalculatedDataEntity.getCollectorItemParentListByCollectorItemCode")
 						.setParameter("collectorid", monitorId)
 						.getResultList();
+			} else if ((HinemosModuleConstant.MONITOR_HTTP_SCENARIO).equals(monitorInfoEntity.getMonitorTypeId())) {
+				itemCodeResultList = em
+						.createNamedQuery("CalculatedDataEntity.getCollectorItemParentListByHttpScenario")
+						.setParameter("collectorid", monitorId)
+						.getResultList();
 			} else {
 				itemCodeResultList = em
 						.createNamedQuery("CalculatedDataEntity.getCollectorItemParentListByMonitorInfo")
@@ -361,7 +402,26 @@ public class CollectorControllerBean {
 				// 監視対象のデバイス
 				perfDataSettings.setTargetDisplayName(monitorInfo.getPerfCheckInfo().getDeviceDisplayName());
 
-			} else {
+			}
+			else if ((HinemosModuleConstant.MONITOR_HTTP_SCENARIO).equals(monitorInfoEntity.getMonitorTypeId())) {
+				if (!perfDataSettings.getItemCodeList().isEmpty()) {
+					// リソース監視の場合
+					for (CollectorItemParentInfo itemInfo : perfDataSettings.getItemCodeList()){
+						perfDataSettings.setItemName(itemInfo.getItemCode(), itemInfo.getDisplayName());
+					}
+
+					// 監視対象のItemCode
+					perfDataSettings.setTargetItemCode("0");
+					// 監視対象のデバイス
+					perfDataSettings.setTargetDisplayName(perfDataSettings.getItemNameMap().get("0"));
+
+					m_log.debug("getPerformanceGraphInfo() : MON_XXX itemCode = " + "0" + ", itemName = " + perfDataSettings.getItemNameMap().get("0"));
+				}
+				else{
+					m_log.info("getPerformanceGraphInfo() itemCode size = 0");
+				}
+			}
+			else {
 				// リソース監視以外は監視設定で取得された値を指定(リソース監視は1つのItemCodeを持つ)
 				if(perfDataSettings.getItemCodeList().size() > 0){
 					CollectorItemParentInfo itemInfo = perfDataSettings.getItemCodeList().get(0);
@@ -453,7 +513,6 @@ public class CollectorControllerBean {
 				for(CollectorItemInfo itemInfo : itemInfoList){
 					m_log.debug("getRecordCollectedData() facilityId = " + facilityId + ", itemInfo = " + itemInfo.getItemCode());
 
-
 					// 収集項目をDBから取得します
 					List<CalculatedDataEntity> dataList = QueryUtil.getCalculatedDataByFilter(
 							itemInfo.getCollectorId(),
@@ -469,7 +528,7 @@ public class CollectorControllerBean {
 							d = new Date(entity.getId().getDateTime().getTime());
 						}
 						CollectedDataInfo data;
-						data = new CollectedDataInfo(facilityId, itemInfo.getItemCode(), itemInfo.getDisplayName(), d==null?null:d.getTime(), entity.getValue());
+						data = new CollectedDataInfo(d==null?null:d.getTime(), (float)entity.getValue());
 
 						collectedDataList.add(data);
 					}
@@ -497,11 +556,11 @@ public class CollectorControllerBean {
 	 * 
 	 * @return 収集項目IDをキーとしCollectorItemTreeItemが格納されているHashMap
 	 */
-	public HashMap<String, CollectorItemTreeItem> getItemCodeMap() throws HinemosUnknown {
+	public Map<String, CollectorItemTreeItem> getItemCodeMap() throws HinemosUnknown {
 		m_log.debug("getItemCodeMap()");
 
 		JpaTransactionManager jtm = null;
-		HashMap<String, CollectorItemTreeItem> map = null;
+		Map<String, CollectorItemTreeItem> map = null;
 		
 		try {
 			jtm = new JpaTransactionManager();
@@ -509,7 +568,7 @@ public class CollectorControllerBean {
 			
 			map = CollectorItemCodeTable.getItemCodeMap();
 			jtm.commit();
-		} catch (Exception e) {
+		} catch (Exception e){
 			m_log.warn("getItemCodeMap() : "
 					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 			jtm.rollback();
@@ -575,7 +634,7 @@ public class CollectorControllerBean {
 		try {
 			jtm = new JpaTransactionManager();
 			jtm.begin();
-			
+
 			String userId = (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID);
 
 			list = ExportCollectedDataFile.create(monitorId, facilityId, header, archive, userId);
