@@ -358,8 +358,18 @@ public class ExportCollectedDataFile {
 			if (checkBeforeWritefile(file)) {
 				String exportEncode = HinemosPropertyUtil.getHinemosPropertyStr(
 						"performance.export.encode", "UTF-8");
-				String exportLineSeparator = HinemosPropertyUtil.getHinemosPropertyStr(
-						"performance.export.line.separator", "\r\n");
+				
+				String exportLineSeparator = "\r\n";
+				String exportLineSeparatorStr = HinemosPropertyUtil.getHinemosPropertyStr(
+						"performance.export.line.separator", "CRLF");
+				
+				if ("CRLF".equals(exportLineSeparatorStr)) {
+					exportLineSeparator = "\r\n";
+				} else if ("LF".equals(exportLineSeparatorStr)) {
+					exportLineSeparator = "\n";
+				} else if ("CR".equals(exportLineSeparatorStr)) {
+					exportLineSeparator = "\r";
+				}
 
 				pw = new PrintWriter(new BufferedWriter(new OutputStreamWriter(new FileOutputStream(file, true),exportEncode)));
 
