@@ -3,18 +3,16 @@ package com.clustercontrol.performance.util;
 import java.util.ArrayList;
 import java.util.List;
 
-import javax.ejb.CreateException;
-import javax.ejb.FinderException;
-import javax.naming.NamingException;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.fault.FacilityNotFound;
-import com.clustercontrol.performance.monitor.ejb.entity.CollectorItemCodeMstData;
+import com.clustercontrol.performance.monitor.entity.CollectorItemCodeMstData;
 import com.clustercontrol.repository.bean.DeviceTypeConstant;
 import com.clustercontrol.repository.bean.NodeDeviceInfo;
+import com.clustercontrol.repository.bean.NodeDiskInfo;
 import com.clustercontrol.repository.bean.NodeInfo;
+import com.clustercontrol.repository.bean.NodeNetworkInterfaceInfo;
 import com.clustercontrol.repository.factory.NodeProperty;
 
 /**
@@ -50,7 +48,7 @@ public class PollingDataManager {
 	// facilityIdのノード情報
 	private NodeInfo nodeInfo = null;
 
-	public PollingDataManager(String facilityId, String itemCode, boolean breakdownFlg) throws FinderException, NamingException, CreateException, FacilityNotFound{
+	public PollingDataManager(String facilityId, String itemCode, boolean breakdownFlg) throws FacilityNotFound{
 		m_log.debug("PollingDataManager() facilityId = " + facilityId + ", itemCode = " + itemCode + ", breakdownFlg = " + breakdownFlg);
 		this.facilityId = facilityId;
 		this.itemCode = itemCode;
@@ -74,11 +72,7 @@ public class PollingDataManager {
 			// プラットフォームIDとサブプラットフォームID
 			this.nodeInfo = NodeProperty.getProperty(this.facilityId);
 			this.platformId = nodeInfo.getPlatformFamily();
-			if ("controller".equals(nodeInfo.getVirtualizationNodeType())) {
-				subPlatformId = "";
-			} else {
-				subPlatformId = nodeInfo.getVirtualizationSolution();
-			}
+			this.subPlatformId = nodeInfo.getSubPlatformFamily();
 			m_log.debug("PollingDataManager() platformId = " + platformId + ", subPlatformId = " + subPlatformId);
 
 			////
@@ -108,17 +102,8 @@ public class PollingDataManager {
 			this.itemCodeList = breakdownItemCodeList;
 			this.pollingTargets = CollectorMasterCache.getPollingTarget(breakdownItemCodeList, collectMethod, platformId, subPlatformId);
 
-		} catch (FinderException e) {
-			// TODO: Internal Event?
-			m_log.error("PollingDataManager()", e);
-			throw e;
-		} catch (NamingException e) {
-			// TODO: Internal Event?
-			m_log.error("PollingDataManager()", e);
-			throw e;
 		} catch (FacilityNotFound e) {
 			// TODO: Internal Event?
-			m_log.error("PollingDataManager()", e);
 			throw e;
 		}
 	}
@@ -173,7 +158,7 @@ public class PollingDataManager {
 	 * @return
 	 */
 	public String getSubPlatformId(){
-		return nodeInfo.getVirtualizationSolution();
+		return nodeInfo.getSubPlatformFamily();
 	}
 
 	/**
@@ -200,10 +185,40 @@ public class PollingDataManager {
 			deviceList = nodeInfo.getNodeMemoryInfo();
 		}
 		else if(DeviceTypeConstant.DEVICE_NIC.equals(getDeviceType())){
-			deviceList = nodeInfo.getNodeNetworkInterfaceInfo();
+			List<NodeNetworkInterfaceInfo> nicList = new ArrayList<NodeNetworkInterfaceInfo>();
+			for (NodeNetworkInterfaceInfo nic : nodeInfo.getNodeNetworkInterfaceInfo()) {
+				if (DeviceTypeConstant.DEVICE_NIC.equals(nic.getDeviceType())) {
+					nicList.add(nic);
+				}
+			}
+			deviceList = nicList;
+		}
+		else if(DeviceTypeConstant.DEVICE_VIRT_NIC.equals(getDeviceType())){
+			List<NodeNetworkInterfaceInfo> nicList = new ArrayList<NodeNetworkInterfaceInfo>();
+			for (NodeNetworkInterfaceInfo nic : nodeInfo.getNodeNetworkInterfaceInfo()) {
+				if (DeviceTypeConstant.DEVICE_VIRT_NIC.equals(nic.getDeviceType())) {
+					nicList.add(nic);
+				}
+			}
+			deviceList = nicList;
 		}
 		else if(DeviceTypeConstant.DEVICE_DISK.equals(getDeviceType())){
-			deviceList = nodeInfo.getNodeDiskInfo();
+			List<NodeDiskInfo> diskList = new ArrayList<NodeDiskInfo>();
+			for (NodeDiskInfo disk : nodeInfo.getNodeDiskInfo()) {
+				if (DeviceTypeConstant.DEVICE_DISK.equals(disk.getDeviceType())) {
+					diskList.add(disk);
+				}
+			}
+			deviceList = diskList;
+		}
+		else if(DeviceTypeConstant.DEVICE_VIRT_DISK.equals(getDeviceType())){
+			List<NodeDiskInfo> diskList = new ArrayList<NodeDiskInfo>();
+			for (NodeDiskInfo disk : nodeInfo.getNodeDiskInfo()) {
+				if (DeviceTypeConstant.DEVICE_VIRT_DISK.equals(disk.getDeviceType())) {
+					diskList.add(disk);
+				}
+			}
+			deviceList = diskList;
 		}
 		else if(DeviceTypeConstant.DEVICE_FILESYSTEM.equals(getDeviceType())){
 			deviceList = nodeInfo.getNodeFilesystemInfo();
