@@ -15,13 +15,11 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.port.factory;
 
-import javax.ejb.FinderException;
-import javax.naming.NamingException;
-
+import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.monitor.run.factory.SelectMonitor;
 import com.clustercontrol.port.bean.PortCheckInfo;
-import com.clustercontrol.port.ejb.entity.MonitorPortInfoLocal;
-import com.clustercontrol.port.ejb.entity.MonitorPortInfoUtil;
+import com.clustercontrol.port.model.MonitorPortInfoEntity;
+import com.clustercontrol.port.util.QueryUtil;
 
 /**
  * port監視判定情報検索クラス
@@ -35,19 +33,19 @@ public class SelectMonitorPort extends SelectMonitor{
 	 * @see com.clustercontrol.monitor.run.factory.SelectMonitor#getCheckInfo()
 	 */
 	@Override
-	protected PortCheckInfo getPortCheckInfo() throws FinderException, NamingException{
+	protected PortCheckInfo getPortCheckInfo() throws MonitorNotFound {
 
 		// port監視情報を取得
-		MonitorPortInfoLocal portLocal = MonitorPortInfoUtil.getLocalHome().findByPrimaryKey(m_monitorId);
+		MonitorPortInfoEntity entity = QueryUtil.getMonitorPortInfoPK(m_monitorId);
 
 		PortCheckInfo port = new PortCheckInfo();
 		port.setMonitorTypeId(m_monitorTypeId);
 		port.setMonitorId(m_monitorId);
-		port.setPortNo(portLocal.getPortNo());  //ポート番号
-		port.setRunCount(portLocal.getRunCount());
-		port.setRunInterval(portLocal.getRunInterval());
-		port.setTimeout(portLocal.getTimeout());
-		port.setServiceId(portLocal.getServiceId());
+		port.setPortNo(entity.getPortNumber());  //ポート番号
+		port.setRunCount(entity.getRunCount());
+		port.setRunInterval(entity.getRunInterval());
+		port.setTimeout(entity.getTimeout());
+		port.setServiceId(entity.getMonitorProtocolMstEntity().getServiceId());
 
 		return port;
 	}
