@@ -15,13 +15,7 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.process.factory;
 
-import javax.ejb.FinderException;
-import javax.ejb.RemoveException;
-import javax.naming.NamingException;
-
 import com.clustercontrol.monitor.run.factory.DeleteMonitor;
-import com.clustercontrol.process.ejb.entity.MonitorProcessInfoLocal;
-import com.clustercontrol.process.ejb.entity.MonitorProcessInfoUtil;
 
 /**
  * プロセス監視情報を削除するクラス<BR>
@@ -35,13 +29,7 @@ public class DeleteMonitorProcess extends DeleteMonitor{
 	 * @see com.clustercontrol.monitor.run.factory.DeleteMonitor#deleteCheckInfo()
 	 */
 	@Override
-	protected boolean deleteCheckInfo() throws FinderException, RemoveException, NamingException {
-
-		// プロセス監視情報を取得
-		MonitorProcessInfoLocal processLocal = MonitorProcessInfoUtil.getLocalHome().findByPrimaryKey(m_monitorId);
-
-		// プロセス監視情報を削除
-		processLocal.remove();
+	protected boolean deleteCheckInfo() {
 
 		boolean result = true;
 
