@@ -15,13 +15,12 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.process.factory;
 
-import javax.ejb.FinderException;
-import javax.naming.NamingException;
-
+import com.clustercontrol.bean.ValidConstant;
+import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.monitor.run.factory.SelectMonitor;
 import com.clustercontrol.process.bean.ProcessCheckInfo;
-import com.clustercontrol.process.ejb.entity.MonitorProcessInfoLocal;
-import com.clustercontrol.process.ejb.entity.MonitorProcessInfoUtil;
+import com.clustercontrol.process.model.MonitorProcessInfoEntity;
+import com.clustercontrol.process.util.QueryUtil;
 
 /**
  * プロセス監視判定情報を検索するクラス<BR>
@@ -35,16 +34,17 @@ public class SelectMonitorProcess extends SelectMonitor{
 	 * @see com.clustercontrol.monitor.run.factory.SelectMonitor#getCheckInfo()
 	 */
 	@Override
-	protected ProcessCheckInfo getProcessCheckInfo() throws FinderException, NamingException{
+	protected ProcessCheckInfo getProcessCheckInfo() throws MonitorNotFound {
 
 		// プロセス監視情報を取得
-		MonitorProcessInfoLocal processLocal = MonitorProcessInfoUtil.getLocalHome().findByPrimaryKey(m_monitorId);
+		MonitorProcessInfoEntity entity = QueryUtil.getMonitorProcessInfoPK(m_monitorId);
 
 		ProcessCheckInfo process = new ProcessCheckInfo();
 		process.setMonitorTypeId(m_monitorTypeId);
 		process.setMonitorId(m_monitorId);
-		process.setCommand(processLocal.getCommand());
-		process.setParam(processLocal.getParam());
+		process.setCommand(entity.getCommand());
+		process.setParam(entity.getParam());
+		process.setCaseSensitivityFlg(ValidConstant.typeToBoolean(entity.getCaseSensitivityFlg()));
 
 		return process;
 	}
