@@ -17,12 +17,11 @@ package com.clustercontrol.repository.bean;
 
 import java.io.Serializable;
 import java.util.ArrayList;
+import java.util.HashSet;
 import java.util.List;
 
 import javax.xml.bind.annotation.XmlType;
 
-import com.clustercontrol.repository.bean.FacilityInfo;
-
 /**
  * スコープ情報をツリー構造化するためのクラス<BR>
  * 
@@ -32,15 +31,8 @@ import com.clustercontrol.repository.bean.FacilityInfo;
 @XmlType(namespace = "http://repository.ws.clustercontrol.com")
 public class FacilityTreeItem implements Serializable, Cloneable {
 
-	//	 ----- static フィールド ----- //
-
-	/**
-	 * 
-	 */
 	private static final long serialVersionUID = 1663475778653652044L;
 
-	//	 ----- instance フィールド ----- //
-
 	/** 親 */
 	private FacilityTreeItem parent = null;
 
@@ -50,7 +42,8 @@ public class FacilityTreeItem implements Serializable, Cloneable {
 	/** 子の格納リスト */
 	private List<FacilityTreeItem> children = null;
 
-	// ----- コンストラクタ ----- //
+	private HashSet<String> authorizedRoleIdSet = null;
+
 	/**
 	 * JAXB(Webservice)のために、引数なしのコンストラクタを用意。
 	 */
@@ -121,6 +114,14 @@ public class FacilityTreeItem implements Serializable, Cloneable {
 		this.data = data;
 	}
 
+	public HashSet<String> getAuthorizedRoleIdSet() {
+		return authorizedRoleIdSet;
+	}
+
+	public void setAuthorizedRoleIdSet(HashSet<String> authorizedRoleIdSet) {
+		this.authorizedRoleIdSet = authorizedRoleIdSet;
+	}
+
 	/**
 	 * 子ファシリティを追加します。<BR>
 	 * <p>
@@ -162,8 +163,6 @@ public class FacilityTreeItem implements Serializable, Cloneable {
 	 * 
 	 */
 	public boolean removeChild(String facilityId){
-
-
 		for(int i=0 ; i< children.size(); i++){
 
 			if(facilityId.equals((children.get(i)).getData().getFacilityId())){
@@ -246,7 +245,6 @@ public class FacilityTreeItem implements Serializable, Cloneable {
 	}
 
 	// Webサービス(jaxb)のためsetter、getterを用意しておく
-	@Deprecated
 	public List<FacilityTreeItem> getChildren() {
 		return children;
 	}
@@ -255,7 +253,7 @@ public class FacilityTreeItem implements Serializable, Cloneable {
 	public void setChildren(List<FacilityTreeItem> children) {
 		this.children = children;
 	}
-	
+
 	/**
 	 * parentはnullとなっているので注意すること。
 	 * parentが必要な場合は、completeParentを呼ぶこと。
@@ -283,7 +281,7 @@ public class FacilityTreeItem implements Serializable, Cloneable {
 		}
 		for (FacilityTreeItem child : item.children) {
 			child.parent = item;
-			completeParent(item);
+			completeParent(child);
 		}
 	}
 }
\ No newline at end of file
