@@ -33,10 +33,11 @@ import com.clustercontrol.repository.util.RepositoryEndpointWrapper;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.viewer.CommonTableViewer;
 import com.clustercontrol.ws.repository.InvalidRole_Exception;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * ノードの割当スコープコンポジットクラス<BR>
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
@@ -60,7 +61,7 @@ public class NodeScopeComposite extends Composite {
 
 	/**
 	 * インスタンスを返します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のコンポジット
 	 * @param style
@@ -80,17 +81,20 @@ public class NodeScopeComposite extends Composite {
 		layout.marginWidth = 0;
 
 		this.facilityIdLabel = new Label(this, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "facilityid", facilityIdLabel);
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		this.facilityIdLabel.setLayoutData(gridData);
 
 		this.facilityNameLabel = new Label(this, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "facilityname", facilityNameLabel);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		this.facilityNameLabel.setLayoutData(gridData);
 
 		Table table = new Table(this, SWT.H_SCROLL | SWT.V_SCROLL
 				| SWT.FULL_SELECTION | SWT.SINGLE);
+		WidgetTestUtil.setTestId(this, null, table);
 		table.setHeaderVisible(true);
 		table.setLinesVisible(true);
 
@@ -106,12 +110,15 @@ public class NodeScopeComposite extends Composite {
 		this.tableViewer.createTableColumn(GetNodeScopeTableDefine.get(),
 				GetNodeScopeTableDefine.SORT_COLUMN_INDEX,
 				GetNodeScopeTableDefine.SORT_ORDER);
+		for (int i = 0; i < table.getColumnCount(); i++){
+			table.getColumn(i).setMoveable(true);
+		}
 
 	}
 
 	/**
 	 * tableViewerを返します。
-	 * 
+	 *
 	 * @return tableViewer
 	 */
 	public CommonTableViewer getTableViewer() {
@@ -120,18 +127,19 @@ public class NodeScopeComposite extends Composite {
 
 	/**
 	 * 指定されたノードの情報を表示します。
-	 * 
+	 *
 	 * @param facilityId
 	 *            ファシリティID
 	 * @param facilityName
 	 *            ファシリティ名
 	 */
-	public void update(String facilityId, String facilityName) {
+	public void update(String managerName, String facilityId, String facilityName) {
 		List<String> data = null;
 
 		if (facilityId != null) {
 			try {
-				data = RepositoryEndpointWrapper.getNodeScopeList(facilityId);
+				RepositoryEndpointWrapper wrapper = RepositoryEndpointWrapper.getWrapper(managerName);
+				data = wrapper.getNodeScopeList(facilityId);
 			} catch (InvalidRole_Exception e) {
 				// アクセス権なしの場合、エラーダイアログを表示する
 				MessageDialog.openInformation(null, Messages.getString("message"),
@@ -166,9 +174,10 @@ public class NodeScopeComposite extends Composite {
 		for (String path : data) {
 			ArrayList<String> a = new ArrayList<String>();
 			a.add(path);
+			a.add(null);
 			dataInput.add(a);
 		}
 
 		this.tableViewer.setInput(dataInput);
 	}
-}
\ No newline at end of file
+}
