@@ -100,40 +100,35 @@ public class SearchNodeBySNMP {
 		SearchDeviceProperties pollingProp = SearchDeviceProperties.getProperties();
 		int retries = pollingProp.getRetry();
 		int timeout = pollingProp.getTimeOut();
-		boolean pollingFault = true;
 		
 		DataTable ret = new DataTable();
-		for (int i = 0; i < pollingProp.getListSize(); i++) {
-			ArrayList<String> oidList = pollingProp.getOidList(i);
-			//pollingします。
-			m_log.debug("searchNode() polling start ipAddress = " + ipAddress);
-			DataTable tmpDataTable = Snmp4jPollerImpl.getInstance().polling(ipAddress,
-					port,
-					SnmpVersionConstant.stringToSnmpType(version),
-					community,
-					retries,
-					timeout,
-					oidList,
-					securityLevel,
-					user,
-					authPass,
-					privPass,
-					authProtocol,
-					privProtocol);
-			m_log.debug("searchNode() polling stop ipAddress = " + ipAddress);
 
-			// 応答がある場合取得したデータをつめる
-			if (tmpDataTable.keySet().size() > 0) {
-				ret.putAll(tmpDataTable);
-				pollingFault = false;
-			}
-		}
-		
-		// 応答がまったくない場合エラーを返す
-		if (pollingFault) {
+		ArrayList<String> oidList = pollingProp.getOidList();
+			//pollingします。
+		m_log.debug("searchNode() polling start ipAddress = " + ipAddress);
+		DataTable tmpDataTable = Snmp4jPollerImpl.getInstance().polling(ipAddress,
+				port,
+				SnmpVersionConstant.stringToSnmpType(version),
+				community,
+				retries,
+				timeout,
+				oidList,
+				securityLevel,
+				user,
+				authPass,
+				privPass,
+				authProtocol,
+				privProtocol);
+		m_log.debug("searchNode() polling stop ipAddress = " + ipAddress);
+
+		// 応答がない場合エラーを返す
+		if (tmpDataTable.keySet().size() == 0) {
 			m_log.info("searchNode: no response ipAddress = " + ipAddress);
 			throw new SnmpResponseError();
 		}
+		
+		//　取得したデータを詰め替える
+		ret.putAll(tmpDataTable);
 
 		//ポーリングした結果をつめるメソッドを呼び出します
 		return stractProperty(ipAddress, port, community, version, securityLevel, user, authPass,
