@@ -753,7 +753,10 @@ public class FacilityTreeCache {
 		roleIdSet.add(RoleIdConstant.HINEMOS_MODULE);
 
 		// オーナーロール
-		roleIdSet.add(facilityInfo.getOwnerRoleId());
+		// スコープの場合のみ。ノードはスコープの参照権限に従うため、ノードのオーナーロールは含めない
+		if(facilityInfo.getFacilityType() == FacilityConstant.TYPE_SCOPE) {
+			roleIdSet.add(facilityInfo.getOwnerRoleId());
+		}
 
 		// オブジェクト権限が設定されている場合
 		ArrayList<String>roleIdList = objectRoleMap.get(facilityInfo.getFacilityId());
