@@ -18,7 +18,6 @@ package com.clustercontrol.repository.util;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.commons.bean.SettingUpdateInfo;
 import com.clustercontrol.hinemosagent.bean.TopicInfo;
 import com.clustercontrol.hinemosagent.util.AgentConnectUtil;
 
@@ -26,7 +25,6 @@ import com.clustercontrol.hinemosagent.util.AgentConnectUtil;
  * マネージャ内で利用されるリポジトリ管理機能のユーティリティクラス
  * 
  * @since 4.0
- * @author Tomoya Takahata
  */
 public class RepositoryManagerUtil {
 
@@ -42,8 +40,6 @@ public class RepositoryManagerUtil {
 		// MAIN
 		log.info("broadcasting configuration modified.");
 
-		SettingUpdateInfo.getInstance().setRepositoryUpdateTime(System.currentTimeMillis());
-
 		topicInfo = new TopicInfo();
 		topicInfo.setRepositoryChanged(true);
 
