@@ -15,11 +15,17 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.repository.view.action;
 
-import org.eclipse.jface.action.IAction;
+import org.eclipse.core.commands.AbstractHandler;
+import org.eclipse.core.commands.Command;
+import org.eclipse.core.commands.ExecutionEvent;
+import org.eclipse.core.commands.ExecutionException;
+import org.eclipse.core.commands.State;
 import org.eclipse.jface.dialogs.IDialogConstants;
-import org.eclipse.jface.viewers.ISelection;
-import org.eclipse.ui.IViewActionDelegate;
-import org.eclipse.ui.IViewPart;
+import org.eclipse.ui.IWorkbenchPart;
+import org.eclipse.ui.IWorkbenchWindow;
+import org.eclipse.ui.commands.ICommandService;
+import org.eclipse.ui.handlers.HandlerUtil;
+import org.eclipse.ui.handlers.RegistryToggleState;
 
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.repository.dialog.NodeFilterDialog;
@@ -27,37 +33,46 @@ import com.clustercontrol.repository.view.NodeListView;
 
 /**
  * ノード検索ダイアログによる、検索処理を行うクライアント側アクションクラス<BR>
- * 
- * @version 1.0.0
+ *
+ * @version 5.0.0
  * @since 1.0.0
  */
-public class NodeFilterAction implements IViewActionDelegate {
+public class NodeFilterAction extends AbstractHandler {
+
+	public static final String ID = NodeFilterAction.class.getName();
 
 	//	 ----- instance フィールド ----- //
 
-	private IViewPart viewPart; // ビュー
+	private IWorkbenchWindow window;
+	private IWorkbenchPart viewPart;
+
+	/**
+	 * Dispose
+	 */
+	@Override
+	public void dispose() {
+		this.viewPart = null;
+	}
 
 	// ----- instance メソッド ----- //
 
 	/**
-	 * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
+	 * @see org.eclipse.core.commands.IHandler#execute
 	 */
 	@Override
-	public void init(IViewPart viewPart) {
-		this.viewPart = viewPart;
-	}
+	public Object execute(ExecutionEvent event) throws ExecutionException {
+		this.viewPart = HandlerUtil.getActivePart(event);
+		this.window = HandlerUtil.getActiveWorkbenchWindow(event);
 
-	/**
-	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
-	 */
-	@Override
-	public void run(IAction action) {
 		// ノード一覧より、選択されているノードのファシリティIDを取得
-
 		NodeListView view = (NodeListView) this.viewPart
 				.getAdapter(NodeListView.class);
 
-		if (action.isChecked()) {
+		ICommandService commandService = (ICommandService)window.getService(ICommandService.class);
+		Command command = commandService.getCommand(ID);
+		boolean isChecked = !HandlerUtil.toggleCommandState(command);
+
+		if (isChecked) {
 			// ダイアログを生成
 			NodeFilterDialog dialog = new NodeFilterDialog(this.viewPart
 					.getSite().getShell());
@@ -68,18 +83,12 @@ public class NodeFilterAction implements IViewActionDelegate {
 
 				view.update(condition);
 			} else {
-				action.setChecked(false);
+				State state = command.getState(RegistryToggleState.STATE_ID);
+				state.setValue(false);
 			}
 		} else {
 			view.update(null);
 		}
+		return null;
 	}
-
-	/**
-	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
-	 *      org.eclipse.jface.viewers.ISelection)
-	 */
-	@Override
-	public void selectionChanged(IAction action, ISelection selection) {
-	}
-}
\ No newline at end of file
+}
