@@ -28,6 +28,7 @@ import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Button;
+import org.eclipse.swt.widgets.Combo;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Group;
@@ -35,30 +36,31 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.HinemosModuleConstant;
+import com.clustercontrol.bean.PriorityColorConstant;
+import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.ValidConstant;
-import com.clustercontrol.composite.RoleIdListComposite;
-import com.clustercontrol.composite.RoleIdListComposite.Mode;
 import com.clustercontrol.monitor.run.bean.MonitorTypeConstant;
 import com.clustercontrol.monitor.run.composite.MonitorBasicScopeComposite;
 import com.clustercontrol.monitor.run.composite.MonitorRuleComposite;
 import com.clustercontrol.monitor.run.dialog.CommonMonitorDialog;
 import com.clustercontrol.monitor.util.MonitorSettingEndpointWrapper;
 import com.clustercontrol.notify.composite.NotifyInfoComposite;
-import com.clustercontrol.notify.util.NotifyGroupIdGenerator;
 import com.clustercontrol.snmptrap.bean.MonitorTrapConstant;
-import com.clustercontrol.snmptrap.composite.OidListComposite;
+import com.clustercontrol.snmptrap.composite.TrapDefineCompositeDefine;
+import com.clustercontrol.snmptrap.composite.TrapDefineListComposite;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.monitor.InvalidRole_Exception;
 import com.clustercontrol.ws.monitor.MonitorDuplicate_Exception;
 import com.clustercontrol.ws.monitor.MonitorInfo;
-import com.clustercontrol.ws.monitor.MonitorTrapValueInfo;
 import com.clustercontrol.ws.monitor.TrapCheckInfo;
+import com.clustercontrol.ws.monitor.TrapValueInfo;
 
 /**
  * SNMPTRAP監視作成・変更ダイアログクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 2.1.0
  */
@@ -71,7 +73,7 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 	public static final int WIDTH_TITLE_SMALL = 4;
 	public static final int WIDTH_VALUE = 2;
 
-	
+
 
 	// 後でpackするためsizeXはダミーの値。
 	private final int sizeX = 750;
@@ -80,46 +82,48 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 	// ----- instance フィールド ----- //
 
 	/** コミュニティチェックボタン **/
-	private Button buttonCommunityCheckOff = null;
 	private Button buttonCommunityCheckOn = null;
 
 	/** コミュニティ名 */
 	private Text textCommunityName = null;
 
 	/** 文字コード変換ボタン **/
-	private Button buttonCharsetConvertOff = null;
 	private Button buttonCharsetConvertOn = null;
 
 	/** 変換文字コード名 */
 	private Text textCharsetName = null;
 
 	/** OIDテーブル */
-	private OidListComposite oidListComposite = null;
+	private TrapDefineListComposite tableDefineListComposite = null;
 
-	/****/
+	/** 未指定のトラップ受信時に通知する */
+	//チェックボックス
+	private Button buttonNotifyNonSpecifiedTrap = null;
+	//重要度
+	private Combo comboPriority = null;
 
 	// ----- コンストラクタ ----- //
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
 	 * @param monitorType 監視判定タイプ
 	 */
 	public SnmpTrapCreateDialog(Shell parent) {
-		super(parent);
+		super(parent, null);
 		setShellStyle(getShellStyle() | SWT.RESIZE | SWT.MAX);
 	}
 
 	/**
 	 * 変更用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
 	 * @param monitorId 変更する監視項目ID
 	 * @param updateFlg 更新するか否か（true:変更、false:新規登録）
 	 */
-	public SnmpTrapCreateDialog(Shell parent, String monitorId, boolean updateFlg) {
-		super(parent);
+	public SnmpTrapCreateDialog(Shell parent, String managerName, String monitorId, boolean updateFlg) {
+		super(parent, managerName);
 		setShellStyle(getShellStyle() | SWT.RESIZE | SWT.MAX);
 
 		this.monitorId = monitorId;
@@ -130,7 +134,7 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 
 	/**
 	 * ダイアログの初期サイズを返します。
-	 * 
+	 *
 	 * @return 初期サイズ
 	 */
 	@Override
@@ -140,7 +144,7 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のインスタンス
 	 */
@@ -172,11 +176,15 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		m_monitorBasic.setLayoutData(gridData);
+		if(this.managerName != null) {
+			m_monitorBasic.getManagerListComposite().setText(this.managerName);
+		}
 
 		/*
 		 * 条件グループ
 		 */
 		groupRule = new Group(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "rule", groupRule);
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
@@ -217,10 +225,14 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 
 		// 監視（有効／無効）
 		this.confirmMonitorValid = new Button(groupMonitor, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "confirmmonitorvalid", confirmMonitorValid);
+
 		gridData = new GridData();
-		gridData.horizontalSpan = MAX_COLUMN;
+		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
+		gridData.verticalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
+		gridData.grabExcessVerticalSpace = true;
 		this.confirmMonitorValid.setLayoutData(gridData);
 		this.confirmMonitorValid.setText(Messages.getString("monitor.run"));
 		this.confirmMonitorValid.addSelectionListener(new SelectionAdapter() {
@@ -240,13 +252,14 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		 */
 		// グループ
 		Group groupCheckRule = new Group(groupMonitor, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "checkrule", groupCheckRule);
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
 		layout.numColumns = MAX_COLUMN;
 		groupCheckRule.setLayout(layout);
 		gridData = new GridData();
-		gridData.horizontalSpan = MAX_COLUMN;
+		gridData.horizontalSpan = MAX_COLUMN - 2;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -258,13 +271,14 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		 * コミュニティ
 		 */
 		Group groupCommunity = new Group(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "community", groupCommunity);
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
 		layout.numColumns = MAX_COLUMN;
 		groupCommunity.setLayout(layout);
 		gridData = new GridData();
-		gridData.horizontalSpan = MAX_COLUMN;
+		gridData.horizontalSpan = MAX_COLUMN / 2;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -272,26 +286,38 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		groupCommunity.setLayoutData(gridData);
 		groupCommunity.setText(Messages.getString("community"));
 
+
 		// ボタン
-		this.buttonCommunityCheckOff = new Button(groupCommunity, SWT.RADIO);
+		this.buttonCommunityCheckOn = new Button(groupCommunity, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "communitycheckon", buttonCommunityCheckOn);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		this.buttonCommunityCheckOff.setLayoutData(gridData);
-		this.buttonCommunityCheckOff.setText(Messages.getString("community.no.check"));
-		// ボタン
-		this.buttonCommunityCheckOn = new Button(groupCommunity, SWT.RADIO);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.buttonCommunityCheckOn.setLayoutData(gridData);
-		this.buttonCommunityCheckOn.setText(Messages.getString("community.name") + " : ");
+		this.buttonCommunityCheckOn.setText(Messages.getString("valid"));
+		this.buttonCommunityCheckOn.addSelectionListener(new SelectionAdapter() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				update();
+			}
+		});
+
+		// ラベル
+		label = new Label(groupCommunity, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "communityname", label);
+		gridData = new GridData();
+		gridData.horizontalSpan = 6;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		label.setLayoutData(gridData);
+		label.setText(Messages.getString("community.name") + " : ");
+
 		// テキスト
 		this.textCommunityName = new Text(groupCommunity, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "communitiname", textCommunityName);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = 10;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.textCommunityName.setLayoutData(gridData);
@@ -301,40 +327,20 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 				update();
 			}
 		});
-		this.buttonCommunityCheckOff.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				update();
-				textCommunityName.setEnabled(false);
-			}
-		});
-		this.buttonCommunityCheckOn.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				update();
-				textCommunityName.setEnabled(true);
-			}
-		});
 
-		// 空白
-		label = new Label(groupCommunity, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = MAX_COLUMN - WIDTH_TITLE *3;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
 
 		/*
 		 * 文字コード
 		 */
 		Group groupCharset = new Group(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "charset", groupCharset);
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
 		layout.numColumns = MAX_COLUMN;
 		groupCharset.setLayout(layout);
 		gridData = new GridData();
-		gridData.horizontalSpan = MAX_COLUMN;
+		gridData.horizontalSpan = MAX_COLUMN / 2;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -342,26 +348,38 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		groupCharset.setLayoutData(gridData);
 		groupCharset.setText(Messages.getString("charset.convert"));
 
+
 		// ボタン
-		this.buttonCharsetConvertOff = new Button(groupCharset, SWT.RADIO);
+		this.buttonCharsetConvertOn = new Button(groupCharset, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "charsetconvert", buttonCharsetConvertOn);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		this.buttonCharsetConvertOff.setLayoutData(gridData);
-		this.buttonCharsetConvertOff.setText(Messages.getString("charset.no.convert"));
-		// ボタン
-		this.buttonCharsetConvertOn = new Button(groupCharset, SWT.RADIO);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE_WIDE;
+		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.buttonCharsetConvertOn.setLayoutData(gridData);
-		this.buttonCharsetConvertOn.setText(Messages.getString("charset.snmptrap.code") + " : ");
+		this.buttonCharsetConvertOn.setText(Messages.getString("valid"));
+		this.buttonCharsetConvertOn.addSelectionListener(new SelectionAdapter() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				update();
+			}
+		});
+
+		// ラベル
+		label = new Label(groupCharset, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "snmptrapcode", label);
+		gridData = new GridData();
+		gridData.horizontalSpan = 12;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		label.setLayoutData(gridData);
+		label.setText(Messages.getString("charset.snmptrap.code") + " : ");
+
 		// テキスト
 		this.textCharsetName = new Text(groupCharset, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "charsetname", textCharsetName);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE_SMALL;
+		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.textCharsetName.setLayoutData(gridData);
@@ -371,37 +389,15 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 				update();
 			}
 		});
-		this.buttonCharsetConvertOff.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				update();
-				textCharsetName.setEnabled(false);
-			}
-		});
-		this.buttonCharsetConvertOn.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				update();
-				textCharsetName.setEnabled(true);
-			}
-		});
-
-		// 空白
-		label = new Label(groupCharset, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = MAX_COLUMN - WIDTH_TITLE*3;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
 
 		/*
 		 * OIDテーブル
 		 */
 		Group groupOid = new Group(groupCheckRule, SWT.NONE);
-		layout = new GridLayout(1, true);
+		WidgetTestUtil.setTestId(this, "oid", groupOid);
+		layout = new GridLayout(MAX_COLUMN, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
-		layout.numColumns = 1;
 		groupOid.setLayout(layout);
 		gridData = new GridData();
 		gridData.horizontalSpan = MAX_COLUMN;
@@ -412,15 +408,60 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		groupOid.setLayoutData(gridData);
 		groupOid.setText("OID");
 
+		this.buttonNotifyNonSpecifiedTrap = new Button(groupOid, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "communitycheckoff", buttonNotifyNonSpecifiedTrap);
+		gridData = new GridData();
+		gridData.horizontalSpan = 10;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		this.buttonNotifyNonSpecifiedTrap.setLayoutData(gridData);
+		this.buttonNotifyNonSpecifiedTrap.setText(Messages.getString("monitor.snmptrap.notify.on.non.specified.trap.receipt"));
+		this.buttonNotifyNonSpecifiedTrap.addSelectionListener(new SelectionAdapter() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				update();
+			}
+		});
+
+		this.comboPriority = new Combo(groupOid, SWT.BORDER | SWT.LEFT | SWT.SINGLE | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "priority", comboPriority);
+		gridData = new GridData();
+		gridData.horizontalSpan = 3;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		this.comboPriority.setLayoutData(gridData);
+		this.comboPriority.add(PriorityConstant.STRING_CRITICAL);
+		this.comboPriority.add(PriorityConstant.STRING_WARNING);
+		this.comboPriority.add(PriorityConstant.STRING_INFO);
+		this.comboPriority.add(PriorityConstant.STRING_UNKNOWN);
+		this.comboPriority.add(PriorityConstant.STRING_NONE);
+		this.comboPriority.setText(PriorityConstant.STRING_UNKNOWN);
+		this.comboPriority.addModifyListener(new ModifyListener(){
+			@Override
+			public void modifyText(ModifyEvent arg0) {
+				update();
+			}
+		});
+
+		// 空白
+		label = new Label(groupOid, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space1", label);
+		gridData = new GridData();
+		gridData.horizontalSpan = MAX_COLUMN - 13;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		label.setLayoutData(gridData);
+
 		// テキスト
-		this.oidListComposite = new OidListComposite(groupOid, SWT.NONE);
+		this.tableDefineListComposite = new TrapDefineListComposite(groupOid, SWT.NONE, new TrapDefineCompositeDefine());
+		WidgetTestUtil.setTestId(this, "oidlist", tableDefineListComposite);
 		gridData = new GridData();
 		gridData.horizontalSpan = MAX_COLUMN;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		gridData.grabExcessVerticalSpace = true;
-		this.oidListComposite.setLayoutData(gridData);
+		this.tableDefineListComposite.setLayoutData(gridData);
 
 		/*
 		 * 通知グループ（監視グループの子グループ）
@@ -441,11 +482,13 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
 		gridData.horizontalAlignment = GridData.FILL;
+		gridData.heightHint = 120;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_notifyInfo.setLayoutData(gridData);
 
 		// ラインを引く
 		Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
+		WidgetTestUtil.setTestId(this, "line", line);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -471,7 +514,8 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		} else {
 			// 変更の場合、情報取得
 			try {
-				info = MonitorSettingEndpointWrapper.getMonitor(this.monitorId, HinemosModuleConstant.MONITOR_SNMPTRAP);
+				MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(getManagerName());
+				info = wrapper.getMonitor(this.monitorId, HinemosModuleConstant.MONITOR_SNMPTRAP);
 			} catch (Exception e) {
 				String errMessage = "";
 				if (e instanceof InvalidRole_Exception) {
@@ -497,7 +541,7 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 
 	/**
 	 * 各項目に入力値を設定します。
-	 * 
+	 *
 	 * @param monitor
 	 *            設定値として用いる監視情報
 	 */
@@ -511,13 +555,15 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		TrapCheckInfo checkInfo = monitor.getTrapCheckInfo();
 		if (checkInfo == null) {
 			checkInfo = new TrapCheckInfo();
-			checkInfo.setCheckMode(0);
-			checkInfo.setCommunityCheck(0);
-			checkInfo.setCharsetConvert(0);
+			checkInfo.setCommunityCheck(MonitorTrapConstant.COMMUNITY_CHECK_OFF);
+			checkInfo.setCharsetConvert(MonitorTrapConstant.CHARSET_CONVERT_OFF);
+			checkInfo.setNotifyofReceivingUnspecifiedFlg(true);
+			checkInfo.setPriorityUnspecified(PriorityColorConstant.TYPE_UNKNOWN);
+			monitor.setTrapCheckInfo(checkInfo);
 		}
-		List<MonitorTrapValueInfo> monitorTrapValueInfoList = monitor.getTrapValueInfo();
+		List<TrapValueInfo> monitorTrapValueInfoList = monitor.getTrapCheckInfo().getTrapValueInfos();
 		if (monitorTrapValueInfoList == null) {
-			monitorTrapValueInfoList = new ArrayList<MonitorTrapValueInfo>();
+			monitorTrapValueInfoList = new ArrayList<TrapValueInfo>();
 		}
 
 		// コミュニティ名
@@ -526,13 +572,8 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		}
 		if (checkInfo.getCommunityCheck() == MonitorTrapConstant.COMMUNITY_CHECK_ON) {
 			buttonCommunityCheckOn.setSelection(true);
-			buttonCommunityCheckOff.setSelection(false);
-			textCommunityName.setEnabled(true);
-		} else {
-			buttonCommunityCheckOn.setSelection(false);
-			buttonCommunityCheckOff.setSelection(true);
-			textCommunityName.setEnabled(false);
 		}
+		textCommunityName.setEnabled(buttonCommunityCheckOn.getSelection());
 
 		// 文字コード
 		if(checkInfo.getCharsetName() != null){
@@ -540,24 +581,22 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		}
 		if (checkInfo.getCharsetConvert() == MonitorTrapConstant.CHARSET_CONVERT_ON) {
 			buttonCharsetConvertOn.setSelection(true);
-			buttonCharsetConvertOff.setSelection(false);
-			textCharsetName.setEnabled(true);
-		} else {
-			buttonCharsetConvertOn.setSelection(false);
-			buttonCharsetConvertOff.setSelection(true);
-			textCharsetName.setEnabled(false);
 		}
+		textCharsetName.setEnabled(buttonCharsetConvertOn.getSelection());
 
-		//OID情報
-		oidListComposite.setCheckMode(checkInfo.getCheckMode());
-		oidListComposite.setMonitorId(monitor.getMonitorId());
-		oidListComposite.setOidList(monitor.getTrapValueInfo());
-		oidListComposite.update();
+		//未指定のトラップ受信時の処理
+		buttonNotifyNonSpecifiedTrap.setSelection(checkInfo.isNotifyofReceivingUnspecifiedFlg());
+		if(checkInfo.isNotifyofReceivingUnspecifiedFlg()){
+			comboPriority.select(comboPriority.indexOf(PriorityConstant.typeToString(checkInfo.getPriorityUnspecified())));
+		} else {
+			comboPriority.select(comboPriority.indexOf(PriorityConstant.typeToString(PriorityColorConstant.TYPE_UNKNOWN)));
+		}
+		tableDefineListComposite.setInputData(checkInfo.getTrapValueInfos());
 	}
 
 	/**
 	 * 入力値を用いて通知情報を生成します。
-	 * 
+	 *
 	 * @return 入力値を保持した通知情報
 	 */
 	@Override
@@ -573,14 +612,9 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 
 		// 監視条件 SNMPTRAP監視情報
 		TrapCheckInfo trapInfo = new TrapCheckInfo();
-		trapInfo.setCheckMode(0);
-		trapInfo.setCommunityCheck(0);
-		trapInfo.setCharsetConvert(0);
 		trapInfo.setMonitorId(monitorInfo.getMonitorId());
 		trapInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_SNMPTRAP);
 		monitorInfo.setTrapCheckInfo(trapInfo);
-		List<MonitorTrapValueInfo> monitorTrapValueInfoList = monitorInfo.getTrapValueInfo();
-		monitorTrapValueInfoList = new ArrayList<MonitorTrapValueInfo>();
 
 		// コミュニティ名
 		if (this.buttonCommunityCheckOn.getSelection()) {
@@ -588,8 +622,7 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		} else {
 			(monitorInfo.getTrapCheckInfo()).setCommunityCheck(MonitorTrapConstant.COMMUNITY_CHECK_OFF);
 		}
-		if (this.textCommunityName.getText() != null
-				&& !"".equals((this.textCommunityName.getText()).trim())) {
+		if (this.buttonCommunityCheckOn.getSelection() && !"".equals((this.textCommunityName.getText()).trim())) {
 			(monitorInfo.getTrapCheckInfo()).setCommunityName(textCommunityName.getText());
 		}
 
@@ -599,32 +632,23 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		} else {
 			(monitorInfo.getTrapCheckInfo()).setCharsetConvert(MonitorTrapConstant.CHARSET_CONVERT_OFF);
 		}
-		if (this.textCharsetName.getText() != null
-				&& !"".equals((this.textCharsetName.getText()).trim())) {
+		if (this.buttonCharsetConvertOn.getSelection() && !"".equals((this.textCharsetName.getText()).trim())) {
 			(monitorInfo.getTrapCheckInfo()).setCharsetName(textCharsetName.getText());
 		}
 
-		//OIDのチェック方法を設定します。
-
-		(monitorInfo.getTrapCheckInfo()).setCheckMode(oidListComposite.getCheckMode());
-
-		//OID情報
-		List<MonitorTrapValueInfo> monitorTrapValueInfoList_old = monitorInfo.getTrapValueInfo();
-		monitorTrapValueInfoList_old.clear();
-		if (oidListComposite.getOidList() != null) {
-			monitorTrapValueInfoList_old.addAll(oidListComposite.getOidList());
+		// 未指定のトラップ情報受信時の処理
+		trapInfo.setNotifyofReceivingUnspecifiedFlg(buttonNotifyNonSpecifiedTrap.getSelection());
+		if(buttonNotifyNonSpecifiedTrap.getSelection()){
+			trapInfo.setPriorityUnspecified(PriorityConstant.stringToType(comboPriority.getText()));
 		}
-		for(int i = 0; i < monitorInfo.getTrapValueInfo().size(); i++){
-			MonitorTrapValueInfo oidInfo = monitorInfo.getTrapValueInfo().get(i);
-			if(oidInfo.getMonitorId() == null ||
-					oidInfo.getMonitorId().equals(monitorInfo.getMonitorId())){
-				oidInfo.setMonitorId(monitorInfo.getMonitorId());
-			}
+		List<TrapValueInfo> monitorTrapValueInfoList_old = monitorInfo.getTrapCheckInfo().getTrapValueInfos();
+		monitorTrapValueInfoList_old.clear();
+		if (tableDefineListComposite.getItems() != null) {
+			monitorTrapValueInfoList_old.addAll(tableDefineListComposite.getItems());
 		}
 
 		// 通知関連情報とアプリケーションの設定
 		// 通知グループIDの設定
-		monitorInfo.setNotifyGroupId(NotifyGroupIdGenerator.createNotifyGroupId(HinemosModuleConstant.MONITOR_SNMPTRAP, monitorInfo.getMonitorId()));
 		validateResult = this.m_notifyInfo.createInputData(monitorInfo);
 		if (validateResult != null) {
 			if(validateResult.getID() == null){	// 通知ID警告用出力
@@ -653,9 +677,9 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -663,12 +687,14 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		boolean result = false;
 
 		MonitorInfo info = this.inputData;
+		String managerName = this.getManagerName();
+		MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(managerName);
 		if(info != null){
-			String[] args = { info.getMonitorId() };
+			String[] args = { info.getMonitorId(), managerName };
 			if(!this.updateFlg){
 				// 作成の場合
 				try {
-					result = MonitorSettingEndpointWrapper.addMonitor(info);
+					result = wrapper.addMonitor(info);
 
 					if(result){
 						MessageDialog.openInformation(
@@ -709,7 +735,7 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 				// 変更の場合
 				String errMessage = "";
 				try {
-					result = MonitorSettingEndpointWrapper.modifyMonitor(info);
+					result = wrapper.modifyMonitor(info);
 				} catch (InvalidRole_Exception e) {
 					// アクセス権なしの場合、エラーダイアログを表示する
 					MessageDialog.openInformation(
@@ -739,18 +765,18 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 
 	/**
 	 * 監視エリアを有効/無効化します。
-	 * 
+	 *
 	 */
 	@Override
 	protected void setMonitorEnabled(boolean enabled){
 		super.setMonitorEnabled(enabled);
-		buttonCommunityCheckOff.setEnabled(enabled);
 		buttonCommunityCheckOn.setEnabled(enabled);
 		textCommunityName.setEnabled(enabled);
-		buttonCharsetConvertOff.setEnabled(enabled);
 		buttonCharsetConvertOn.setEnabled(enabled);
 		textCharsetName.setEnabled(enabled);
-		oidListComposite.setEnabled(enabled);
+		buttonNotifyNonSpecifiedTrap.setEnabled(enabled);
+		tableDefineListComposite.setEnabled(enabled);
+		update();
 	}
 
 	/**
@@ -760,18 +786,23 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 	protected void update() {
 		super.update();
 
+		textCommunityName.setEnabled(buttonCommunityCheckOn.getEnabled() && buttonCommunityCheckOn.getSelection());
+		textCharsetName.setEnabled(buttonCharsetConvertOn.getEnabled() &&buttonCharsetConvertOn.getSelection());
+
 		// コミュニティチェックボタンが有効な場合のみ
-		if(this.buttonCommunityCheckOn.getSelection() && "".equals(this.textCommunityName.getText())){
+		if(this.textCommunityName.getEnabled() && "".equals(this.textCommunityName.getText())){
 			this.textCommunityName.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
 		}else{
 			this.textCommunityName.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
 		}
 
 		// 文字コードチェックボタンが有効な場合のみ
-		if(this.buttonCharsetConvertOn.getSelection() && "".equals(this.textCharsetName.getText())){
+		if(this.textCharsetName.getEnabled() && "".equals(this.textCharsetName.getText())){
 			this.textCharsetName.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
 		}else{
 			this.textCharsetName.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
 		}
+
+		comboPriority.setEnabled(buttonNotifyNonSpecifiedTrap.getEnabled() && buttonNotifyNonSpecifiedTrap.getSelection());
 	}
-}
\ No newline at end of file
+}
