@@ -25,7 +25,7 @@ import com.clustercontrol.ws.monitor.MonitorInfo;
 
 /**
  * SQL監視情報を登録するクライアント側アクションクラス<BR>
- * 
+ *
  * @version 2.2.0
  * @since 2.0.0
  */
@@ -33,16 +33,18 @@ public class AddSql {
 
 	/**
 	 * SQL監視情報を追加します。
-	 * 
+	 *
+	 * @param managerName マネージャ名
 	 * @param info SQL監視情報
 	 * @return 登録に成功した場合、true
 	 */
-	public boolean add(MonitorInfo info) {
+	public boolean add(String managerName, MonitorInfo info) {
 
 		boolean result = false;
-		String[] args = { info.getMonitorId() };
+		String[] args = { info.getMonitorId(), managerName };
 		try {
-			result = MonitorSettingEndpointWrapper.addMonitor(info);
+			MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(managerName);
+			result = wrapper.addMonitor(info);
 
 			if(result){
 				MessageDialog.openInformation(
@@ -82,4 +84,4 @@ public class AddSql {
 
 		return result;
 	}
-}
\ No newline at end of file
+}
