@@ -31,11 +31,12 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.composite.TextWithParameterComposite;
+import com.clustercontrol.monitor.bean.MonitorTypeMstConstant;
 import com.clustercontrol.monitor.run.dialog.CommonMonitorStringDialog;
-import com.clustercontrol.notify.util.NotifyGroupIdGenerator;
 import com.clustercontrol.sql.action.AddSql;
 import com.clustercontrol.sql.action.GetJdbc;
 import com.clustercontrol.sql.action.GetSql;
@@ -46,7 +47,7 @@ import com.clustercontrol.ws.monitor.SqlCheckInfo;
 
 /**
  * SQL監視（文字列）作成・変更ダイアログクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 2.0.0
  */
@@ -67,39 +68,45 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 	/** クエリ */
 	private Text textQuery = null;
 
+	/** マネージャ名 */
+	private String managerName = null;
 	// ----- コンストラクタ ----- //
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
 	 */
 	public SqlStringCreateDialog(Shell parent) {
-		super(parent);
+		super(parent, null);
 	}
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
+	 * @param マネージャ名
 	 * @param monitorType 監視判定タイプ
 	 */
-	public SqlStringCreateDialog(Shell parent, int monitorType) {
-		super(parent);
+	public SqlStringCreateDialog(Shell parent, String managerName, int monitorType) {
+		super(parent, managerName);
 
+		this.managerName = managerName;
 		this.m_monitorType = monitorType;
 	}
 
 	/**
 	 * 変更用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
+	 * @param マネージャ名
 	 * @param monitorId 変更する監視項目ID
 	 * @param updateFlg 更新するか否か（true:変更、false:新規登録）
 	 */
-	public SqlStringCreateDialog(Shell parent, String monitorId, boolean updateFlg) {
-		super(parent);
+	public SqlStringCreateDialog(Shell parent, String managerName, String monitorId, boolean updateFlg) {
+		super(parent, managerName);
 
+		this.managerName = managerName;
 		this.monitorId = monitorId;
 		this.updateFlg = updateFlg;
 	}
@@ -108,7 +115,7 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のインスタンス
 	 */
@@ -129,13 +136,14 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 		 * チェック設定グループ（条件グループの子グループ）
 		 */
 		Group groupCheckRule = new Group(groupRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "checkrule", groupCheckRule);
 		GridLayout layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
-		layout.numColumns = 15;
+		layout.numColumns = BASIC_UNIT;
 		groupCheckRule.setLayout(layout);
 		gridData = new GridData();
-		gridData.horizontalSpan = 15;
+		gridData.horizontalSpan = BASIC_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		groupCheckRule.setLayoutData(gridData);
@@ -144,16 +152,18 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 		// 接続文字列
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "connectionurl", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("connection.url") + " : ");
 		// テキスト
 		this.textUrl = new TextWithParameterComposite(groupCheckRule, SWT.BORDER | SWT.LEFT | SWT.SINGLE);
+		WidgetTestUtil.setTestId(this, "url", textUrl);
 		gridData = new GridData();
-		gridData.horizontalSpan = 10;
+		gridData.horizontalSpan = LONG_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.textUrl.setLayoutData(gridData);
@@ -169,8 +179,9 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 
 		// 空白
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space1", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = 1;
+		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -178,20 +189,22 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 		// 接続先DB
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "connectiondb", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("connection.db") + " : ");
 		// コンボ
 		this.textJdbcDriver = new Combo(groupCheckRule, SWT.BORDER | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "jdbcdriver", textJdbcDriver);
 		gridData = new GridData();
-		gridData.horizontalSpan = 10;
+		gridData.horizontalSpan = LONG_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.textJdbcDriver.setLayoutData(gridData);
-		List<List> list = getJdbcDriver();
+		List<List<String>> list = getJdbcDriver();
 		if(list != null){
 			for(int i = 0; i < list.size(); i++){
 				List<String> driver = list.get(i);
@@ -210,8 +223,9 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 
 		// 空白
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space2", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = 1;
+		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -219,16 +233,18 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 		// ユーザ
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "user", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("user.id") + " : ");
 		// テキスト
 		this.textUser = new Text(groupCheckRule, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "user", textUser);
 		gridData = new GridData();
-		gridData.horizontalSpan = 10;
+		gridData.horizontalSpan = LONG_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.textUser.setLayoutData(gridData);
@@ -241,8 +257,9 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 
 		// 空白
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space3", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = 1;
+		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -250,16 +267,18 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 		// パスワード
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "password", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("password") + " : ");
 		// テキスト
 		this.textPassword = new Text(groupCheckRule, SWT.BORDER | SWT.LEFT | SWT.PASSWORD);
+		WidgetTestUtil.setTestId(this, "password", textPassword);
 		gridData = new GridData();
-		gridData.horizontalSpan = 10;
+		gridData.horizontalSpan = LONG_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.textPassword.setLayoutData(gridData);
@@ -272,8 +291,9 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 
 		// 空白
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space4", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = 1;
+		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -281,16 +301,18 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 		// SQL文
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "sqlstring", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("sql.string") + " : ");
 		// テキスト
 		this.textQuery= new Text(groupCheckRule, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "query", textQuery);
 		gridData = new GridData();
-		gridData.horizontalSpan = 10;
+		gridData.horizontalSpan = LONG_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.textQuery.setLayoutData(gridData);
@@ -303,8 +325,9 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 
 		// 空白
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space5", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = 1;
+		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -321,7 +344,7 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 		}
 		else{
 			// 変更の場合、情報取得
-			info = new GetSql().getSql(this.monitorId);
+			info = new GetSql().getSql(this.managerName, this.monitorId, MonitorTypeMstConstant.MONITOR_TYPE_STRING);
 		}
 		this.setInputData(info);
 
@@ -330,7 +353,7 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	@Override
 	public void update(){
@@ -366,7 +389,7 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * 各項目に入力値を設定します。
-	 * 
+	 *
 	 * @param monitor
 	 *            設定値として用いる監視情報
 	 */
@@ -390,13 +413,13 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 				this.textPassword.setText(sqlInfo.getPassword());
 			}
 			if (sqlInfo.getJdbcDriver() != null) {
-				List<List> list = getJdbcDriver();
+				List<List<String>> list = getJdbcDriver();
 				if(list != null){
 					for(int i = 0; i < list.size(); i++){
-						List driver = list.get(i);
-						String className = (String)driver.get(1);
+						List<String> driver = list.get(i);
+						String className = driver.get(1);
 						if(className.equals(sqlInfo.getJdbcDriver())){
-							this.textJdbcDriver.setText((String)driver.get(0));
+							this.textJdbcDriver.setText(driver.get(0));
 							break;
 						}
 					}
@@ -417,7 +440,7 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * 入力値を用いて通知情報を生成します。
-	 * 
+	 *
 	 * @return 入力値を保持した通知情報
 	 */
 	@Override
@@ -428,11 +451,11 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 		}
 
 		// SQL監視（文字列）固有情報を設定
-		monitorInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_SQL);
+		monitorInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_SQL_S);
 
 		// 監視条件 SQL監視情報
 		SqlCheckInfo sqlInfo = new SqlCheckInfo();
-		sqlInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_SQL);
+		sqlInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_SQL_S);
 		sqlInfo.setMonitorId(monitorInfo.getMonitorId());
 
 		//接続先URL
@@ -460,13 +483,13 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 		if (this.textJdbcDriver.getText() != null
 				&& !"".equals((this.textJdbcDriver.getText()).trim())) {
 
-			List<List> list = getJdbcDriver();
+			List<List<String>> list = getJdbcDriver();
 			if(list != null){
 				for(int i = 0; i < list.size(); i++){
-					List driver = list.get(i);
-					String name = (String)driver.get(0);
+					List<String> driver = list.get(i);
+					String name = driver.get(0);
 					if(name.equals(this.textJdbcDriver.getText())){
-						sqlInfo.setJdbcDriver((String)driver.get(1));
+						sqlInfo.setJdbcDriver(driver.get(1));
 						break;
 					}
 				}
@@ -481,8 +504,6 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 		}
 
 		// 通知関連情報とアプリケーションの設定
-		//通知グループIDの設定
-		monitorInfo.setNotifyGroupId(NotifyGroupIdGenerator.createNotifyGroupId(HinemosModuleConstant.MONITOR_SQL,monitorInfo.getMonitorId()));
 		validateResult = m_notifyInfo.createInputData(monitorInfo);
 		if (validateResult != null) {
 			if(validateResult.getID() == null){	// 通知ID警告用出力
@@ -501,9 +522,9 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -511,14 +532,15 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 		boolean result = false;
 
 		MonitorInfo info = this.inputData;
+		String managerName = this.getManagerName();
 		if(info != null){
 			if(!this.updateFlg){
 				// 作成の場合
-				result = new AddSql().add(info);
+				result = new AddSql().add(managerName, info);
 			}
 			else{
 				// 変更の場合
-				result = new ModifySql().modify(info);
+				result = new ModifySql().modify(managerName, info);
 			}
 		}
 
@@ -529,7 +551,7 @@ public class SqlStringCreateDialog extends CommonMonitorStringDialog {
 	 * JDBC情報を返却します
 	 * @return
 	 */
-	private List<List> getJdbcDriver(){
-		return GetJdbc.getJdbcDriverList();
+	private List<List<String>> getJdbcDriver(){
+		return GetJdbc.getJdbcDriverList(m_monitorBasic.getManagerListComposite().getText());
 	}
-}
\ No newline at end of file
+}
