@@ -20,19 +20,16 @@ import java.sql.SQLException;
 import java.text.NumberFormat;
 import java.util.Map;
 
-import javax.ejb.CreateException;
-import javax.ejb.FinderException;
-import javax.naming.NamingException;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.monitor.run.factory.RunMonitor;
 import com.clustercontrol.monitor.run.factory.RunMonitorStringValueType;
 import com.clustercontrol.repository.util.RepositoryUtil;
-import com.clustercontrol.sql.ejb.entity.MonitorSqlInfoLocal;
-import com.clustercontrol.sql.ejb.entity.MonitorSqlInfoUtil;
+import com.clustercontrol.sql.model.MonitorSqlInfoEntity;
 import com.clustercontrol.sql.util.AccessDB;
+import com.clustercontrol.sql.util.QueryUtil;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.StringBinder;
 
@@ -49,7 +46,7 @@ public class RunMonitorSqlString extends RunMonitorStringValueType {
 	private static final String MESSAGE_ID_UNKNOWN = "100";
 
 	/** SQL監視情報 */
-	private MonitorSqlInfoLocal m_sql = null;
+	private MonitorSqlInfoEntity m_sql = null;
 
 	/** 接続文字列 */
 	private String m_url = null;
@@ -76,7 +73,7 @@ public class RunMonitorSqlString extends RunMonitorStringValueType {
 	 * コンストラクタ
 	 * 
 	 */
-	public RunMonitorSqlString() throws NamingException, CreateException{
+	public RunMonitorSqlString() {
 		super();
 	}
 
@@ -87,7 +84,7 @@ public class RunMonitorSqlString extends RunMonitorStringValueType {
 	 * @see com.clustercontrol.monitor.run.util.CallableTask
 	 */
 	@Override
-	protected RunMonitor createMonitorInstance() throws NamingException, CreateException{
+	protected RunMonitor createMonitorInstance() {
 		return new RunMonitorSqlString();
 	}
 
@@ -143,14 +140,14 @@ public class RunMonitorSqlString extends RunMonitorStringValueType {
 
 					NumberFormat numberFormat = NumberFormat.getNumberInstance();
 					m_messageOrg = Messages.getString("record.value") + " : " + m_value + ", " +
-					Messages.getString("records.number") + " : " + numberFormat.format(number);
+							Messages.getString("records.number") + " : " + numberFormat.format(number);
 					m_messageOrg += "\n" + Messages.getString("connection.url") + " : " + url;
 
 					result = true;
 				}
 				else{
 					//SELECT文以外はエラー
-					m_log.debug("collect(): " + Messages.getString("message.sql.5"));
+					m_log.info("collect(): " + Messages.getString("message.sql.5"));
 					m_unKnownMessage = Messages.getString("message.sql.5");
 					m_messageOrg = Messages.getString("sql.string") + " : " + m_query;
 					m_messageOrg += "\n" + Messages.getString("connection.url") + " : " + url;
@@ -158,17 +155,21 @@ public class RunMonitorSqlString extends RunMonitorStringValueType {
 			}
 			else{
 				//SELECT文以外はエラー
-				m_log.debug("collect(): " + Messages.getString("message.sql.5"));
+				m_log.info("collect(): " + Messages.getString("message.sql.5"));
 				m_unKnownMessage = Messages.getString("message.sql.5");
 				m_messageOrg = Messages.getString("sql.string") + " : " + m_query;
 				m_messageOrg += "\n" + Messages.getString("connection.url") + " : " + url;
 			}
 		} catch (ClassNotFoundException e) {
+			m_log.info("collect() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 			m_unKnownMessage = Messages.getString("message.sql.6");
 			m_messageOrg = Messages.getString("sql.string") + " : " + m_query + " (" + e.getMessage() + ")";
 			m_messageOrg += "\n" + Messages.getString("connection.url") + " : " + url;
 		} catch (SQLException e) {
 			// SQL実行エラー
+			m_log.info("collect() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 			m_unKnownMessage = Messages.getString("message.sql.7");
 			m_messageOrg = Messages.getString("sql.string") + " : " + m_query + " (" + e.getMessage() + ")";
 			m_messageOrg += "\n" + Messages.getString("connection.url") + " : " + url;
@@ -182,7 +183,8 @@ public class RunMonitorSqlString extends RunMonitorStringValueType {
 					access.terminate();
 				}
 			} catch (SQLException e) {
-				m_log.error("collect(): ", e);
+				m_log.warn("collect() : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 			}
 		}
 		return result;
@@ -193,17 +195,17 @@ public class RunMonitorSqlString extends RunMonitorStringValueType {
 	 * @see com.clustercontrol.monitor.run.factory.OperationNumericValueInfo#setMonitorAdditionInfo()
 	 */
 	@Override
-	protected void setCheckInfo() throws FinderException, NamingException{
+	protected void setCheckInfo() throws MonitorNotFound {
 
 		// SQL監視情報を取得
-		m_sql = MonitorSqlInfoUtil.getLocalHome().findByPrimaryKey(m_monitorId);
+		m_sql = QueryUtil.getMonitorSqlInfoPK(m_monitorId);
 
 		// SQL監視情報を設定
-		m_url = m_sql.getConnection_url().trim();
-		m_user = m_sql.getConnection_user().trim();
-		m_password = m_sql.getConnection_password().trim();
+		m_url = m_sql.getConnectionUrl().trim();
+		m_user = m_sql.getConnectionUser().trim();
+		m_password = m_sql.getConnectionPassword().trim();
 		m_query = m_sql.getQuery().trim();
-		m_jdbcDriver = m_sql.getJdbc_driver().trim();
+		m_jdbcDriver = m_sql.getJdbcDriver().trim();
 	}
 
 	/* (非 Javadoc)
