@@ -9,7 +9,6 @@ import org.eclipse.swt.widgets.Shell;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.monitor.run.dialog.CommonMonitorStringDialog;
 import com.clustercontrol.monitor.util.MonitorSettingEndpointWrapper;
-import com.clustercontrol.notify.util.NotifyGroupIdGenerator;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.monitor.InvalidRole_Exception;
 import com.clustercontrol.ws.monitor.MonitorDuplicate_Exception;
@@ -32,23 +31,23 @@ public class SystemlogStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のシェルオブジェクト
 	 */
 	public SystemlogStringCreateDialog(Shell parent) {
-		super(parent);
+		super(parent, null);
 		logLineFlag = true;
 	}
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
 	 * @param monitorType 監視判定タイプ
 	 */
-	public SystemlogStringCreateDialog(Shell parent, int monitorType) {
-		super(parent);
+	public SystemlogStringCreateDialog(Shell parent, String managerName, int monitorType) {
+		super(parent, managerName);
 
 		logLineFlag = true;
 		this.m_monitorType = monitorType;
@@ -56,13 +55,13 @@ public class SystemlogStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * 変更用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
 	 * @param monitorId 変更する監視項目ID
 	 * @param updateFlg 更新するか否か（true:変更、false:新規登録）
 	 */
-	public SystemlogStringCreateDialog(Shell parent, String monitorId, boolean updateFlg) {
-		super(parent);
+	public SystemlogStringCreateDialog(Shell parent, String managerName, String monitorId, boolean updateFlg) {
+		super(parent, managerName);
 
 		logLineFlag = true;
 		this.monitorId = monitorId;
@@ -73,7 +72,7 @@ public class SystemlogStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親のインスタンス
 	 */
 	@Override
@@ -101,7 +100,8 @@ public class SystemlogStringCreateDialog extends CommonMonitorStringDialog {
 		} else {
 			// 変更の場合、情報取得
 			try {
-				info = MonitorSettingEndpointWrapper.getMonitor(this.monitorId, HinemosModuleConstant.MONITOR_SYSTEMLOG);
+				MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(managerName);
+				info = wrapper.getMonitor(this.monitorId, HinemosModuleConstant.MONITOR_SYSTEMLOG);
 			} catch (InvalidRole_Exception e) {
 				// アクセス権なしの場合、エラーダイアログを表示する
 				MessageDialog.openInformation(
@@ -122,7 +122,7 @@ public class SystemlogStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * 各項目に入力値を設定します。
-	 * 
+	 *
 	 * @param monitor 設定値として用いる監視情報
 	 */
 	@Override
@@ -136,7 +136,7 @@ public class SystemlogStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * 入力値を用いて通知情報を生成します。
-	 * 
+	 *
 	 * @return 入力値を保持した通知情報
 	 */
 	@Override
@@ -156,8 +156,6 @@ public class SystemlogStringCreateDialog extends CommonMonitorStringDialog {
 		}
 
 		// 通知関連情報とアプリケーションの設定
-		// 通知グループIDの設定
-		monitorInfo.setNotifyGroupId(NotifyGroupIdGenerator.createNotifyGroupId(HinemosModuleConstant.MONITOR_SYSTEMLOG, monitorInfo.getMonitorId()));
 		validateResult = m_notifyInfo.createInputData(monitorInfo);
 		if (validateResult != null) {
 			if(validateResult.getID() == null){	// 通知ID警告用出力
@@ -176,9 +174,9 @@ public class SystemlogStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -186,13 +184,15 @@ public class SystemlogStringCreateDialog extends CommonMonitorStringDialog {
 		boolean result = false;
 
 		MonitorInfo info = this.inputData;
+		String managerName = this.getManagerName();
 
 		if(info != null){
-			String[] args = { info.getMonitorId() };
+			String[] args = { info.getMonitorId(), managerName };
+			MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(managerName);
 			if(!this.updateFlg){
 				// 作成の場合
 				try {
-					result = MonitorSettingEndpointWrapper.addMonitor(info);
+					result = wrapper.addMonitor(info);
 
 					if(result){
 						MessageDialog.openInformation(
@@ -231,7 +231,7 @@ public class SystemlogStringCreateDialog extends CommonMonitorStringDialog {
 				// 変更の場合
 				String errMessage = "";
 				try {
-					result = MonitorSettingEndpointWrapper.modifyMonitor(info);
+					result = wrapper.modifyMonitor(info);
 				} catch (InvalidRole_Exception e) {
 					// アクセス権なしの場合、エラーダイアログを表示する
 					MessageDialog.openInformation(
