@@ -15,10 +15,6 @@
 
 package com.clustercontrol.systemlog.factory;
 
-import javax.ejb.FinderException;
-import javax.ejb.RemoveException;
-import javax.naming.NamingException;
-
 import com.clustercontrol.monitor.run.factory.DeleteMonitor;
 
 /**
@@ -33,7 +29,7 @@ public class DeleteMonitorSystemlog extends DeleteMonitor{
 	 * @see com.clustercontrol.monitor.run.factory.DeleteMonitor#deleteCheckInfo()
 	 */
 	@Override
-	protected boolean deleteCheckInfo() throws FinderException, RemoveException, NamingException {
+	protected boolean deleteCheckInfo() {
 
 		// システムログ監視のチェック条件はないため、常にtrue
 		return true;
