@@ -15,9 +15,6 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.winservice.factory;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.monitor.run.factory.AddMonitor;
@@ -36,8 +33,6 @@ import com.clustercontrol.winservice.model.MonitorWinserviceInfoEntity;
  */
 public class AddMonitorWinService extends AddMonitorTruthValueType{
 
-	private static Log m_log = LogFactory.getLog(AddMonitorWinService.class);
-
 	/* (非 Javadoc)
 	 * @see com.clustercontrol.monitor.run.factory.AddMonitor#addCheckInfo()
 	 */
