@@ -26,23 +26,26 @@ import javax.xml.ws.WebServiceContext;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.accesscontrol.bean.FunctionConstant;
+import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.SystemPrivilegeMode;
+import com.clustercontrol.accesscontrol.bean.SystemPrivilegeInfo;
+import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.fault.FacilityDuplicate;
 import com.clustercontrol.fault.FacilityNotFound;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.InvalidSetting;
 import com.clustercontrol.fault.InvalidUserPass;
+import com.clustercontrol.fault.SnmpResponseError;
 import com.clustercontrol.fault.UsedFacility;
-import com.clustercontrol.accesscontrol.bean.FunctionConstant;
-import com.clustercontrol.accesscontrol.bean.SystemPrivilegeInfo;
-import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.SystemPrivilegeMode;
-import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.repository.bean.AgentStatusInfo;
 import com.clustercontrol.repository.bean.FacilityInfo;
 import com.clustercontrol.repository.bean.FacilityTreeItem;
 import com.clustercontrol.repository.bean.NodeInfo;
+import com.clustercontrol.repository.bean.NodeInfoDeviceSearch;
 import com.clustercontrol.repository.bean.RepositoryTableInfo;
 import com.clustercontrol.repository.bean.ScopeInfo;
+import com.clustercontrol.repository.factory.NodeSearcher;
 import com.clustercontrol.repository.session.RepositoryControllerBean;
 import com.clustercontrol.repository.util.RepositoryUtil;
 import com.clustercontrol.util.StringBinder;
@@ -61,9 +64,9 @@ public class RepositoryEndpoint {
 
 	/**
 	 * echo(WebサービスAPI疎通用)
-	 * 
+	 *
 	 * 権限必要なし（ユーザ名チェックのみ実施）
-	 * 
+	 *
 	 * @param str
 	 * @return
 	 * @throws InvalidUserPass
@@ -87,12 +90,12 @@ public class RepositoryEndpoint {
 	 * このメソッドはクライアントの画面情報を作成するために
 	 * 呼び出されます。クライアントのロケールを引数をして必要とします。<BR>
 	 * （最上位のスコープという表記をscopeをいう表記を切り替えるため。）
-	 * 
+	 *
 	 * RepositoryRead権限が必要
-	 * 
+	 *
 	 * @version 1.0.0
 	 * @since 1.0.0
-	 * 
+	 *
 	 * @param ownerRoleId オーナーロールID
 	 * @return FacilityTreeItemの階層オブジェクト
 	 * @throws HinemosUnknown
@@ -118,12 +121,12 @@ public class RepositoryEndpoint {
 	 * 取得したファシリティツリーには割り当てられたノードを含みます。<BR>
 	 * このメソッドはクライアントの画面情報を作成するために
 	 * 呼び出されます。クライアントのロケールを引数をして必要とします。<BR>
-	 * 
+	 *
 	 * RepositoryRead権限が必要
-	 * 
+	 *
 	 * @version 1.0.0
 	 * @since 1.0.0
-	 * 
+	 *
 	 * @param facilityId ファシリティID
 	 * @param ownerRoleId オーナーロールID
 	 * @return FacilityTreeItemの階層オブジェクト
@@ -155,9 +158,9 @@ public class RepositoryEndpoint {
 	 * このメソッドはクライアントの画面情報を作成するために
 	 * 呼び出されます。クライアントのロケールを引数をして必要とします。<BR>
 	 * （最上位のスコープという表記をscopeをいう表記を切り替えるため。）
-	 * 
+	 *
 	 * RepositoryRead権限が必要
-	 * 
+	 *
 	 * @param ownerRoleId オーナーロールID
 	 * @return FacilityTreeItemの階層オブジェクト
 	 * @throws HinemosUnknown
@@ -191,12 +194,12 @@ public class RepositoryEndpoint {
 	 * ・IPアドレスバージョン、IPv4, Ipv6
 	 * ・説明
 	 * getNodeFacilityIdListを利用すること。（getNodeと組み合わせて利用する。）
-	 * 
+	 *
 	 * RepositoryRead権限が必要
-	 * 
+	 *
 	 * @version 1.0.0
 	 * @since 1.0.0
-	 * 
+	 *
 	 * @return NodeInfoの配列
 	 * @throws HinemosUnknown
 	 * @throws InvalidRole
@@ -216,16 +219,16 @@ public class RepositoryEndpoint {
 	}
 	/**
 	 * ノード一覧を取得します。<BR>
-	 * 
+	 *
 	 * クライアントなどで検索した場合に呼ばれ、該当するノード一覧を取得します。<BR>
 	 * 引数はNodeInfoであり、"ファシリティID"、"ファシリティ名"、"説明"、
 	 * "IPアドレス"、"OS名"、"OSリリース"、"管理者"、"連絡先"が１つ以上含まれており、
 	 * その条件を元に該当するノードを戻り値とします。<BR>
 	 * 戻り値はNodeInfoのArrayListで、NodeInfoには
 	 * ノードの"ファシリティID"、"ファシリティ名"、"説明"のみ格納されています。<BR>
-	 * 
+	 *
 	 * RepositoryRead権限が必要
-	 * 
+	 *
 	 * @param property　検索条件のプロパティ
 	 * @return NodeInfoの配列
 	 * @throws HinemosUnknown
@@ -252,20 +255,20 @@ public class RepositoryEndpoint {
 	}
 
 	/**
-	 * 
+	 *
 	 * 監視・ジョブ等の処理を実行する対象となる、ファシリティIDのリストを取得します。
 	 * 引数で指定されたファシリティIDが、ノードかスコープによって、以下のようなリストを取得します。
-	 * 
+	 *
 	 * ノードの場合
 	 *   引数で指定されたfacilityIdが格納されたArrauList
 	 *   ただし、管理対象（有効/無効フラグが真）の場合のみ
-	 * 
+	 *
 	 * スコープの場合
 	 *   配下に含まれるノードのファシリティIDが格納されたArrayList
 	 *   ただし、管理対象（有効/無効フラグが真）のみ
-	 * 
+	 *
 	 * RepositoryRead権限が必要
-	 * 
+	 *
 	 * @param facilityId 処理を実行する対象となるファシリティID
 	 * @param ownerRoleId オーナーロールID
 	 * @return 有効なノードのリスト（有効なノードがひとつも含まれない場合は空のリスト）
@@ -293,11 +296,11 @@ public class RepositoryEndpoint {
 
 	/**
 	 * ノードの詳細プロパティを取得します。<BR>
-	 * 
+	 *
 	 * faciliyIDで指定されるノードの詳細プロパティを取得します。<BR>
-	 * 
+	 *
 	 * RepositoryRead権限が必要
-	 * 
+	 *
 	 * @param facilityId ファシリティID
 	 * @param locale クライアントのロケール
 	 * @return ノード情報プロパティ
@@ -326,13 +329,13 @@ public class RepositoryEndpoint {
 
 	/**
 	 * ファシリティパスを取得します。<BR>
-	 * 
+	 *
 	 * 第一引数がノードの場合は、パスではなく、ファシリティ名。<BR>
 	 * 第一引数がスコープの場合は、第二引数との相対的なファシリティパスを取得します。<BR>
 	 * (例　○○スコープ>××システム>DBサーバ)<BR>
-	 * 
+	 *
 	 * RepositoryRead権限が必要
-	 * 
+	 *
 	 * @param facilityId ファシリティID
 	 * @param parentFacilityId 上位のファシリティID
 	 * @return String ファシリティパス
@@ -363,28 +366,36 @@ public class RepositoryEndpoint {
 
 	/**
 	 * SNMPを利用してノードの情報を取得します。<BR>
-	 * 
-	 * 
+	 *
+	 *
 	 * クライアントからSNMPで検出を行った際に呼び出されるメソッドです。<BR>
 	 * SNMPポーリングにより、ノード詳細プロパティをセットし、クライアントに返す。
 	 * 戻り値はNodeInfo
-	 * 
+	 *
 	 * RepositoryRead権限が必要
-	 * 
-	 * @param pollingData ポーリング対象のIPアドレス、コミュニティ名、バージョン、ポート
+	 *
+	 * @param pollingData ポーリング対象のIPアドレス、コミュニティ名、バージョン、ポート、ファシリティID、セキュリティレベル、ユーザー名、認証パスワード、暗号化パスワード、認証プロトコル、暗号化プロトコル
 	 * @param locale クライアントのロケール
-	 * @return ノード情報
+	 * @return ノード情報（更新情報）
 	 * @throws HinemosUnknown
 	 * @throws FacilityNotFound
 	 * @throws UnknownHostException
 	 * @throws InvalidRole
 	 * @throws InvalidUserPass
 	 */
-	public NodeInfo getNodePropertyBySNMP(String ipAddress, int port, String community, String version) throws HinemosUnknown, InvalidUserPass, InvalidRole {
-		m_log.debug("getNodePropertyBySNMP : ipAddress=" + ipAddress + ", port=" + port +
-				", community=" + community + ", version=" + version);
+	public NodeInfoDeviceSearch getNodePropertyBySNMP(String ipAddress,
+			int port, String community, String version, String facilityID,
+			String securityLevel, String user, String authPass,
+			String privPass, String authProtocol, String privProtocol)
+			throws HinemosUnknown, InvalidUserPass, InvalidRole,
+			SnmpResponseError {
+		m_log.debug("getNodePropertyBySNMP : ipAddress=" + ipAddress
+				+ ", port=" + port + ", community=" + community + ", version="
+				+ version + ", securityLevel=" + securityLevel + ", user=" + user + ", authPassword=" + authPass
+				+ ", privPassword=" + privPass + ", authProtocol=" + authProtocol + ", privProtocol=" + privProtocol);
 		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.REPOSITORY, SystemPrivilegeMode.READ));
+		systemPrivilegeList.add(new SystemPrivilegeInfo(
+				FunctionConstant.REPOSITORY, SystemPrivilegeMode.READ));
 		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
 
 		// 認証済み操作ログ
@@ -397,11 +408,25 @@ public class RepositoryEndpoint {
 		msg.append(community);
 		msg.append(", Version=");
 		msg.append(version);
+		msg.append(", securityLevel=");
+		msg.append(securityLevel);
+		msg.append(", user=");
+		msg.append(user);
+		msg.append(", authPassword=");
+		msg.append(authPass);
+		msg.append(", privPassword=");
+		msg.append(privPass);
+		msg.append(", authProtocol=");
+		msg.append(authProtocol);
+		msg.append(", privProtocol=");
+		msg.append(privProtocol);
 		m_opelog.debug(HinemosModuleConstant.LOG_PREFIX_REPOSITORY + " Get, Method=getNodePropertyBySNMP, User="
 				+ HttpAuthenticator.getUserAccountString(wsctx)
 				+ msg.toString());
 
-		return new RepositoryControllerBean().getNodePropertyBySNMP(ipAddress, port, community, version);
+		return new RepositoryControllerBean().getNodePropertyBySNMP(ipAddress,
+				port, community, version, facilityID, securityLevel, user,
+				authPass, privPass, authProtocol, privProtocol);
 	}
 
 
@@ -412,9 +437,9 @@ public class RepositoryEndpoint {
 	 * ノードを新規に追加します。<BR>
 	 * またこのメソッドで組み込みスコープである"登録済みノード"スコープにも
 	 * 割り当てが行われます。
-	 * 
+	 *
 	 * RepositoryAdd権限が必要
-	 * 
+	 *
 	 * @param nodeinfo 追加するノード情報のプロパティ
 	 * @throws FacilityDuplicate
 	 * @throws HinemosUnknown
@@ -435,7 +460,9 @@ public class RepositoryEndpoint {
 		}
 
 		try {
+			long startTime = System.currentTimeMillis();
 			new RepositoryControllerBean().addNode(nodeInfo);
+			m_log.info(String.format("addNode: %dms", System.currentTimeMillis() - startTime));
 		} catch (Exception e) {
 			m_opelog.warn(HinemosModuleConstant.LOG_PREFIX_REPOSITORY + " Add Node Failed, Method=addNode, User="
 					+ HttpAuthenticator.getUserAccountString(wsctx)
@@ -451,12 +478,12 @@ public class RepositoryEndpoint {
 	/**
 	 * ノードを変更します。<BR>
 	 * 引数のpropertyには変更する属性のみを設定してください。<BR>
-	 * 
+	 *
 	 * RepositoryWrite権限が必要
-	 * 
+	 *
 	 * @version 2.0.0
 	 * @since 1.0.0
-	 * 
+	 *
 	 * @param property　変更するノード情報のプロパティ
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
@@ -466,7 +493,7 @@ public class RepositoryEndpoint {
 	public void modifyNode(NodeInfo property) throws InvalidUserPass, InvalidRole, HinemosUnknown, InvalidSetting {
 		m_log.debug("modifyNode : nodeInfo=" + property);
 		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.REPOSITORY, SystemPrivilegeMode.WRITE));
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.REPOSITORY, SystemPrivilegeMode.MODIFY));
 		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
 
 		// 認証済み操作ログ
@@ -492,33 +519,34 @@ public class RepositoryEndpoint {
 
 	/**
 	 * ノード情報を削除します。<BR>
-	 * 
+	 *
 	 * faciityIDで指定されたノードをリポジトリから削除します。
-	 * 
+	 *
 	 * RepositoryWrite権限が必要
-	 * 
+	 *
 	 * @version 1.0.0
 	 * @since 1.0.0
-	 * 
-	 * @param facilityId ファシリティID
+	 *
+	 * @param facilityIds ファシリティIDの配列
 	 * @throws UsedFacility
 	 * @throws HinemosUnknown
 	 * @throws InvalidRole
 	 * @throws InvalidUserPass
 	 */
-	public void deleteNode(String facilityId) throws UsedFacility, InvalidUserPass, InvalidRole, HinemosUnknown {
-		m_log.debug("deleteNode : facilityId=" + facilityId);
+	public void deleteNode(String[] facilityIds) throws UsedFacility, InvalidUserPass, InvalidRole, HinemosUnknown {
+		m_log.debug("deleteNode : facilityId=" + facilityIds);
 		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.REPOSITORY, SystemPrivilegeMode.WRITE));
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.REPOSITORY, SystemPrivilegeMode.MODIFY));
 		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
-
-		// 認証済み操作ログ
 		StringBuffer msg = new StringBuffer();
-		msg.append(", FacilityID=");
-		msg.append(facilityId);
 
 		try {
-			new RepositoryControllerBean().deleteNode(facilityId);
+			for (String facilityId : facilityIds) {
+				// 認証済み操作ログ
+				msg.append(", FacilityID=");
+				msg.append(facilityId);
+			}
+			new RepositoryControllerBean().deleteNode(facilityIds);
 		} catch (Exception e) {
 			m_opelog.warn(HinemosModuleConstant.LOG_PREFIX_REPOSITORY + " Delete Node Failed, Method=deleteNode, User="
 					+ HttpAuthenticator.getUserAccountString(wsctx)
@@ -539,12 +567,12 @@ public class RepositoryEndpoint {
 	 * このメソッドは引数としてそのスコープのファシリティIDを要求します。<BR>
 	 * 戻り値はArrayListで中のScopeInfoには子の
 	 * "ファシリティID"、"ファシリティ名"、"説明"のみ格納されています。<BR>
-	 * 
+	 *
 	 * RepositoryWrite権限が必要
-	 * 
+	 *
 	 * @version 1.0.0
 	 * @since 1.0.0
-	 * 
+	 *
 	 * @param parentFacilityId　スコープのファシリティID
 	 * @return ScopeInfoの配列
 	 * @throws HinemosUnknown
@@ -569,9 +597,9 @@ public class RepositoryEndpoint {
 
 	/**
 	 * スコープ用プロパティ情報を取得します。<BR>
-	 * 
+	 *
 	 * RepositoryRead権限が必要
-	 * 
+	 *
 	 * @param facilityId ファシリティID
 	 * @param locale クライアントのロケール
 	 * @return スコープのプロパティ情報（ファシリティID、ファシリティ名、説明）
@@ -599,13 +627,13 @@ public class RepositoryEndpoint {
 
 	/**
 	 * スコープを新規に追加します。<BR>
-	 * 
+	 *
 	 * parentFacilityIdで指定されるスコープの下にpropertyで指定されるスコープを
 	 * 追加します。<BR>
 	 * 引数propertyには、"ファシリティID"、"ファシリティ名"、"説明"（任意）を含める必要があります。
-	 * 
+	 *
 	 * RepositoryAdd権限が必要
-	 * 
+	 *
 	 * @param parentFacilityId
 	 * @param property
 	 * @throws FacilityDuplicate
@@ -644,13 +672,13 @@ public class RepositoryEndpoint {
 
 	/**
 	 * スコープの情報を変更します。<BR>
-	 * 
+	 *
 	 * 引数propertyで指定した内容でスコープ情報を更新します。<BR>
 	 * 引数propertyには、"ファシリティID"、"ファシリティ名"、"説明"（任意）を含める必要があります。
 	 * propertyに含まれるファシリティIDに対応するスコープの情報が変更されます。<BR>
-	 * 
+	 *
 	 * RepositoryWrite権限が必要
-	 * 
+	 *
 	 * @param property
 	 * @throws HinemosUnknown
 	 * @throws InvalidRole
@@ -659,7 +687,7 @@ public class RepositoryEndpoint {
 	public void modifyScope(ScopeInfo property) throws InvalidUserPass, InvalidRole, HinemosUnknown, InvalidSetting {
 		m_log.debug("modifyScope : scopeInfo=" + property);
 		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.REPOSITORY, SystemPrivilegeMode.WRITE));
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.REPOSITORY, SystemPrivilegeMode.MODIFY));
 		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
 
 		// 認証済み操作ログ
@@ -683,30 +711,30 @@ public class RepositoryEndpoint {
 
 	/**
 	 * スコープ情報を削除します。<BR>
-	 * 
+	 *
 	 * faciityIDで指定されたスコープをリポジトリから削除します。
-	 * 
+	 *
 	 * RepositoryWrite権限が必要
-	 * 
-	 * @param facilityId ファシリティID
+	 *
+	 * @param facilityIds ファシリティIDの配列
 	 * @throws UsedFacility
 	 * @throws HinemosUnknown
 	 * @throws InvalidRole
 	 * @throws InvalidUserPass
 	 */
-	public void deleteScope(String facilityId) throws UsedFacility, InvalidUserPass, InvalidRole, HinemosUnknown {
-		m_log.debug("deleteScope : facilityId=" + facilityId);
+	public void deleteScope(String[] facilityIds) throws UsedFacility, InvalidUserPass, InvalidRole, HinemosUnknown {
+		m_log.debug("deleteScope : facilityId=" + facilityIds);
 		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.REPOSITORY, SystemPrivilegeMode.WRITE));
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.REPOSITORY, SystemPrivilegeMode.MODIFY));
 		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
 
 		// 認証済み操作ログ
 		StringBuffer msg = new StringBuffer();
 		msg.append(", FacilityID=");
-		msg.append(facilityId);
+		msg.append(facilityIds);
 
 		try {
-			new RepositoryControllerBean().deleteScope(facilityId);
+			new RepositoryControllerBean().deleteScope(facilityIds);
 		} catch (Exception e) {
 			m_opelog.warn(HinemosModuleConstant.LOG_PREFIX_REPOSITORY + " Delete Scope Failed, Method=deleteScope, User="
 					+ HttpAuthenticator.getUserAccountString(wsctx)
@@ -725,15 +753,15 @@ public class RepositoryEndpoint {
 	 **********************/
 	/**
 	 * 割当ノード一覧を取得します。<BR>
-	 * 
+	 *
 	 * あるファシリティIDの配下または直下のノード一覧を取得します。<BR>
 	 * 引数がノードの場合は、そのノードのファシリティIDを返す。<BR>
 	 * このメソッドでは、引数levelで直下または配下を制御します。<BR>
 	 * 戻り値はNodeInfoのArrayListで、NodeInfoには
 	 * ノードの"ファシリティID"、"ファシリティ名"、"説明"のみ格納されています。<BR>
-	 * 
+	 *
 	 * RepositoryRead権限が必要
-	 * 
+	 *
 	 * @param parentFacilityId
 	 * @param level　取得レベル 0:ALL(配下) 1:ONE_LEVEL（直下）
 	 * @return NodeInfoの配列
@@ -769,12 +797,12 @@ public class RepositoryEndpoint {
 	 * 戻り値はArrayListのArrayListで中のArrayListには"スコープ"が最上位からの
 	 * スコープパス表記で（Stringで）格納されています。
 	 * 外のArrayListには、そのレコードが順に格納されています。
-	 * 
+	 *
 	 * RepositoryRead権限が必要
-	 * 
+	 *
 	 * @version 1.0.0
 	 * @since 1.0.0
-	 * 
+	 *
 	 * @param facilityId ノードのファシリティID
 	 * @return Stringの配列
 	 * @throws InvalidUserPass
@@ -800,13 +828,13 @@ public class RepositoryEndpoint {
 
 	/**
 	 * ファシリティIDリストを取得します。<BR>
-	 * 
+	 *
 	 * 引数に指定した親ファシリティIDの配下または直下のファシリティ（スコープ、ノード）の
 	 * リストを取得します。<BR>
 	 * 戻り値は ファシリティID（String）のArrayList
-	 * 
+	 *
 	 * RepositoryRead権限が必要
-	 * 
+	 *
 	 * @param parentFacilityId ファシリティID
 	 * @param level　取得レベル 0:ALL(配下) 1:ONE_LEVEL（直下）
 	 * @return ファシリティIDの配列
@@ -836,13 +864,13 @@ public class RepositoryEndpoint {
 
 	/**
 	 * ノードのファシリティIDリストを取得します。<BR>
-	 * 
+	 *
 	 * 引数に指定した親ファシリティIDの配下または直下のファシリティ（ノード）の
 	 * リストを取得します。<BR>
 	 * 戻り値は ファシリティID（String）のArrayList
-	 * 
+	 *
 	 * RepositoryRead権限が必要
-	 * 
+	 *
 	 * @param parentFacilityId ファシリティID
 	 * @param ownerRoleId オーナーロールID
 	 * @param level  取得レベル 0:ALL(配下) 1:ONE_LEVEL（直下）
@@ -872,12 +900,12 @@ public class RepositoryEndpoint {
 
 	/**
 	 * スコープへのノードの割り当てを行います。<BR>
-	 * 
+	 *
 	 * parentFacilityIdで指定されるスコープにfacilityIdsで指定されるノード群を
 	 * 割り当てます。
-	 * 
+	 *
 	 * RepositoryWrite権限が必要
-	 * 
+	 *
 	 * @param parentFacilityId　ノードを割り当てるスコープ
 	 * @param facilityIds 割り当てさせるノード(群)
 	 * @throws InvalidUserPass
@@ -888,7 +916,7 @@ public class RepositoryEndpoint {
 	public void assignNodeScope(String parentFacilityId, String[] facilityIds) throws InvalidUserPass, InvalidRole, HinemosUnknown,InvalidSetting {
 		m_log.debug("assignNodeScope : parentFacilityId=" + parentFacilityId + ", facilityIds=" + facilityIds);
 		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.REPOSITORY, SystemPrivilegeMode.WRITE));
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.REPOSITORY, SystemPrivilegeMode.MODIFY));
 		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
 
 		// 認証済み操作ログ
@@ -917,9 +945,9 @@ public class RepositoryEndpoint {
 	 * ノードをスコープから削除します。（割り当てを解除します。）<BR>
 	 * parentFacilityIdで指定されるスコープからfacilityIdsで指定されるノード群を
 	 * 削除（割り当て解除）します。
-	 * 
+	 *
 	 * RepositoryWrite権限が必要
-	 * 
+	 *
 	 * @param parentFacilityId ノードを取り除くスコープ
 	 * @param facilityIds 取り除かれるノード（群）
 	 * @throws InvalidUserPass
@@ -930,7 +958,7 @@ public class RepositoryEndpoint {
 	public void releaseNodeScope(String parentFacilityId, String[] facilityIds) throws InvalidUserPass, InvalidRole, HinemosUnknown,InvalidSetting {
 		m_log.debug("releaseNodeScope : parentFacilityId=" + parentFacilityId + ", facilityIds=" + facilityIds);
 		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.REPOSITORY, SystemPrivilegeMode.WRITE));
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.REPOSITORY, SystemPrivilegeMode.MODIFY));
 		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
 
 		// 認証済み操作ログ
@@ -961,11 +989,11 @@ public class RepositoryEndpoint {
 	 **********************/
 	/**
 	 * ファシリティがノードかどうかをチェックします。<BR>
-	 * 
+	 *
 	 * ファシリティIDに対応するものがノードかチェックし、結果をbooleanで返します。
-	 * 
+	 *
 	 * RepositoryRead権限が必要
-	 * 
+	 *
 	 * @param facilityId　ファシリティID
 	 * @return true：ノード　false:ノードではない（スコープ）
 	 * @throws FacilityNotFound
@@ -992,9 +1020,9 @@ public class RepositoryEndpoint {
 
 	/**
 	 * ノード作成変更時に、利用可能プラットフォームを表示するためのメソッド。
-	 * 
+	 *
 	 * RepositoryRead権限が必要
-	 * 
+	 *
 	 * @return ArrayList
 	 * @throws HinemosUnknown
 	 * @throws InvalidUserPass
@@ -1013,57 +1041,11 @@ public class RepositoryEndpoint {
 		return new RepositoryControllerBean().getPlatformList();
 	}
 
-	/**
-	 * ノード作成変更時に、仮想化種別hostのファシリティIDを表示するためのメソッド。
-	 * 
-	 * RepositoryRead権限が必要
-	 * 
-	 * @return ArrayList
-	 * @throws HinemosUnknown
-	 * @throws InvalidUserPass
-	 * @throws InvalidRole
-	 */
-	public ArrayList<RepositoryTableInfo> getHostList() throws HinemosUnknown, InvalidUserPass, InvalidRole {
-		m_log.debug("getHostList : ");
-		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.REPOSITORY, SystemPrivilegeMode.READ));
-		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
-
-		// 認証済み操作ログ
-		m_opelog.debug(HinemosModuleConstant.LOG_PREFIX_REPOSITORY + " Get, Method=getHostList, User="
-				+ HttpAuthenticator.getUserAccountString(wsctx));
-
-		return new RepositoryControllerBean().getHostList();
-	}
-
-	/**
-	 * OpenFlowスイッチであるノードを取得する。
-	 * 
-	 * RepositoryRead権限が必要
-	 * 
-	 * @return List
-	 * @throws HinemosUnknown
-	 * @throws InvalidUserPass
-	 * @throws InvalidRole
-	 */
-	public List<NodeInfo> getOpenFlowSwitchList() throws HinemosUnknown, InvalidUserPass, InvalidRole {
-		m_log.debug("getOpenFlowSwitchList : ");
-		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.REPOSITORY, SystemPrivilegeMode.READ));
-		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
-
-		// 認証済み操作ログ
-		m_opelog.debug(HinemosModuleConstant.LOG_PREFIX_REPOSITORY + " Get, Method=getOpenFlowSwitchList, User="
-				+ HttpAuthenticator.getUserAccountString(wsctx));
-
-		return new RepositoryControllerBean().getOpenFlowSwitchList();
-	}
-
 	/**
 	 * ノード作成変更時に、利用可能な仮想化ソリューションを表示するためのメソッド。
-	 * 
+	 *
 	 * RepositoryRead権限が必要
-	 * 
+	 *
 	 * @version 3.2.0
 	 * @since 3.2.0
 	 * @return ArrayList
@@ -1086,9 +1068,9 @@ public class RepositoryEndpoint {
 
 	/**
 	 * ノードの「管理対象」フラグを変更します。
-	 * 
+	 *
 	 * RepositoryWrite権限が必要
-	 * 
+	 *
 	 * @return ArrayList
 	 * @throws HinemosUnknown
 	 * @throws InvalidRole
@@ -1099,7 +1081,7 @@ public class RepositoryEndpoint {
 	public void setValid(String facilityId, boolean validFlag) throws InvalidUserPass, InvalidRole, HinemosUnknown, FacilityNotFound, InvalidSetting {
 		m_log.debug("setValid : ");
 		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.REPOSITORY, SystemPrivilegeMode.WRITE));
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.REPOSITORY, SystemPrivilegeMode.MODIFY));
 		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
 
 		// 認証済み操作ログ
@@ -1126,9 +1108,9 @@ public class RepositoryEndpoint {
 
 	/**
 	 * ノード作成変更時に、利用可能な仮想化プロトコルを表示するためのメソッド。
-	 * 
+	 *
 	 * RepositoryRead権限が必要
-	 * 
+	 *
 	 * @return ArrayList
 	 * @throws HinemosUnknown
 	 * @throws InvalidRole
@@ -1148,9 +1130,9 @@ public class RepositoryEndpoint {
 	}
 	/**
 	 * リポジトリの最終更新時刻を取得
-	 * 
+	 *
 	 * RepositoryRead権限が必要
-	 * 
+	 *
 	 * @return
 	 * @throws InvalidRole
 	 * @throws InvalidUserPass
@@ -1174,9 +1156,9 @@ public class RepositoryEndpoint {
 
 	/**
 	 * エージェントの状態を返します。<BR>
-	 * 
+	 *
 	 * RepositoryRead権限が必要
-	 * 
+	 *
 	 * @throws HinemosUnknown
 	 * @throws InvalidRole
 	 * @throws InvalidUserPass
@@ -1196,9 +1178,9 @@ public class RepositoryEndpoint {
 
 	/**
 	 * エージェントを再起動、アップデートします。<BR>
-	 * 
+	 *
 	 * RepositoryExecute権限が必要
-	 * 
+	 *
 	 * @param facilityId　ファシリティID
 	 * @param agentCommand エージェントに実行するコマンド。
 	 * @throws HinemosUnknown
@@ -1237,7 +1219,7 @@ public class RepositoryEndpoint {
 
 	/**
 	 * 指定された文字列内に存在するノード変数を置換した文字列を返します。
-	 * 
+	 *
 	 * @param facilityId ファシリティID
 	 * @param replaceObject 置換対象
 	 * @return ret 置換後の文字列
@@ -1273,4 +1255,73 @@ public class RepositoryEndpoint {
 		return ret;
 	}
 
+	/**
+	 * SNMPを利用してノードの情報を検索します。<BR>
+	 *
+	 *
+	 * クライアントからノードサーチを行った際に呼び出されるメソッドです。<BR>
+	 * SNMPポーリングにより、検索結果をセットし、クライアントに返す。
+	 *
+	 * RepositoryRead権限が必要
+	 *
+	 * @param pollingData オーナーロールID、ポーリング対象のIPアドレス(開始)、ポーリング対象のIPアドレス(終了)、コミュニティ名、バージョン、ポート、ファシリティID、セキュリティレベル、ユーザー名、認証パスワード、暗号化パスワード、認証プロトコル、暗号化プロトコル
+	 * @return ノード情報（更新情報）
+	 * @throws HinemosUnknown
+	 * @throws FacilityNotFound
+	 * @throws UnknownHostException
+	 * @throws InvalidRole
+	 * @throws InvalidUserPass
+	 * @throws InvalidSetting
+	 * @throws FacilityDuplicate
+	 */
+	public List<NodeInfoDeviceSearch> searchNodesBySNMP(String ownerRoleId, String ipAddressFrom, String ipAddressTo,
+			int port, String community, String version, String facilityID,
+			String securityLevel, String user, String authPass,
+			String privPass, String authProtocol, String privProtocol)
+			throws HinemosUnknown, InvalidUserPass, InvalidRole, FacilityDuplicate, InvalidSetting {
+
+		m_log.debug("searchNodesBySNMP : ipAddressFrom=" + ipAddressFrom
+				+ ", ipAddressTo=" + ipAddressTo
+				+ ", port=" + port + ", community=" + community + ", version="
+				+ version + ", securityLevel=" + securityLevel + ", user=" + user + ", authPassword=" + authPass
+				+ ", privPassword=" + privPass + ", authProtocol=" + authProtocol + ", privProtocol=" + privProtocol);
+
+		//権限チェック
+		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
+		systemPrivilegeList.add(new SystemPrivilegeInfo(
+				FunctionConstant.REPOSITORY, SystemPrivilegeMode.ADD));
+		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
+
+		// 認証済み操作ログ
+		StringBuffer msg = new StringBuffer();
+		msg.append(", ipAddressFrom=");
+		msg.append(ipAddressFrom);
+		msg.append(", ipAddressTo=");
+		msg.append(ipAddressTo);
+		msg.append(", Port=");
+		msg.append(port);
+		msg.append(", Community=");
+		msg.append(community);
+		msg.append(", Version=");
+		msg.append(version);
+		msg.append(", securityLevel=");
+		msg.append(securityLevel);
+		msg.append(", user=");
+		msg.append(user);
+		// msg.append(", authPassword="); msg.append(authPass);
+		// msg.append(", privPassword="); msg.append(privPass);
+		msg.append(", authProtocol=");
+		msg.append(authProtocol);
+		msg.append(", privProtocol=");
+		msg.append(privProtocol);
+		m_opelog.info(HinemosModuleConstant.LOG_PREFIX_REPOSITORY + " Get, Method=searchNodesBySNMP, User="
+				+ HttpAuthenticator.getUserAccountString(wsctx)
+				+ msg.toString());
+
+		//SNMPによる検索・登録
+		NodeSearcher bean = new NodeSearcher();
+		return bean.searchNode(ownerRoleId, ipAddressFrom, ipAddressTo, port,
+				community, version, facilityID, securityLevel, user, authPass,
+				privPass, authProtocol, privProtocol);
+	}
 }
